//! Low-level DSA tests.

use crate::Result;
use crate::crypto::{mpi, hash::Digest};
use crate::packet::{prelude::*, signature::subpacket::*};
use crate::types::*;

#[test]
fn fips_186_3() -> Result<()> {
    if ! PublicKeyAlgorithm::DSA.is_supported() {
        eprintln!("Skipping because DSA is not supported.");
        return Ok(());
    }

    fn test(hash: HashAlgorithm,
            msg: &[u8],
            p: &[u8], q: &[u8], g: &[u8], y: &[u8],
            r: &[u8], s: &[u8])
            -> Result<()>
    {
        if ! hash.is_supported() {
            eprintln!("Skipping because {} is not supported.", hash);
            return Ok(());
        }

        if cfg!(feature = "crypto-cng") && q.len() == 28 {
            eprintln!("Skipping DSA key with N = 224 because \
                       CNG doesn't support this.");
            return Ok(());
        }

        let now = Timestamp::now();
        let key: Key<key::PublicParts, key::PrimaryRole> =
            Key4::new(now, PublicKeyAlgorithm::DSA,
                      mpi::PublicKey::DSA {
                          p: mpi::MPI::new(p),
                          q: mpi::MPI::new(q),
                          g: mpi::MPI::new(g),
                          y: mpi::MPI::new(y),
                      })?.into();
        let mut h = hash.context()?;
        h.update(msg);
        let mut d = h.into_digest()?;
        let mut sig: Signature =
            Signature4::new(SignatureType::Binary,
                            PublicKeyAlgorithm::DSA,
                            hash,
                            SubpacketArea::new(vec![
                                Subpacket::new(
                                    SubpacketValue::SignatureCreationTime(now),
                                    false)?,
                            ])?,
                            SubpacketArea::default(),
                            [d[0], d[1]],
                            mpi::Signature::DSA {
                                r: mpi::MPI::new(r),
                                s: mpi::MPI::new(s),
                            }).into();

        sig.verify_digest(&key, &d)?;

        // Sanity check: Change the digest and retry.
        d[0] ^= 1;
        sig.verify_digest(&key, &d).unwrap_err();

        Ok(())
    }

    // [mod = L=1024, N=160, SHA-1]
    let p = b"\xa8\xf9\xcd\x20\x1e\x5e\x35\xd8\x92\xf8\x5f\x80\xe4\xdb\x25\x99\xa5\x67\x6a\x3b\x1d\x4f\x19\x03\x30\xed\x32\x56\xb2\x6d\x0e\x80\xa0\xe4\x9a\x8f\xff\xaa\xad\x2a\x24\xf4\x72\xd2\x57\x32\x41\xd4\xd6\xd6\xc7\x48\x0c\x80\xb4\xc6\x7b\xb4\x47\x9c\x15\xad\xa7\xea\x84\x24\xd2\x50\x2f\xa0\x14\x72\xe7\x60\x24\x17\x13\xda\xb0\x25\xae\x1b\x02\xe1\x70\x3a\x14\x35\xf6\x2d\xdf\x4e\xe4\xc1\xb6\x64\x06\x6e\xb2\x2f\x2e\x3b\xf2\x8b\xb7\x0a\x2a\x76\xe4\xfd\x5e\xbe\x2d\x12\x29\x68\x1b\x5b\x06\x43\x9a\xc9\xc7\xe9\xd8\xbd\xe2\x83";
    let q = b"\xf8\x5f\x0f\x83\xac\x4d\xf7\xea\x0c\xdf\x8f\x46\x9b\xfe\xea\xea\x14\x15\x64\x95";
    let g = b"\x2b\x31\x52\xff\x6c\x62\xf1\x46\x22\xb8\xf4\x8e\x59\xf8\xaf\x46\x88\x3b\x38\xe7\x9b\x8c\x74\xde\xea\xe9\xdf\x13\x1f\x8b\x85\x6e\x3a\xd6\xc8\x45\x5d\xab\x87\xcc\x0d\xa8\xac\x97\x34\x17\xce\x4f\x78\x78\x55\x7d\x6c\xdf\x40\xb3\x5b\x4a\x0c\xa3\xeb\x31\x0c\x6a\x95\xd6\x8c\xe2\x84\xad\x4e\x25\xea\x28\x59\x16\x11\xee\x08\xb8\x44\x4b\xd6\x4b\x25\xf3\xf7\xc5\x72\x41\x0d\xdf\xb3\x9c\xc7\x28\xb9\xc9\x36\xf8\x5f\x41\x91\x29\x86\x99\x29\xcd\xb9\x09\xa6\xa3\xa9\x9b\xbe\x08\x92\x16\x36\x81\x71\xbd\x0b\xa8\x1d\xe4\xfe\x33";
    test(
        HashAlgorithm::SHA1,
        b"\x3b\x46\x73\x6d\x55\x9b\xd4\xe0\xc2\xc1\xb2\x55\x3a\x33\xad\x3c\x6c\xf2\x3c\xac\x99\x8d\x3d\x0c\x0e\x8f\xa4\xb1\x9b\xca\x06\xf2\xf3\x86\xdb\x2d\xcf\xf9\xdc\xa4\xf4\x0a\xd8\xf5\x61\xff\xc3\x08\xb4\x6c\x5f\x31\xa7\x73\x5b\x5f\xa7\xe0\xf9\xe6\xcb\x51\x2e\x63\xd7\xee\xa0\x55\x38\xd6\x6a\x75\xcd\x0d\x42\x34\xb5\xcc\xf6\xc1\x71\x5c\xca\xaf\x9c\xdc\x0a\x22\x28\x13\x5f\x71\x6e\xe9\xbd\xee\x7f\xc1\x3e\xc2\x7a\x03\xa6\xd1\x1c\x5c\x5b\x36\x85\xf5\x19\x00\xb1\x33\x71\x53\xbc\x6c\x4e\x8f\x52\x92\x0c\x33\xfa\x37\xf4\xe7",
        p,
        q,
        g,
        b"\x31\x3f\xd9\xeb\xca\x91\x57\x4e\x1c\x2e\xeb\xe1\x51\x7c\x57\xe0\xc2\x1b\x02\x09\x87\x21\x40\xc5\x32\x87\x61\xbb\xb2\x45\x0b\x33\xf1\xb1\x8b\x40\x9c\xe9\xab\x7c\x4c\xd8\xfd\xa3\x39\x1e\x8e\x34\x86\x83\x57\xc1\x99\xe1\x6a\x6b\x2e\xba\x06\xd6\x74\x9d\xef\x79\x1d\x79\xe9\x5d\x3a\x4d\x09\xb2\x4c\x39\x2a\xd8\x9d\xbf\x10\x09\x95\xae\x19\xc0\x10\x62\x05\x6b\xb1\x4b\xce\x00\x5e\x87\x31\xef\xde\x17\x5f\x95\xb9\x75\x08\x9b\xdc\xda\xea\x56\x2b\x32\x78\x6d\x96\xf5\xa3\x1a\xed\xf7\x53\x64\x00\x8a\xd4\xff\xfe\xbb\x97\x0b",
        b"\x50\xed\x0e\x81\x0e\x3f\x1c\x7c\xb6\xac\x62\x33\x20\x58\x44\x8b\xd8\xb2\x84\xc0",
        b"\xc6\xad\xed\x17\x21\x6b\x46\xb7\xe4\xb6\xf2\xa9\x7c\x1a\xd7\xcc\x3d\xa8\x3f\xde",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xd2\xbc\xb5\x3b\x04\x4b\x3e\x2e\x4b\x61\xba\x2f\x91\xc0\x99\x5f\xb8\x3a\x6a\x97\x52\x5e\x66\x44\x1a\x3b\x48\x9d\x95\x94\x23\x8b\xc7\x40\xbd\xee\xa0\xf7\x18\xa7\x69\xc9\x77\xe2\xde\x00\x38\x77\xb5\xd7\xdc\x25\xb1\x82\xae\x53\x3d\xb3\x3e\x78\xf2\xc3\xff\x06\x45\xf2\x13\x7a\xbc\x13\x7d\x4e\x7d\x93\xcc\xf2\x4f\x60\xb1\x8a\x82\x0b\xc0\x7c\x7b\x4b\x5f\xe0\x8b\x4f\x9e\x7d\x21\xb2\x56\xc1\x8f\x3b\x9d\x49\xac\xc4\xf9\x3e\x2c\xe6\xf3\x75\x4c\x78\x07\x75\x7d\x2e\x11\x76\x04\x26\x12\xcb\x32\xfc\x3f\x4f\x70\x70\x0e\x25",
        p,
        q,
        g,
        b"\x29\xbd\xd7\x59\xaa\xa6\x2d\x4b\xf1\x6b\x48\x61\xc8\x1c\xf4\x2e\xac\x2e\x16\x37\xb9\xec\xba\x51\x2b\xdb\xc1\x3a\xc1\x2a\x80\xae\x8d\xe2\x52\x6b\x89\x9a\xe5\xe4\xa2\x31\xae\xf8\x84\x19\x7c\x94\x4c\x73\x26\x93\xa6\x34\xd7\x65\x9a\xbc\x69\x75\xa7\x73\xf8\xd3\xcd\x5a\x36\x1f\xe2\x49\x23\x86\xa3\xc0\x9a\xae\xf1\x2e\x4a\x7e\x73\xad\x7d\xfc\x36\x37\xf7\xb0\x93\xf2\xc4\x0d\x62\x23\xa1\x95\xc1\x36\xad\xf2\xea\x3f\xbf\x87\x04\xa6\x75\xaa\x78\x17\xaa\x7e\xc7\xf9\xad\xfb\x28\x54\xd4\xe0\x5c\x3c\xe7\xf7\x65\x60\x31\x3b",
        b"\xa2\x6c\x00\xb5\x75\x0a\x2d\x27\xfe\x74\x35\xb9\x34\x76\xb3\x54\x38\xb4\xd8\xab",
        b"\x61\xc9\xbf\xcb\x29\x38\x75\x5a\xfa\x7d\xad\x1d\x1e\x07\xc6\x28\x86\x17\xbf\x70",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xd5\x43\x1e\x6b\x16\xfd\xae\x31\x48\x17\x42\xbd\x39\x47\x58\xbe\xb8\xe2\x4f\x31\x94\x7e\x19\xb7\xea\x7b\x45\x85\x21\x88\x22\x70\xc1\xf4\x31\x92\xaa\x05\x0f\x44\x85\x14\x5a\xf8\xf3\xf9\xc5\x14\x2d\x68\xb8\x50\x18\xd2\xec\x9c\xb7\xa3\x7b\xa1\x2e\xd2\x3e\x73\xb9\x5f\xd6\x80\xfb\xa3\xc6\x12\x65\xe9\xf5\xa0\xa0\x27\xd7\x0f\xad\x0c\x8a\xa0\x8a\x3c\xbf\xbe\x99\x01\x8d\x00\x45\x38\x61\x73\xe5\xfa\xe2\x25\xfa\xeb\xe0\xce\xf5\xdd\x45\x91\x0f\x40\x0a\x86\xc2\xbe\x4e\x15\x25\x2a\x16\xde\x41\x20\xa2\x67\xbe\x2b\x59\x4d",
        p,
        q,
        g,
        b"\x23\xb4\xf4\x04\xaa\x3c\x57\x5e\x55\x0b\xb3\x20\xfd\xb1\xa0\x85\xcd\x39\x6a\x10\xe5\xeb\xc6\x77\x1d\xa6\x2f\x03\x7c\xab\x19\xea\xcd\x67\xd8\x22\x2b\x63\x44\x03\x8c\x4f\x7a\xf4\x5f\x5e\x62\xb5\x54\x80\xcb\xe2\x11\x11\x54\xca\x96\x97\xca\x76\xd8\x7b\x56\x94\x41\x38\x08\x4e\x74\xc6\xf9\x0a\x05\xcf\x43\x66\x0d\xff\x8b\x8b\x3f\xab\xfc\xab\x3f\x0e\x44\x16\x77\x5f\xdf\x40\x05\x58\x64\xbe\x10\x2b\x45\x87\x39\x2e\x77\x75\x2e\xd2\xae\xb1\x82\xee\x4f\x70\xbe\x4a\x29\x1d\xbe\x77\xb8\x4a\x44\xee\x34\x00\x79\x57\xb1\xe0",
        b"\x3f\x0a\x4a\xd3\x2f\x08\x16\x82\x1b\x8a\xff\xb5\x18\xe9\xb5\x99\xf3\x5d\x57\xc2",
        b"\xea\x06\x63\x8f\x2b\x2f\xc9\xd1\xdf\xe9\x9c\x2a\x49\x28\x06\xb4\x97\xe2\xb0\xea",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x85\x66\x2b\x69\x75\x50\xe4\x91\x5c\x29\xe3\x38\xb6\x24\xb9\x12\x84\x5d\x6d\x1a\x92\x0d\x9e\x4c\x16\x04\xdd\x47\xd6\x92\xbc\x7c\x0f\xfb\x95\xae\x61\x4e\x85\x2b\xeb\xaf\x15\x73\x75\x8a\xd0\x1c\x71\x3c\xac\x0b\x47\x6e\x2f\x12\x17\x45\xa3\xcf\xee\xff\xb2\x44\x1f\xf6\xab\xfb\x9b\xbe\xb9\x8a\xa6\x34\xca\x6f\xf5\x41\x94\x7d\xcc\x99\x27\x65\x9d\x44\xf9\x5c\x5f\xf9\x17\x0f\xdc\x3c\x86\x47\x3c\xb6\x01\xba\x31\xb4\x87\xfe\x59\x36\xba\xc5\xd9\xc6\x32\xcb\xcc\x3d\xb0\x62\x46\xba\x01\xc5\x5a\x03\x8d\x79\x7f\xe3\xf6\xc3",
        p,
        q,
        g,
        b"\x6b\xc3\x6c\xb3\xfa\x61\xce\xcc\x15\x7b\xe0\x86\x39\xa7\xca\x9e\x3d\xe0\x73\xb8\xa0\xff\x23\x57\x4c\xe5\xab\x0a\x86\x7d\xfd\x60\x66\x9a\x56\xe6\x0d\x1c\x98\x9b\x3a\xf8\xc8\xa4\x3f\x56\x95\xd5\x03\xe3\x09\x89\x63\x99\x0e\x12\xb6\x35\x66\x78\x41\x71\x05\x8e\xac\xe8\x5c\x72\x8c\xd4\xc0\x82\x24\xc7\xa6\xef\xea\x75\xdc\xa2\x0d\xf4\x61\x01\x3c\x75\xf4\x0a\xcb\xc2\x37\x99\xeb\xee\x7f\x33\x61\x33\x6d\xad\xc4\xa5\x6f\x30\x57\x08\x66\x7b\xfe\x60\x2b\x8e\xa7\x5a\x49\x1a\x5c\xf0\xc0\x6e\xbd\x6f\xdc\x71\x61\xe1\x04\x97",
        b"\x3b\xc2\x9d\xee\x96\x95\x70\x50\xba\x43\x8d\x1b\x3e\x17\xb0\x2c\x17\x25\xd2\x29",
        b"\x0a\xf8\x79\xcf\x84\x6c\x43\x4e\x08\xfb\x6c\x63\x78\x2f\x4d\x03\xe0\xd8\x88\x65",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x87\xb6\xe7\x5b\x9f\x8e\x99\xc4\xdd\x62\xad\xb6\x93\xdd\x58\x90\xed\xff\x1b\xd0\x02\x8f\x4e\xf8\x49\xdf\x0f\x1d\x2c\xe6\xb1\x81\xfc\x3a\x55\xae\xa6\xd0\xa1\xf0\xae\xca\xb8\xed\x9e\x24\x8a\x00\xe9\x6b\xe7\x94\xa7\xcf\xba\x12\x46\xef\xb7\x10\xef\x4b\x37\x47\x1c\xef\x0a\x1b\xcf\x55\xce\xbc\x8d\x5a\xd0\x71\x61\x2b\xd2\x37\xef\xed\xd5\x10\x23\x62\xdb\x07\xa1\xe2\xc7\xa6\xf1\x5e\x09\xfe\x64\xba\x42\xb6\x0a\x26\x28\xd8\x69\xae\x05\xef\x61\x1f\xe3\x8d\x9c\xe1\x5e\xee\xc9\xbb\x3d\xec\xc8\xdc\x17\x80\x9f\x3b\x6e\x95",
        p,
        q,
        g,
        b"\x01\x4a\xc7\x46\xd3\x60\x5e\xfc\xb8\xa2\xc7\xda\xe1\xf5\x46\x82\xa2\x62\xe2\x76\x62\xb2\x52\xc0\x94\x78\xce\x87\xd0\xaa\xa5\x22\xd7\xc2\x00\x04\x34\x06\x01\x6c\x0c\x42\x89\x6d\x21\x75\x0b\x15\xdb\xd5\x7f\x97\x07\xec\x37\xdc\xea\x56\x51\x78\x1b\x67\xad\x8d\x01\xf5\x09\x9f\xe7\x58\x4b\x35\x3b\x64\x1b\xb1\x59\xcc\x71\x7d\x8c\xeb\x18\xb6\x67\x05\xe6\x56\xf3\x36\xf1\x21\x4b\x34\xf0\x35\x7e\x57\x7a\xb8\x36\x41\x96\x9e\x31\x1b\xf4\x0b\xdc\xb3\xff\xd5\xe0\xbb\x59\x41\x9f\x22\x95\x08\xd2\xf4\x32\xcc\x28\x59\xff\x75",
        b"\x63\x7e\x07\xa5\x77\x0f\x3d\xc6\x5e\x45\x06\xc6\x8c\x77\x0e\x5e\xf6\xb8\xce\xd3",
        b"\x7d\xfc\x6f\x83\xe2\x4f\x09\x74\x5e\x01\xd3\xf7\xae\x0e\xd1\x47\x4e\x81\x1d\x47",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x22\x59\xee\xad\x2d\x6b\xbc\x76\xd4\x92\x13\xea\x0d\xc8\xb7\x35\x0a\x97\x69\x9f\x22\x34\x10\x44\xc3\x94\x07\x82\x36\x4a\xc9\xea\x68\x31\x79\xa4\x38\xa5\xea\x45\x99\x8d\xf9\x7c\x29\x72\xda\xe0\x38\x51\xf5\xbe\x23\xfa\x9f\x04\x18\x2e\x79\xdd\xb2\xb5\x6d\xc8\x65\x23\x93\xec\xb2\x7f\x3f\x3b\x7c\x8a\x8d\x76\x1a\x86\xb3\xb8\xf4\xd4\x1a\x07\xb4\xbe\x7d\x02\xfd\xde\xfc\x42\xb9\x28\x12\x4a\x5a\x45\xb9\xf4\x60\x90\x42\x20\x9b\x3a\x7f\x58\x5b\xd5\x14\xcc\x39\xc0\x0e\xff\xcc\x42\xc7\xfe\x70\xfa\x83\xed\xf8\xa3\x2b\xf4",
        p,
        q,
        g,
        b"\x0f\xe7\x40\x45\xd7\xb0\xd4\x72\x41\x12\x02\x83\x1d\x49\x32\x39\x6f\x24\x2a\x97\x65\xe9\x2b\xe3\x87\xfd\x81\xbb\xe3\x8d\x84\x50\x54\x52\x8b\x34\x8c\x03\x98\x41\x79\xb8\xe5\x05\x67\x4c\xb7\x9d\x88\xcc\x0d\x8d\x3e\x8d\x73\x92\xf9\xaa\x77\x3b\x29\xc2\x9e\x54\xa9\xe3\x26\x40\x60\x75\xd7\x55\xc2\x91\xfc\xed\xbc\xc5\x77\x93\x4c\x82\x4a\xf9\x88\x25\x0f\x64\xed\x56\x85\xfc\xe7\x26\xcf\xf6\x5e\x92\xd7\x08\xae\x11\xcb\xfa\xa9\x58\xab\x8d\x8b\x15\x34\x0a\x29\xa1\x37\xb5\xb4\x35\x7f\x7e\xd1\xc7\xa5\x19\x0c\xbf\x98\xa4",
        b"\x83\x36\x6b\xa3\xfe\xd9\x3d\xfb\x38\xd5\x41\x20\x3e\xcb\xf8\x1c\x36\x39\x98\xe2",
        b"\x1f\xe2\x99\xc3\x6a\x13\x32\xf2\x3b\xf2\xe1\x0a\x6c\x6a\x4e\x0d\x3c\xdd\x2b\xf4",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x21\x9e\x8d\xf5\xbf\x88\x15\x90\x43\x0e\xce\x60\x82\x50\xf7\x67\x0d\xc5\x65\x37\x24\x93\x02\x42\x9e\x28\xec\xfe\xb9\xce\xaa\xa5\x49\x10\xa6\x94\x90\xf7\x65\xf3\xdf\x82\xe8\xb0\x1c\xd7\xd7\x6e\x56\x1d\x0f\x6c\xe2\x26\xef\x3c\xf7\x52\xca\xda\x6f\xeb\xdc\x5b\xf0\x0d\x67\x94\x7f\x92\xd4\x20\x51\x6b\x9e\x37\xc9\x6c\x8f\x1f\x2d\xa0\xb0\x75\x09\x7c\x3b\xda\x75\x8a\x8d\x91\xbd\x2e\xbe\x9c\x75\xcf\x14\x7f\x25\x4c\x25\x69\x63\xb3\x3b\x67\xd0\x2b\x6a\xa0\x9e\x7d\x74\x65\xd0\x38\xe5\x01\x95\xec\xe4\x18\x9b\x41\xe7\x68",
        p,
        q,
        g,
        b"\x3a\x41\xb0\x67\x8f\xf3\xc4\xdd\xe2\x0f\xa3\x97\x72\xba\xc3\x1a\x2f\x18\xba\xe4\xbe\xde\xc9\xe1\x2e\xe8\xe0\x2e\x30\xe5\x56\xb1\xa1\x36\x01\x3b\xef\x96\xb0\xd3\x0b\x56\x82\x33\xdc\xec\xc7\x1e\x48\x5e\xd7\x5c\x92\x2a\xfb\x4d\x06\x54\xe7\x09\xbe\xe8\x49\x93\x79\x21\x30\x22\x0e\x30\x05\xfd\xb0\x6e\xbd\xfc\x0e\x2d\xf1\x63\xb5\xec\x42\x4e\x83\x64\x65\xac\xd6\xd9\x2e\x24\x3c\x86\xf2\xb9\x4b\x26\xb8\xd7\x3b\xd9\xcf\x72\x2c\x75\x7e\x0b\x80\xb0\xaf\x16\xf1\x85\xde\x70\xe8\xca\x85\x0b\x14\x02\xd1\x26\xea\x60\xf3\x09",
        b"\x57\x97\x61\x03\x9a\xe0\xdd\xb8\x11\x06\xbf\x49\x68\xe3\x20\x08\x3b\xbc\xb9\x47",
        b"\x50\x3e\xa1\x5d\xba\xc9\xde\xde\xba\x91\x7f\xa8\xe9\xf3\x86\xb9\x3a\xa3\x03\x53",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x2d\xa7\x9d\x06\x78\x85\xeb\x3c\xcf\x5e\x29\x3a\xe3\xb1\xd8\x22\x53\x22\x20\x3a\xbb\x5a\xdf\xde\x3b\x0f\x53\xbb\xe2\x4c\x4f\xe0\x01\x54\x1e\x11\x83\xd8\x70\xa9\x97\xf1\xf9\x46\x01\x00\xb5\xd7\x11\x92\x31\x80\x15\x43\x45\x28\x7a\x02\x14\xcf\x1c\xac\x37\xb7\xa4\x7d\xfb\xb2\xa0\xe8\xce\x49\x16\xf9\x4e\xbd\x6f\xa5\x4e\x31\x5b\x7a\x8e\xb5\xb6\x3c\xd9\x54\xc5\xba\x05\xc1\xbf\x7e\x33\xa4\xe8\xa1\x51\xf3\x2d\x28\x77\xb0\x17\x29\xc1\xad\x0e\x7c\x01\xbb\x8a\xe7\x23\xc9\x95\x18\x38\x03\xe4\x56\x36\x52\x0e\xa3\x8c\xa1",
        p,
        q,
        g,
        b"\x56\xf7\x27\x22\x10\xf3\x16\xc5\x1a\xf8\xbf\xc4\x5a\x42\x1f\xd4\xe9\xb1\x04\x38\x53\x27\x1b\x7e\x79\xf4\x09\x36\xf0\xad\xcf\x26\x2a\x86\x09\x7a\xa8\x6e\x19\xe6\xcb\x53\x07\x68\x5d\x86\x3d\xba\x76\x13\x42\xdb\x6c\x97\x3b\x38\x49\xb1\xe0\x60\xac\xa9\x26\xf4\x1f\xe0\x73\x23\x60\x10\x62\x51\x5a\xe8\x5f\x31\x72\xb8\xf3\x48\x99\xc6\x21\xd5\x9f\xa2\x1f\x73\xd5\xae\x97\xa3\xde\xb5\xe8\x40\xb2\x5a\x18\xfd\x58\x08\x62\xfd\x7b\x1c\xf4\x16\xc7\xae\x9f\xc5\x84\x2a\x01\x97\xfd\xb0\xc5\x17\x3f\xf4\xa4\xf1\x02\xa8\xcf\x89",
        b"\x5d\xd9\x0d\x69\xad\xd6\x7a\x5f\xae\x13\x8e\xec\x1a\xaf\xf0\x22\x9a\xa4\xaf\xc4",
        b"\x47\xf3\x9c\x4d\xb2\x38\x7f\x10\x76\x2f\x45\xb8\x0d\xfd\x02\x79\x06\xd7\xef\x04",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xba\x30\xd8\x5b\xe3\x57\xe7\xfb\x29\xf8\xa0\x7e\x1f\x12\x7b\xaa\xa2\x4b\x2e\xe0\x27\xf6\x4c\xb5\xef\xee\xc6\xaa\xea\xbc\xc7\x34\x5c\x5d\x55\x6e\xbf\x4b\xdc\x7a\x61\xc7\x7c\x7b\x7e\xa4\x3c\x73\xba\xbc\x18\xf7\xb4\x80\x77\x22\xda\x23\x9e\x45\xdd\xf2\x49\x84\x9c\xbb\xfe\x35\x07\x11\x2e\xbf\x87\xd7\xef\x56\x0c\x2e\x7d\x39\x1e\xd8\x42\x4f\x87\x10\xce\xa4\x16\x85\x14\x3e\x30\x06\xf8\x1b\x68\xfb\xb4\xd5\xf9\x64\x4c\x7c\xd1\x0f\x70\x92\xef\x24\x39\xb8\xd1\x8c\x0d\xf6\x55\xe0\x02\x89\x37\x2a\x41\x66\x38\x5d\x64\x0c",
        p,
        q,
        g,
        b"\x09\x42\xa5\xb7\xa7\x2a\xb1\x16\xea\xd2\x93\x08\xcf\x65\x8d\xfe\x3d\x55\xd5\xd6\x1a\xfe\xd9\xe3\x83\x6e\x64\x23\x7f\x9d\x68\x84\xfd\xd8\x27\xd2\xd5\x89\x0c\x9a\x41\xae\x88\xe7\xa6\x9f\xc9\xf3\x45\xad\xe9\xc4\x80\xc6\xf0\x8c\xff\x06\x7c\x18\x32\x14\xc2\x27\x23\x6c\xed\xb6\xdd\x12\x83\xca\x2a\x60\x25\x74\xe8\x32\x75\x10\x22\x1d\x4c\x27\xb1\x62\x14\x3b\x70\x02\xd8\xc7\x26\x91\x68\x26\x26\x59\x37\xb8\x7b\xe9\xd5\xec\x6d\x7b\xd2\x8f\xb0\x15\xf8\x4e\x0a\xb7\x30\xda\x7a\x4e\xaf\x4e\xf3\x17\x4b\xf0\xa2\x2a\x63\x92",
        b"\x44\x84\x34\xb2\x14\xee\xe3\x8b\xde\x08\x0f\x8e\xc4\x33\xe8\xd1\x9b\x3d\xdf\x0d",
        b"\x0c\x02\xe8\x81\xb7\x77\x92\x3f\xe0\xea\x67\x4f\x26\x21\x29\x8e\x00\x19\x9d\x5f",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x83\x49\x9e\xfb\x06\xbb\x7f\xf0\x2f\xfb\x46\xc2\x78\xa5\xe9\x26\x30\xac\x5b\xc3\xf9\xe5\x3d\xd2\xe7\x8f\xf1\x5e\x36\x8c\x7e\x31\xaa\xd7\x7c\xf7\x71\xf3\x5f\xa0\x2d\x0b\x5f\x13\x52\x08\xa4\xaf\xdd\x86\x7b\xb2\xec\x26\xea\x2e\x7d\xd6\x4c\xde\xf2\x37\x50\x8a\x38\xb2\x7f\x39\xd8\xb2\x2d\x45\xca\xc5\xa6\x8a\x90\xb6\xea\x76\x05\x86\x45\xf6\x35\x6a\x93\x44\xd3\x6f\x00\xec\x66\x52\xea\xa4\xe9\xba\xe7\xb6\x94\xf9\xf1\xfc\x8c\x6c\x5e\x86\xfa\xdc\x7b\x27\xa2\x19\xb5\xc1\xb2\xae\x80\xa7\x25\xe5\xf6\x11\x65\xfe\x2e\xdc",
        p,
        q,
        g,
        b"\xa0\x15\x42\xc3\xda\x41\x0d\xd5\x79\x30\xca\x72\x4f\x0f\x50\x7c\x4d\xf4\x3d\x55\x3c\x7f\x69\x45\x99\x39\x68\x59\x41\xce\xb9\x5c\x7d\xcc\x3f\x17\x5a\x40\x3b\x35\x96\x21\xc0\xd4\x32\x8e\x98\xf1\x5f\x33\x0a\x63\x86\x5b\xaf\x3e\x7e\xb1\x60\x4a\x07\x15\xe1\x6e\xed\x64\xfd\x14\xb3\x5d\x3a\x53\x42\x59\xa6\xa7\xdd\xf8\x88\xc4\xdb\xb5\xf5\x1b\xbc\x6e\xd3\x39\xe5\xbb\x2a\x23\x9d\x5c\xfe\x21\x00\xac\x8e\x2f\x9c\x16\xe5\x36\xf2\x51\x19\xab\x43\x58\x43\xaf\x27\xdc\x33\x41\x4a\x9e\x46\x02\xf9\x6d\x7c\x94\xd6\x02\x1c\xec",
        b"\x8c\x2f\xab\x48\x9c\x34\x67\x21\x40\x41\x5d\x41\xa6\x5c\xef\x1e\x70\x19\x2e\x23",
        b"\x3d\xf8\x6a\x9e\x2e\xfe\x94\x4a\x1c\x7e\xa9\xc3\x0c\xac\x33\x1d\x00\x59\x9a\x0e",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xf2\x3e\xe7\x9e\xb4\xfc\xe5\xcb\xf3\xb0\x8d\x65\xa1\x80\x3d\x2e\x3e\x19\x1d\x35\x80\xa4\x4d\x17\x7d\x8f\xf0\x69\xf9\x07\x84\xd0\x12\xca\x57\x46\xe6\xdd\x66\x38\xdf\xe8\x41\x3f\x1d\xb3\xd8\xfe\x28\x2c\x21\x60\xf5\xdd\x96\x60\x7d\xd6\x3d\x61\x0f\x79\x1d\xfc\x10\xab\xad\x18\x72\x15\x87\x10\x1c\xec\x8a\x2a\x12\x91\x3c\xfb\xad\xa3\xa5\xb7\x59\x39\x58\xb9\xbf\xa6\xe9\xaf\x3a\xf5\xd7\x1f\xf1\x7e\xc7\x2a\xaa\xee\xca\xaf\xfc\x5d\x17\x4e\x62\x9a\x09\x02\x97\xe9\x4c\xdf\xe9\x88\xd9\xbf\x6c\x80\x82\x7c\x23\xdf\x51\x37",
        p,
        q,
        g,
        b"\x22\x9a\x26\xdc\xaf\xf2\x9e\xd1\xa7\x26\x4e\xd0\xf7\x7d\x67\x62\x39\xb9\xba\x1e\xf4\x77\x8e\x7d\xd6\x40\xe8\xaa\x6f\xab\xdc\x1f\x1b\xd3\xf5\x82\xe2\x11\xbd\x01\xc2\x6b\x3d\x9d\x3b\xff\xe7\x19\x9f\x9e\xd4\x5d\x76\x4c\xd9\xd0\xe8\x44\xb3\x85\xcb\x34\xe6\xde\x22\x37\x0e\xbc\x6b\xa4\x1d\xb4\x09\xd6\x3f\x50\xc1\xac\x09\xbe\xd0\x0c\xdc\x2b\x7c\x55\x22\x3c\x59\x6b\x7e\x13\x3b\xa2\x5b\xa9\xe7\x8f\x33\x50\x2f\x8d\xd5\x2f\x32\xa6\x67\xa7\x68\x3e\x50\x40\x47\x81\x79\x63\x23\x8d\x96\x29\xa9\x18\xa0\xce\xeb\xaa\xd5\x18",
        b"\x8d\x38\x8e\xc7\xf2\x86\x3d\xd5\xb7\xc9\x9a\xc9\x35\x05\xd1\x58\x0b\xf2\xe0\xc7",
        b"\x76\xae\x93\x17\x69\x6d\x37\xf2\xd8\xbd\x61\xc4\x77\x33\xe9\x45\x5b\x61\xd3\x47",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x68\x36\x25\x5e\x6e\x65\x9d\xe4\xff\xb5\x35\x89\x2d\x46\x6a\x3b\xea\x09\x69\x3e\x58\x7e\xb5\xbd\x50\xf4\x4f\x8a\x22\xf1\x16\x97\x05\x7d\x68\x66\x0b\xc6\x56\x24\x00\xd5\x87\xba\xac\x1c\x19\xd3\x30\xff\x79\x4a\x70\xdf\x53\x00\xa5\x21\x1c\x72\x54\x1a\x56\xd0\xff\x2a\xf0\x2a\x27\x8e\xd2\xdb\x1d\xf9\x4c\xcb\x20\x26\xd3\x13\x8b\x2d\x92\x42\x45\x02\x1e\xe8\x35\xd3\xc1\x7b\x0b\x3b\x76\x77\xde\xf8\x56\x11\x22\x7f\x6c\xe2\x91\x3e\x7c\xb4\x46\xa4\x79\xb9\x5a\xcf\xd0\x10\x5c\x25\xe4\x65\x6f\xbc\x56\xc2\xa1\x0a\x22\xb3",
        p,
        q,
        g,
        b"\xa7\xbb\xc3\x54\x23\x51\x0e\xdf\xeb\xf7\x9c\x4e\x2e\x56\x98\x6f\x28\x06\xd1\x11\x16\xbc\xae\x90\xa7\x16\xf0\x5d\xcb\xfc\x46\xdc\xbf\xeb\xe2\xec\x94\x6c\x40\xf9\xcc\x8c\x1a\x74\x39\xcd\xd0\x4e\x27\x01\x22\xec\x1c\x3b\xac\xa8\x38\x11\xa9\xf1\xbd\xae\xd9\xb1\x17\x21\x50\xaf\x1c\x8c\xe1\xc5\xd5\x02\xdf\xe5\xf4\xe8\x46\x7e\x50\x60\x50\x87\xa8\xf8\xc5\xf4\x5c\xa6\x72\xfd\x04\x9e\xec\x0a\x06\xf5\xe0\x1f\x78\x2d\x51\xf3\xba\x56\x40\x4b\xf1\x38\x80\x65\x55\x2f\xc8\x7a\xd2\x1a\xc0\xfa\x40\x27\xa1\x45\xd0\xb0\xd9\xe6",
        b"\xc0\xab\x43\xd3\x09\xa5\xe9\x4b\x6e\xf4\xdb\x99\x43\x30\x6e\x6d\x96\x6f\xc9\xb5",
        b"\x07\xec\x5a\xa1\x92\x8f\x19\xfc\x3a\x42\x0f\x29\xb9\x35\xba\xc4\x61\x24\xc0\xe2",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x4b\x08\x45\xc9\x9d\xb3\x48\x29\x4f\x1d\x83\x16\x6b\x27\xf4\x48\xec\x29\xab\x79\x65\x46\x44\x77\xf4\x54\x44\xf4\x46\x72\xa4\x09\xdd\xca\xfa\xf3\x5e\x91\xfa\xf4\x01\xec\xa7\x49\x8e\x32\x68\xca\xa2\xd9\x6b\xf1\xaa\x84\x0c\x0e\x1e\xd4\x3a\x5a\xb6\x08\x88\xfc\xf0\x2b\x2f\x8a\x2c\x89\xda\xa5\x98\xad\xf0\xb7\xd2\xda\xce\x92\x10\xef\xd4\x1a\xb4\x96\xa1\xe7\x3a\x18\x2d\xa4\x30\xc1\xd0\x43\xe2\x49\xa1\x28\x9c\x91\x80\x9c\x8c\x72\x98\xcf\xdb\xb0\xae\x43\x8b\x00\x93\x6c\x28\x3a\x0e\xc2\xd7\x9c\xdc\x81\xc9\xce\x3c\x2d",
        p,
        q,
        g,
        b"\x54\x1a\x9c\x45\xe1\x65\xd3\xd9\x1e\x71\xbb\x13\x70\xd7\xc0\x32\xc3\x60\x32\x2a\xa1\x5e\x99\xd8\xc1\xc1\x6e\xa3\x5c\x8c\x19\x32\x24\xa0\x64\x67\xab\x77\xa6\x54\x78\xc4\x67\xb3\xf2\x0c\xb0\xc5\xfd\xb8\xc8\x4c\xef\xa6\x95\x66\xa5\x94\xa2\xaa\x54\xc3\xa9\x48\xeb\xc1\xea\x7e\x6c\x3d\x28\xd3\x80\xcb\xd0\x17\x40\x63\x4c\x96\xb7\x6d\x6a\x03\xcc\x6e\xba\x0a\xfa\x72\x26\xf2\x3f\xc1\x0a\x18\xb0\xb6\xf9\x72\x70\xdf\xa0\x38\x16\x09\x60\xb5\xb8\x39\xba\x66\xaf\x50\xfd\xa0\x72\x45\x81\x0e\x80\xd3\x8b\x66\x93\xe8\xa9\xce",
        b"\x44\x28\x60\x19\xc1\xd5\x31\x03\x98\x06\x16\x94\x0c\x02\x8b\xad\x32\x17\xf7\x8d",
        b"\x4b\x37\x2b\xf5\x27\xc5\x15\xf5\x80\x25\x69\x9a\x45\xf2\x02\x1e\xf1\x8e\x11\xb9",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x45\x97\xc1\xca\x0b\x07\x64\xbe\x31\xfa\x73\xcc\xc5\x89\x11\x6c\xc8\xd0\xa3\x16\x05\xf2\x55\x0e\xb3\x7f\xa5\x69\xb2\x49\x6c\x4f\x34\x32\x1d\x61\xbb\x8e\x49\xf8\x58\xc8\x67\x1b\x74\x37\xfc\x15\xf2\x69\xdd\x2d\x41\x46\x47\x0b\x81\x7d\xfe\x30\x69\x22\x5d\xdd\x3c\xd4\xa6\xc9\x77\xfb\x6c\xfc\x0d\x43\x26\x4a\x7b\xf6\x65\x92\x83\xe1\x40\xe4\xc8\x9a\xb2\xe8\xa4\xd0\xed\xe6\x27\x49\x61\xd6\x55\xbd\x79\xc7\xe4\x78\x80\xa7\x41\xfb\x01\x80\xc3\x25\xb5\xb7\xd2\xf7\xb8\xa5\x7a\xed\x52\xd0\x20\x6a\x83\xbb\x69\xa9\xd7\xa4",
        p,
        q,
        g,
        b"\x53\x15\xad\xf9\x0e\x19\x69\x46\xbe\x6b\x04\xc5\x41\x4d\xa1\xfa\xfd\x98\xb0\xd1\x7c\x3a\x39\x00\x0a\x00\x09\x1b\x7b\x56\x57\x4b\x1e\xcd\x02\x6e\xab\xb2\x5b\xe9\xec\xd0\xad\x69\x1d\xf2\xb7\xbf\x7e\xec\xd6\xad\x95\xbb\x4d\x7d\x17\xac\x74\x70\x60\xee\x7e\x3e\xb5\xc6\xfb\x75\x57\xcf\x7e\x80\x03\xa6\x20\xe4\x3e\x58\x7d\x06\x12\x85\x44\x72\xc3\xad\x85\x18\x39\xf7\x44\x15\x94\x11\xa3\x38\x76\xae\xc3\x65\xeb\x04\x91\xde\xc8\x0b\xa1\x4c\xba\x2d\x11\xde\xc4\x2a\xf4\xa4\xbf\x9c\x99\x31\x2a\x2a\xe7\xe5\x46\x2a\x2a\xdf",
        b"\x90\xd5\x47\x71\x2b\xc0\xce\xbb\xd3\xeb\xd1\x8a\x63\xd9\xb9\x2a\x03\x95\x30\x50",
        b"\x34\xea\x61\x76\xb4\xc6\x30\x43\x29\x5f\x12\x9a\x48\x95\xe1\x4e\xe5\x81\x65\x63",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x18\xc6\x2a\x40\xb5\x23\x47\xa4\x73\xf5\x7a\xa6\x68\xee\xbb\x44\x84\xbe\xb5\xf1\x0f\xdc\x51\x77\x9e\x67\x70\x10\x6c\x0d\x12\x2e\xb6\x35\x6a\xe5\x3a\x33\x79\xe2\x70\xed\xca\x39\x01\x5d\xa3\x00\x57\x70\xc7\xb2\xa5\xaf\xd1\x12\x17\x99\x31\x53\xff\x43\xa0\xb2\x6d\xb0\x1a\xa2\xa4\x93\xde\x06\x14\x92\xa0\xaa\x3f\x22\x9b\x5a\xbd\x1a\xff\x29\x39\x5e\x31\xb0\x63\x50\x4e\xb3\x56\x20\x21\x9b\xa2\x99\x97\xf9\x2a\x52\xe1\xb2\xe6\xff\x20\x74\x80\xfd\x13\xd5\x8f\xf0\x29\x0e\xec\x5a\xab\xf2\x3b\x84\x94\x3e\xea\x20\xa4\x3c",
        p,
        q,
        g,
        b"\x3b\x73\x82\x46\xf9\xe3\x8c\xeb\xf4\x54\x2c\xed\x3f\xc0\xc0\x09\x6a\xeb\x9e\x9a\x3a\xd9\x28\xf4\xdd\x47\x45\xd8\x75\xfe\x6e\x20\xfb\x65\x55\x6d\x06\x69\x64\x32\xec\xff\xd5\x5b\x33\x49\x40\xc6\xe2\x3c\x90\x3f\x0a\xa4\xa1\x33\x5f\x73\x94\xc5\x50\x70\x58\x6b\xaa\xc8\x6c\x38\xcc\x19\x8e\xba\xf1\x54\x01\x25\x95\x28\xc5\x51\x92\xe9\x29\x8d\x2a\x0c\x89\x14\xda\xf2\xad\x00\x25\x9f\xe7\x25\x55\xc3\xc0\x44\x2e\x38\xc1\xe6\xe5\x02\x09\x28\xc6\xe6\x57\x1a\x0a\x98\xf6\xf4\x85\xe4\x37\x91\xae\x8a\xaa\xb1\x80\x46\x1f\xa4",
        b"\x29\xb7\xc0\xf9\x0d\x62\x4f\x8d\x58\x7e\xfd\x3f\x49\xf9\x7d\xa7\x0f\x6e\x63\xe7",
        b"\x22\x2a\x3d\x9f\xfc\xa0\xdc\xf5\x79\x37\xe8\x9c\x92\x53\x8e\x32\xe7\xa8\x68\x0f",
    )?;

    // [mod = L=1024, N=160, SHA-224]
    let p = b"\x8b\x9b\x32\xf5\xba\x38\xfa\xad\x5e\x0d\x50\x6e\xb5\x55\x54\x0d\x0d\x79\x63\x19\x55\x58\xca\x30\x8b\x74\x66\x22\x8d\x92\xa1\x7b\x3b\x14\xb8\xe0\xab\x77\xa9\xf3\xb2\x95\x9a\x09\x84\x8a\xa6\x9f\x8d\xf9\x2c\xd9\xe9\xed\xef\x0a\xdf\x79\x2c\xe7\x7b\xfc\xec\xca\xdd\x93\x52\x70\x0c\xa5\xfa\xec\xf1\x81\xfa\x0c\x32\x6d\xb1\xd6\xe5\xd3\x52\x45\x80\x11\xe5\x1b\xd3\x24\x8f\x4e\x3b\xd7\xc8\x20\xd7\xe0\xa8\x19\x32\xac\xa1\xeb\xa3\x90\x17\x5e\x53\xea\xda\x19\x72\x23\x67\x4e\x39\x00\x26\x3e\x90\xf7\x2d\x94\xe7\x44\x7b\xff";
    let q = b"\xbc\x55\x0e\x96\x56\x47\xfb\x3a\x20\xf2\x45\xec\x84\x75\x62\x4a\xbb\xb2\x6e\xdd";
    let g = b"\x11\x33\x3a\x93\x1f\xba\x50\x34\x87\x77\x73\x76\x85\x9f\xdc\x12\xf7\xc6\x87\xb0\x94\x8a\xe8\x89\xd2\x87\xf1\xb7\xa7\x12\xad\x22\x0a\xe4\xf1\xce\x37\x9d\x0d\xbb\x5c\x9a\xbf\x41\x96\x21\xf0\x05\xfc\x12\x3c\x32\x7e\x50\x55\xd1\x85\x06\x34\xc3\x6d\x39\x7e\x68\x9e\x11\x1d\x59\x8c\x1c\x36\x36\xb9\x40\xc8\x4f\x42\xf4\x36\x84\x6e\x8e\x7f\xca\xd9\x01\x2c\xed\xa3\x98\x72\x0f\x32\xff\xfd\x1a\x45\xab\x61\x36\xce\x41\x70\x69\x20\x7a\xc1\x40\x67\x5b\x8f\x86\xdd\x06\x39\x15\xae\x6f\x62\xb0\xce\xc7\x29\xfb\xd5\x09\xac\x17";
    test(
        HashAlgorithm::SHA224,
        b"\xfb\x21\x28\x05\x25\x09\x48\x8c\xad\x07\x45\xed\x3e\x63\x12\x85\x0d\xd9\x6d\xda\xf7\x91\xf1\xe6\x24\xe2\x2a\x6b\x9b\xea\xa6\x53\x19\xc3\x25\xc7\x8e\xf5\x9c\xac\xba\x0c\xcf\xa7\x22\x25\x9f\x24\xf9\x2c\x17\xb7\x7a\x8f\x6d\x8e\x97\xc9\x3d\x88\x0d\x2d\x8d\xbb\xbe\xdc\xf6\xac\xef\xa0\x6b\x0e\x47\x6c\xa2\x01\x3d\x03\x94\xbd\x90\xd5\x6c\x10\x62\x6e\xf4\x3c\xea\x79\xd1\xef\x0b\xc7\xac\x45\x2b\xf9\xb9\xac\xae\xf7\x03\x25\xe0\x55\xac\x00\x6d\x34\x02\x4b\x32\x20\x4a\xbe\xa4\xbe\x5f\xaa\xe0\xa6\xd4\x6d\x36\x5e\xd0\xd9",
        p,
        q,
        g,
        b"\x7e\x33\x9f\x37\x57\x45\x03\x90\x16\x0e\x02\x29\x15\x59\xf3\x0b\xed\x0b\x2d\x75\x8c\x5c\xcc\x2d\x8d\x45\x62\x32\xbb\x43\x5a\xe4\x9d\xe7\xe7\x95\x7e\x3a\xad\x9b\xfd\xcf\x6f\xd5\xd9\xb6\xee\x3b\x52\x1b\xc2\x22\x9a\x84\x21\xdc\x2a\xa5\x9b\x99\x52\x34\x5a\x8f\xc1\xde\x49\xb3\x48\x00\x3a\x9b\x18\xda\x64\x2d\x7f\x6f\x56\xe3\xbc\x66\x51\x31\xae\x97\x62\x08\x8a\x93\x78\x6f\x7b\x4b\x72\xa4\xbc\xc3\x08\xc6\x7e\x25\x32\xa3\xa5\xbf\x09\x65\x20\x55\xcc\x26\xbf\x3b\x18\x83\x35\x98\xcf\xfd\x70\x11\xf2\x28\x5f\x79\x45\x57",
        b"\xaf\xee\x71\x9e\x7f\x84\x8b\x54\x34\x9c\xcc\x3b\x4f\xb2\x60\x65\x83\x3a\x4d\x8e",
        b"\x73\x4e\xfe\x99\x22\x56\xf3\x13\x25\xe7\x49\xbc\x32\xa2\x4a\x1f\x95\x7b\x3a\x1b",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x02\x97\x1e\x0c\xdd\x48\xae\x23\x31\xdb\x9c\x62\x85\xe9\x88\x0e\x96\x10\x4f\xa7\xa9\xf3\x78\xdf\xea\x71\x8e\x63\xef\xe9\x83\x52\xfe\x4d\x35\xa2\xbc\x94\xb3\xa8\x88\xcf\xb8\x8b\x8b\x7d\x9f\x6c\x8c\x54\xe4\x86\x13\xf3\x2c\x99\x46\xff\xe6\xe9\xa4\xb7\x10\x8e\xce\xcd\xda\x41\xbc\x15\x1b\x3d\x87\x24\xb6\x1f\x5b\x83\xa4\xe2\x74\x76\x91\x43\x87\xb0\x48\x8e\x41\xbe\x54\xf6\x3a\xa7\x73\x17\x5e\xb3\x73\xa3\x64\x1e\x6e\x79\x50\xee\xe8\xfa\xf0\x48\xa8\x41\xf1\x07\xd3\x0c\xf9\xbe\x26\x84\x93\x23\x15\x45\xd8\x98\x46\x94",
        p,
        q,
        g,
        b"\x63\x3b\xb7\x57\xb3\xc0\xe3\xb7\x86\x7b\xf8\x45\x30\x1e\xa4\xe3\x9f\x75\xc9\x75\x9c\x22\x3f\x46\xce\x26\x6d\x40\x6b\x9d\xf5\xdb\x50\x1f\xb8\x26\xb6\xe6\x1c\xba\x61\x04\xc6\x04\x45\x8c\x90\x79\x9f\x2a\x36\xab\x51\x16\x6d\x0e\x83\xb7\x70\x84\x06\x24\xfe\xdc\x35\xeb\xfb\x98\x53\x41\x9e\x7e\x09\xb3\x2b\x4b\xd6\x52\xda\x4f\x1c\xe9\x73\xac\x26\x20\xc9\x66\xb6\x1e\x35\xa3\xf2\x16\x43\x9a\x8d\xe1\xa1\x04\xf1\x72\xe1\xb6\xe2\x87\x81\x12\xa6\x6c\x34\xd1\x6a\x9a\xef\x3a\xc2\x4a\x34\xaf\x5e\xdb\xf3\x98\x18\xa3\xe2\xef",
        b"\x92\xc6\x5e\x07\x46\x2d\x66\x8b\x06\xdd\x45\xb6\x08\x78\x49\x65\x89\x78\x38\xbc",
        b"\x2e\x40\xad\xf4\x1c\xaf\xb8\x04\x8c\x79\x3c\x70\x92\xa7\xe8\x23\x51\x5b\x6c\xfa",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x06\x2e\x82\xfb\x43\x23\x6e\xe1\x7e\xbf\xaa\x3d\x36\x3b\x9b\x87\x3d\x0f\xe4\x14\x44\xc7\x4c\xef\x7f\x7e\x3b\xd8\x1f\x72\x3f\xd9\x0f\xd1\x48\xa2\x8e\x99\x75\x85\x41\x36\x95\x11\x37\x57\x75\x8a\xa4\xdd\x27\x5f\x70\xb3\x75\xf8\x90\x3c\x7b\xe4\x6e\x3a\x3a\xd3\x19\x0c\xd0\x49\x71\xab\xd2\xf1\xdb\x19\x2e\xf0\xd2\xb9\x8b\xbb\x80\x18\x1a\x72\x1a\x58\x09\x92\x8b\x5b\xca\x5c\x11\x8a\x29\x11\x13\x2a\xd2\x33\xcd\x27\xc7\xe4\x1a\xdf\xcc\xfe\xb4\xe9\x52\x87\x4b\xfa\x81\x96\x61\x18\x29\x75\xe4\x4d\x37\xc6\x17\x34\x75\x9c",
        p,
        q,
        g,
        b"\x3b\x0a\x09\x1d\xfc\xa0\x5d\xce\x61\xe9\xf0\x5b\x15\xb0\x74\x87\xd2\xe3\xea\x4f\x56\x8d\xc9\xac\x75\x2d\x42\xc0\xaa\x77\x1a\xe0\xcc\xc3\x72\xce\x97\x74\xfb\x9f\xd1\x6a\x30\xcb\x37\x59\xbb\x19\x89\x48\x8c\xe8\x5d\xb7\xcd\xfa\x50\x64\x76\xac\xec\x64\x4c\x21\x16\x8f\x2d\xb1\xf3\x6e\xfe\x02\x30\xc6\xfb\x8f\x1f\x2a\xe4\xea\xf1\x79\x9d\x5e\x29\xe2\x12\x46\x7b\x11\xbf\xbc\x1e\xeb\xed\x14\x2d\x7a\x01\x72\x62\xcd\x87\x35\xe3\xe2\x9d\x8e\x0c\x4a\x6e\x76\x6c\x07\xd7\xaa\x9f\x8d\x17\x6f\x53\x60\x87\xbf\xec\xf4\xc4\x14",
        b"\xba\x55\x41\x24\x87\x4d\x06\xa6\xce\xf6\x27\x40\xe1\x58\x21\xcc\xdd\xbf\xe6\xf3",
        b"\x59\x62\xbe\x75\x7d\x75\xb0\xf1\x7d\x15\x48\x2e\xbb\x59\x5c\xa4\xe9\xfb\xfe\x22",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x4f\xca\x07\x48\x44\xea\xe2\x47\xd1\x9c\x06\xe9\x20\x32\xae\x8e\x77\x30\x43\xe2\xe1\xf4\x5d\x40\x0e\x9d\xce\xbb\xde\x5d\x65\xe7\xc1\x42\x3b\x03\x90\x16\x19\x91\xc0\x26\xf3\x8a\x0e\x2b\xfe\xef\x40\xda\xe1\x87\x41\x73\x7b\x1d\x53\x5a\xb4\x6b\x56\x6a\x1b\x67\x2f\xc2\x2d\xec\x86\x74\x7a\x7c\x76\x38\xfa\x65\x04\x7f\x1e\xde\x36\xad\x43\xf6\xae\xdf\x51\xb5\xbf\x29\x79\xad\xf4\xd9\xa9\x4e\xd8\x02\xa2\x9d\xe5\x60\x3b\x70\x47\x70\xb3\x2c\x8b\x94\x6a\x32\xe1\xb6\x05\x4c\xd7\x0c\x3a\xdd\x02\x5c\xc9\x37\x1d\x1e\x40\x4d",
        p,
        q,
        g,
        b"\x40\xb6\x38\xc9\x4b\x1e\x71\x9a\x33\x7d\x83\x35\x86\x99\xc7\x0c\xd8\x67\xff\x88\x8c\x65\x5a\x5f\x5a\x1d\xe8\x73\x2d\x05\x8b\xf0\x27\xd4\x74\x7e\xfe\x3b\x8d\xed\xca\x32\x76\xde\x5a\x58\xf1\x36\xed\x35\xcf\xf0\x30\x30\xf6\x72\xda\x65\xc7\x1f\x18\xe5\x82\x78\xdd\xfc\x7b\x9b\x50\xa2\x48\xef\xf9\x23\x68\x74\xee\x3c\xb0\xd0\xa3\x5b\x7b\x2e\xe1\x85\xb1\x39\xea\x84\xee\xd7\xbf\xfc\x50\x94\xab\x87\x43\xa7\x53\x74\xbc\x36\xc7\xd6\x9d\x5f\x3e\x6f\xe5\xf3\xef\x1f\x93\x58\xf0\x0a\x3c\x58\x92\xff\xf4\x1e\xd6\xaf\xee\x3b",
        b"\x65\x1a\x38\x9d\x8c\xa5\x0d\x6e\x32\x73\xca\xbb\xe7\x1c\xd8\x4c\xcc\xd0\x23\x61",
        b"\x34\x01\xfe\x47\xb3\x81\x2d\xaa\x8c\x02\x0c\x9b\xd4\x26\x09\xcb\xeb\xdf\xa7\x28",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x4d\x96\x30\xfe\x05\x89\x98\xca\x5b\x80\xae\x62\xf3\xf7\x3d\xc8\x5b\xee\x29\x15\x09\x84\x3a\xc0\x02\x40\xd1\x3d\x55\x25\x1a\xe5\x3b\x37\x79\x47\x83\xb9\x7d\x53\xe0\x42\xca\xb2\x6f\x8c\x84\xde\x0a\x70\xf5\xb4\x30\x51\xfb\xef\xb3\xe4\x3f\x08\xf5\xd2\xe8\xaa\xd9\xe2\xde\x27\x17\x41\x2d\xbb\x90\x2a\xcc\x88\x49\xad\xc0\x4d\x06\xfe\xd8\xc1\x42\x1c\x4c\xfe\x8b\x81\xee\x7f\x5a\xc5\xd4\xf0\xc0\xb6\x8e\x80\xb6\xf8\x8f\xd3\xc7\xd5\xb3\x20\x22\x57\x2b\x0a\x68\x1b\xd2\xd4\xdf\x2d\x04\x7b\x0b\x23\xb6\x88\x71\x45\xaf\xe1",
        p,
        q,
        g,
        b"\x72\x7b\x65\x28\x35\x7d\x67\x05\xc2\x0d\x31\x35\x8f\x64\x19\x34\xfd\xec\x63\xcc\x66\xdf\x98\x83\x7d\x2f\x37\x81\x64\xe1\x5f\xa0\x84\x22\x07\xac\xf3\x22\x0c\x80\x23\xa9\xf4\xf8\xd2\x05\x71\x65\xb3\xc8\x49\xea\xeb\x53\x76\xe3\xfa\xd1\x17\x85\xf1\xd0\x26\x17\x79\xaa\xed\xd5\x3b\x1e\x52\x79\x80\x07\xeb\x4c\x8e\x83\xb1\xff\x32\x1b\x62\x0d\x88\x33\x91\xa1\x4f\xa4\x7f\xec\x49\x01\xd9\x6e\xc2\x32\xea\xbb\x4a\x0b\xb4\x45\x33\x68\xfe\xf5\x17\x6c\x67\x13\x56\x49\x97\x9d\x32\x14\xd3\xfb\x67\xa1\x31\x9a\xc5\x4f\xeb\x01",
        b"\x9c\xa3\xe4\x33\x50\x4c\x55\x7b\xa1\xaa\xc6\x64\x69\x78\x11\x75\xcd\xfb\x4a\xd5",
        b"\x72\x14\x5d\xfa\x52\x79\xdd\x82\xae\x99\x60\x4d\x16\xa2\xb8\xdf\x71\xb9\x53\x20",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x62\xb9\xd6\x01\xe3\x0b\x42\xa2\x79\xc7\xe0\x4d\xf3\xca\x8d\x81\x40\xa5\x5c\xd5\x87\x6c\x7e\x91\x81\xc7\x35\x75\xe4\xc4\xf9\x21\xa9\x4e\x4e\x2d\x0b\xdd\x7b\xa9\x86\x00\xd6\x52\xe5\xdf\x5b\xe9\x46\x4e\x7a\x90\x11\xab\x48\x69\x60\xf6\x9d\x57\xec\xe1\xd2\xc4\xaf\x93\x24\x45\x7c\x1e\x3d\x83\xfb\xa4\x26\x5b\xeb\x47\x40\x7e\x47\x61\xdb\xc9\x49\xd5\xbd\x67\xfe\xe4\xa4\x76\xa4\xd5\xa9\x3d\x77\xac\xda\x96\xa2\x21\xa0\xa3\x1e\x0f\x02\x4b\x3f\x0b\x82\x34\xc0\x15\x23\x8f\x32\x58\xda\xa0\x85\xae\x9f\x4e\x1a\xa7\xb1\xcc",
        p,
        q,
        g,
        b"\x5f\x6d\xfb\x06\x4c\xad\xdf\x64\x4a\xf3\x99\xe3\x3a\x67\x25\x65\x76\x67\x61\xd5\x5a\xc0\xb8\x4b\xea\xd4\x2c\x39\x80\xe7\xe3\x96\x04\x37\x44\x36\x17\x78\xf0\x4d\xcb\x69\x8e\x45\x63\x85\x34\x20\xfe\xca\xcd\x59\x4a\xf8\x28\xf5\x7d\xf5\x41\xd9\xe4\xde\x89\x9d\x61\xf0\x4f\x63\x79\xc1\xc9\x62\x46\xd1\x52\x36\x93\x95\x24\x2a\x1c\x2e\x70\xee\xf8\xf3\x54\x17\xa0\xff\xdb\x03\x92\x82\x51\x6c\xe2\x1b\x85\x68\x79\x04\xc5\x11\x08\x7f\x11\x3e\x51\x42\xf0\x27\xf1\x17\x97\x12\xed\xcb\xce\x27\x93\x9a\xb1\x5e\xc4\x9c\x08\x5f",
        b"\x33\x19\x20\xa7\xb7\x9e\x3c\xfa\x76\x38\xe4\x09\xd9\x70\x2a\xaf\xd0\x8f\xbe\xc6",
        b"\x07\x1d\x06\xe6\xcd\x30\x15\x15\xf3\x7b\x60\x69\x0a\xfa\x21\x9f\xe5\x08\x3d\x96",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x00\x06\xe0\x9c\x20\x37\x64\x42\xe6\x89\xbf\x2d\x34\x26\x8f\xd6\x91\x09\xc1\x30\x1e\xa6\x6c\xbe\x90\x39\x4c\xc0\xf4\x1f\x94\x82\x2c\x28\x84\x58\x19\xb9\xa9\x87\x64\xd2\xf7\x26\x2e\x98\x89\x14\x87\xff\x55\xb0\x5b\xd6\x9e\x18\xb7\xca\xd4\x1b\xd9\x8e\x13\x75\x66\xb6\x04\x1c\x73\x9d\xb1\x1f\x78\xe5\x67\xca\xc0\x2f\x33\xf1\x40\xd1\x9a\x48\x05\x00\x25\x45\x37\x5d\xae\xbf\xd7\xdc\xbe\xa3\x32\x42\xe7\x3c\x8e\x26\x91\x49\xd7\xeb\x9d\xb9\xf9\x00\x6e\x17\xac\xb7\x36\xb5\xe9\x77\x64\x5a\xb6\x51\xb8\x12\x25\xc5\xe5\x43",
        p,
        q,
        g,
        b"\x1b\x1f\x72\x56\x64\xd7\x5b\xdc\xb2\xa5\xa4\xc6\x53\x06\x1c\x46\x07\x99\xdd\x48\xbf\x1e\x6b\x03\xe1\x3c\x71\xd8\x3e\x3f\xdb\x50\x6f\xa9\x4e\x6c\xaf\xb5\xdb\xde\xad\x88\xa3\x3d\x23\xd4\xe9\x28\x7b\x47\x07\xe1\xfb\xa8\x71\xb9\x7c\x9a\x48\xf9\x30\xcd\xcc\xba\x0d\xc0\x6a\x4f\x0a\x8b\xfb\xb4\xe1\x4d\x0b\x4d\x5a\x08\x71\xfa\x13\x41\xca\xec\x7b\xc0\x81\x38\x71\x31\x21\xd4\x19\x76\x9f\x31\x20\x35\x08\xdf\x71\x94\x72\x65\x64\x4f\xdc\x61\x37\xd8\xe4\x66\xc8\xcb\x0c\xe9\x85\x34\x0c\xb2\xe2\x79\xb4\xce\x93\x15\xa7\x72",
        b"\xb6\xaa\x83\x3b\x82\x51\x84\x72\x9a\xf3\x08\xf8\x1b\xf5\xe5\x8e\x2d\x7e\x92\x84",
        b"\x54\x53\xb4\xb2\xe3\xfc\x80\x2b\x2f\x97\x7d\x0c\xf6\xeb\x7f\x5c\x16\x67\x3f\xa3",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xe0\x4a\x71\xf2\xb5\xc1\x76\xa0\xdb\x17\xa9\x83\xa1\x7d\xec\x58\x8c\x00\xf4\x2c\x9a\xa3\x02\x6b\x5e\xb4\x40\xf0\x7a\x21\x40\xc2\xed\x84\x02\x4e\x05\x31\xea\x77\x88\xdf\xea\xa9\x18\x83\xfb\x6a\x98\x41\xc1\x7d\xcf\xd3\x12\x96\x8a\xdb\x00\xe5\x56\xbc\x7e\xb3\x02\x1f\x57\xb7\xa1\x68\x94\xfa\x4f\xe1\x2e\xc9\x3d\xfd\x49\x4a\x0a\x1c\x69\x3d\x6a\xde\x15\x4e\xf6\x48\xc0\x55\x52\xda\x41\x22\x4d\x49\x22\xd1\x86\x1d\x9f\x76\x71\xb8\xce\x6c\xe4\x48\xe8\x95\xea\x0e\xed\x25\x80\x2e\x33\x50\xec\x08\xae\x79\xf2\xd6\x1e\x0f",
        p,
        q,
        g,
        b"\x68\x7e\x16\x30\x9b\x06\x81\x7b\x93\x23\x6d\xd9\x90\xfa\xef\x9e\x23\x2e\xb8\x1c\xb9\xc7\xd6\xda\xe4\xfd\xd4\xf8\xe7\xca\x93\x3e\x18\x5b\x1d\xa6\x22\xd7\xc7\xfa\x35\xe0\xa3\x90\x6f\x91\x5d\xed\x14\xba\x96\xd6\x03\x5b\x46\xbd\x6c\xa5\xfe\x17\x2a\xf9\x4e\x08\x1f\xb0\xb9\xa9\x58\x3a\x45\x8b\xd2\x06\xc1\xe8\x7f\x97\xa5\x7d\x00\xd6\xea\xde\x19\xec\x56\xac\x2e\x9b\xbd\x8c\x15\xdf\x35\x6e\xe7\xb1\x2c\x91\x31\x1a\x38\xfc\x33\x15\xcf\xde\x9f\xf4\x62\xca\x6a\xdf\xf2\x80\x8b\x3f\x8e\x80\x5e\xe9\x15\xae\x88\x5c\xa9\x57",
        b"\x14\x89\x2b\x1e\xc7\xfc\x71\x6c\x75\xa1\x7f\x7a\xd2\xe4\x1e\xc6\xfa\xa7\x88\x36",
        b"\x72\xcc\x56\xa9\x89\x0e\x8b\xdf\x1a\x53\xd3\xac\xc6\xf8\x91\x37\x26\x4f\x9f\xf8",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x5e\x8e\xb9\x6b\x5c\x6a\xd7\x5d\x3d\xab\x1e\x28\xbb\x2c\xe7\x51\xec\xc3\x16\x11\xa0\x19\xe8\xd4\xb5\x61\xc7\xe4\x53\x3c\xc7\xab\x73\xbd\x9d\xe9\x31\xe8\xc5\x4c\x51\xc5\x71\x1e\x6c\x27\x6a\x8e\xd9\x2f\x4b\xb4\x57\xdd\xf2\x82\x33\xda\x2c\xa3\xe3\x01\x3c\x56\xe3\xcd\x2b\xc6\x1d\x4d\x4e\x0e\x22\xcf\x63\x61\x30\x4e\x56\xd6\x8b\x31\x5c\xa5\xd3\xfc\xc4\x72\xa7\xee\xf8\xcc\xa5\x75\x20\x4d\xd0\x84\xa2\x1a\x99\xba\x67\xfd\xdb\xf9\x0d\xf7\xc6\xc6\x58\x76\x17\x34\xbc\xe1\x3c\x3d\x22\xd8\x0b\x6f\xb9\xbe\xce\x55\x14\x92",
        p,
        q,
        g,
        b"\x50\xb0\xf7\x60\x59\x11\xbc\xe6\xed\x5e\xcf\xf1\xe3\xc1\x81\x6f\xbb\xf0\x3a\x14\x79\xa0\x82\x06\x03\xff\xa7\x15\xae\xf9\xff\xbc\xcb\xd0\x67\x57\x9c\xbb\xc8\xc8\x7c\x39\x2e\x85\xbb\xe9\x29\xa0\xb5\xe1\x05\x9f\xaa\xe6\xf9\x12\x1d\xf4\x9c\x66\xa0\x49\xa9\x8a\x90\xd8\x4c\x70\xa2\x13\x12\xbf\x83\x7f\x47\x23\x99\x3d\x0e\xc0\xac\x4c\x2a\x7f\xfb\x9d\x40\x09\x57\xb3\x9f\xb8\x3e\x95\x1e\xf4\x13\x62\x45\x2c\xf4\x58\xd7\x84\xc4\x3f\xe8\x22\xea\x7a\x7a\xbb\xea\x0a\x69\x98\x32\x1a\x93\x81\x9d\x2d\x28\x2c\x78\x84\xf5\xc2",
        b"\x73\x99\xb1\x20\xd4\xbf\xbd\x6d\xc4\x06\x4d\x2f\x3f\x8f\x0c\xa5\xc3\x62\xb2\xd8",
        b"\x23\x02\xd8\x1d\x7e\xbb\x24\x17\xee\xf4\x5d\x88\x94\x1b\x07\x0e\xca\xb1\x1c\xab",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xda\x91\xc6\x92\xcd\xb0\xa5\x95\x62\xe2\xb6\x64\xdc\xfe\x75\x54\xac\x58\x9d\x57\xf8\x22\x46\xc4\xa8\xa3\xf9\x57\x3b\xf4\x7b\x25\x7e\xb8\xf9\x34\x47\xc1\xeb\xab\x13\xdc\xe5\x3d\x6f\x44\x16\xfb\x2c\x6c\x36\x30\x3e\xd9\x78\x85\xcf\x7a\x6c\xae\xf0\x55\xf7\xe3\x14\x5e\xf3\x83\x8c\x31\x87\x7f\xad\x7a\x88\x83\xff\xc8\x4e\xbd\x97\x3f\x8c\x06\xd1\x7c\xdd\x33\x9b\xb3\x37\x1f\x9d\x3d\x4f\x2d\x9f\x0b\x80\xae\x2b\xcc\x87\x8b\x4a\xf7\x8f\x84\x5e\xac\x4f\x2a\xac\xee\x6a\x94\x51\xda\xf8\x14\xa4\x4e\x92\x7b\xb5\x42\x88\x20",
        p,
        q,
        g,
        b"\x67\x8b\x39\x58\xed\x24\xfc\x84\x94\x20\x54\xf4\x9d\x9e\x6f\x27\xbb\xac\x7d\xe3\xa4\xa5\x2a\xf9\xff\xcb\x9c\xe6\xc1\xfb\x8b\xdd\x99\xdb\x0e\x80\xc8\x68\xac\x54\x7c\x4c\xfc\x78\x2d\xe7\xeb\xcf\x69\x43\xb2\xe4\x64\x33\xc6\x70\x17\x8d\xe0\x10\x4b\xd6\xfc\x25\xdc\x30\x54\xdb\x9c\x48\xc1\x27\x06\xe1\xde\xa3\x5e\x16\x3b\xe3\x6a\x4a\xb7\x21\x95\x0c\x02\x8b\x05\x46\xf1\x71\x9f\xf2\xed\xd8\x1b\x2b\x79\x74\xfb\x9b\x12\x12\x24\xcc\xfa\xab\xc4\x7e\x9e\x62\x9a\x97\xbc\x6b\xa4\x26\x91\xca\x3f\x64\x9c\xca\xc4\x7d\x0f\x1e",
        b"\x6f\x15\x79\xed\xcf\x43\x75\x84\xd3\xe9\x39\xfa\x5b\x00\x2e\xee\x83\xe3\xb6\x14",
        b"\x71\x20\x8a\x87\xa4\xcf\x2b\x3a\x9b\x65\x47\x77\x73\xb0\x09\x6d\x45\x2d\xae\x60",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x0f\x2e\xdc\x87\xf4\xd2\x94\x2c\x46\x93\xb0\x64\xa5\x11\xb9\x3f\x79\x0c\x60\xdc\x14\x9a\x1b\x0b\x70\x41\xaf\x51\x83\xbc\x0f\x42\x23\x41\x34\xb2\x84\x27\x0e\x4c\x7e\x53\x61\x4f\x7e\xcf\xe7\x11\xde\x0e\xfb\x28\x33\x6d\x0b\xb3\x59\xc8\x6e\x8b\xe8\x83\x9f\x58\x32\x11\xe9\x17\x48\x32\xb3\xd4\x1e\xe6\xd2\x18\x64\xac\x61\x86\xfd\x1d\xb9\x20\xdd\xa6\x5b\x25\x96\x6c\x59\x51\xab\x8a\x20\x50\xdd\xa8\x7d\x1d\x72\xe3\x03\x28\x52\xad\x43\xda\x9f\xb4\x30\xe8\x50\x02\x2b\x4b\xb6\xcc\x9c\xb9\x0e\x42\x8f\x3a\x5c\xa3\x2a\x62",
        p,
        q,
        g,
        b"\x3a\x97\x8e\x90\x22\xa8\xf7\xa0\xca\xa9\x1f\x27\x5b\xf9\xcf\x76\x48\xe1\xb9\xa3\x1a\x07\x02\xd8\xac\xdb\xf5\x9a\xff\xb5\x46\x7f\xb0\x7a\x8f\x7e\x5b\x4c\x86\x77\x5a\xc4\xef\xb6\x09\xb9\x46\xf0\x5a\x3f\x13\x03\x4d\xb9\x4a\xcc\x64\x05\x7f\x90\x6d\x18\x54\x91\x0d\xe5\x38\xf8\x43\x67\x18\x1c\x61\x8e\x96\xc3\xf9\x22\x54\x7d\x40\x8e\xe6\x40\x8b\x7a\x70\xac\xed\xc7\x5d\xe8\xae\x44\x5c\x5d\x4d\xd5\xde\xf4\xa3\x52\xd2\x52\x82\x34\x07\x0c\xc7\x20\x70\x0c\x14\xce\x12\xd2\xf3\x69\x90\xd3\x6b\x29\xd7\xb0\x05\x96\xe3\x4b",
        b"\xb6\xea\x9c\xdb\x21\x1c\x45\x60\xb3\xd5\x92\xe9\x3a\xf6\xd5\xf1\x33\xb6\x4b\x9b",
        b"\x62\x42\xe4\x5a\x47\x2f\xa8\x14\x7c\xb5\x25\x3d\xbd\xde\xba\xe3\x1e\xf3\x1e\x4e",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xd1\x2f\xc1\x98\x3e\x00\x95\xe9\xe2\xb6\xb8\x74\x3f\xb3\x43\x86\xcc\x48\x21\x54\x0e\x3e\xfe\x1a\x29\xf8\x4c\xf7\xe6\x3e\x2a\x06\x68\xd5\x51\xf9\x12\xad\x22\x21\xb5\xa3\xd6\xb9\xeb\xd1\x21\x36\xde\xf5\xe6\x69\x0e\x1d\x32\xaa\xe9\x19\xf9\xf1\xcf\x5d\x24\xd6\x2a\x46\xa9\xa9\xa6\x04\xba\xe1\x1b\x9c\x08\x66\x35\x03\x67\x20\x4a\x92\x0b\x58\x9a\x31\x7d\xdf\xbb\x87\x7f\x9f\xad\x6b\x0d\x36\x29\xaf\x96\x35\xda\x46\x93\x31\x51\xc0\xd9\xa2\x0a\xaa\xbd\xdd\x3d\xf5\xd0\x49\x65\x9b\x28\x60\xdd\xb8\xb2\x09\x63\x26\x1e\xa0",
        p,
        q,
        g,
        b"\x10\xb7\xb1\x4a\xd2\x9f\xb3\x4d\x7a\x39\xf3\xe9\x53\x05\x1f\x45\x6a\x0c\xd1\x23\x3e\xf5\x4d\x90\xa4\xad\xc8\x2d\xfb\xd9\xfa\x7a\x85\x62\x8f\x11\x03\x96\x32\xb4\x7b\xa9\xda\xec\xa6\xe4\x63\xec\x46\x44\xf5\xe2\xa2\xa4\xbf\x95\xd3\x92\xe8\xc9\xc9\xf2\x87\xa2\x0b\xa4\x5a\x19\x88\x15\xca\x0e\x9b\xa8\x54\xd7\xf3\xc7\x9d\x90\x37\xfa\x14\x17\x72\x4f\xb7\xf0\x27\x99\xb1\xc2\xb2\xbc\xc7\x9d\x64\x36\x7b\x90\xc0\x6d\x17\x89\xdc\xc6\xde\x57\xca\x19\xfc\xef\xaf\xc0\x4f\xcc\xe2\x9c\x8f\x49\x5e\xd5\x64\xf5\xd9\xa1\x12\xca",
        b"\x36\x06\x17\x96\x5f\x65\xa6\x8a\xbc\xb8\x3d\xbf\x2d\x88\x6a\x1a\x10\xca\x05\xde",
        b"\x71\xab\xb6\xac\xbf\x7e\x65\x3d\x2e\xbc\x3c\xb7\x14\x9b\x51\xcc\x0c\x92\xfb\xa8",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x87\xa6\xdf\xb8\x48\x7f\x16\xf6\xfe\xf1\xd6\x8b\xc3\x14\x69\xac\x21\x0e\xa5\x53\x87\x96\x5b\xb4\x45\x8c\xa0\xd0\x0d\x6c\x46\x85\x8b\xe2\x8a\x01\x9c\xe9\x14\xc3\x9c\x24\x79\xf3\x21\xf0\x25\x2c\xa4\xa8\xbd\x68\x1a\x5b\x35\x8a\x09\x3f\xc8\x34\x1c\x31\xbc\x47\xc6\x18\x40\x3f\x93\x32\x2b\x44\x30\x84\xce\x58\x18\x49\x0b\x74\xe8\x3c\x38\x66\xb8\x16\x4b\xbc\xf7\x9b\xf8\x25\x39\xf4\x28\xc9\x35\x1c\x40\xb1\x0d\x77\x3c\xbe\x1c\xba\xa8\xc9\x80\x0a\x6d\xcf\x38\xd8\x55\x15\xe2\xdf\xf5\xd4\xf8\xa9\x65\xec\xae\xf3\x7e\x38",
        p,
        q,
        g,
        b"\x75\xef\x5d\x5f\x67\x02\x24\x26\xf5\x31\xe9\xb8\xca\x91\x15\x92\x1d\x5a\x5c\x44\x6b\xcd\xf1\xaf\x70\x1b\x60\x5b\xae\x68\x7d\xff\x8d\x1e\x7b\x3c\x4f\x8b\x28\x95\x37\xeb\x09\xa7\x46\x1d\x66\x88\xa3\x71\x19\x74\x37\x1a\x5b\x73\xa2\x08\x2e\x99\x14\x10\x11\x86\x66\xcc\xd9\x4f\x44\x49\x77\xd0\xc8\x9b\xa3\x61\x62\xde\x02\x3a\xa5\x19\x03\x7a\x6b\xa6\x30\x54\x17\xda\xd3\xf2\xdc\x38\x75\x6a\x40\x04\x64\x91\xe8\xee\x80\xc4\xf1\x47\x82\x5b\x8c\x02\x1b\x5d\x09\xa2\x42\x2d\x39\xd7\xc4\xab\xc3\x95\xf6\xc2\xd7\x90\x3c\x66",
        b"\x54\x09\xcd\x62\xf5\x53\x93\x06\xae\x8c\x93\x60\x82\xee\xf9\x32\xc6\x50\x5c\x39",
        b"\x07\xc0\xcc\xb3\x0e\xc9\x0b\x14\x81\x40\x9c\xbf\xa2\xf5\xde\x6c\xfa\xf1\xef\xc5",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xa3\x32\xb3\x8e\x64\x2b\xca\xd8\xbd\x27\x1f\x77\x6f\xff\x24\xa7\x31\x72\x4a\x43\x40\x0c\x16\x14\xf5\xe2\x12\x96\xdb\x04\xf7\x25\xee\xba\xd2\x8d\x62\xe2\x0c\xa3\xf7\xf1\x83\x28\xa7\x6b\x80\x92\xd9\x7b\x63\x2b\xb7\x87\x18\xf0\xf2\xf9\xec\xc7\xc1\x2c\xc3\x6b\x50\x59\x59\x91\x7b\x5c\x54\x31\x2a\xd4\x71\x7b\xe8\x4f\xa8\x40\xb9\xf0\x6d\xe0\x05\xc7\x92\xaf\x3e\x9e\xa7\x2b\x7a\xe2\xe3\x42\x3d\x07\xc7\x81\xc9\xc2\x55\x3f\x89\x95\x54\xa0\xd8\xde\xc9\xa2\x85\xc1\xee\x25\x16\x0f\xa2\x78\x48\x94\x74\xa0\xe4\x37\x95\x16",
        p,
        q,
        g,
        b"\x41\xcc\x1d\x6d\x9e\x0c\xf5\xf1\x58\xda\xb5\x99\x11\x4f\x3e\xe4\x73\x8f\x19\x7c\xf2\xc9\x56\xb6\xbb\x0d\xdd\x6d\xfd\xcf\x5e\x4d\xb3\x99\xaa\xcc\x16\xc5\x38\x94\x8c\x4b\x50\xde\x85\xba\xd6\xd9\x16\xdb\xc4\x15\xba\xd2\xf6\x73\x70\x23\xfc\x70\x63\xc1\x33\xbd\x0c\x42\x31\xd6\xb3\x3c\xe8\x13\xc0\xd6\x02\x4d\x13\x15\x26\x95\x71\xb2\x55\x4b\xbb\x2e\xdf\x2a\x99\x10\x8a\x43\x59\xe8\xe2\x3b\xf8\xa1\x43\xbf\xc5\x38\xab\x9f\x88\x42\xcd\x4e\x92\x59\x68\xf4\x9a\xc5\x6a\x02\xe3\xf0\x67\xe2\x60\x01\xe5\x20\x7b\xcb\x56\xd4",
        b"\xa1\x6a\x73\x08\xa6\x82\x4d\x92\x9b\x6a\x9a\x3b\xdb\x28\x0d\x15\x1a\x6e\xed\x81",
        b"\x7a\x42\xad\xda\xb7\xdd\xb9\x80\x00\x28\x60\x44\xd9\x99\x3d\x5c\xf8\x18\xf2\xb1",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x79\xb1\x44\xd5\x0e\x00\x47\x59\x6c\xf0\x6b\xfc\xb3\xe9\xce\x39\x59\xec\x4b\x8c\xc9\xba\x01\x43\x4f\xc3\xf6\x8f\x47\xc8\x68\xce\xa0\x48\xb9\x90\xe6\x2c\xd7\xa5\x0e\xee\x28\x8b\x35\xae\x62\xaa\x79\x79\x24\xc9\xdc\xab\x76\x40\x9b\x86\x9b\x33\xde\x28\x88\x5e\x62\xf1\x7d\xb7\xa7\x75\x89\x73\x48\x29\x68\xb9\xf9\x60\xeb\x2d\xba\x84\xae\x85\x10\x1a\xa6\xc6\x14\x1b\x3f\x08\x39\xa4\x18\x5a\x4c\x49\x6e\xae\x87\x6e\xcd\xc4\x56\x27\x33\x0d\x36\xf0\x1a\x67\xcb\xb7\xfa\xef\x83\x43\x57\x33\x0a\xac\x36\xc7\xc6\xf4\x7a\xc9",
        p,
        q,
        g,
        b"\x74\xdb\x74\x60\xc5\x19\x19\xa9\xe8\x7b\x43\x0d\x10\x5d\x86\x36\x2e\xe4\xac\xd9\x68\x2b\xf6\xc9\xfe\x87\xd9\x95\x6c\x2f\x5f\xf1\x7d\x95\x93\x0c\xcc\x12\xf7\xe9\x2d\x8b\xcb\x6a\xf5\xf7\xef\x18\x48\xda\x8d\x15\xc9\x15\x20\x82\x47\x7d\xe9\x95\x94\x78\x1b\x99\x8d\xaa\xfb\xf8\xae\x4a\xf2\x37\x72\x12\x5c\x19\xe1\x66\x42\x1f\x80\x6b\xd0\xfb\xea\xc3\x65\x07\x6e\xcd\x9e\x15\x43\x2a\xd4\xac\x25\x23\x41\x8f\x6e\x41\x0c\xbf\xcb\xc5\xa7\x1a\x0e\xdf\x22\xe6\x94\xa6\x7d\x14\xb9\xcf\xc9\x72\x2b\xc4\xbd\x8c\x43\xe2\x2a\x91",
        b"\x02\x1a\x3d\xe9\x8c\x3d\xa6\x98\xb4\x77\xb4\xc3\xd5\x0b\x21\x69\xe6\x5f\x5e\x91",
        b"\xaf\xd7\x64\x31\x8d\xd0\xfe\xe0\x4f\xd6\xb0\x7f\x55\x03\x20\x78\x9c\xd9\xbf\xa5",
    )?;

    // [mod = L=1024, N=160, SHA-256]
    let p = b"\xcb\xa1\x3e\x53\x36\x37\xc3\x7c\x0e\x80\xd9\xfc\xd0\x52\xc1\xe4\x1a\x88\xac\x32\x5c\x4e\xbe\x13\xb7\x17\x00\x88\xd5\x4e\xef\x48\x81\xf3\xd3\x5e\xae\x47\xc2\x10\x38\x5a\x84\x85\xd2\x42\x3a\x64\xda\x3f\xfd\xa6\x3a\x26\xf9\x2c\xf5\xa3\x04\xf3\x92\x60\x38\x4a\x9b\x77\x59\xd8\xac\x1a\xdc\x81\xd3\xf8\xbf\xc5\xe6\xcb\x10\xef\xb4\xe0\xf7\x58\x67\xf4\xe8\x48\xd1\xa3\x38\x58\x6d\xd0\x64\x8f\xee\xb1\x63\x64\x7f\xfe\x71\x76\x17\x43\x70\x54\x0e\xe8\xa8\xf5\x88\xda\x8c\xc1\x43\xd9\x39\xf7\x0b\x11\x4a\x7f\x98\x1b\x84\x83";
    let q = b"\x95\x03\x1b\x8a\xa7\x1f\x29\xd5\x25\xb7\x73\xef\x8b\x7c\x67\x01\xad\x8a\x5d\x99";
    let g = b"\x45\xbc\xaa\x44\x3d\x4c\xd1\x60\x2d\x27\xaa\xf8\x41\x26\xed\xc7\x3b\xd7\x73\xde\x6e\xce\x15\xe9\x7e\x7f\xef\x46\xf1\x30\x72\xb7\xad\xca\xf7\xb0\x05\x3c\xf4\x70\x69\x44\xdf\x8c\x45\x68\xf2\x6c\x99\x7e\xe7\x75\x30\x00\xfb\xe4\x77\xa3\x77\x66\xa4\xe9\x70\xff\x40\x00\x8e\xb9\x00\xb9\xde\x4b\x5f\x9a\xe0\x6e\x06\xdb\x61\x06\xe7\x87\x11\xf3\xa6\x7f\xec\xa7\x4d\xd5\xbd\xdc\xdf\x67\x5a\xe4\x01\x4e\xe9\x48\x9a\x42\x91\x7f\xbe\xe3\xbb\x9f\x2a\x24\xdf\x67\x51\x2c\x1c\x35\xc9\x7b\xfb\xf2\x30\x8e\xaa\xcd\x28\x36\x8c\x5c";
    test(
        HashAlgorithm::SHA256,
        b"\x81\x21\x72\xf0\x9c\xba\xe6\x25\x17\x80\x48\x85\x75\x41\x25\xfc\x60\x66\xe9\xa9\x02\xf9\xdb\x20\x41\xee\xdd\xd7\xe8\xda\x67\xe4\xa2\xe6\x5d\x00\x29\xc4\x5e\xca\xce\xa6\x00\x2f\x95\x40\xeb\x10\x04\xc8\x83\xa8\xf9\x00\xfd\x84\xa9\x8b\x5c\x44\x9a\xc4\x9c\x56\xf3\xa9\x1d\x8b\xed\x3f\x08\xf4\x27\x93\x5f\xbe\x43\x7c\xe4\x6f\x75\xcd\x66\x6a\x07\x07\x26\x5c\x61\xa0\x96\x69\x8d\xc2\xf3\x6b\x28\xc6\x5e\xc7\xb6\xe4\x75\xc8\xb6\x7d\xdf\xb4\x44\xb2\xee\x6a\x98\x4e\x9d\x6d\x15\x23\x3e\x25\xe4\x4b\xd8\xd7\x92\x4d\x12\x9d",
        p,
        q,
        g,
        b"\x4c\xd6\x17\x86\x37\xd0\xf0\xde\x14\x88\x51\x5c\x3b\x12\xe2\x03\xa3\xc0\xca\x65\x2f\x2f\xe3\x0d\x08\x8d\xc7\x27\x8a\x87\xaf\xfa\x63\x4a\x72\x7a\x72\x19\x32\xd6\x71\x99\x4a\x95\x8a\x0f\x89\x22\x3c\x28\x6c\x3a\x9b\x10\xa9\x65\x60\x54\x2e\x26\x26\xb7\x2e\x0c\xd2\x8e\x51\x33\xfb\x57\xdc\x23\x8b\x7f\xab\x2d\xe2\xa4\x98\x63\xec\xf9\x98\x75\x18\x61\xae\x66\x8b\xf7\xca\xd1\x36\xe6\x93\x3f\x57\xdf\xdb\xa5\x44\xe3\x14\x7c\xe0\xe7\x37\x0f\xa6\xe8\xff\x1d\xe6\x90\xc5\x1b\x4a\xee\xdf\x04\x85\x18\x38\x89\x20\x55\x91\xe8",
        b"\x76\x68\x3a\x08\x5d\x67\x42\xea\xdf\x95\xa6\x1a\xf7\x5f\x88\x12\x76\xcf\xd2\x6a",
        b"\x3b\x9d\xa7\xf9\x92\x6e\xaa\xad\x0b\xeb\xd4\x84\x5c\x67\xfc\xdb\x64\xd1\x24\x53",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xc1\xb1\xf1\x47\x2f\x08\xdf\x38\xa5\x2a\x55\xba\x55\x82\x7b\xa3\xb7\xcd\xd6\xbe\xde\xd9\x04\xfc\xd5\x26\x10\xc8\x99\xed\xa3\xc6\x16\x82\x65\x68\x73\xbb\xfa\xab\x0d\x90\x74\x95\xda\xcf\x45\x8e\xa3\x45\x0a\xfd\x93\xbe\x96\x7a\x37\x43\x4d\x41\x2b\x63\x25\x66\x9a\xd8\x4b\x4e\xaa\x27\x8a\x24\x87\x0e\xcc\x2d\xf0\xda\x13\xad\x52\x6a\x9e\x66\x69\x95\x8d\x4e\x52\xdb\xfb\xa2\x80\x3a\xe9\xae\x13\x5d\x0c\x0a\xcc\xa8\x6a\x04\xc4\x2b\xa9\xca\xfb\x09\xb7\xaf\x96\x34\x71\x88\x88\x0b\x08\x61\x69\xeb\xdf\x9f\x1f\x5f\x31\x73",
        p,
        q,
        g,
        b"\x99\x18\x74\x98\x53\x4f\x31\x3d\xc7\xcd\x7f\x3a\x48\xd6\x2b\x23\x35\xbc\xdc\x36\xf0\xdc\x98\xdb\xf8\x45\xdc\x60\x85\xc2\x67\x47\x4c\x36\xfd\xfc\xa3\x88\x54\x21\x98\x30\xe6\x14\xbb\xca\xb2\xbb\x9d\xec\xb8\x1e\x86\x12\x4b\xd7\x8f\x86\xd4\x71\xbd\x84\xbe\x06\xac\x1f\x0f\x41\xfe\x5b\x4b\x37\x40\xb2\x10\x7e\x0c\x9c\x48\xf8\x1e\x31\xe9\xbf\x55\x0d\x96\x56\x4d\xd3\x80\xca\x47\xa1\x1d\x72\xf0\xd0\xa3\x27\x5f\x07\x5f\x95\xbb\xd5\x98\x69\xc1\x4d\xc9\x12\xa1\xcb\xcf\x01\xdb\x9f\xb7\xf7\x10\x15\xcc\x14\x99\x86\x82\x5e",
        b"\x54\xed\x4e\xfa\xec\xdf\xc7\x8d\x02\x64\x71\xb6\x5c\xfe\xfc\x65\x29\x94\x5b\xbf",
        b"\x6d\x6d\xac\x29\x6e\xbd\xe3\xf8\x73\xb7\x51\xc6\xb1\x48\x43\xf0\xb7\xbe\xfd\xff",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xb8\x0a\x47\x07\x1d\x13\x76\xfe\x61\x7e\x59\xfd\xc0\x05\xa8\x90\x36\x9a\x4c\xa5\xe6\x78\xff\x46\xeb\x9b\x20\x5d\x6e\xc0\x9c\xbd\x49\x37\x3b\xb3\x41\xfe\x78\x13\xee\x44\x2a\x6e\xce\x17\xe7\x20\xbf\x71\xa7\x45\x57\xac\x9a\x37\x5c\x05\x9e\x55\x35\xe7\x73\xa4\x5e\x79\xe1\xbf\xf3\x46\x5a\x38\x86\xc8\x6e\x2a\x2b\xc8\x82\xf0\xbe\xce\xef\xff\xb2\xae\x1a\x52\x2f\x13\xc8\x2d\xef\x4c\xfd\x0c\xfc\xa6\xfc\xee\xb4\xce\xce\x71\x86\x9e\x90\xcd\x10\xd0\xaf\xf2\x7a\x84\xb5\x60\x1d\xaa\xe0\x61\xcb\xeb\x3a\xa6\x2b\x37\xfd\x3a",
        p,
        q,
        g,
        b"\x91\xf5\x02\x70\xa7\x54\x05\x5e\x5d\xa6\x11\xc7\x20\xa4\x26\x2f\x3c\xb8\xbd\x41\x61\xf7\x7d\x07\x40\x16\x04\xd3\xd1\x16\x5e\x45\x51\x8f\x7e\x19\x01\xad\xef\x66\x28\xf2\x3d\xc4\x82\x71\xd3\x5f\xf4\x92\xaf\x8d\x62\xaa\x53\x8c\x0e\x77\xe0\x42\xf2\x3a\x52\x2f\x22\x14\xe6\x21\x14\xbf\xee\xa4\x6a\xe8\x88\x8b\xda\xda\xcd\xaa\x0a\x9a\x5b\x50\x3d\x79\xc2\x3e\x4c\x20\xc9\x8b\xd4\xeb\xb3\x6f\x95\xbf\x44\x51\xcc\xb0\xb5\xbb\x44\xdf\xd0\x11\x34\x1c\xfa\x29\xa9\xe1\x56\xa3\xcd\x82\x8e\x12\x6e\x68\xcb\x91\x1e\x8f\x9d\xc0",
        b"\x1f\xc2\xd1\xcb\x80\xbf\x6e\x0e\x78\xb2\x5f\xac\x29\x3b\x75\x2c\xbf\xf2\xb5\xac",
        b"\x75\xbc\xc7\x72\xf7\x73\xd5\xfd\x98\xdd\xe1\xf9\x07\xe7\xec\x2c\xba\x20\x1d\xfb",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xa9\x60\x30\x54\x46\x58\x87\xdf\x15\xdb\x07\xc0\x70\x9a\x8c\x87\x8d\x2f\x1a\xbd\xcf\xc6\x19\x5e\xab\xf3\xe9\xb3\xad\x07\xe8\x55\x8b\x99\xcc\x4a\x7a\xa0\x76\xda\xf6\x7e\x9b\x7d\x84\x80\xf1\x1e\x8a\xfb\x18\xe2\xac\x56\xa9\x54\x7b\x48\x45\x3f\xed\xca\x32\xda\x9e\xb0\xc2\x92\x71\xeb\x60\xf0\xa1\xd9\x5c\x18\xf4\x2d\x99\x23\x94\xb3\x26\x4f\xf3\xe2\x1e\x60\x6e\x0b\xea\xc0\x8a\x7b\xa7\x1b\x8e\x57\x95\xa8\xda\x98\x51\x18\xe4\x32\xcf\x5b\x30\xb6\xcd\x3a\x60\x3d\x8b\x0d\x58\x0f\x06\xc6\x26\xee\x93\x7c\x6c\xd0\x5f\x40",
        p,
        q,
        g,
        b"\xa2\xc4\x56\x9a\x30\x14\x73\xae\x4f\x16\x4d\x68\xb9\xa3\xc6\xeb\x70\x5a\xe8\x1f\x75\xd6\xe5\xcc\x30\x70\xa5\x59\xcc\xcb\x8b\x1a\x2d\x8c\x21\x09\x0e\xd7\x0e\x61\x67\x0c\x7e\x9d\xbf\x5f\x75\x5a\x37\xd5\x8d\x3a\xbb\x34\xc2\xdf\xd4\x0d\xb9\xf2\x6f\x68\x68\xd0\xdd\x91\xbe\x98\xf3\x95\xac\x0e\xbd\xc3\x7e\x1b\x54\x23\x80\x2b\xea\x7a\x6c\xb1\x96\xd7\xe0\xf9\x3d\xb9\x2f\x66\x3b\x6c\x9c\x72\x6e\x80\xfe\xb2\xe9\x22\x71\x54\xce\x1c\x15\xf8\xe8\xdf\x93\xec\x0d\x37\xfa\x47\xe5\xfa\x11\x2b\xb0\xa4\x8f\x4a\x23\x9d\x60\x52",
        b"\x48\x53\x95\x23\x81\x5b\xd8\xd7\x3c\xe7\x02\x36\x7c\x77\x12\xb9\xb1\x38\x67\xf2",
        b"\x20\xff\x4c\xfe\xf8\xa6\x68\x82\x9f\xea\xe7\x3b\x52\x0e\x8a\xa4\xd0\x2c\x81\x68",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x19\xeb\x08\x8c\x32\x29\xa4\x4f\x95\x86\xf0\x04\x21\xcf\xe7\x42\x3a\x48\x6d\x5f\x7e\x28\xad\x2c\x91\x19\xdd\x2e\x13\x95\xdf\x1a\xcc\x06\xcb\x28\xe9\x06\x9c\xee\x62\xf0\x9f\x48\xe4\xca\x29\x26\x9d\xd8\x9d\xf9\xfe\xc1\xff\xdf\x64\xb1\xfe\x27\x17\xfe\x52\xb1\x42\x1f\xcf\x6c\x70\x5c\x0c\xf3\x99\x30\xf9\x0e\xcb\x33\x9b\x51\xef\x95\xb2\xef\x38\xa6\xd9\x6a\x57\x5f\x7b\x36\xf5\xed\xf4\xf2\xcb\xd6\xd2\x61\xe1\xfd\xd7\x7d\x44\x59\x28\x8c\x02\xe6\x8c\x82\xa3\x91\x0f\xf8\xca\x17\x47\xc8\x6b\xb1\x87\xd5\x20\x5f\x51\xa8",
        p,
        q,
        g,
        b"\x49\xe6\x06\xaa\xd5\xd2\xe5\x4e\x1b\xae\x25\x17\x91\x5c\x66\x0b\xa3\x0e\xc4\xfd\x28\xd7\x18\x61\x3a\x7c\x84\x46\x4b\x0f\x44\xbc\x6d\x54\x6e\x5a\x9b\xc1\xdc\x60\x42\x3b\x45\xdd\x01\xec\x29\x55\x64\xec\x08\xf2\x9d\x68\x87\xe6\x9f\x68\x9d\x6b\x34\x88\xf9\xda\x5d\x5a\x60\xf3\x9c\xdd\x5a\x15\x8d\x51\xa3\xd0\x73\xb2\x22\x5f\xea\x55\x9e\x58\xbb\x22\x2e\x29\xa8\x7b\x5f\x0f\x5a\xb3\x1d\xd7\xc0\xce\xaa\xd8\x87\x07\x0d\xac\x95\x5d\x28\x97\x36\x07\xa9\x9e\x46\xdd\xd7\x73\x7b\xea\xb6\x51\x99\xf2\x50\xd7\xf0\x3b\x65\x83",
        b"\x6b\xf4\xf5\xd3\x25\x12\x01\x05\x9e\xe8\x5e\xdb\x99\xa6\x7a\x70\x6f\x37\x19\x7d",
        b"\x31\x25\xc5\xaf\x39\x77\x59\x99\x6b\x87\x6c\xb5\x85\x7b\xe2\x63\x2a\xaa\xf3\xb6",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xad\xdb\x5a\x04\x5c\x9f\x4f\x4f\xb9\xeb\x5e\x5d\xb4\x4d\x65\x15\x98\x0c\x9e\x08\x80\x15\xb6\x85\x93\xd8\xbc\xbf\xfc\x6f\xf5\x7f\x18\x86\x5a\xb8\x24\xd3\xd1\x58\x64\x25\xcb\x50\x81\x19\x7e\x9e\x01\xcb\x72\x97\xb0\x6b\x64\x10\x3c\xea\x43\x7e\xee\xec\x9c\x50\x79\x86\x79\xfb\x86\x9e\xc3\x06\xa7\x25\x75\x05\x7f\xd3\x68\xae\xb0\xf6\x74\xa2\x9c\x3a\xc2\x48\xb6\xa0\x8f\x91\x33\x1d\x84\x56\xd0\x62\x02\x53\x47\xc1\x2a\x0a\x61\xc6\x1f\x76\xe5\x20\x6f\xe6\xca\x43\x77\x35\xaf\x43\x0d\xea\x7c\xc8\xf3\x9f\x1a\x5b\x75\x05",
        p,
        q,
        g,
        b"\x22\x1c\xed\x57\xa9\x13\x25\xb1\x0f\x8d\xcd\x12\x20\xb1\xaf\x68\xf8\xda\xf3\x97\xf4\x19\xa4\x3b\xbd\x8f\xbe\x64\x43\x11\x75\x5b\x11\x1a\xae\x52\x57\xc6\x42\xfa\xfd\x83\xb0\x47\xa1\xf5\x6f\x2a\x82\x9f\xcd\xf4\xdf\x3e\x5d\xcc\xb2\x36\x45\xb2\x8c\x0a\x34\xc6\xe8\xa6\x50\xef\xcd\xfa\xdd\x48\xfe\xa4\x67\xcc\x94\x3c\xa4\xe7\x37\x88\x29\x30\x07\x13\x83\x8b\x6c\x71\x09\x62\xba\x72\xe7\x90\xc1\x0a\xb8\x79\xa0\x1f\xe1\x45\x7e\xa3\xdd\x4b\x7c\x3c\x3a\x54\x2e\x35\x22\xa7\x5d\x0d\xb2\x61\xe5\x76\xcd\x3f\x22\xc9\x98\xe4",
        b"\x7c\xc6\x62\xe3\x52\xe0\xee\xde\x85\x14\x01\x07\xa7\x77\x3a\xd8\x66\x3e\x70\xbd",
        b"\x15\xc1\x7b\x9d\x24\x58\x72\x84\x4e\xaa\xc3\xd4\x6b\xb0\x8c\x3e\x08\x59\x74\x23",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x02\x70\x9d\x2b\xe0\xd9\xdc\x1d\xc0\xeb\xc5\x5f\x63\x0d\x91\xfa\x23\x60\x9f\x61\xb5\x13\xc2\x27\x57\x66\x03\x4d\x8f\x40\xe8\x19\xaa\xf9\x32\x6c\x8d\xb3\x7c\x35\xc5\xa1\x7e\x96\xbc\x95\x6d\xf6\xd1\x1b\x55\x8d\x16\xd9\x18\x71\xaf\xc0\x10\xb3\x11\x9c\x57\x98\xc2\xe2\x94\x11\xff\x4f\x0d\x71\x96\xe7\xe4\x76\xbf\x0a\xd0\x3b\xf7\x2e\x89\x7f\xed\x87\x3c\x10\x61\x3d\xd2\x55\xd1\x52\x43\x87\x0b\x81\xcd\x87\xd0\xab\xc1\x6e\x14\x0d\x03\x2f\xe5\xbd\x1c\x8e\xeb\x2f\x66\xe0\x4d\x13\xd4\x92\x69\xfc\x7d\xa6\xb6\x5a\x7c\x1c",
        p,
        q,
        g,
        b"\x9e\x93\xbc\x03\xe6\xe8\x15\x30\x87\x34\xe3\xb8\xf1\xd1\x06\x96\x1b\xeb\xdf\xf1\x0a\x52\x53\x03\x25\x7a\x05\x3d\xea\x4d\xa6\xdc\xf5\x04\xc7\x83\x9b\x54\xd5\x75\x22\xf2\xac\xb3\xaa\xc9\x59\xff\x4a\xe8\x61\x00\x22\xca\x5a\x1e\x68\x82\x32\x33\x6c\xa1\xee\x8f\xd7\x02\x8b\xf7\xb6\xe9\xee\xdf\x8a\x4b\x0d\x09\x89\x69\xf5\xe5\xfd\x3d\x93\x00\xc3\x40\xe7\xf1\x9f\xd4\x71\xa4\x51\xaf\xb9\x2e\xd4\x82\x9f\xa4\xd9\x02\x49\x14\x4a\xa3\x63\xdc\x18\x80\x7b\x3e\x29\xd2\x7e\x6e\xc3\xda\x73\x6c\x33\xb1\x85\x51\x1b\xb3\xaa\xa0",
        b"\x72\xb0\xbc\xc6\xde\xfa\x66\xfa\x8b\xab\x02\x96\x76\xa1\xc7\x70\x3f\x96\x08\xf2",
        b"\x69\xd9\x11\xe0\x5a\xcd\x7b\xe5\x2f\x28\x34\xc0\xaa\x00\x51\x28\xe7\xfa\x85\xb8",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xcc\x06\x1e\xdb\x31\xc3\x4d\x39\x81\x51\x7f\x4d\x89\xaf\xbe\x98\x0f\x74\x18\x52\x60\xcf\x48\xb3\x04\x3b\xc1\x3a\x14\x49\x44\xad\x43\xe0\xe5\x76\xd2\xa5\x8b\xf5\x89\xcc\x02\x1d\xc1\xc1\xd3\x32\xc4\xd7\x68\x96\xea\x77\xdd\xa1\x97\xf6\x83\xe5\x1e\xed\x71\xb4\xd6\xdf\x46\x66\x6a\x1b\x14\x2e\x67\x9b\x02\x83\xcf\x33\x9e\x5b\xca\x90\xe2\xff\x9c\x34\xdd\x5f\xd7\xcc\x49\x17\xd6\x67\x04\xfe\xe4\x36\x4f\x76\x93\x10\x1d\xc7\x66\x70\x71\x04\xef\xb2\xb9\x33\xc4\x84\x8b\x93\xe1\x3f\x94\x85\x5f\x75\xe4\xfd\x75\x6c\xb6\xe3",
        p,
        q,
        g,
        b"\x5d\x7d\x2e\x34\x21\x54\x98\x3e\xbc\x20\x15\xbc\x67\x50\xf9\x87\x6f\x56\x89\xca\x0a\xda\x85\x29\x90\x8e\xd4\xfd\xbc\x59\x6b\x97\x2c\x5c\xc6\xd5\x3e\x80\xa8\xad\x8a\x8c\xed\xf3\xce\x64\xb6\x2a\x75\xdb\x44\x1c\x96\x20\x7f\xc7\x47\x7e\x3f\x7b\x9f\x10\xdf\x28\xe0\xcc\x2f\xb7\x73\x83\xe7\xca\x4c\x51\x50\xf7\x12\xdd\x82\x3c\x23\x09\xf0\x16\x1b\xe0\xbd\x5e\xed\xd6\x0c\xf6\xba\x23\x08\x61\xa0\x8b\x9d\x9a\x74\x68\x43\x8b\x4d\x6e\xc6\x73\xd2\x8a\x54\xd8\x3c\x70\x10\xd5\x06\x31\xe5\x5f\x0a\x02\x83\x2a\xbc\x5a\x0a\x46",
        b"\x21\xf5\x12\x42\x56\x70\x94\x34\x77\x53\x4e\x90\x75\xce\xb5\xb7\xd6\x3f\x20\xdf",
        b"\x73\xc6\xf6\xf8\xde\x3a\xae\xa5\x20\xa0\x83\xb2\x26\x42\x99\xe8\x1c\xfc\x91\xc5",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x79\xd5\x29\xe4\x0c\x2b\xa4\xe5\xb9\xc7\xd7\x7d\x72\x07\x6f\x1f\xd9\x49\x09\x28\xff\x44\x19\xc8\x24\xe6\x4d\xb8\xfb\x9a\x05\x1e\x01\xe8\xe1\x73\xc6\xf2\x14\xe0\xe9\xe6\x45\xed\x25\x0b\x6d\xaa\xa6\xf8\xc1\xa5\xcc\x90\x0d\x52\xcf\x3e\x1e\xfb\xfe\xa2\x57\x48\xe8\x9a\x1a\x54\x8c\x73\xe2\xd1\x10\xb2\x5f\x53\x08\xbc\xf7\x57\xb2\x13\x52\x16\xc9\x1d\xca\x27\x83\x33\x2c\x0d\x79\x03\xeb\x21\xc2\x26\xdb\xd3\x3a\x69\xee\xf5\x75\xaa\x8a\x41\xcb\xbd\xcd\x1b\x3d\x94\x92\x8a\xa8\xf8\xba\x58\xc5\xce\x0d\x31\x77\x86\xe8\x7b",
        p,
        q,
        g,
        b"\x28\x2d\xec\xc0\xe3\x79\x94\xc2\x85\x6e\x61\xf3\x6b\x83\x1b\x61\xbd\xc0\x2b\x7c\xa6\x75\xdb\xc3\xc2\x03\x28\x00\xb7\xef\xd3\xb7\x11\xac\xf1\x4c\x88\x69\x96\x88\x31\xe1\x45\x36\x1b\xf2\x18\x2b\x06\x0e\x48\x38\xf0\x7d\xc6\x1f\x76\x58\x4c\xf1\x02\xa9\x13\xbb\x28\xa5\x2c\x73\x17\xaf\x5f\x9d\x23\x22\x92\x7c\x96\x66\xe5\xe8\x7c\x2f\x2b\xfd\x2f\x18\x1d\xd3\x26\x12\xd7\xb2\xb2\xa6\x45\xbf\x1a\x47\xc0\xeb\xfd\x79\xa9\x40\xf6\x27\xa6\x68\xa8\xf2\xeb\x72\x9f\xd0\x51\xaa\x2c\x65\x9a\xbc\x91\x8e\x55\x71\x99\x4e\x65\x93",
        b"\x92\x9a\x48\x51\xbe\x0a\xe4\xba\x91\xda\x0e\x6c\x73\x76\xd7\x1d\xf7\x59\x2d\xbb",
        b"\x7e\x6b\x65\x04\xb7\x48\xef\x00\x24\xd9\xd2\xa2\xe6\xf3\xbc\xd7\xcf\x13\x5a\xc7",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xf5\x51\x64\x10\x70\x63\x23\x54\x9b\x20\xc5\x2d\xaf\xa2\xf2\xf9\x07\x99\x78\x6c\x0d\xdb\x85\x04\x88\x92\xcc\xc1\x87\x20\xdc\xe5\xc1\x29\xa1\x0e\xb4\x38\x87\x88\xa3\xd9\x7a\x03\xb0\x00\x17\x99\xcb\x65\xa7\x9c\x88\x08\x36\xbc\x9f\x32\x04\xea\x75\xa5\x77\x20\x4d\xc1\xe2\x89\x4c\x57\x2a\x25\x8f\x9e\x51\x7c\xa3\x7c\x5b\x79\x1e\x48\xb2\x7c\x8d\xc1\xc8\x21\xb3\x4e\xbb\x1f\x29\x85\x8c\x4a\x72\xa0\xd5\x17\x2c\x56\x5e\x9d\xbe\x1b\xdd\xdf\x6e\x02\x48\x91\xcd\x62\x91\xfa\xa8\x1e\xd5\x65\x74\x6c\x61\xc2\xed\xa2\x01\x1f",
        p,
        q,
        g,
        b"\x74\xcc\xc6\xeb\x83\xad\xbc\xba\xd0\xfc\x37\x14\x4d\x9b\xfb\x85\xfd\xcc\x85\xab\x92\xc9\xf8\x87\x7c\x9c\xda\x66\x25\x1d\x1a\xff\x2f\xb2\x24\x88\x8d\xdd\xb7\xd7\x72\xa8\xb7\x38\xc5\x3e\x03\xec\xad\x99\x03\x79\x6f\xa3\xc9\xc6\x02\x4d\x06\x36\x7e\x08\x70\xad\x79\x76\x94\xf5\x98\x70\x8d\x08\x91\x2c\x0f\xe0\x98\x81\x76\x3a\x0a\x72\x2d\xda\x95\xd9\x4e\xee\x88\x24\x92\x7c\xbf\xa6\x76\x1a\x79\xa0\x38\xaa\x6d\x33\x1d\xa3\x4d\x9b\xd5\xc5\x83\x3c\x94\xc5\x26\xa8\x6a\xf1\xcd\xfb\x2d\x40\x79\xd2\xdb\x6d\x0b\x9a\x12\x38",
        b"\x27\xb3\xf2\x35\xe4\xaf\xc1\x8c\x66\x13\xb4\xfa\x7f\x27\xd7\xa8\x26\x2b\xa4\xc0",
        b"\x8b\x22\x63\x4e\x4d\x45\xb7\x1a\x84\xea\xba\xa1\xe5\xa4\xbf\x1e\x37\x33\x7a\x59",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x55\xbd\x15\x26\xe0\x8f\x64\x43\xb2\x55\xac\xd3\x2c\x28\x68\x07\x54\x2d\x34\xc0\xf3\xd7\x98\x92\x71\x3f\x9d\x6d\x6d\x6b\x3b\xe7\x07\xe4\xaf\x6e\x71\xf7\xda\xb4\xa2\xc5\xf6\xbd\x25\xf5\xae\x1f\x51\x4b\x26\x44\xa4\xcd\xaf\xce\xce\x1e\x58\xf7\x57\x6f\x82\xe2\xab\x0a\xf2\x32\x6c\x71\x27\x9e\x9b\xce\xf1\xe1\xc5\x4a\x76\xfa\x77\xec\x2b\x2d\x05\x67\x17\x64\x57\x64\xe7\x99\x1b\x52\x0b\x0e\x5a\x1b\x04\x91\x09\x51\x9b\x22\xaa\x52\x04\xe3\xed\x53\xb1\xe0\x95\x7d\xab\x5e\xc3\x24\x79\xd0\x6a\xc3\xe1\x1a\x5d\x1c\xbd\x03",
        p,
        q,
        g,
        b"\x5d\x6e\xdf\x6d\xb6\xe6\xc2\x7e\x80\xa7\xf0\x25\x97\x23\x79\x19\x17\x0b\x49\x36\x48\x9d\x6f\x15\xf5\x98\xb8\x20\xcd\x91\x7e\x17\x25\x09\xb7\xe2\x87\xb8\x8b\x0c\xc1\x4e\x1a\x01\x86\x79\x38\x86\x80\x9a\xb4\x17\x02\x09\x98\x70\x95\x09\x22\x34\xb4\xfd\xc4\x4b\x3d\x1f\xc1\x6e\xeb\x2e\xfa\xf8\x52\xed\x39\x16\x69\x8c\xf9\xec\xa4\x61\x2b\x49\x61\xbb\x6e\x20\xc3\x2e\x18\x84\x69\x88\x3f\x97\xf4\x9e\x29\xa8\x19\x7c\x30\xd0\x72\x3b\xab\xb0\x6d\xea\x70\x4f\x77\x04\xb2\x78\x8e\x57\xd7\x6d\x6d\x9a\x3c\xfa\x68\xf6\xc7\x83",
        b"\x62\x1a\x29\x09\x30\xac\x43\x67\x37\xa7\x2f\xb4\xc6\x2b\xf5\xc4\xb6\x74\x81\xaf",
        b"\x62\xdb\x20\xf8\x2a\x57\x54\xf1\x09\xf7\xa2\xce\x58\x1d\x4c\x8d\x71\xc6\x8d\x29",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x62\x78\x9a\x89\xf0\xd7\x08\xe2\x1a\x12\x1f\xc3\x40\x09\xaf\x88\x41\x33\x68\x1b\x9d\x4a\x66\xcc\x36\xc0\x36\x5c\x34\xbe\x72\xa4\x98\x2e\xb0\x96\x1c\xe2\x57\xf3\x5e\x6e\x71\x83\xf0\x20\x4a\x96\xa5\x45\x19\x30\x01\x02\x3d\x33\x09\xa8\x99\x7e\x7c\x4b\x76\x2a\xb4\xf4\xc4\x0e\x03\xe1\x3f\x4e\xdb\x32\x8b\x23\xcf\x00\xc0\x91\x19\xde\xb4\x0a\xdd\xf6\x56\x7b\x3b\x74\xac\xef\x5c\xef\xf0\x45\x30\x4d\x61\x84\x21\xe8\x73\xc4\x1a\x72\xd3\x1e\x45\x1d\x21\x3b\x06\x08\x29\xb2\x86\xf6\x40\x13\xd4\xd9\x34\x2a\xe7\xab\x80\x64",
        p,
        q,
        g,
        b"\xad\x59\x05\x90\xa8\x2e\x89\x29\xca\x86\xf4\x05\x51\x6c\x32\x91\x3b\xf5\x28\x2f\x70\x30\x9c\x6d\x4a\x88\xcc\xf1\x65\xce\x15\xfc\xf1\x1e\x14\x0c\x36\x6b\xb2\x73\x83\x9a\x71\x1c\xb6\xae\x52\xbb\x71\x78\x59\x57\x0f\xdb\xf9\xfc\x26\x72\x67\x28\x59\x6e\x6f\xc7\x19\x23\xde\xad\xb3\x5a\x9d\x57\xcd\xb2\x13\xc0\xf2\x9c\x13\x75\xf8\xb1\xd3\xc6\xb5\x26\x90\xc4\x28\xf7\x48\x1c\x14\xaa\xd8\x2f\xba\x7f\x24\xee\xa8\xcd\x8d\xa7\xf0\xef\x7a\xe7\x81\xc1\xa9\x26\x67\x1a\x61\xd4\xe5\xff\xc8\xdd\xf1\xbc\x10\xd6\x88\xa9\x04\xc6",
        b"\x89\xdc\xbc\xa7\xc8\xcd\x6b\x90\xaa\x90\x6a\x4c\x54\x71\x53\x76\x2f\xcf\xff\xd6",
        b"\x23\xe8\x92\x6b\x18\xcf\xd4\xb6\x7c\x53\xfa\xc4\xa2\xd5\x32\x1e\x5c\x3d\x88\x0c",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x4e\xaf\xcc\x68\x74\xae\x2a\x6d\x52\x57\x38\x96\x7a\xfb\x30\x54\x35\x7a\x39\x67\x0d\x1e\x55\x55\xd7\xdc\x55\xbe\x24\xdd\x5a\x32\xa0\xc7\xca\x3f\x1b\x5c\x6d\x94\x8c\x9c\xe3\x91\x01\x3a\xbe\xb4\x7f\x7e\x24\xcd\x2c\x54\xe1\xfc\x7c\x0e\x92\xc4\xab\x77\xf5\x97\x3a\x70\x54\xbd\x1c\x6c\x84\x5b\x80\x2b\x79\x37\xd6\x52\x05\x08\xae\x01\x8a\xe1\x4b\x27\xff\x4b\x1e\x34\x0a\x4b\x9f\x6f\x6b\x48\x14\xd0\x7e\x90\xcb\x8f\x19\xb1\x5e\x91\x5d\x6a\xd1\x83\x4c\x0f\x7a\x3c\x3e\x1e\x45\x20\x67\x72\xa0\xee\xc2\xd3\xf9\x16\x08\x97",
        p,
        q,
        g,
        b"\xb9\x3d\x79\x47\x2f\x04\x98\x93\x77\x9a\x3a\x0e\x83\xb3\x85\x3f\x78\xb3\xcf\x69\xb7\x59\x61\xa6\x0e\x95\x0f\x0c\x00\xf4\x98\xf3\xea\xa2\x38\x43\x25\xf7\x4d\xdd\x38\x29\x2f\xbd\xbd\xb1\x99\x21\x2e\x90\xb1\x4e\xc9\xe5\x54\x72\x7d\xf8\x1e\x06\xeb\x77\x83\xad\xda\x38\x69\x1c\x63\xa7\xcb\x00\xcd\x76\xd8\xe1\x8e\x3d\x29\xc7\x93\xe9\xf1\xfe\x83\x37\xf1\x59\x8b\x89\x65\x1f\x63\x4c\xb7\x03\xf2\x18\xe1\x90\x63\x19\xf8\x2a\xc6\xd5\x8e\x67\x86\xda\x7a\xec\xfb\xca\x59\x39\xf0\x3a\x13\xe7\xb4\xd5\xa8\xac\x81\x2d\x78\x29",
        b"\x63\x3e\x98\x12\xa0\x65\x7c\xec\x33\x26\xaa\x54\x15\x34\x0c\x46\x36\x2f\xcd\x4b",
        b"\x6b\x20\x1f\x0c\x3f\xd4\x42\x47\xf6\xc2\x8c\x01\xd1\x21\x7e\xb9\x91\x46\xc0\x40",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x86\xd9\x89\x2b\x48\xf5\x95\x41\x01\x48\x27\x42\xc0\xda\xfb\x68\xdc\x97\x12\x24\x83\xb9\xe4\x59\xf9\x74\x95\xcc\x97\x0e\x05\x6d\x21\x62\xc7\xc7\x1d\xb1\x67\x22\x9f\xb7\xf4\x52\x09\xe0\xc0\x1e\xb0\x6f\xf9\x24\xb8\x23\xed\xa5\x1a\x7e\x99\x0f\x3c\x98\x6e\xb9\xaf\x2a\x7a\x07\x3f\x75\x4c\xb8\x4d\xb4\x53\xa9\xe8\xc0\xae\x7f\xa5\xc0\x5a\x26\x55\xd2\x61\xad\x7e\xc5\x61\x28\x76\xfa\x7d\xf0\x95\x22\xe0\xb6\x9a\xe9\x24\x77\xf6\x3d\xef\x19\x92\xc9\x6c\xe9\x5e\xe7\xbd\x63\x0e\xc1\x61\x46\x21\xda\x6a\x51\x2a\xb5\x3d\xd7",
        p,
        q,
        g,
        b"\xae\x26\x4e\xa9\x6b\xf0\x93\xef\x2d\xe2\x73\x81\x73\x82\x19\xe3\xbf\xdb\x08\x61\x69\x67\xcd\x13\xe9\x41\x5f\x47\x5c\x4a\x79\x4c\x19\xf1\x2a\x60\x7b\x89\x8d\xb1\xe3\xe6\xbc\x54\x02\x32\x75\x85\xd3\x28\x41\xae\x15\xe3\x46\x28\x80\x85\x0e\x9e\x41\x36\xa4\x75\x1b\x64\xa7\x29\xea\x27\xb7\x2c\xe3\x61\x28\xa4\x4f\xa5\x37\x52\xa0\x8d\x73\x58\x4f\xaa\x44\xfb\x14\x12\x0f\x47\xa0\x4c\x47\xe9\x89\xea\xda\xbc\x7e\x5c\xdb\x15\xd2\x7c\x2b\x0e\xa4\x25\x7c\xec\x22\x9a\x2c\x7b\xf7\xc9\x3c\x57\x1e\x8d\x22\xae\xaa\x2e\x38\xbe",
        b"\x77\xb4\x80\x88\x5c\x70\xc1\xfe\xe2\x05\x62\x37\xd1\xb7\x9c\xfd\x9f\xb5\x4a\x1f",
        b"\x22\x83\xf4\xc0\x64\x0f\xf6\xda\xac\xbd\xfb\xbe\xf7\x22\x4a\xfa\x59\xca\x39\x59",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x8b\x60\xb9\xb6\xba\x37\x54\x48\xde\x4f\x00\xde\x51\xd1\x87\x06\xef\x8c\x4f\x97\xba\x34\xc9\xcc\xe2\xb0\xab\xb0\x69\x84\x36\x00\x9d\x1d\x2b\xaf\xcb\xef\x73\xa8\xb5\xdf\xf6\xa3\xcd\x5d\xb5\x25\x8a\xc8\x4e\xf7\x24\xb2\x8d\x8a\x62\xd7\x15\xda\x6e\x11\x19\x39\x73\x53\x66\xa7\xc6\x64\x70\x36\x45\x57\xf5\x46\x37\x7d\x5c\x0e\x7e\xa9\x06\x47\x31\xcb\x71\x49\xe1\x05\x1d\x66\xa7\xbe\xd1\x4a\xa2\x05\xbd\xc5\xd4\xb9\xca\x02\x9a\x1e\x68\xa6\xfa\x2c\x1d\xb2\x2d\x27\xfb\x79\xd8\x38\x77\xcf\xaa\x67\x42\x11\x92\x29\xa4\x93",
        p,
        q,
        g,
        b"\x87\x03\x2f\x26\x3d\xe2\xbf\x2f\x26\x8a\x09\x3f\x33\xc3\x66\xd6\xbc\xda\x77\x2c\xa9\x59\xfa\x17\xcf\xe9\x48\xf1\xdc\xa3\xe7\x5e\xc9\x42\x76\xde\x91\xd9\xbc\x60\xfc\x6a\xb9\x22\x48\x61\xc5\x5d\xc9\xcc\xc5\xf7\x15\xc2\x51\xdd\x50\x8b\xd4\x38\x68\x1c\xab\x20\x50\x59\x05\x0f\x8e\x11\xe8\xa5\x46\x8d\xa4\x2d\x20\xae\xfa\xc5\x3d\x7a\x9f\xb7\x1f\x64\x24\xd7\xbd\xc6\x5d\xb8\x73\xee\x4f\x9d\xcd\x91\x80\x91\xaa\x72\x4b\x26\x1b\x60\x56\xf3\x20\xca\x77\x24\x51\x8e\x14\xcb\x8d\xba\x0b\x71\x3f\x54\xa0\xfe\x44\xff\x15\x97",
        b"\x5d\x15\x9f\x89\x4d\x25\x0d\xb9\x0d\x7f\xcc\xd4\x93\x29\xe4\x4d\x11\x12\xdb\x47",
        b"\x37\x23\x1b\xc1\x51\x95\xec\xb6\xba\xdb\x7c\x3f\xe8\x03\x80\xff\x91\x2b\xae\xda",
    )?;

    // [mod = L=1024, N=160, SHA-384]
    let p = b"\xf2\x4a\x4a\xfc\x72\xc7\xe3\x73\xa3\xc3\x09\x62\x33\x2f\xe5\x40\x5c\x45\x93\x09\x63\x90\x94\x18\xc3\x07\x92\xaa\xf1\x35\xdd\xea\x56\x1e\x94\xf2\x47\x26\x71\x6b\x75\xa1\x88\x28\x98\x2e\x4c\xe4\x4c\x1f\xdd\xcb\x74\x64\x87\xb6\xb7\x7a\x9a\x5a\x17\xf8\x68\xab\x50\xcd\x62\x1b\x5b\xc9\xda\x47\x08\x80\xb2\x87\xd7\x39\x81\x90\xa4\x2a\x5e\xe2\x2e\xd8\xd1\xff\x14\x7e\x20\x19\x81\x0c\x82\x98\xed\x68\xe1\xca\x69\xd4\x1d\x55\x5f\x24\x9e\x64\x9f\xb1\x72\x5d\xdb\x07\x5c\x17\xb3\x7b\xef\xf4\x67\xfd\xd1\x60\x92\x43\x37\x3f";
    let q = b"\xda\x06\x5a\x07\x8d\xdb\x56\xee\x5d\x2a\xd0\x6c\xaf\xab\x20\x82\x0d\x2c\x47\x55";
    let g = b"\x47\xb5\x59\x1b\x79\x04\x3e\x4e\x03\xca\x78\xa0\xe2\x77\xc9\xa2\x1e\x2a\x6b\x54\x3b\xf4\xf0\x44\x10\x4c\xd9\xac\x93\xef\xf8\xe1\x01\xbb\x60\x31\xef\xc8\xc5\x96\xd5\xd2\xf9\x2e\x3a\x3d\x0f\x1f\x74\x70\x2d\xd5\x4f\x77\xd3\xcd\x46\xc0\x4d\xee\x7a\x5d\xe9\xf0\x0a\xd3\x17\x69\x1f\xdd\xce\xfe\x4a\x22\x0a\x26\x51\xac\xae\x7f\xce\xdd\xa9\x2b\xfc\xca\x85\x5d\xb6\x70\x5e\x8d\x86\x4f\x81\x92\xbf\x6b\xf8\x60\xc0\x0f\x08\xad\x64\x93\xec\xc1\x87\x2e\x00\x28\xd5\xc8\x6d\x44\x50\x5d\xb5\x74\x22\x51\x5c\x38\x25\xa6\xf7\x8a";
    test(
        HashAlgorithm::SHA384,
        b"\xb0\xdb\xbf\x4a\x42\x1b\xa5\xc5\xb0\xe5\x2f\x09\x62\x98\x01\xc1\x13\x25\x8c\x25\x2f\x29\x89\x8c\x33\x54\x70\x6e\x39\xec\x58\x24\xbe\x52\x3d\x0e\x2f\x8c\xfe\x02\x2c\xd6\x11\x65\x30\x12\x74\xd5\xd6\x21\xa5\x97\x55\xf5\x04\x04\xd8\xb8\x02\x37\x1c\xe6\x16\xde\xfa\x96\x2e\x36\x36\xae\x93\x4e\xc3\x4e\x4b\xcf\x77\xa1\x6c\x7e\xff\x8c\xf4\xcc\x08\xa0\xf4\x84\x9d\x6a\xd4\x30\x7e\x9f\x8d\xf8\x3f\x24\xad\x16\xab\x46\xd1\xa6\x1d\x2d\x7d\x4e\x21\x68\x1e\xb2\xae\x28\x1a\x1a\x5f\x9b\xca\x85\x73\xa3\xf5\x28\x1d\x30\x8a\x5a",
        p,
        q,
        g,
        b"\x43\xa2\x7b\x74\x0f\x42\x2c\xb2\xdc\x3e\xaa\x23\x23\x15\x88\x3a\x2f\x6a\x22\x92\x7f\x99\x7d\x02\x4f\x5a\x63\x8b\x50\x7b\x17\xd3\xb1\xcb\xd3\xec\x69\x1c\xc6\x74\x47\x09\x60\xa0\x14\x6e\xfd\xec\xb9\x5b\xb5\xfe\x24\x97\x49\xe3\xc8\x06\xcd\x5c\xc3\xe7\xf7\xba\xb8\x45\xda\xdb\xe1\xf5\x0b\x33\x66\xfb\x82\x7a\x94\x2c\xe6\x24\x6d\xda\x7b\xd2\xc1\x3e\x1b\x4a\x92\x6c\x0c\x82\xc8\x84\x63\x95\x52\xd9\xd4\x60\x36\xf9\xa4\xbc\x2a\x9e\x51\xc2\xd7\x6e\x30\x74\xd1\xf5\x3a\x63\x22\x4c\x42\x79\xe0\xfa\x46\x04\x74\xd4\xff\xde",
        b"\x77\xc4\xd9\x9f\x62\xb3\xad\x7d\xd1\xfe\x64\x98\xdb\x45\xa5\xda\x73\xce\x7b\xde",
        b"\x23\x87\x1a\x00\x2a\xe5\x03\xfd\xab\xaa\x6a\x84\xdc\xc8\xf3\x87\x69\x73\x7f\x01",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xec\x84\xbe\xd0\x9e\xcb\x4a\x6f\xee\xec\x3a\x70\x71\xb6\x5a\x4c\x12\x67\xa0\x3c\xac\x8b\x5a\x05\x00\xc2\x37\xb2\x0d\xc0\x58\x51\x4d\xa7\x98\x33\x5a\x21\xb2\x3d\x7e\x8c\xbb\x15\xef\xcf\x92\xe6\x06\x0a\x13\xfb\x77\xf4\x99\x81\x47\xde\xc1\xd0\xfa\x0e\xdd\x41\x8b\x0a\xae\x8e\xb0\x05\x6f\xc7\xd4\x00\x8b\x19\x8b\xd4\x0b\x96\x9d\xc1\x0d\x79\xe1\x5b\x23\x00\x82\x03\x23\xbd\x5e\x1b\x7d\x89\x4c\xe8\xe7\xbc\x8f\x7c\xec\xa1\x29\xb5\xe5\x11\xee\x1c\x8c\xae\xc2\x55\x14\xf5\x37\x35\x3a\x91\x2a\x97\x1b\x80\x70\xe3\xf1\x41",
        p,
        q,
        g,
        b"\xd7\xa0\x95\x0d\x0e\x63\x62\xb0\xc9\x42\xad\x8a\xf6\x71\x61\xdf\x07\xde\xbc\xa5\x9a\x4c\xfa\x72\x8f\x93\xd4\x9b\x6e\x29\x6a\x23\x96\x9a\x65\xa9\x2b\x2e\x05\x39\x8a\x11\x4d\x73\xd5\xa5\x2b\x73\xb7\x1e\xbb\x28\x57\x1c\xf6\xb6\x00\x2f\x85\x3a\x8f\x59\x4b\x5c\x93\xb9\xa8\x42\x33\xf3\xc5\x52\x82\x36\x19\xe0\xaa\x84\x7d\x60\x20\x3d\xb1\x5d\x2a\x91\x6a\xd0\x22\x28\x32\x5e\x15\x78\x39\x88\xf4\x15\x9e\x05\xc8\xca\x08\x83\x60\xe6\xea\x7a\xce\x51\xb0\x55\x10\x21\x53\xc0\x0a\xdf\x33\x5f\xf6\xaf\xfd\x17\x54\xf2\xa8\xaa",
        b"\xb2\x57\x0e\x0e\x19\x93\x54\x38\xd3\x26\x86\xc4\x78\x47\x3a\x0e\x45\xda\xd0\x23",
        b"\x39\xa0\x2e\x98\x03\x62\x4f\x7e\x90\xfe\xab\x87\x14\xcd\xdc\x41\xe0\x1f\x8f\xce",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x80\xf7\x57\xfc\x06\x40\x9b\x70\xd7\x33\xef\xdb\x68\xb5\x20\xf3\xf9\x07\x8a\xb9\x36\xc4\x47\x9f\xb9\x8d\x0b\xeb\x16\x31\xd8\x30\x33\x24\x47\x08\x24\x86\x22\x24\xb4\x39\xbc\x85\xde\xcf\xcc\xb8\xde\x8f\xbf\x36\xa2\xbc\x4c\xe3\xa0\x92\x68\x82\x49\xab\x4e\xb9\xfe\xbf\xad\x26\x82\x45\xfb\xd7\xe7\x2e\x0f\x24\x05\x00\xaf\x71\x29\x2e\xa2\x3c\x8a\xd4\xb7\x1e\x03\x21\x06\xf5\x87\xf4\x61\x16\x63\x13\x76\x90\xcb\x25\x24\x19\x12\x76\x3c\x5e\x18\x79\xb3\xab\x67\xe2\x18\x7f\x92\xd8\x21\xfc\x81\xf5\x52\xe2\xc3\x55\xbd\x73",
        p,
        q,
        g,
        b"\x1f\x03\x01\x3e\x66\xfd\x1e\x63\x3f\xf7\x43\x89\x4c\x37\xf6\x96\x48\x39\xa5\x2c\xfb\xb6\xe8\x49\xcf\xb4\xea\xc9\xa3\xc9\xcd\xb5\x5c\x28\xe1\x47\x88\x86\x5c\x21\x2b\xe6\x20\x47\xcb\x39\xc6\x36\x57\x80\xbb\x2e\x62\x79\x57\xd3\x4e\x99\x23\x2f\x69\x17\x0a\x8e\xfb\x89\x4d\x80\x29\xd1\xb8\xbe\xa8\xb9\x11\xce\xbc\xd4\x3b\x86\xbd\x53\x66\x93\xf1\x8b\xfe\x50\xc8\x4b\x99\x91\x11\x81\xac\xe1\x4c\x3f\xab\x9f\xb6\xac\xd9\x87\x86\xf9\xd2\xad\x12\x9c\x5e\xfe\xb8\xcd\x09\x41\xa3\xd8\x90\x98\xd5\x72\x1d\x43\x53\x43\xcb\x76",
        b"\xc7\xdb\x4a\x9f\x54\xd8\x82\xec\x5f\x56\x17\x05\x39\x6c\x94\x83\x4d\xd5\x3c\x5a",
        b"\x67\x52\xcb\x6b\xe9\xb8\x72\x65\xd7\x6d\x69\xb3\x82\x29\x96\x78\xf9\x6a\x5f\xaf",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x36\xa2\x56\x59\xa7\xf1\xde\x66\xb4\x72\x1b\x48\x85\x5c\xde\xbe\x98\xfe\x61\x13\x24\x1b\x7b\xed\xdc\x26\x91\x49\x3e\xd0\xad\xd0\xb6\xa9\xfb\xbf\x9f\xb8\x70\xa1\xbc\x68\xa9\x01\xb9\x32\xf4\x7d\xed\x53\x2f\x93\x49\x3b\x1c\x08\x14\x08\x16\x58\x07\xb3\x8e\xfc\xe7\xac\xc7\xdb\xc2\x16\xbe\xf7\x4e\xd5\x9e\x20\x97\x33\x26\x55\x3c\xc8\x37\x79\xf7\x42\xe3\xf4\x69\xa7\x27\x8e\xeb\x15\x37\xdd\x71\xcd\x8f\x15\x11\x4d\x84\x69\x3c\x2e\x6b\xbf\x62\x81\x4a\x08\xe8\x2b\xa7\x15\x39\xf4\xcb\x4b\xf0\x8c\x86\x9d\x7d\xb9\xde\xa9",
        p,
        q,
        g,
        b"\xc9\x00\x39\x95\xb0\x14\xaf\xad\x66\xde\x25\xfc\x0a\x22\x10\xb1\xf1\xb2\x2d\x27\x5d\xa5\x1a\x27\xfa\xac\xda\x04\x2f\xd7\x64\x56\x86\xec\x8b\x1b\x62\xd5\x8d\x8a\xf2\xe1\x06\x3a\xb8\xe1\x46\xd1\x1e\x3a\x07\x71\x0b\xc4\x52\x12\x28\xf3\x5f\x51\x73\x44\x3b\xbf\xd0\x89\xf6\x42\xcd\x16\x64\x1c\x57\x19\x9c\x9a\xb6\xe0\xd9\xb0\xc0\x19\x31\xc2\xd1\x62\xf5\xe2\x0d\xbe\x73\x65\xc9\x3a\xdc\x62\xfd\x5a\x46\x1b\xea\x59\x56\xd7\xc1\x1a\xc6\x76\x47\xbe\xdc\xea\xd5\xbb\x31\x12\x24\xa4\x96\xaa\x15\x59\x92\xae\xe7\x4e\x45\xad",
        b"\x17\xcc\x53\xb5\xb9\x55\x8c\xc4\x1d\xf9\x46\x05\x5b\x8d\x7e\x19\x71\xbe\x86\xd7",
        b"\x00\x3c\x21\x50\x39\x71\xc0\x3b\x5e\xf4\xed\xc8\x04\xd2\xf7\xd3\x3f\x9e\xa9\xcc",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x65\xa3\xc9\x24\x53\xf9\x61\xde\x7f\x57\x6d\x5a\x1e\x31\x06\xc3\x8b\x7f\x20\x81\x39\x94\xb5\xdd\x20\x15\x46\xdc\x45\x50\x65\xdd\xe5\x9e\xdc\xd8\x4d\x0f\xa1\x7a\x85\xc0\xf9\xf9\x91\x71\xd6\x7a\x34\x47\x5c\xef\x4f\x31\x19\x51\xf2\xee\xf7\xf6\xb6\x4a\x5b\xbc\x6d\xa6\xd1\xb6\x22\x48\x0c\xde\x56\xa0\x7a\x77\xaa\x60\x40\xeb\xc1\xfc\xb2\x65\xb3\xb6\x24\x88\x1f\xd2\x72\x03\xdc\xfe\x8a\x12\x49\x21\x98\x47\x4a\x99\x0c\xb9\xf3\x4a\x19\x43\x35\x6f\xde\x5b\xce\x3f\xd8\x35\x16\xda\x8b\xf7\x80\xf8\xcb\x18\x51\xb3\xb9\x54",
        p,
        q,
        g,
        b"\x0f\xc5\x14\xca\x16\x0f\x34\xf2\xf6\xed\xe1\xba\x59\x14\xd5\x84\x4c\x9d\xe5\x14\x20\x8c\x72\x56\x9a\x0b\x36\xec\x92\xc8\xb2\xc8\xfd\xfb\x7d\x68\x12\x74\x86\xe5\x8a\x04\xa3\x2d\x0d\x15\x0e\x51\xbb\x05\xe6\x66\x24\xcb\x62\x2e\xda\xe1\x9a\x6b\x4b\x1d\x83\x17\x68\x9b\xaa\xfa\x30\x16\x8e\xf3\x75\x9e\xe8\x2e\x61\x4e\x47\x61\x90\x01\x82\xdf\x90\xe9\xcd\x2d\x93\x11\x53\x77\x1b\x8b\xe3\x0d\x89\xc2\xfb\xb9\x5b\xe7\xe0\x5a\x4b\x29\xda\x96\x8f\xfe\xbb\xda\x5c\x0c\x98\x39\x35\x4b\xb5\x9d\xc6\x97\xa2\x69\x06\x3f\x2f\x50",
        b"\x77\xff\xaf\x42\x90\xc4\x1e\xb0\x89\xc1\xd7\xbe\x5c\x8d\x38\x33\x02\x77\x02\xef",
        b"\xcb\x75\x3a\x2d\x4c\xe0\xe5\x98\x51\xf8\x14\x77\x9f\x34\x3b\xeb\x61\x5f\x27\x70",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x15\x26\xb6\x4c\xe4\x1c\xc8\xe2\xce\xf2\x6f\x37\x06\xbe\x53\x0a\x36\xac\x9c\xd1\x6f\xf6\x9f\x05\x77\x3e\x94\x47\xed\x94\x52\x06\x4b\x77\x51\xf3\xa6\x49\x19\xbf\xa3\xa7\xe1\x02\x0d\xfc\x17\x5a\x10\xac\xfd\xf0\x96\xfd\x41\xc0\x33\x72\xe4\xd2\xab\xd7\xba\x88\x7e\x00\x76\x71\x6c\xe9\x55\x2f\x2c\x7c\x8e\xdd\xb1\xb3\xfc\xa1\xbd\xcd\x23\x30\x0c\xe2\xb1\x67\x7d\x4a\x2d\xeb\xea\xa7\x05\x34\x66\xe5\x9b\x09\x87\x71\xbf\xb9\x21\x8e\x0f\xb4\xab\x6b\x74\x18\xab\xeb\xcc\x34\xd6\x81\xe1\x4c\x4a\x89\x75\x00\x0d\x83\xbb\x44",
        p,
        q,
        g,
        b"\xd3\x0e\xed\x73\x9f\x46\x47\x93\x64\xd4\xc2\xbe\xc1\x8c\xf4\xc7\x5c\x32\x4f\x8d\xb8\x18\x4d\x9c\x3c\x17\x55\x56\xa0\x0a\xcf\xb0\xa6\x81\x38\x87\xb6\x87\x06\xe7\x0c\x16\x7f\x40\x63\xbc\x00\x46\x39\x6b\xa1\xbb\x32\x26\xc2\x92\x21\xbd\x64\xec\x4c\xeb\xc9\x90\xa7\xb4\x04\xe2\x6e\x2c\xf0\x42\x30\x4a\x7c\x57\xab\x7d\xe4\x18\xba\x67\x1e\x17\xf7\xf5\x02\xb9\xe1\xbb\x59\x84\x46\x9b\x30\x4e\xbc\x0c\x3c\x3a\x5a\x69\xcf\xf7\xab\xff\x41\x10\x13\x03\x16\x65\x1e\x0f\x93\xeb\xd2\x83\x4d\xd0\x44\xea\xe1\xfd\x6f\x04\x51\x02",
        b"\x31\xab\xe8\xe7\x45\x8c\xe3\x63\xa5\xf3\x98\x51\x11\xb2\x39\xbc\x8d\xf8\xdc\xb9",
        b"\x1d\x96\x7b\xe0\x11\x61\x28\x69\x9d\x16\x7f\xc1\x6e\x5e\x92\x0a\x41\x31\x16\x69",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xd7\x85\x2e\xe9\x0b\x3f\x11\x20\xbb\x11\x24\x98\x08\xc7\xe7\xbe\x14\xfe\x57\x7b\xff\x18\x86\xbe\x3c\x42\x58\x9a\x6e\xeb\x06\xa1\x83\x41\x10\x86\x2b\x65\xd2\x6c\xc5\xa2\xe5\xd9\x03\xed\x24\x32\x8d\x68\x4c\x96\xe3\xba\xbb\x37\xae\x31\xf9\x6d\x32\xf5\x76\x57\xa3\xbd\x77\x98\xaa\xfa\xe8\x6f\x44\xad\x89\x81\xe7\xcd\x47\xd7\xf3\x1b\xb4\x56\x4a\x75\x7c\x92\x5c\x64\xda\x98\x20\x96\x3c\x1c\x51\x48\xf5\x89\xd6\x39\x30\x04\xa6\xa5\x8a\xa2\xc8\xa5\x78\xf4\xdb\x75\x95\xf8\x86\x17\x0e\x79\xe9\xd5\x7b\xf7\xff\x8f\xd0\xa7",
        p,
        q,
        g,
        b"\x0d\xd3\x79\x85\x16\x3f\x93\x61\x8f\xde\xa8\xe3\x97\x54\x19\xfc\xf7\x44\x6f\xf9\x80\x85\x1e\x18\x93\x2d\x74\x94\xf8\x09\xc0\xae\x9c\x03\xcc\x39\x77\x9f\xf0\x42\x2c\xb2\x24\x8a\xe1\x98\x6f\x9a\xad\x2a\x43\xd6\xfa\x68\x78\xd2\x44\xb4\x29\xaa\xc5\xea\x80\x15\x79\x80\x57\x7e\x5b\xa0\xd1\x1b\x1f\xa3\x40\xa2\x83\xfa\x0a\x2d\x65\x1e\x02\x43\x31\xe6\xbb\xe7\xd0\x1a\xc0\x34\xdb\x37\xb0\x08\xb9\x1f\x9f\x88\xd1\x35\xfa\xd2\x3a\xf8\xc2\x27\x65\xd8\x33\xa9\xc9\xef\xf7\xac\xcf\x66\x8e\x17\xf9\xa8\xbd\xf5\x93\x17\xc2\x02",
        b"\x44\xc2\xd6\x50\x98\x74\xac\xe7\x1a\xcd\x1d\xcc\x32\x33\x5b\x39\x4c\x4e\x41\xe0",
        b"\x37\xe7\x8f\x13\xae\xc0\x52\xeb\x7b\x07\xa8\xb9\xf6\xd5\x4d\xbc\x77\x82\x90\x06",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x9a\xb9\x14\x48\xa0\xdc\x96\x94\xbe\x17\x3c\xe6\xd9\xb5\x22\xce\x0e\x2f\x75\xfc\xb5\x77\x20\xfc\x5e\xb8\xf9\x2d\x8f\xb0\xe1\x95\x03\x00\x63\x96\x89\x25\xa5\x68\x63\x6f\x4a\xea\x1e\xdf\x6c\x5f\xcb\x86\xdc\xed\xd2\x04\x53\x9d\x8c\x29\x17\x57\xfb\x8a\x51\x62\x0a\xbd\xa5\x9a\xa8\xf8\x50\x2e\x69\x04\xbc\xe0\x66\x7d\x92\xc8\xcb\x3f\xcf\x1a\x61\xb1\xfb\x0b\xb4\xe9\x38\x3b\x37\xeb\x46\x9b\xd5\xc2\xf5\xa7\x76\x80\xda\x62\xf9\x07\xc2\xe2\x63\xcb\x48\x40\x2b\x4b\x12\x98\x5e\xaa\xb9\x04\x51\x88\x5e\x81\x9b\x3e\x8c\x3a",
        p,
        q,
        g,
        b"\x49\xd7\xf0\x8f\xde\x0a\x83\xcf\xb8\x11\x6c\x9b\x7c\xdc\xab\x29\x75\x1f\xca\x5f\xfe\x31\x07\x60\xfe\xa7\x13\xc3\x0e\x95\xe7\x75\x5e\x65\xce\x60\x92\x88\x93\xc6\x50\x20\xee\x9b\x61\xf6\xc9\xc8\x9c\x07\xe0\xfc\x50\x3b\x7b\x03\x13\x68\xf0\x69\x57\x8a\x9e\x6b\x45\x1f\xef\x36\x9e\xf9\x0c\x26\xdd\x66\x0e\xe1\xa6\xb8\xb7\x14\xd1\xcc\x28\x24\x5e\x9f\x13\xf1\x87\x12\x2d\xe2\x6a\xc2\xfb\xf5\xbc\xcb\x7c\xaf\xf5\x9f\x1d\xe9\x10\x55\x11\x04\xd3\xa0\xe8\xfa\x9f\xe6\xb7\xea\xcc\x9a\x5f\xd5\x56\xb7\xbf\x71\x39\xd6\xed\xf9",
        b"\x95\xda\x25\xd0\x6f\xf9\xc0\x2b\xc8\x93\xfb\x03\x25\x08\x30\x4c\x17\xeb\xcf\x08",
        b"\x61\x7a\xdb\x8d\xe1\x0d\xa1\xa8\x74\x13\xd6\x44\x66\xb4\x82\x40\x9d\x27\xbc\xe7",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xc9\xc0\xe6\x9f\x84\x0c\xb6\xde\xb9\x84\xc2\x57\x5d\x7f\x68\x16\xfa\x35\xaf\x03\xb4\x42\x9c\x70\x3a\x5a\xec\x90\xe7\xcb\x26\xe5\x24\x13\x58\x7f\x3b\xc5\xa0\x77\x2b\xe7\xb5\xe5\x89\xc9\xa7\x60\x71\xc1\x73\x98\x33\xf4\x61\x1f\xa9\x51\xd3\x75\x82\x0b\x48\xd7\x40\x62\x6c\x66\x55\x34\xd6\x04\x87\xbf\x3e\x0a\x84\xeb\x63\x89\xe0\x99\xfe\x62\x1f\x26\x94\x91\xc3\xb8\x94\x2e\x03\xbb\xad\x2a\x52\x20\xca\xf5\x1e\x7b\x4a\x26\x50\xe4\xb3\x00\x02\x4a\x0a\x96\xf0\x86\x1b\x32\x06\xff\xfc\xa8\x3d\x08\x50\xf2\xa3\xe2\xa0\x6c",
        p,
        q,
        g,
        b"\x26\xf7\x32\x19\xd0\xe7\xdd\x3a\x80\xe7\xfb\xc0\x79\xd9\xba\xad\x45\x12\x89\x1a\xad\xfd\x24\x16\xb1\x85\x9f\x41\xad\xac\x31\x17\x1e\xc6\x24\xd8\xa4\xd6\xa1\x0d\x5d\xe1\xb9\x39\x59\xbc\x49\x95\x3f\x23\x49\x2f\x18\xab\x76\x5f\x96\x3a\x98\x58\x48\x07\xd6\x66\x29\xe5\xa1\xe0\x57\xd7\x7d\x42\xe3\x36\x34\x58\x64\x1a\x04\x69\x16\x6a\x0d\x85\x3b\x27\x79\x8b\xd8\x48\xaa\x0d\x3c\xcd\xbb\x40\xfa\x21\xb9\xfe\x62\x82\x4c\xb2\xc7\xcc\x62\x42\x59\x78\xe6\x72\xaf\xf0\xbb\xd8\xc8\xcd\x08\xe4\x63\x85\xb0\xd6\x21\x9d\xc5\x6e",
        b"\xb6\xb2\x5a\x9d\xa1\x10\xb5\xd5\x76\x75\x88\x9e\xae\x75\xab\x58\xa4\xd8\xe2\x81",
        b"\x5a\x60\xc2\xb0\xad\xbe\xa4\xc5\xbe\x06\x5b\xbd\x0f\xd0\xe3\xce\x4b\xf2\x92\x00",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x40\x02\xde\x82\x5b\xb8\x7a\xc3\x46\xbd\x84\x87\xcf\x6b\xe0\x53\xcb\x30\xee\x67\xc6\x64\x34\x21\x71\x07\xa8\xb0\xb5\x2e\x57\x26\x90\x06\x15\xed\xd2\xfd\x0a\xcd\xf8\x8a\x7e\x65\xe7\xdd\x3b\xa6\xab\xbb\xb3\x71\xa1\xc8\x40\x25\x0d\x9c\xe8\x09\xe7\xb1\x11\x1f\x16\xda\xf5\x19\x42\x11\x71\x5f\xf5\xfe\x63\x1e\x37\x84\x08\x74\x98\x48\xa0\xc8\x1a\x28\x9b\x43\x38\xbc\xcd\x8d\x10\x53\xf8\x63\x19\x7a\xd0\x29\x20\xfc\xbc\xa5\x14\xe2\xdf\xd9\x4a\x8b\x00\xf9\x0c\xf0\x34\xad\xfd\x77\x6f\x4d\xca\xef\x2c\x8d\xce\x3b\x05\x39",
        p,
        q,
        g,
        b"\x14\x9b\xcb\xb4\xf5\x98\x3d\xb5\x6f\xbe\x99\x8f\xcd\x02\xd7\x36\xe6\xd2\xf1\x8f\xcf\x96\x46\x8c\xd7\xe9\x9b\xc6\x47\x43\x6f\xbd\x74\xfd\x7a\x2c\xc2\xf0\xd8\x86\x69\x52\xb9\x7b\x44\xff\x64\x4b\x56\x65\xcd\x10\x65\xb0\x7a\x2c\x33\xd9\x15\x1d\xeb\x33\x5e\x35\x22\xc1\xb7\x7d\xa1\x44\x3a\x13\x73\xc9\x3b\xfa\x04\x0d\xa5\xa1\x35\x3b\x88\xa7\x8e\x3a\x5a\x08\x4e\x6c\x44\x2d\xb0\x3f\x7f\xbb\x4b\xdb\xd3\x0b\x1a\xf3\x96\x3f\x8c\x5d\x3e\x83\x45\x32\x94\xe3\xa0\x7d\xda\xcf\xd4\x3d\xc8\xf9\xe8\x30\x32\xfe\xf7\x84\x20\xc4",
        b"\xd3\xcd\xe1\x70\xd8\x21\x54\xec\x1b\xbd\x90\x77\xc4\x86\x97\x11\x20\x60\x03\x76",
        b"\xb0\x08\xfc\xd0\x1b\x5e\x49\xa8\x5a\x92\x1b\xee\x1d\xdd\x70\x62\x12\x79\x90\x86",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xf7\x01\x8f\xf0\xaf\x67\x76\xed\x42\x34\xc1\xfb\x9c\xca\x1f\x8c\xff\x31\x29\x5c\xb9\xf7\x6d\x8b\x73\x89\x84\x30\x09\x7c\x49\xa4\x00\x28\x44\x17\x71\xea\x1d\xe0\x8f\xfd\x5c\xec\x7e\xaa\x59\xe3\x2b\x3a\x17\x03\x29\x13\x92\x27\xba\x86\xe0\xc5\xef\xca\xee\x38\x2b\xff\xf9\x62\x24\x9d\xa8\x53\xde\xe4\x18\x41\x3f\x20\x1a\x28\xfe\x45\xb8\x29\x3c\x26\x20\x89\xd2\xce\xeb\x9a\xf6\x75\x29\xab\x01\x1f\x04\xf5\xee\xaf\x82\xba\x32\xdc\xe9\xa9\x82\x17\x62\xc3\x35\x1b\x00\x20\x65\x91\xa3\xf8\x7c\x52\x60\xa4\x26\x36\x59\xf0",
        p,
        q,
        g,
        b"\x6c\x20\x6e\x71\xfe\xd8\xb3\x63\xfc\xf5\x71\x78\x6c\xe1\xb4\xe5\x2a\x40\x4d\xe7\xed\xa7\x03\x1e\x5d\x93\xa4\x7e\xa6\x68\xde\x43\xdc\x70\x73\xe3\x1d\x3b\x6b\x12\x5a\xe3\xe8\xee\x45\xae\xd2\x73\xbc\x87\x8c\x73\x42\x3b\x22\x5a\x15\x26\xbb\xb1\x49\xa0\xce\x5e\x9a\x2d\x29\x62\xbd\x6d\x33\x23\x75\x86\x0f\x84\xce\x0e\x78\x7a\x0a\xf9\x3f\x44\xe6\x4e\xda\xa2\xdc\xe6\xca\x22\xbc\xc6\xd4\x8b\x84\xb0\xaf\xfb\xa3\x42\x75\x3b\x18\x42\x94\x10\x67\xd5\xb8\x41\x4c\x35\x61\x38\xe6\x25\xbb\x50\x65\x66\xa2\x7b\x33\x50\x94\xb0",
        b"\x07\x9b\x08\xbc\x01\x6c\x54\x3d\x09\xd6\xb2\x76\xc0\x23\x34\x7a\x3a\xac\xe9\xae",
        b"\x16\x4c\x3c\x38\x0f\x20\x9f\xea\xf8\xff\xcf\x53\x69\x1e\xe3\x03\x1c\x3b\x3f\xff",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x4a\x18\xbd\xcc\xcd\x46\xbb\x89\x56\x7c\xeb\x9c\x1e\x2e\x50\x0a\x3b\xae\xd2\x4f\xf2\xc5\xfc\x7f\x83\xcb\x3c\xf6\xa6\xf3\x88\x59\xa1\xa9\x27\xfa\xb5\xe2\xfd\x7e\xa1\xe1\xa4\x15\x47\x39\x30\x1c\xb1\x95\x77\x09\x10\x3a\xf8\x86\xc9\x29\xcf\x88\xd2\x5c\xed\x5c\xd6\xf8\xcf\x3f\xfe\xe7\xb0\x88\xed\xc2\xf6\xab\xd1\x11\x43\x98\xa3\xab\x00\xfc\x21\xbe\xc0\x2e\x8e\x53\x9b\xa1\x2d\xf7\x0a\x58\x7f\xbf\xba\x63\x19\x5c\x64\x49\xb2\xb8\x49\x54\x7c\x42\x27\x78\x34\xe1\xec\x08\x6b\x5e\x53\xd9\x49\x84\x67\x69\xe8\x97\x15\xbf",
        p,
        q,
        g,
        b"\x8e\x66\x8d\xd1\x52\x7b\x5d\x1e\x56\xaa\xe4\xa6\xca\x22\x5e\x67\x73\x68\x41\x23\x24\xa7\x9d\x98\xbf\xda\xd9\xa8\x4d\x9f\x87\xc1\x35\x75\x18\xc9\xa5\x05\x6e\xa6\xa0\x88\x2e\x94\xd4\xff\xad\xd9\x7d\x89\xbc\xf2\xf3\x2f\xf4\x42\xb2\x5d\xd2\xaf\x2a\x78\xdd\xad\xe4\x6b\x75\xaa\x8a\x5b\x1a\x14\x71\x76\x4a\xb6\x99\xd7\x00\xcb\x2a\x28\xb9\x59\xa3\x84\x8e\xdb\xbd\x6c\x95\x14\xee\x84\x9f\x83\x3c\x43\x00\x85\x31\x36\x5a\x01\x54\x1f\x9c\x0b\x65\xd5\xe7\xd3\xc2\x1d\xc8\xbe\xf1\x36\x9a\x41\xc0\x40\x5f\x37\x23\xf6\x79\x10",
        b"\xb2\x2c\x00\xfe\x0b\xc2\xfa\xe7\xa4\xab\x74\xed\xcd\x49\x6c\x64\xa9\x99\xc7\xd3",
        b"\x85\xba\x8d\xbb\xc9\x3a\xb9\x4a\x76\x13\x3d\x47\x9e\x3f\x79\x57\x69\x44\xe6\xca",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x75\x47\x47\x11\x82\x17\x66\xb0\x65\xe2\x44\x86\x01\xe8\x2b\x88\x15\x3a\x41\xbf\xb5\xc6\xb6\xa9\xdd\xcf\x73\x17\x0e\xe3\x74\xa6\x62\x5d\xe1\x9c\x56\x0b\xcb\xd2\x02\x0b\xfe\xab\x5c\xbf\xad\x8f\xc6\x0c\xcf\xc9\x5a\x1b\x94\xfb\xef\xdf\x81\x5d\x9b\xfc\x43\xfa\x59\x31\x5e\x70\x93\xd5\x68\x52\x74\xb8\xaf\xc3\x13\x9b\x92\x5e\xbf\x69\x7f\xe2\x69\x9b\x0f\xeb\x1e\x42\xbc\xa6\x5e\x5d\x4e\xb0\xb4\x51\x4a\xf9\x2d\xfa\xb8\x5e\x7f\x26\x66\xc8\x7e\x97\x89\x39\x5f\x35\x4c\xe3\x39\x38\xe9\x62\x30\x61\x11\x34\x65\xa4\xe2\xb9",
        p,
        q,
        g,
        b"\x74\xa9\x3c\x73\xd7\x55\x00\xca\x43\x05\xca\x31\x84\x47\x5b\x53\xd9\x6c\x6f\xdd\x41\x7e\xf2\x3d\x9d\xc6\x1b\x80\xbb\xc1\x10\x82\x28\xd2\x54\x3c\x1c\x3a\x9f\x2e\x77\x83\xca\x69\xb0\x19\xc0\xcd\x9a\x6d\x2b\x62\xb0\xed\x93\xd4\x22\x9d\xa8\x7b\xfc\x21\xf9\xe4\xbd\x0d\xea\x2c\x4e\x6d\x4d\x2f\x88\x20\x1a\xb0\x50\x4b\x31\xf4\xef\x15\x58\xad\xf4\x93\xe4\x70\xad\xfc\x57\x2c\xa6\x8d\xeb\xc4\x61\x23\x58\x9a\xe9\x13\xb9\x67\x98\x3d\xbc\xac\x6b\xf3\xbd\x86\x11\x13\x7e\x39\xd5\x87\x00\x57\xae\x18\xcb\x84\xa7\x6a\xae\x30",
        b"\x1e\xd1\x31\xc9\x6a\x2c\x31\x0e\x1f\x79\x76\xd3\x08\x2a\x69\xa5\xaf\x45\xbd\xd0",
        b"\x70\x66\x3e\x9a\xd7\x11\x3a\xe5\x7d\x4a\xf6\x90\x77\x12\xe0\xaa\xf8\x8b\xc0\x7a",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x34\x0d\xf7\x08\xd4\x57\xdf\x94\x13\xef\x2b\xda\x22\x5c\x5f\x55\x8b\x90\x96\x6c\xdd\x53\x1a\x0b\x5a\xa7\x45\xd5\xc3\xea\x79\x0d\xeb\xea\x22\x48\x61\xef\x12\xfb\x16\x38\xbf\xf0\x12\x1f\xf2\x6d\xbd\xcf\xfc\x29\x9b\xf9\xf3\xa9\xc1\xfe\x60\x27\x40\x0f\xf1\x4c\x34\xfb\x06\xf6\x7d\xb9\xc3\x0a\x1d\xcb\xfd\x99\x69\x03\x52\x3d\x85\x04\x63\x82\xff\x28\x04\x18\xd9\x74\xa3\xec\xe6\xb5\xfa\xfe\x30\x5e\x2e\x79\xb1\xd0\x7a\x7c\x1e\xeb\x7a\x12\x77\xa8\x22\x82\xbe\x62\x83\x1d\xf7\xfe\xe3\x88\x41\x46\x26\x02\x98\x6a\x8e\x9b",
        p,
        q,
        g,
        b"\x61\x50\xa6\x8d\x64\xad\xda\x3d\x3f\xb5\xa9\x73\xc6\x2b\x99\x2a\xd3\xfe\x53\x8a\xf7\x16\x1b\xae\x41\xea\x2f\x17\x99\x30\x4f\xe5\xb8\xc8\x64\xe0\x61\xd1\x33\xd9\x4c\x16\xa4\xc6\xb0\xed\x8d\xff\xdf\x2c\xef\xa7\x39\x40\x15\xe7\x5c\x57\xb1\x81\x41\x9d\xcf\xef\xe3\x40\x9d\x3b\x53\xd8\x69\x11\xc7\x49\xf9\xf2\x8f\x7c\x1d\xe9\x9f\x7e\x4b\x2e\xa2\x2a\x48\x81\x7a\xce\x4f\xd9\x97\x4f\xa5\x3b\x8d\x4f\x05\xf5\x73\x14\x88\x81\x38\x03\xd7\xf3\xaa\xf1\xcf\xa1\x38\xbc\x73\xc4\xd2\x7c\xa1\x62\x1e\x92\x26\x66\x18\x83\xe9\xdd",
        b"\x4f\x18\x2a\xd4\x2c\xb5\x67\x1d\x31\x62\xbb\x9d\x04\xa0\x6c\xd2\x0e\xdb\xc5\x58",
        b"\xa6\xc5\x41\x79\x47\x44\x77\x18\xed\x1c\xb8\x9a\x6e\xfc\xe2\xd3\x11\x6e\x50\xd1",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x9f\x23\xc8\x25\x63\xab\x7c\x0b\xa8\x6b\xbb\x98\x93\x35\x00\x0a\x49\x3b\x29\x1e\x5d\xc1\x7c\xe7\x29\x49\x49\x58\x90\x36\x23\xed\x99\xdf\x34\x42\x30\xff\xb6\x26\xb1\xdb\xef\xcc\xe0\x59\xae\x16\xc2\xee\x7e\xe6\xfd\x2a\x78\x07\x33\x6c\xb7\x1b\x88\x53\xe2\xed\x3b\x74\xb2\xfa\xac\x82\xa8\x31\xd5\x3e\x03\xd7\xbb\xb9\x6d\x38\xdf\x98\xfd\x19\xbd\x4c\x1a\x62\x48\xcd\x50\x7c\x89\xf7\x99\x5f\x59\x57\x9a\xfe\x53\x19\x73\x1b\x44\x3d\x68\x71\xe5\x58\xf5\xb7\x7f\x2f\x9a\x4d\xd9\x9e\xfb\x30\x5e\x27\x91\x65\x94\x52\x4e\x02",
        p,
        q,
        g,
        b"\x96\xd7\x45\x11\x81\xfb\x25\x3f\xbc\x3f\x44\x14\x09\xbe\x5e\x5e\x01\x44\x97\x26\x10\xe3\x7f\xa8\x2b\xc2\xaf\x24\x66\x37\xa4\xc9\x18\x02\x30\x97\x87\x52\x55\xa2\x17\xea\x89\x5d\xad\xdf\x46\xbf\xbb\x17\x47\x49\xb0\x4c\x59\xfe\xfa\x62\x89\x68\x4f\x2f\x9a\xea\xdf\x5c\xe7\xca\x47\xf0\x03\x2e\x38\x4b\x7d\x50\x59\x79\x01\x18\x15\x01\xcb\x59\x15\xfb\x46\x86\xa6\xad\x7b\xcd\x5b\x46\x86\x24\x11\xa4\xdf\x22\xb1\xed\x2a\x56\x90\x5e\x07\xc0\xa9\x36\xc9\x94\x42\x13\x19\x4e\xbe\xfd\x4e\xc6\x85\x97\xcc\xa0\x36\x33\x8b\x3c",
        b"\xb6\x59\x9f\xbd\xdb\x48\x56\x27\x6d\xf4\x48\xcf\x09\xd6\x2f\xd7\x65\x7d\xe6\xc3",
        b"\x4b\x49\x58\x90\x99\xbe\x55\x78\x32\x2d\x82\x9b\x87\xb4\x3a\xc0\x7f\x62\xe3\x5d",
    )?;

    // [mod = L=1024, N=160, SHA-512]
    let p = b"\x88\xd9\x68\xe9\x60\x2e\xcb\xda\x6d\x86\xf7\xc9\x70\xa3\xff\xbe\xb1\xda\x96\x2f\x28\xc0\xaf\xb9\x27\x0e\xf0\x5b\xc3\x30\xca\x98\xc3\xad\xf8\x3c\x07\x2f\xeb\x05\xfb\x2e\x29\x3b\x50\x65\xbb\xb0\xcb\xcc\x93\x0c\x24\xd8\xd0\x78\x69\xde\xae\xcd\x92\xa2\x60\x4c\x0f\x5d\xd3\x5c\x5b\x43\x1f\xda\x6a\x22\x2c\x52\xc3\x56\x2b\xf7\x57\x1c\x71\x02\x09\xbe\x8b\x3b\x85\x88\x18\x78\x87\x25\xfe\x81\x12\xb7\xd6\xbc\x82\xe0\xff\x1c\xbb\xf5\xd6\xfe\x94\x69\x0a\xf2\xb5\x10\xe4\x1a\xd8\x20\x7d\xc2\xc0\x2f\xb9\xfa\x5c\xef\xaa\xb5";
    let q = b"\xa6\x65\x68\x9b\x9e\x5b\x9c\xe8\x2f\xd1\x67\x60\x06\xcf\x4c\xf6\x7e\xcc\x56\xb7";
    let g = b"\x26\x7e\x28\x28\x57\x41\x77\x52\x11\x3f\xba\x3f\xca\x71\x55\xb5\xce\x89\xe7\xc8\xa3\x3c\x1a\x29\x12\x2e\x2b\x72\x09\x65\xfc\x04\x24\x52\x67\xff\x87\xfc\x67\xa5\x73\x0f\xe5\xb3\x08\x01\x3a\xa3\x26\x69\x90\xfb\xb3\x98\x18\x5a\x87\xe0\x55\xb4\x43\xa8\x68\xce\x0c\xe1\x3a\xe6\xae\xe3\x30\xb9\xd2\x5d\x3b\xbb\x36\x26\x65\xc5\x88\x1d\xaf\x0c\x5a\xa7\x5e\x9d\x4a\x82\xe8\xf0\x4c\x91\xa9\xad\x29\x48\x22\xe3\x39\x78\xab\x0c\x13\xfa\xdc\x45\x83\x1f\x9d\x37\xda\x4e\xfa\x0f\xc2\xc5\xeb\x01\x37\x1f\xa8\x5b\x7d\xdb\x1f\x82";
    test(
        HashAlgorithm::SHA512,
        b"\x3a\x84\xa5\x31\x4e\x90\xfd\x33\xbb\x7c\xd6\xca\x68\x72\x0c\x69\x05\x8d\xa1\xda\x1b\x35\x90\x46\xae\x89\x22\xca\xc8\xaf\xc5\xe0\x25\x77\x16\x35\xfb\x47\x35\x49\x15\x21\xa7\x28\x44\x1b\x5c\xb0\x87\xd6\x07\x76\xee\x0e\xcc\x21\x74\xa4\x19\x85\xa8\x2c\xf4\x6d\x8f\x8d\x8b\x27\x4a\x0c\xc4\x39\xb0\x09\x71\x07\x7c\x74\x5f\x8c\xf7\x01\xcf\x56\xbf\x99\x14\xcc\x57\x20\x9b\x55\x5d\xc8\x7c\xa8\xc1\x3d\xa0\x63\x27\x0c\x60\xfc\x2c\x98\x8e\x69\x2b\x75\xa7\xf2\xa6\x69\x90\x3b\x93\xd2\xe1\x4e\x8e\xfb\x6f\xb9\xf8\x69\x4a\x78",
        p,
        q,
        g,
        b"\x60\xf5\x34\x1e\x48\xca\x7a\x3b\xc5\xde\xce\xe6\x12\x11\xdd\x27\x27\xcd\x8e\x2f\xc7\x63\x5f\x3a\xab\xea\x26\x23\x66\xe4\x58\xf5\xc5\x1c\x31\x1a\xfd\xa9\x16\xcb\x0d\xcd\xc5\xd5\xa5\x72\x9f\x57\x3a\x53\x2b\x59\x47\x43\x19\x9b\xcf\xa7\x45\x49\x03\xe7\x4b\x33\xdd\xfe\x65\x89\x63\x06\xce\xc2\x0e\xbd\x84\x27\x68\x2f\xa5\x01\xee\x06\xbc\x4c\x5d\x14\x25\xcb\xe3\x18\x28\xba\x00\x8b\x19\xc9\xda\x68\x13\x6c\xf7\x18\x40\xb2\x05\x91\x9e\x78\x3a\x62\x8a\x5a\x57\xcf\x91\xcf\x56\x9b\x28\x54\xff\xef\x7a\x09\x6e\xda\x96\xc9",
        b"\xa5\x3f\x1f\x8f\x20\xb8\xd3\xd4\x72\x0f\x14\xa8\xba\xb5\x22\x6b\x07\x9d\x99\x53",
        b"\x11\xf5\x3f\x6a\x4e\x56\xb5\x1f\x60\xe2\x0d\x49\x57\xae\x89\xe1\x62\xae\xa6\x16",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x6f\x39\x97\x3f\xd2\x25\x16\x7a\x76\x73\xcd\x71\xab\x35\x34\xd2\x68\x66\x87\xc3\x32\xf9\x3f\xd6\x6d\xb5\xf1\xca\x99\x67\x8e\xfd\x28\x25\xa8\x4c\xd7\xa7\x10\x7a\xdf\x96\x50\x1d\xd1\xd0\x5e\x7b\xbc\x8d\x11\x3e\x08\x7b\xba\x77\xb2\x34\x6b\x43\x64\x13\x21\x25\x24\x5e\x9a\xac\xe3\xa1\x46\xb5\x76\xf6\x54\xc8\x6e\x07\xfc\x19\x14\xca\xfa\x20\x9d\xd6\xd0\x48\x45\x57\x5d\xbb\x27\x9c\xd1\xb2\x32\x96\xd0\x1e\xf5\x05\xb5\xe1\xce\x7f\x21\x94\xf1\x89\x88\xf3\x55\xc9\xb3\x4f\x92\x0a\xb3\x51\x52\xe0\x3b\xcf\x79\x2a\xc5\x29",
        p,
        q,
        g,
        b"\x11\x0e\x39\x8e\x36\xc9\xd2\x72\x6e\x77\xde\xb4\x65\xdd\x23\x30\x3f\x9e\x38\x77\x78\xb5\x49\x70\x0a\x52\xb9\xa5\x46\x85\x12\xee\x37\x7c\xe3\xd7\xdc\xbf\xc6\xb6\x4e\xe3\x53\xea\xc6\xa4\x38\x98\xb2\x64\x84\x05\x8b\xa1\xb2\x4b\x22\x9c\xd6\x9c\x99\x4d\x97\x6d\x43\x34\x4c\x18\x1e\xa6\xc4\x7d\xf0\x06\x2c\x09\xa1\x6b\x23\xab\x60\x75\xc0\x4a\x08\x99\xba\xc3\xe4\xf0\x34\xa9\x83\xbf\x90\x43\x8f\x6a\xc2\x68\x55\xd8\xa5\xfd\xed\x90\x17\x2e\x7e\x8c\x19\x6a\x2c\xe7\xe1\xfc\x0d\xac\x94\x27\x8a\xff\x16\x53\xc3\xae\x09\xf5",
        b"\x1b\x9e\xd3\x9b\xcc\x4b\x46\xed\x00\x07\x67\x9c\xe9\xc3\xf6\xdc\x7c\x41\x57\xb9",
        b"\x25\x8d\x41\x36\xad\x95\xb7\x04\xa7\x95\x9d\x04\x09\x6d\xcd\x78\x1e\xb5\x4b\xde",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x7f\x59\x74\x4c\x79\x0c\x0f\x98\x5a\x9a\xe1\x01\xd9\xfa\x00\xda\x3b\x95\xd2\x47\x3d\x79\x28\x05\xec\x1d\x6d\x1e\x95\x22\x2a\x6f\x30\xee\x6a\xb8\xfc\x5a\x63\x20\x57\x15\x3f\x23\x7a\xd3\xaa\x2f\xae\x8f\x1e\x51\xea\xe7\x59\x06\xd0\x7e\x57\x6d\xd0\x02\x1a\xc1\x71\x1b\x1c\x88\x53\xe6\x2d\x27\xfe\x6b\x09\x87\x66\xb8\xce\x3e\x76\xd3\x47\xc8\xe4\x9b\xe0\xab\x05\xd0\xd1\x2f\xd7\x77\xa8\x5c\xff\xc7\xad\x12\x07\xa9\xaa\x75\x64\x3d\x7b\x41\x5b\xa4\xb1\xb9\x7d\xc0\xee\x19\xd0\x5a\x60\x7b\xa0\x63\xa0\x34\x1f\x17\x61\x04",
        p,
        q,
        g,
        b"\x3e\xad\x9c\xf2\x11\xf3\x85\x9d\x5b\xaa\x51\x55\xfb\x62\x33\x1b\xca\x3f\xff\x9e\xcb\xe1\x82\xeb\xf8\xb0\x4d\xb0\xeb\xb1\x9e\xda\x54\x8c\x86\xdb\x4c\xbb\x5e\xca\x98\xce\x44\x9c\xfd\x51\xf1\xc4\x60\xd7\x84\x83\x26\xee\xe2\x2f\xca\xc7\x24\x7f\xb8\x89\xee\x41\x5c\x49\x33\xa9\x09\xc7\x8c\xe9\xbc\x50\xee\x19\x01\x16\xda\x9a\xe2\x54\x7a\xe6\x24\x2a\x34\x0d\xdb\xb9\xa1\x5a\xc8\x18\xc4\x67\x7f\x29\x19\xc6\x45\x09\xd0\x3c\x49\xd1\x30\x7b\xb2\xcd\x78\xe0\x1c\xe5\xb2\x5a\x9f\x47\xd8\x28\xfc\x75\x84\xeb\xce\x36\x6c\x2f",
        b"\x38\xf5\x2d\xf7\x8b\x0e\x45\x4d\x35\x83\x20\x8a\x0f\xce\x03\xb9\x04\xee\xc8\x16",
        b"\x5c\xdc\x57\xa9\x43\xab\x1f\x26\x9c\xa1\x1c\x63\xbc\xb1\x05\x9e\xe7\x6f\x9c\x2e",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x16\x25\x0c\x74\xcc\xb4\x04\x43\x62\x5a\x37\xc4\xb7\xe2\xb3\x61\x52\x55\x76\x82\x41\xf2\x54\xa5\x06\xfa\x81\x9e\xfb\xb8\x69\x8a\xde\x38\xfc\x75\x94\x6b\x3a\xf0\x90\x55\x57\x8f\x28\xa1\x81\x82\x7d\xda\x31\x1b\xd4\x03\x8f\xd4\x7f\x6d\x86\xcc\xeb\x1b\xbb\xef\x2d\xf2\x0b\xf5\x95\xa0\xad\x77\xaf\xd3\x9c\x84\x87\x74\x34\xad\xe3\x81\x2f\x05\xec\x54\x1e\x04\x03\xab\xad\xc7\x78\xd1\x16\xfd\x07\x7c\x95\xc6\xec\x0f\x47\x24\x1f\x4d\xb8\x13\xf3\x19\x86\xb7\x50\x4c\x1c\xd9\xdd\xb4\x96\xac\x6e\xd2\x2b\x45\xe7\xdf\x72\xcc",
        p,
        q,
        g,
        b"\x6e\x8c\x85\x15\x0c\x5c\x9c\xa6\xdc\xb0\x48\x06\x67\x1d\xb1\xb6\x72\xfc\x10\x87\xc9\x95\x31\x1d\x70\x87\xad\x12\xab\x18\xf2\xc1\x4b\x61\x2c\xea\x13\xbf\x79\x51\x8d\x2b\x57\x0b\x8b\x69\x6b\x3e\x4e\xfc\xd0\xfd\xa5\x22\xa2\x53\xbb\xcb\x7d\xbb\x71\x1d\x98\x4c\x59\x8f\xa2\x01\xc2\x1a\x8a\x9e\x27\x74\xbc\x15\x02\x09\x20\xcd\x8c\x27\xc2\x87\x5c\x77\x9b\x08\xef\x95\x09\x3c\xaa\xc2\xc9\xce\xa3\x7e\xc4\x98\xc2\x3d\xd2\x4b\x68\x4a\xbc\xb4\x67\xec\x95\x2a\x20\x2c\xbd\x2d\xf7\x96\x0c\x1e\xf9\x29\xcc\x2b\x61\x1c\xa6\xc8",
        b"\x00\x01\x8f\x0f\xdc\x16\xd9\x14\x97\x1c\x8f\x31\x0f\x1a\xf7\x79\x6c\x6f\x66\x2a",
        b"\x62\xb7\xae\xcc\x75\xcb\xc6\xdb\x00\xdd\x0c\x24\x33\x9f\x7b\xdb\x5a\xe9\x66\xa5",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xa2\xce\x90\xb5\x1a\x48\x0c\x06\x68\xb5\x59\x36\xbb\xee\xbe\x36\x79\xf8\xd4\x06\xa0\xb6\x94\xb9\x03\x45\x74\x9e\x3b\x9c\x67\x77\x6c\xae\x9a\x62\xc2\x5c\xc0\x11\xcd\xb3\x18\x02\x63\xdd\xd7\x3a\xa2\x09\x0e\xc7\xa7\x49\x09\x2f\x6c\x78\x16\xc2\x67\x44\xc5\x39\x3a\xcb\x08\xc6\xb7\xb3\x59\xbb\x3a\x3c\x75\x43\x68\x4f\x80\x50\xec\xc6\x42\x22\x34\xff\x24\x97\x8a\xe0\x6b\x91\xd6\xa2\x4c\x08\x6d\x71\xeb\x17\x61\xca\xf1\x41\x76\xd8\xba\xcd\xca\xd5\x3b\x78\x95\xbd\xb0\xe0\x53\xc6\x16\xb1\x47\xff\x73\xd2\xd8\x6b\xa3\xbc",
        p,
        q,
        g,
        b"\x0e\x6b\x41\x9d\xa8\xb4\xdb\x80\x2d\x93\x88\x73\xe3\xb1\x05\xab\x3e\xff\x43\x2d\x8a\x13\x76\x60\x20\x59\xcf\x2e\x51\x0f\x69\x6a\x2a\x4e\x42\x02\x56\x70\xdb\x00\x11\xe9\xbe\x31\xe8\xb1\x40\x36\x15\xb9\xa3\x39\xce\x65\x4a\x89\xa2\xd4\x62\xee\x20\xc0\x80\xc4\x47\x96\x48\xc5\xc0\x0e\x17\x2e\xcd\x53\x7c\x93\x4e\x75\x34\xaf\x70\x02\xbd\x6f\xda\xfa\xb5\x65\x06\x68\x0c\x01\x9c\xed\x38\x77\x9d\x95\x40\x91\x64\x5f\xed\xf5\xd0\x05\x7a\x23\xff\x63\x49\x19\xfc\x56\xa9\x67\x71\xce\x21\xfa\x99\xec\xd9\xaa\x7f\x79\x85\xf1",
        b"\x5b\x13\xf1\x33\x7a\xc7\x2e\x41\x98\x67\xc9\x2f\x93\x87\xf9\xdf\x62\x88\x3a\xa5",
        b"\x90\xab\x5b\x68\xfd\x82\x53\xb6\xbb\x64\xc6\x17\x59\x16\x4a\x97\x83\x4c\x39\xe1",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x3b\x6e\xea\xed\xc5\xfb\x38\xce\x86\x91\x68\x6c\x89\x99\x3c\xaf\x17\xc9\xe2\x4f\xa5\x65\xa9\xe8\xd4\x84\x36\xb8\x7d\xb6\x2f\xab\x83\x9c\x42\xd8\x1f\xb1\xf8\xb8\x96\x8c\x82\x6e\x78\xd3\x33\xb1\xd9\x9d\x5c\x36\xe0\x8a\x9a\x0e\xc7\x55\x4c\x2b\xde\x07\xfd\x8e\xc4\x22\xaf\x12\x82\x46\xba\x3b\xea\xe1\x8e\xf2\xbe\x75\x5d\xb2\x2a\x86\x92\x02\x95\x1c\xd9\x57\x96\xfc\x2f\xf7\xba\x2a\x69\x67\xd1\x9e\x5c\xa2\x30\x46\x55\xbf\xdf\x87\x9b\x77\x47\xf8\x0a\x59\xb1\xda\xc0\x46\x1c\xf6\xe4\x90\x37\x8e\x56\xab\x37\x85\x84\xf2",
        p,
        q,
        g,
        b"\x4a\x7f\xf6\x67\xf7\xab\x28\x91\xa8\xa6\x9a\xb5\xd1\x5d\x93\xd1\xfd\x83\x39\x06\xc9\xb6\x29\xfc\xb9\xb4\x9e\x84\xd8\xec\xb3\x5b\x39\x7d\x93\x83\x9d\x79\x85\x59\x03\x26\xcf\xfb\x55\xa7\x0e\x4a\x51\xa2\x82\x9e\x38\x72\x90\xf6\xfa\xfb\x7d\x22\x61\x51\xc2\x82\x47\x02\x24\xfd\x71\x7f\x3d\x52\x65\x89\xc6\xee\xd9\x61\x1c\x5b\xdf\x4b\xde\x63\xfc\xc9\x20\x4c\x80\x07\xb0\xb1\x43\xc4\x9d\x19\x81\x83\x56\x58\xbc\xf8\x00\xa2\x15\x7c\x5c\x14\x3d\x76\x36\x9f\xd6\xe7\x8d\x0a\x3f\x80\x0b\x8a\x3a\x8f\x0e\x11\xc9\x05\x9d\xcd",
        b"\x61\x38\x0c\xa8\x67\x98\xfc\x5f\xb6\x1c\x35\x67\x5a\xf0\x8d\x5c\xc1\x3c\x25\xaa",
        b"\x54\xdd\xf6\x8f\x47\x68\x84\xaf\x3e\x0e\x65\x36\xf3\xa8\x09\x25\xee\x63\xa4\x02",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x01\x19\x7a\xe9\x60\xde\x90\xa9\x3d\x97\x36\x89\x6f\xe1\x36\xbc\x56\x1f\x05\x50\xc6\xb1\xcc\x36\x31\xb3\x1d\xf6\x83\x01\x7c\x2a\xb8\xc6\xf4\x1d\x27\x45\xf1\xa7\x97\xe0\xe8\x9d\xc3\xd5\x87\x88\x66\xc3\x69\x4a\x08\x03\x66\x75\x7e\x6f\xd8\x92\xd2\x66\x68\xfd\x2d\x86\x0e\xa2\xa2\xb6\x7f\xda\xca\x96\xe3\x22\x97\x75\x87\x87\xec\xc0\xa7\xe1\xd3\x04\xcc\x71\x98\x03\x27\x2e\x72\xe3\x39\xb3\xf3\x4c\x34\x7e\x47\xb9\x1a\x1e\xd6\x9c\xa8\x06\x2c\xd3\x50\xdc\xcc\x9c\x22\x64\x73\x2b\x9f\xdd\x84\x62\xd9\xf6\xfc\x76\x85\x0c",
        p,
        q,
        g,
        b"\x37\x30\x81\x77\x0a\x9f\x4d\xae\x8d\xf5\xdf\xa7\x05\x03\xe1\x49\xd7\x59\xca\x37\x40\x85\x49\xaa\x34\xd1\xb4\x9b\x31\x76\xa3\x9d\x7c\x46\x61\xe4\x21\xa1\xf5\xd6\x1e\x3f\x77\xb3\xc4\xb3\x9b\xb2\xe6\x3c\xd2\x49\x19\xa2\x91\x0a\x8b\x15\x5e\x17\x58\xf5\xa3\x75\xda\x60\xf1\x9d\x2b\xf4\x02\x0e\x82\x8f\x42\x37\xeb\x3e\x2a\x36\x12\x4a\x6a\x39\x14\x46\x9d\x68\x33\x69\x5b\x83\xb9\x37\x7f\xb2\x85\xb2\x7b\xd2\x68\x99\x33\xc1\x89\xc7\xfd\xe4\x2e\x1e\x0e\x20\x30\x83\x31\xfd\x56\xed\x0d\xb2\xef\xbc\x77\xea\x3a\xc7\x12\x1f",
        b"\x41\xed\x17\x0c\x8b\xf6\xf2\x0f\xd1\xce\x18\xfa\xac\x97\x56\x5f\xdb\x4f\xe6\xf4",
        b"\x7c\x8c\x6f\xea\xce\x68\xc9\x7c\xa4\x37\x80\x74\x1f\xae\x58\xf2\xf6\x1b\xf7\x65",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x0d\x5a\xb2\x7b\x2b\x7e\x18\xcf\xce\x4c\xcd\xa1\x3a\xa1\xa5\xa8\xc1\x8b\xaa\xf3\x9b\x14\xe6\x42\xb8\xf8\x1b\x30\xcd\x54\x18\xa1\xdd\x05\xdf\x22\x59\x9f\xbb\xb3\xba\xe4\xfe\xe1\xe4\xb2\xc1\x50\xa2\x3e\x21\x6c\x13\x3f\xe2\xd8\x23\x54\x85\xe3\x4f\x80\x68\x5c\x66\xbc\x0c\x19\x0a\xf6\x7a\x0a\x49\x93\x0b\x47\x6b\x28\x03\xe1\x22\x74\xcd\x43\x09\x09\x21\xbf\x66\x8f\xdf\xef\x15\x50\x72\xa3\xcd\xf1\x79\x01\x42\x7a\xfa\x51\x31\x8a\xfd\xda\x93\x7e\x28\x3e\x2c\x60\xd8\x5e\x3b\xfe\x07\xf3\xda\x5f\x99\x2c\x1f\xca\x4b\x98",
        p,
        q,
        g,
        b"\x1c\xa3\x6e\x35\x05\xee\x70\xa5\x6a\xfd\x5d\xc4\x0a\x48\xe9\x79\x79\xe9\x84\xdd\x2d\x89\x6a\xbc\x7a\x49\x1d\x34\x61\xc6\x93\x16\x68\xa0\xce\xf1\x1e\x45\xbb\x66\xc6\x11\x13\x79\x99\x90\x7a\xd7\xe1\xf7\xcf\xea\x7f\x7e\xd4\x9a\xae\x93\x5b\xfc\x41\x44\x32\x93\xe7\x1d\xd2\xfe\xc2\x9f\x37\xa9\x54\x46\x72\xab\x92\x50\xca\xa2\x81\x88\xf3\x90\xb5\xd4\xaf\x13\xbb\x05\xe9\x69\x2c\x1c\x6a\x4d\x6a\xaf\xeb\xdd\xaf\x7e\xef\x18\x34\xff\xfe\x0f\x53\x91\xbc\xe2\x43\x78\x9a\x2d\x55\xd2\x9e\x2b\x90\xce\x12\x04\x29\xf2\xa0\x75",
        b"\x66\x01\x5e\x5f\xb3\xab\xe9\xd7\x85\x23\x77\x0f\x7b\xa0\x99\x00\x31\x06\x5a\xd7",
        b"\x4b\x8b\x15\x3d\x5b\x01\xdd\xfa\x91\xf2\xde\xc6\xf0\xfa\xff\x02\xe6\xe8\x72\x18",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x90\x6a\x93\x3b\xc8\x23\xa3\x07\xe2\xab\x29\xa4\xa8\xf7\xf1\x51\x0d\x5d\x30\x35\x04\xfd\xe3\x81\x69\xde\xd1\x68\x91\x3e\x3b\xf8\x1d\x53\xa4\x38\x9a\x3e\x73\xa3\xef\xeb\xd5\xe4\x2c\xf4\x02\xbf\x9f\xdc\x5d\xa5\xef\x46\x87\x81\x65\xad\xa6\xd2\xe0\x72\x99\x03\x5a\x39\x87\xed\x6c\x2c\x6c\x8b\xec\xc4\x4e\xa1\x31\xa9\x49\x3e\x72\xae\xe2\x82\x42\xcf\x7c\xfa\xc3\x8e\xe8\x70\xe5\x4e\xb9\x5a\x6e\xfa\x9f\xad\x74\x35\x4b\x28\x1c\xb6\x3e\xa7\x16\x52\xeb\xa1\xad\x73\xf8\x41\xdb\xa7\x77\x8f\x3a\x03\xd3\xe0\x01\x90\xed\x68",
        p,
        q,
        g,
        b"\x4f\x3a\xde\x3e\xa4\xf7\x06\x61\x07\x32\x1e\x8b\xfb\x12\xee\xaf\x9b\x3c\x7b\xdc\xc6\x14\x79\x08\x75\x42\x31\x15\x6b\x46\xe0\x63\x9c\x9d\xb9\xd5\x44\x7a\xbd\x2d\x0a\x92\x23\xc8\x5d\x63\xd8\xb1\xdf\xa6\x97\x42\xeb\xf7\xe0\x41\x9e\x60\x8c\x4b\x18\xc3\xad\x9f\x55\xf5\xd2\x84\x8e\xdb\xec\x4e\x71\x80\xe3\x4b\xfb\xb1\xf6\xb6\xeb\xbb\x68\x64\x97\x14\xb5\xfb\xfa\x6c\xfa\xb4\xa0\x1f\x65\x50\x08\xa9\x5a\x7e\xed\xcd\xc2\xf7\x17\x10\x94\x56\x3a\x3c\x18\x31\xe8\x1f\x5c\xa0\x75\xc6\xe8\x53\xbe\xea\xe8\x7a\x67\xff\x90\x22",
        b"\x99\xc9\x1e\x07\x94\x72\x3b\xcd\xe3\x45\x94\xdd\x22\x68\x41\x8d\xfb\x35\x34\x43",
        b"\x42\xe9\xc4\x9d\x60\xad\x8f\x9b\x41\xf2\x90\xae\x6b\x77\x2f\x44\xbe\x62\xce\xa9",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x1d\x6b\xa4\x3a\x0f\xf6\x77\xcf\x8c\xf6\x8d\x6a\x1d\x33\x04\xd9\x94\x90\xa7\xca\xe5\x6f\xe3\x53\x18\xf3\x8e\xd0\xf5\x87\x9f\xe2\x54\x70\x3f\xa7\x74\x58\xc4\x5e\x8a\x69\x84\x69\xb8\x99\xa2\x15\xc2\x5e\x86\x9f\xd2\x87\x41\x10\x1d\x27\xdc\x11\x1f\xfa\xd6\x98\x0f\x8e\xbd\x74\x8f\x69\x77\xd5\xd6\x04\x38\xe6\xed\xec\x37\xa4\x9d\x30\x11\xf8\xf0\xf0\x85\x25\x15\x6a\xe6\x0b\xc9\x1a\xbe\x66\x16\x38\xf4\xb9\xc6\xc3\x65\xc3\xaf\x17\x13\xbf\x7f\x72\x25\xd4\xaf\xad\x7a\x1b\x53\x1a\x33\x11\x33\xd8\xb8\xfd\x23\x85\x98\xa4",
        p,
        q,
        g,
        b"\x08\xad\x77\xf2\x33\x33\x4c\x04\xca\x22\x82\xf6\xda\xc0\xb0\xd8\xa0\x0d\x59\x6e\x02\xe8\x36\xa7\x67\xa1\x46\xef\x80\x62\x4b\x33\xfd\xba\x8b\x35\x20\x4b\x20\xbe\xe8\xff\x2b\xe9\xa8\x2b\xd8\x01\x31\xc0\xaa\x89\x8b\x17\xee\xab\x5a\xf2\x4c\x20\x55\x1d\x5d\x63\x6a\x11\x54\x8f\xdd\x2e\x6c\x61\x6b\x09\xdf\x86\xb0\x57\xe5\x70\x21\x46\xec\xc4\xfa\x2d\x44\xd8\x5b\xb1\x42\x7e\x7e\x35\x76\xf6\x98\xb4\xf2\x16\x45\xa1\xe0\x04\x79\xd0\x89\x82\xb0\x57\x3d\xd1\x98\x1b\xbd\x40\x5c\x2a\x45\xd7\xde\x92\x42\xaf\xae\x8f\x95\xc9",
        b"\xa2\xb4\x2c\xca\x55\xbc\x1b\xa3\x3f\x82\x52\xd1\xa8\x9c\x8d\x89\xb0\x0b\x39\x50",
        b"\x2e\xc5\x16\x6e\x35\xe6\x3f\x0f\xa1\x16\xb3\xdb\x1b\xd1\x86\x81\xa4\x39\x9c\x04",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x3b\xd0\xc5\xb7\x59\xcb\x71\x0c\x52\xb8\x1f\xba\x48\xb6\x77\x1c\xab\x17\xbf\x1b\x67\xea\xfd\x08\xf4\xee\x17\x77\xdd\x47\x30\x64\xdd\x0b\xec\x98\xd3\x58\x2e\xe1\xe9\x91\xab\x9a\x91\xa6\xfe\x55\x8a\x41\xdb\x9a\xe6\xb2\x1a\x05\x79\x32\x81\x14\x40\xd6\x4c\x78\x6b\x22\xd1\x50\xe3\xd3\x8c\x71\x90\x0a\xd5\xb6\x1e\x05\x30\x74\x4e\x76\x5b\x5c\x2e\xf3\x0b\xcb\x96\xe7\x26\xe3\x07\x9e\x44\x00\x86\xef\x30\x0b\xae\x90\x00\xdf\x34\x03\xc3\x3a\x79\x84\x9f\x8f\x83\xd6\xc0\x3f\x77\xea\xe9\x80\x52\x57\x8d\x82\xd6\x28\xe6\x5c",
        p,
        q,
        g,
        b"\x3a\x1e\xd9\x76\xb7\x93\x4b\xee\x3e\x80\xd6\x9f\xbc\xdd\x35\xf8\x20\x51\xcc\xc2\x14\xbd\xe6\xfa\x75\x6b\xe6\x70\x17\xff\x60\xac\x68\x47\xcf\x8d\x1f\x82\x3f\x89\x0d\x26\xaf\x8c\xd3\x51\x71\x6a\xd2\xd4\xee\xfd\x7f\x06\xc1\x95\x1e\xa4\xa7\xdb\x5c\xaf\x25\x0f\x40\x7b\x78\xf2\x1f\xff\x42\x5d\x0c\xba\x1b\x5f\xb3\x5a\x5b\x5d\xcf\x06\x2a\x1c\xdf\x25\x07\xaf\x74\x78\x93\x26\x71\x0e\x33\x4f\xaf\x3c\x50\x1b\xd8\xc8\x34\x72\x25\xf9\x4f\x89\x73\xad\xb7\xa8\xb5\xde\xf9\x89\x61\x09\xd1\xef\xe5\x50\x32\x5d\xd8\x9f\x31\xd6",
        b"\x77\xd6\x2e\xc2\xa9\x5b\xeb\xa6\xc6\x72\xd8\x42\x2e\xe6\x63\xd1\xd1\x80\x49\xd0",
        b"\x2a\x33\x9c\xc8\xf5\x67\xc1\x21\x49\xa8\x91\x73\x75\xec\x6c\xa4\xb4\x72\x54\xa1",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x8d\xc5\x82\xa2\xb5\xaf\x65\xe6\x6e\xbd\xf5\xb5\x33\xd8\xe2\x2b\x38\xb5\xc1\x97\x7e\x57\x8d\x32\x13\xa1\x10\xe9\xd4\x83\x7a\x74\xd4\xb7\xbf\x7d\x71\x87\x56\x90\xb5\xb7\x1c\x8e\x8a\xfa\xb8\x94\x34\xc4\x6a\x86\x41\xcc\xed\x1a\x13\x0e\x21\xcd\x0c\x80\x5e\xe4\x5c\x13\x4c\x7c\x0d\xf7\x5d\x5c\xd3\x0c\x41\x81\x8f\x7a\xe4\x75\xdd\x60\x22\x87\x7c\x74\x3d\x09\xd5\x4f\x0c\x94\x58\x1a\xe7\xbd\x4b\x42\x3f\x02\xe1\x93\x97\xbe\x7b\xd4\xa9\x04\xb8\x8c\xbd\x2f\x81\x4b\x1d\xff\x1e\x79\x6d\x9f\x2d\x1c\x84\x70\xb7\x96\xc6\x9a",
        p,
        q,
        g,
        b"\x5d\x6d\xc1\x74\x9f\x28\xcb\x8f\x7c\x01\x4d\x5c\x55\x16\xcf\x5b\xc2\x22\xc6\xd9\x33\x7a\xc0\x08\x9b\x19\xb9\x0b\x32\x19\x56\xcf\x61\x92\xf3\x25\x5d\x0e\xec\x45\x84\x08\x10\xc2\x1f\xe9\x1c\xf5\x30\x89\x48\x85\x2a\x57\xcd\x01\x89\xf1\x5b\xd9\x6a\xf8\x38\x0d\x19\xcb\x82\x1b\x1c\x56\xaf\xdc\x38\xa9\x4b\x2c\x32\xfe\xb1\x82\x13\x93\x96\x93\xb6\x9f\x2b\xcb\xae\x7e\x70\xab\x09\xea\xd3\xb6\xa8\xb7\xda\xd3\xc4\xf5\x21\xad\x04\x55\xdd\x4e\x87\x2b\x36\x27\xd4\xfe\xd2\x0d\x5e\xfc\x78\xf6\xae\x46\x7f\xb9\x26\x7a\xb1\xd4",
        b"\x05\x36\x3b\xcc\xa1\x93\xd7\x26\xcd\x20\xe0\x34\x89\xe1\xb1\x3b\x7d\xf3\xbc\x98",
        b"\x31\xbd\xac\xcb\x29\xe4\xa6\x00\x23\x92\x9f\x18\x21\x99\xc0\x70\xb7\x1a\xc5\x75",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x47\x7a\xf8\xc0\x25\x18\x1b\x55\x77\x32\xb9\x56\x86\x34\xb1\x32\x4e\x66\x69\xb4\xc2\x8a\x0b\xcd\x4c\x65\x3d\x4c\x81\xed\x68\xb2\xa2\x04\x3a\x80\x0a\x31\x4b\xa9\x5e\x50\xde\xea\xcc\x5e\xe9\xc2\xba\x6f\x6f\x62\xfd\xba\x0e\x86\xac\xa2\x27\xd7\x27\x37\x75\x52\xa3\xab\xdb\xab\x60\x1c\x26\x01\x84\x6e\xc2\x7a\x19\x2a\x3f\x33\xe7\xff\xdb\xe4\xa4\xaa\x7b\xeb\x2b\x3f\xf6\xc9\x1b\xd5\xcd\x5c\x89\x0b\xcb\x6f\x4c\x90\x8f\xf5\xb9\xb5\x55\xe2\xa0\xa7\xdf\x8c\x3e\xf6\x77\x01\x36\xbb\xf0\x09\x75\x5b\xf6\xc3\xe6\x30\x73\x10",
        p,
        q,
        g,
        b"\x2c\xce\xdd\xc9\xe2\xce\xbb\xc1\xe9\x9b\x83\xb0\x30\x53\xbb\x14\xa9\xcf\xaf\x07\x2b\x45\xe4\x74\x6d\x18\xcb\x39\x01\xf6\xa2\xc3\xcf\x72\xda\x66\xb0\xb9\xb3\xe1\x05\xbd\x4c\xd0\xe5\x42\x7d\x7e\x9b\x65\x7e\xd7\x18\x84\xcd\x49\xf5\x1f\xe8\xfa\x18\xa3\x66\x01\x8a\x3e\xaf\xac\x33\x81\xe0\x7a\x5b\x19\xf6\xd3\x86\x2e\xd2\x91\x60\x94\x90\x6e\x75\x28\x6e\xaf\x1d\x13\xc4\x85\x74\x4b\x27\x04\x04\xff\x9a\xdc\x8e\x17\x78\x33\x04\x3b\xdc\x34\xc3\x07\xe6\xfc\x9c\x55\xc5\x3d\x8f\xf8\x4a\x6e\x25\x10\x38\xdb\xeb\x5e\xf7\x74",
        b"\x35\x91\xc5\x21\xb2\xa5\x6c\xf4\x60\x51\xc0\xcb\x3d\x44\x4b\x9a\x22\xff\xf6\x3f",
        b"\x7a\xc7\x8e\xe2\x52\x44\x0c\xf9\xe8\x51\x04\x94\xd1\xfa\xd8\xb5\x18\xf1\xe1\x28",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xbb\x65\x93\xff\x21\x9c\x9f\x20\xaa\x47\xe1\xe1\x57\xe8\x8e\xd5\x9a\xe2\x9c\x89\x40\xa5\x27\xc8\x2e\x0e\x0f\x2e\x85\x5f\xa9\x8e\x94\xe0\x7b\xe1\xf6\xbc\xe3\x83\x2b\x7e\xa1\xe6\x0a\x5c\x9e\xf5\x83\xf2\xec\x7b\x17\x92\x27\xe4\xaf\xdc\xf8\x29\xd6\x73\xe1\x37\x7f\x83\x2a\xe3\x8e\x7c\xad\xed\xe4\x15\x96\x4f\x12\xba\xf7\x75\xd3\x8c\xe3\x8e\x94\x55\x63\xe7\x28\x61\x51\x91\x97\xc2\xd0\x8f\x28\xd8\xb6\x46\x65\x62\xe0\x59\xec\x41\x74\x1d\xe3\x49\xed\x5d\xe2\xc7\xd6\xcc\x75\x18\xa8\x77\x20\xa2\x48\xb3\x01\x73\x3a\x47",
        p,
        q,
        g,
        b"\x15\xd9\xe2\x0c\x3f\x39\xcc\x9e\x3b\x8f\xb6\x5f\xeb\x64\xfb\x15\x68\xf6\xef\xde\xf6\x45\x7d\x23\x1c\x49\x1e\xd5\x17\x31\xd5\x8f\x06\xe4\x5e\xa5\xd6\x65\xd0\x49\x69\x82\x3d\xa4\xe6\x75\x0a\x2c\x3d\x16\xc5\xff\x60\x80\xec\xd0\x9a\xa3\x9c\x00\x6e\xed\xce\xb4\xdb\xc1\x6e\xbd\x64\xbc\x5b\x1e\x44\xb8\x31\xa6\xbb\x25\xaf\xbc\xb3\x00\x0f\xa6\xb6\xc2\x00\x08\x60\x01\x40\x11\x18\x9c\x22\x54\x2c\x14\x5e\x40\x7e\x7b\x59\xf6\xd3\xfb\x1e\x13\x62\x95\xec\x85\x0b\x14\xff\x2f\x49\x94\xea\x37\x48\x1e\x80\x19\x99\x10\xbe\x8e",
        b"\x61\xe7\x27\x71\x6c\xc9\x69\x14\x50\x97\x40\xa7\xcb\xa6\xe7\x4a\x9d\xec\x64\x06",
        b"\x2e\x77\xc1\x4f\x01\xf2\x21\x80\xbc\xda\x57\x25\xcf\x0e\xaa\xc9\xad\x13\xa7\xd1",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x56\x5f\x19\x24\x44\x68\x51\x5e\x84\x63\xd0\x7b\x42\x5b\x4d\x5f\x81\xff\x2e\xfa\xb5\x15\x6b\xa1\x9a\x63\x73\x42\x19\xc2\x26\xcc\xca\x59\x03\xbf\x9c\x35\xdb\xca\x09\x61\xdb\x7c\x2e\x3f\x69\x44\xd0\x57\xed\xfa\x6c\x23\x94\xc3\x9a\x00\xf1\xc4\x25\x96\xe7\xee\x72\xed\x64\x4c\x6a\x18\x21\x15\xbd\xc4\x4b\x90\x10\xc8\x6e\x7b\x0e\xc2\xe3\xbd\xf7\x01\x6c\x5e\x04\xf4\x55\xb4\xcb\x69\x3e\x32\x49\x0b\x8f\x49\x4b\xb4\x10\x3b\x3b\x5e\xa6\x80\x82\x22\x45\x28\x41\xb7\x33\xfa\xf7\x35\xf1\x0a\x95\xfb\x28\x3d\xd8\x6c\xe5\x93",
        p,
        q,
        g,
        b"\x66\x42\x45\xaa\xeb\xcf\x5c\x05\x5c\x32\x10\x9b\x21\x59\xa1\x74\x73\x04\x30\x87\x91\x5f\x14\xe9\x59\xdd\xdc\x0c\x9b\x20\xc7\x26\xf0\x12\x4f\x1e\xcb\xaf\x20\x2f\xe2\x67\x6a\xfd\xab\xd3\x46\xa7\xb5\xbe\xf7\x69\xa2\x5c\x6f\x73\x36\x12\xd7\x37\x8d\xf1\xb2\xd4\xc5\x18\xa2\xda\x5b\x3a\x4c\xd0\x25\x2b\xb8\x18\x08\x38\xa4\x63\x89\xa8\x46\x93\xbe\x8c\xc2\x4f\xbd\xc6\x39\xb6\x2c\xb2\x1d\x8a\xbe\x12\x72\xb5\xaa\x06\x22\x2f\xe2\x13\x3f\xc5\x55\x6d\x24\xe7\x54\x96\xa5\x3e\x19\x34\xd3\xb5\x84\x8e\x51\x0b\x69\xda\x04\xa4",
        b"\x5c\xa0\x7b\xc7\xcd\x9f\x7a\x60\xcf\x79\x39\x1d\x87\x3b\x6f\xdd\xf5\xa4\x8c\xca",
        b"\x97\x99\xc7\x4a\x80\x6f\xc1\x96\xe0\x22\x3f\xb1\xa6\x13\xfd\x17\x8c\xaf\xbd\x99",
    )?;

    // [mod = L=2048, N=224, SHA-1]
    let p = b"\xf2\xd3\x9e\xd3\x06\x2b\x13\xc9\x16\x27\x36\x00\xa0\xf2\xa0\x29\xe8\x6d\x7a\x4b\x92\x17\xb4\xf1\x81\x5b\xf2\xb2\x4d\x97\x10\xa5\x7a\xb3\x3f\x99\x72\x94\xb0\x14\x58\x5b\x8d\x01\x98\xdf\xdc\xcb\xcd\x75\x31\x4d\xa5\xff\x85\xaa\x34\x4b\x45\xad\xae\xaa\x97\x9b\x51\xa3\x12\xa7\xbf\xa9\x44\x72\xfb\x63\x3f\x1a\x6f\x15\x6b\xb4\x45\x88\x67\xdf\xd3\x84\x03\xf0\x6b\x85\x1f\x00\xfe\x2d\x34\x84\x07\x7b\xde\xd7\x1a\xb7\x51\x3d\x04\xa1\x40\x22\x05\x75\xfb\x69\x33\x95\x48\x0e\x4c\x84\x02\xb7\xa4\x6c\xec\x2d\x37\xa7\x78\xc3\x05\xac\xcd\x1f\x13\xe9\xf6\x2e\x86\x53\x15\xf4\xb2\x2c\xc4\x67\xc8\x98\x6e\xc8\xe4\x96\x1d\xdf\x81\x05\x66\xb0\xc4\xee\x36\x9a\xc6\xaa\x15\xe4\x3f\x47\x44\x00\x58\x26\xf5\xbd\xe8\x07\x1a\x19\xe3\x0b\x69\x09\xaa\xc4\xb3\xd1\x74\x23\x72\x70\xda\xd0\x27\x99\xd0\x9b\x8a\x2c\xc5\xf2\x2e\x66\x89\x4b\x54\x22\x22\x8b\x2c\x23\x4f\x11\xf5\xa7\x71\xc5\xb8\x9c\xf4\x65\xa2\xac\xec\xbb\xee\xaa\x17\x25\xfe\x8f\x9b\x59\x42\x2b\xe8\x99\x10\x52\xcb\x55\x6d\xdf\x2c\x8c\xe8\xfa\x92\x06\xdb\xf3\x9f\xea\xdc\x19\x4e\x00\xf8\xe5";
    let q = b"\x80\x00\x00\x00\x00\x00\x00\x00\xc1\x18\xf4\x98\x35\xe4\xef\x73\x3c\x4d\x15\x80\x0f\xcf\x05\x9e\x88\x4d\x31\xb1";
    let g = b"\xe3\xa9\x3c\x09\xda\x6f\x56\x0e\x4d\x48\x3a\x38\x2a\x4c\x54\x6f\x23\x35\xc3\x6a\x4c\x35\xac\x14\x63\xc0\x8a\x3e\x6d\xd4\x15\xdf\x56\xfd\xc5\x37\xf2\x5f\xd5\x37\x2b\xe6\x3e\x4f\x53\x00\x78\x0b\x78\x2f\x1a\xcd\x01\xc8\xb4\xeb\x33\x41\x46\x15\xfd\x0e\xa8\x25\x73\xac\xba\x7e\xf8\x3f\x5a\x94\x38\x54\x15\x1a\xfc\x2d\x7d\xfe\x12\x1f\xb8\xcd\x03\x33\x5b\x06\x5b\x54\x9c\x5d\xcc\x60\x6b\xe9\x05\x24\x83\xbc\x28\x4e\x12\xac\x3c\x8d\xba\x09\xb4\x26\xe0\x84\x02\x03\x0e\x70\xbc\x1c\xc2\xbf\x89\x57\xc4\xba\x06\x30\xf3\xf3\x2a\xd6\x89\x38\x9a\xc4\x74\x43\x17\x60\x63\xf2\x47\xd9\xe2\x29\x6b\x3e\xa5\xb5\xbc\x23\x35\x82\x8e\xa1\xa0\x80\xed\x35\x91\x8d\xee\x21\x2f\xd0\x31\x27\x9d\x1b\x89\x4f\x01\xaf\xec\x52\x38\x33\x66\x9e\xac\x03\x1a\x42\x0e\x54\x0b\xa1\x32\x0a\x59\xc4\x24\xa3\xe5\x84\x9a\x46\x0a\x56\xbc\xb0\x01\x64\x78\x85\xb1\x43\x3c\x4f\x99\x29\x71\x74\x6b\xfe\x29\x77\xce\x72\x59\xc5\x50\xb5\x51\xa6\xc3\x57\x61\xe4\xa4\x1a\xf7\x64\xe8\xd9\x21\x32\xfc\xc0\xa5\x9d\x16\x84\xea\xb9\x0d\x86\x3f\x29\xf4\x1c\xf7\x57\x8f\xaa\x90\x8c";
    test(
        HashAlgorithm::SHA1,
        b"\xed\xc6\xfd\x9b\x6c\x6e\x8a\x59\xf2\x83\x01\x6f\x7f\x29\xee\x16\xde\xea\xa6\x09\xb5\x73\x79\x27\x16\x2a\xef\x34\xfe\xd9\x85\xd0\xbc\xb5\x50\x27\x56\x37\xba\x67\x83\x1a\x2d\x4e\xfc\xcb\x35\x29\x6d\xfe\x73\x0f\x4a\x0b\x4f\x47\x28\xd1\xd7\xd1\xbb\x8f\x4a\x36\x23\x8a\x5c\x94\x31\x1f\xa1\x13\x4a\x93\xa6\xb4\xde\x39\xc0\x85\xe9\xf6\x0a\xe4\xe2\x37\xc0\x41\x6d\x58\x04\x2b\xb3\x6b\xaa\x38\xcb\xa8\xc8\x96\x29\x5b\x74\x5d\x53\x76\xfd\x8c\xe4\x2e\xb6\xee\x5a\x1b\x38\xf8\x77\x16\xb2\x65\xb7\x6e\x58\xcf\xb2\x4a\x91\x70",
        p,
        q,
        g,
        b"\x28\x9f\xf1\x8c\x32\xa5\x6b\xb0\xb8\x83\x93\x70\x64\x76\x83\xa3\x8a\x5a\x7e\x29\x14\x10\xb9\x32\x07\x21\x2a\xdc\x80\x88\xd3\x0f\x93\xe9\xe4\xab\xc5\x23\xf3\xd4\x69\x36\xe7\xd5\xc9\x0d\x88\x74\x2b\x36\xaf\xd3\x75\x63\x40\x8f\x15\xc8\xc1\xa4\xf7\xac\x24\xbf\x05\xf0\x10\x08\xff\xee\x70\xc8\x82\x5d\x57\xc3\xa9\x30\x8b\xad\x8a\x09\x5a\xf2\xb5\x3b\x2d\xda\x3c\xbe\xd8\x46\xd9\x5e\x30\x1e\xb9\xb8\x47\x66\x41\x5d\x11\xf6\xc3\x32\x09\xa0\xd2\x85\x71\x09\x6a\xb0\x4a\x79\xaa\x0d\xc4\x65\x99\x75\x29\x68\x6b\x68\xe8\x87\xcd\x8a\x20\x5c\x2d\xc8\x19\x5a\xef\x04\x22\xeb\xa9\x97\x9f\x54\x9a\xc8\x55\x48\xe4\x19\x41\x36\x43\xb7\x24\x43\x61\x15\x3a\xda\x14\x80\xd2\x38\xcd\x00\xdc\x16\x52\x79\x38\x95\x55\x48\xdd\x5d\x02\x7d\xed\x10\x29\xee\xeb\x8e\xd6\xc6\x1b\x4c\xd5\x93\x41\xd8\xb1\x54\x66\xe9\xda\x89\x0a\x98\x99\x96\xf4\xd7\x69\x1e\x60\x72\xde\x13\x6a\xf2\x8b\x58\x74\xbf\x08\xbd\x1f\x8a\x60\xcf\xb1\xc0\x08\x88\x13\x29\x09\xf5\x15\xe0\x4b\xce\x81\xb0\x29\x51\xaa\x41\xba\xac\x68\xff\xdb\x8c\x5d\xc7\x7a\x1d\x32\xd8\xf2\xc1\x0d\xd7",
        b"\x45\xdf\x2f\x42\x3e\x94\xbf\x15\x5d\xd4\xe1\xd9\xe6\x3f\x31\x5e\xa6\x06\xdd\x38\x52\x7d\x4c\xf6\x32\x87\x38\xc8",
        b"\x59\xb3\xe8\xef\xa5\xbc\x0c\xcb\xf4\xa3\xcb\xb6\x51\x5c\x4b\x9b\xf7\x84\xcf\xac\xdc\xc1\x01\xdc\x9f\x81\xd3\x1f",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x3b\xd2\xab\x08\x21\x78\x78\xe6\x77\x4e\xc7\x79\x7d\xeb\x75\xd5\xc9\x4c\x40\xe2\x4d\xdf\x1f\xac\x8d\xde\x3a\x29\xc8\x6b\x26\xf5\x71\x57\xd3\x29\xaa\xc3\x1a\x66\x22\xe1\xd6\xda\xc9\x7e\x22\x69\x5d\x7d\x1f\x8e\x20\xaa\x26\xb0\x67\x95\xc2\xf8\x78\xba\x5d\x2b\x9c\xc4\xb1\x6d\x5f\xa6\x0a\x5f\xa5\xc2\x4c\x09\x03\x1d\xe2\xf9\x70\xa9\xb5\x7e\xa2\x4a\xf1\x71\x92\xec\xe2\x1a\x4d\x12\x0f\xdb\x52\xe6\x2b\x82\x38\xf7\x78\xff\x85\x52\xfa\x45\x3c\x0a\x88\x91\x24\x3f\xc8\x75\x71\x88\xe9\xc4\xe0\xe7\x49\xf7\xe9\xcd\xf1\xc1",
        p,
        q,
        g,
        b"\xb9\xb0\xe1\xcd\x37\xba\xfb\xed\xee\xd1\x73\xfd\x70\x99\x83\xf5\x3c\x2c\x42\x7f\x9f\x61\xc8\x95\xfa\xc9\xeb\x54\x9b\xd6\x20\x1d\x05\xef\xd5\x51\xae\xcb\x98\xb2\xdf\x80\x14\x2d\xea\x7a\x35\x49\x1d\x47\x4a\x3a\xdc\x83\xf0\xda\x8d\xc4\xea\xcd\x7f\x6d\x72\x01\xc6\xfc\x0a\xb7\x98\xab\xe8\x9d\xcd\x7d\x03\x10\xd5\xf0\x0f\xa1\x0d\x21\x1f\x18\xea\x85\x35\x79\xe2\xfe\x31\xee\x55\x37\x1d\x1c\x9f\xc4\xcf\xb0\x50\x78\x65\x86\x65\x9b\xdc\x0f\x1a\xac\x4c\x10\x9b\x9e\x4f\x94\x16\xd2\x2c\x42\xb3\x9a\x47\x13\x11\xe2\x8a\x8e\xd6\x2f\x1f\x41\xbc\xfe\x06\xe0\x74\xbb\x2f\x1a\xcd\x29\x59\x79\x53\xc3\xb6\x9d\x3a\x78\x83\x1f\xb2\xf8\x36\x65\xd0\x4a\x13\x95\x77\x5e\xa3\xa2\xa6\xea\x14\x2e\xc0\x05\x07\xba\xdd\x4d\xe0\xd9\xc1\x02\xea\xc7\xbb\x89\x4f\x74\x53\xe6\xa8\xe0\xdd\x3f\x14\x97\x83\x77\xd1\xdd\xb1\xfd\xf1\xc5\x58\x35\xb9\x92\x4f\x42\xad\x45\xc8\x47\xc7\x9b\x3f\x83\xfb\xf9\x24\xf8\x0b\x78\xf5\x03\x29\x73\x10\x16\x76\x3e\x01\xba\x8e\xf6\x9e\x81\x52\x3e\x18\x15\x84\xf4\x5c\x21\xe3\xc8\xed\xfe\xd4\xe2\xec\x56\xfb\x7b\x02\xaa\x4e\xe9",
        b"\x6d\x19\xfe\x3c\x41\x5d\x6b\x07\xd6\xa1\x03\x9a\x1f\xe3\x4b\x10\x6d\xaa\x2e\xea\x4c\xbc\xa9\x71\xcb\x66\x9e\xac",
        b"\x14\xd7\xde\xcc\x2c\xc0\x5a\x17\x00\xfa\x25\x6e\x4d\x29\x94\xbc\x4b\xd9\x57\xbe\xd0\xba\xf9\xa1\x8b\xda\x70\x90",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xc6\x7f\xa7\x7c\xd7\x35\x1d\x10\x0c\x76\x24\xe2\x54\x18\x48\x1f\x8f\xa4\x99\xd7\x5f\x59\x49\xa5\xca\xe6\x0f\x96\xa0\xf7\xbf\xcd\xda\x7d\xba\x37\x3f\x9f\x75\x12\xa5\xf1\x46\x0a\x95\x21\x30\x77\xce\xbd\x91\x2e\x26\x62\xc4\x3a\xc6\xbb\xe3\x8c\x44\x79\xb0\x41\x51\xa5\xe2\xd2\x88\x09\x02\xd0\x31\xaa\x0d\xff\x3f\x41\x12\x6d\xd0\x9f\xba\x5c\x05\x07\x63\x4e\xd1\x6c\x39\x38\xfb\xd3\xa9\x64\x73\xa8\xb1\xeb\xdc\x37\xd3\x2c\x76\x7f\xd5\x93\x2e\xfa\x23\x55\x55\xf3\x82\x5a\x15\x95\x36\x92\x38\x67\x54\x53\x60\x4d\x27\x8e",
        p,
        q,
        g,
        b"\x31\x93\x9c\xcd\xd3\x93\xf7\x47\x54\x1a\x5c\x69\xf8\xe5\x09\x76\x1d\xd6\x7e\xdd\xb4\x2e\x0b\xdf\xc4\x12\xd4\xcc\x30\xd3\x68\xd8\x78\xd2\x6d\x85\x6c\x52\x90\xec\x74\x6b\x59\xc5\xe5\xaf\x65\xef\x3f\xd6\x2c\x9a\x2d\xcc\xfc\x15\x58\xdf\xbf\xb6\x2c\xfe\xcd\x78\x38\xe6\xd5\x94\x95\xb2\x0d\xb5\xad\x9d\x78\xe8\x2f\x04\x6f\x9f\x15\x98\x11\x3a\xae\x0a\x79\x60\x1d\x6b\x94\xa3\x2e\x05\xf6\xec\xfd\xf2\xb9\xc4\xcf\xa7\x20\xde\xbf\xc2\x12\x22\x1b\x14\xb0\xdd\x6f\x70\x78\x20\x5a\x4f\x21\x8c\xd4\xb8\xf1\x0b\xea\x8f\xa4\x81\xec\xa5\x25\x4f\x36\x5d\x01\xf3\xc8\x65\x20\xbf\x25\x43\x23\xd5\x63\x4b\x96\x92\x0a\x13\xb8\xf2\x9d\x73\x4e\x07\xfd\xe8\x06\x4e\xb0\xc9\xf8\xeb\xb6\xae\x0b\x40\xb4\xaa\x7d\x26\xbb\x8d\x80\x86\x82\x31\xd4\x55\x8a\x27\x80\x45\xcb\x5f\x29\x51\xcb\xfe\x0d\xc9\x7b\xbd\xce\xe7\xaf\x8c\x9b\x1e\x3b\x63\xcb\x49\xdc\x29\xf3\x00\x77\x5c\xdb\xe4\xd2\xd2\x78\x94\xe2\x7e\x0e\x7c\x9e\xad\xa1\x3a\x35\x9f\x0b\x92\xb4\x49\xe9\xd0\x69\xb9\x5b\xdc\x2a\xa7\xc8\x5e\x56\x81\x1c\x07\x20\x7a\x15\x0e\x59\x87\x35\x99\x6a\x6e\x53\x49",
        b"\x79\x24\xb7\x6e\xe7\x6a\xd7\xff\x2a\xb3\x27\xda\xbb\xbd\x31\x33\x67\x50\xfc\x76\x63\xdf\x4b\x5b\x94\xee\xb6\x2d",
        b"\x59\x14\xcf\x96\x54\x90\xb0\xbf\x81\x92\xfc\x6e\x16\x97\x54\xbd\xfd\x31\xc4\x8d\x71\x63\x61\xdd\x15\xf4\x5b\xf7",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xfd\xe7\x43\x4c\x41\x66\x60\x22\xd6\xd7\xda\xbc\x7a\x67\x31\x5b\x1f\xf4\x9a\x2a\x85\xa6\x16\x8f\x2b\x60\x63\xe3\x03\x6a\x4f\x35\xe6\x6d\x28\x72\xaf\x3d\x97\xe5\xbe\xba\x23\x96\x98\xd8\x8e\x13\xbd\x03\x6e\xf0\x8c\xf0\xe8\x3a\x41\x66\x4c\x3d\x0d\x21\x86\x3c\x24\x12\x9a\x6a\x9b\x27\xb8\xe9\x6c\x80\x29\xec\x67\x3e\x07\xaf\x72\x46\xab\x77\xa5\x6c\x21\xca\x20\x8d\xf4\xb1\x81\x8d\xed\xa9\x06\xb5\x53\xb2\xb2\x3a\x37\xb5\xa0\x5e\x29\x82\x5e\xbe\xb4\x7f\x53\x98\x6c\x2b\xf2\x6d\x73\x1a\x5b\x73\x1f\xff\xc3\x53\x25\x8c",
        p,
        q,
        g,
        b"\x59\xa1\x4e\x36\xc9\xed\xed\xdc\xe8\x00\x0f\x04\xc6\xf7\x40\x1a\xd9\x87\xf1\xc7\xa5\xa0\x70\xb8\x0e\x0a\xae\xd7\x75\x1d\x1d\x50\xd9\x9a\x58\x0c\xf2\x05\xdb\xcc\x37\x97\xa0\xa0\x40\x6b\x04\x77\x6d\x80\xf2\xf2\xdf\x41\x8c\xee\x24\x9b\x98\x67\x2d\xe7\xe6\x1c\xda\x85\xcf\xbe\x90\x36\x90\xe5\x46\x42\xdc\x2a\x12\xa9\x0e\xcf\x88\xc5\x92\x56\xa4\xd7\x7c\x4c\x0c\xb5\x4e\x13\xfa\x36\x47\xb1\x14\x31\xe1\x73\x4f\x3c\xee\xea\x04\xfb\xf3\x45\x96\x65\xe9\x99\xfc\x0f\x7a\x75\x46\x83\xe4\x8c\xef\xeb\x4a\x95\xfe\x47\x39\x11\xff\xe0\xde\x0f\x73\x89\x60\x75\x3d\xac\x33\x66\x6c\x53\xed\x28\x93\xbc\x63\xdd\x41\x62\xd7\xa6\x32\x87\x39\xa2\x52\xcd\xae\xa7\xa9\x48\xc9\x7d\x02\x41\x53\xb5\x5d\x14\xfd\x53\x04\xe3\x57\x50\x48\x41\x88\x08\xa9\x52\x67\x5f\xaf\xb9\x5f\xad\x84\xb1\x15\x6b\x24\xe9\x8e\x04\x8a\xa7\x77\xa7\x45\x32\x4e\xc1\x3b\xa3\x78\xe8\x3b\x23\x84\xbc\x2e\x96\xc6\x09\x5a\xa7\x86\xbd\x28\xfc\x3b\xe6\xbf\xa4\xdb\x0c\x3c\x44\xfe\xd4\xc3\x51\xbd\x88\xa1\x9e\x17\x9a\x6a\x7b\xc1\x2f\xc0\x14\xf1\x7d\xe4\x6f\xd1\x2e\xf1\x28\x7f\x72",
        b"\x49\xea\x82\x71\x3a\xaa\xd7\x99\xe2\x63\x80\x9e\x16\x1b\x06\x55\xf1\xe7\x43\x23\xa0\x60\x41\x83\x6f\x67\x69\x80",
        b"\x76\xb3\xf6\xc1\x64\x7f\x8d\x17\x71\x8f\xfb\x92\xd6\xe1\x42\x46\x06\xba\x97\x24\xe5\x29\x0d\xaa\x4e\xe9\x5e\xfb",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x66\x76\xa3\xa1\x31\xce\xf7\xe5\x64\x7e\xa7\x59\x0d\xa3\xc7\x04\xa0\xf5\xdc\x3f\x37\xf2\x69\x13\xa7\x0d\x43\x06\x09\xcc\x24\x97\xc4\x5e\x68\xb7\xbd\x6f\x58\x93\xdb\xa2\x62\x87\xff\x0d\x24\x0b\xab\x8a\x07\x61\x93\x6a\xa7\x09\xa2\x16\x2e\xbf\x1c\x20\xa6\x13\x6a\x74\x83\x52\xdc\x39\xba\x44\x03\xcb\xe4\xb0\xa5\xa5\x4a\x72\x92\x86\xdd\x19\x3e\xac\x1a\x2e\x6b\xdc\x15\x0f\xb0\x63\x69\xbe\x44\x43\xa6\x0e\x75\xe5\x33\x00\x83\xff\x00\x9e\xab\xb0\x52\x32\xc5\x23\x68\xa2\x6f\xd2\x37\xc7\xc3\x18\x5c\x1c\x7e\x7d\x59\x55",
        p,
        q,
        g,
        b"\xdd\xcd\xf4\xc6\x16\xfd\x6e\x40\x16\x09\x9f\xb3\x4e\xbc\x4e\xc5\x07\x29\x07\x62\xc5\xee\x68\x76\xf1\x0c\x6a\x2d\xed\xec\x97\xba\x86\xa6\x06\x3a\xa8\xff\x06\x9f\x3f\x3d\xb4\x0c\x94\x64\xaf\xb1\xba\x7e\xd6\x91\x77\x3a\xfd\x60\x83\x58\x6b\x14\xe3\x56\x94\xa9\xdd\xc3\x76\xdd\xc3\x9d\xac\x57\x13\x2a\x05\xbf\x88\xa0\xa6\x08\x5c\x72\xa8\x0a\x21\xc1\x3e\x59\x0c\x68\xc4\xe9\x8e\xed\xb6\x7f\x1e\x16\xc8\xcc\x7e\x9e\x25\xff\x37\xc8\x7e\xe3\xbe\x9a\xdf\x1a\xd0\xb8\x38\x65\x1b\x0f\xdd\xf8\xd0\x26\x96\x9d\x4a\x16\xbb\xb8\x28\xfc\xaf\x00\xef\xa3\x06\xfc\xed\xd5\xae\x19\xca\x1a\x1a\xbf\x44\xa2\xbd\xf6\xf9\x94\x12\x3c\xe9\x41\xfd\x35\x23\xbc\x13\x35\xf5\x1f\xa8\xdc\x5d\x52\x53\x58\xbd\xdf\x0c\x55\xfe\x2c\xe0\x7c\xe9\x74\x40\x8d\x90\x90\x48\x88\x37\x97\x6f\x16\x84\x5e\xb7\xa8\x2d\x04\xc4\x3a\x70\x4b\xe2\xde\xe1\xbe\x2c\x86\x83\xb2\xd9\xe5\xc4\x4f\x18\x33\xf5\xc4\x6c\x65\xb6\xe6\x2c\x2a\x72\x04\x21\xbb\x35\x84\x3f\xea\xd7\xb9\xe0\xb3\xfc\x04\xc6\x46\xbe\x39\xe8\x90\xe3\x70\xb9\x82\xbd\xe9\x1f\x2f\xc1\x84\x42\xb6\x50\xae\x60\x2f",
        b"\x16\x58\xa7\xef\x2f\x44\x4b\x01\x4a\x18\x85\xb1\xed\xa8\xda\xd3\x60\x5b\x96\xc3\x94\x8e\x54\x4e\x4c\x88\x25\xeb",
        b"\x60\x21\x50\xf6\x7b\x19\xa5\xe3\xe3\x9f\xc5\x3a\xbe\xa0\x2d\xd8\xf3\xb3\x0d\x25\xc0\xb4\xea\x0b\xcd\xdc\xbd\xb0",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x07\x1f\x06\xa1\x15\x88\x58\x4d\xa5\x57\x60\x13\x02\x9b\x5a\x14\x71\x25\x81\xa4\x84\x08\xbb\xfd\xbe\x34\xe1\x75\x68\xc0\xa0\xe4\xd1\x2c\x1e\x9c\x3f\xb2\x27\x10\x14\x40\xdd\x8d\xcd\xc4\x15\xe3\xb4\x9f\x68\xa2\x6a\x0e\xc7\x61\x2a\x10\xbb\xc6\x4d\xdb\x8f\x7e\xc9\xe9\x75\x0d\x1e\xfc\x9c\x05\x74\x70\x08\x75\xfc\xf5\x2d\x00\xd3\x7b\x9d\xd7\x44\xca\x84\x1e\xcf\x75\x66\x97\x7c\x1b\x57\x99\xdc\x41\x05\xd0\xb7\xa9\x25\x51\xc5\xb3\x3a\x50\x13\x3f\xa3\x00\xa5\x90\x8b\x18\xf4\xc0\x19\x36\x34\x7c\x60\x49\x44\x7a\xbf\x29",
        p,
        q,
        g,
        b"\xb1\xf4\xdf\xc9\xc8\x34\x55\xf2\x79\xa3\xe7\x52\x27\x34\xd6\xb1\x20\xab\x8e\xd3\x6c\xcb\xa7\x85\x4e\x26\x50\x4c\x70\x79\x83\xd2\xa9\xc0\x75\x04\x57\x23\xf4\x41\xab\xfc\x7b\x36\xfb\xb5\xd4\xbf\x04\x47\x67\x8f\x5b\x70\x9c\xa5\x12\x9b\x74\x88\x8a\x07\x23\xe9\x05\x76\x98\x36\xb9\xda\xc1\x30\x3f\x1b\x9a\xce\x26\x55\x43\x42\xb6\xe6\xd0\x32\xac\x4b\x47\x7e\x01\x1a\x4d\xdd\x3e\x29\x78\xfc\x0c\x44\x9c\x64\xa6\x6e\xfe\x7d\x4e\x22\xe5\xa5\xfa\x2b\x01\xbb\x17\xfc\xdb\xec\x71\x85\xdd\x41\x15\xa1\x9d\x97\x2f\xb0\x1a\x06\xb3\x3b\xb1\x8b\x93\x49\xff\x95\xfb\x10\xdb\xbf\x2d\xcf\x89\x9b\x18\x17\xd3\x0a\xd4\x8a\x99\xa6\x14\xd5\x77\x70\xba\x76\x4a\x11\xa8\x4a\x8d\xb3\xaf\x30\x41\xec\x36\x26\x14\xf8\x07\x19\x6e\xa3\xb9\x0d\x05\xb0\x14\x05\x4f\xf4\xe1\x85\x24\xc7\x95\xe6\x72\x2c\x0f\xa1\xf6\xd1\x20\x5d\x53\x2d\x94\x34\x76\x33\xeb\x13\x2e\x6c\xbb\x59\x6d\x8b\x34\x1e\x65\xf2\xb2\xf9\x55\x87\x2e\xbd\x4d\x30\x06\xc4\x5a\xc3\x3d\xa1\x11\x67\xfa\x46\x86\x9c\x7e\xe7\x0e\x9c\xf1\x47\xb2\x33\x68\xb3\xaa\xcd\x9c\x18\x80\xb0\x9a\xc8\x6a\x8d",
        b"\x07\xbd\x3f\x67\x18\xe3\x98\x39\x30\x4e\xf5\x4a\xc4\x8b\xda\x8d\x9a\xc8\xee\x05\x1a\x49\xbb\x91\x31\xdc\xc9\x18",
        b"\x64\x96\xb2\x46\x9b\xfb\x58\x45\x48\x50\x04\x70\x2b\x0c\x79\x94\x1b\xc3\xc3\x00\x70\x07\xba\x16\x9d\x83\x07\xce",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x71\x27\x9b\x84\x8c\x00\x20\x8f\xb4\xe4\xd8\x79\x79\xcf\x97\x3b\x32\x1b\x20\xd0\x98\xde\xa9\x12\xa3\xb4\xb5\x78\x9c\xdd\x3b\x7c\xcd\x8f\x39\x93\xa9\xc9\x2c\x34\xb7\x0e\x9b\x0b\xd5\x75\x20\xdb\x56\xf2\xde\xd3\xa6\x12\xa6\x16\x9d\x2a\x1c\xc6\x35\x09\x05\xed\x02\x02\xa2\x5c\x11\x3b\x7b\xf8\xfa\xec\x4e\xdd\x2e\xa3\xb8\xf4\x47\xca\x75\xd1\x5a\x71\x2b\x4b\x43\x94\xc2\x2d\xe0\xc2\x55\x4b\x9a\xa0\x7e\xc8\x46\x67\x27\xe7\xef\x6f\x1f\x04\xac\x45\x68\xd7\x72\x6d\x9d\x77\xf5\x0a\x2f\xd5\x51\xac\x29\xe4\x2f\x8d\xda\x23",
        p,
        q,
        g,
        b"\x7c\x8d\x63\xb9\xd5\x5f\x59\x29\x0b\x02\xa0\xfc\xea\x6d\x98\xc6\xc5\x45\xe2\xc0\xd4\xb1\x09\xa0\x69\x69\x4d\x80\xcb\x03\x4d\xbd\xbd\x9e\xdb\x6b\x4d\x9b\x15\x28\x49\xca\xbd\x65\x5f\xc7\x70\x71\x64\x4b\xbf\x4a\x0c\x7e\xa4\xed\xfe\x86\x4a\x43\xc4\x4f\xde\xd1\x63\xdd\x89\x9c\x21\xcc\x2f\x9c\x33\xcb\xf5\x6e\x8c\xaf\x84\x39\x4b\x24\xf8\xc1\x4e\x84\xf2\x2c\x3b\x0f\x74\x71\x29\xd9\xae\xf4\x1b\x6f\x1b\x1f\xa8\xff\x5a\x8f\x68\x0b\x49\x65\x95\xdb\xc7\xb7\xb6\x3a\x77\x90\xe3\x62\x87\x47\x01\x1b\x32\x77\xb0\x6e\x80\xde\x0b\x67\x94\x2f\x60\x2e\xad\xa6\x0b\x51\x8f\x28\x2c\xde\x69\xcd\x71\x7a\x5f\x6a\x19\xc8\xe1\x69\x44\x9e\x0d\x32\xa9\xd8\xce\x8f\x09\xa5\xad\xa2\x3c\x12\xa0\x2d\xcc\xfc\xdc\x02\x90\xa8\xbd\x46\xe8\xb7\xeb\x39\x74\x94\xf3\x2a\x0e\xcb\x49\xfa\x5a\x8e\xdd\x41\x84\x5e\xb4\x17\xfb\xb8\xcd\xb8\x9a\x9f\x18\xb9\xad\x1b\x41\xdd\x41\x22\xab\x34\x9b\xb3\xc4\x49\x51\xe4\xf9\x60\x43\x60\xfc\xb1\xb7\x95\x31\x15\x45\xa6\x1c\xfd\x67\xc2\x87\xa7\xc9\xd4\xd3\x53\x02\x14\x98\x8e\x76\x16\x97\x9e\x2c\xe9\x07\xd5\xc7\xf3\xe9\xad",
        b"\x4c\xf5\xc2\x6c\x4c\x2c\xd4\x8c\x05\x50\x8e\x52\xd7\x43\xef\x48\x68\x5f\x63\x24\x14\x1a\xde\xf2\x3d\x79\xa3\x96",
        b"\x59\xf6\x47\x55\xa0\x4c\x90\xa1\x4b\x18\x7a\xe1\x42\xec\x48\x3c\x46\x00\xb6\xfb\xbe\x19\xf0\x4a\x49\xe9\xff\x88",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x3e\xa0\x3e\x9b\x00\x5e\xc1\x95\x4f\xee\x0c\x73\x32\x6d\x8a\xca\x1a\x4f\x63\x64\x8e\xb4\xcc\x59\x26\x55\x28\xee\x8e\x96\x9e\xce\xfe\xcf\x27\x97\xa0\x14\x4c\x83\x36\x50\x0e\x26\xa1\xc7\xcb\x1a\x64\x2b\x1e\xc6\x52\x01\x41\x6e\x5d\xeb\x35\x52\x01\xde\x2b\xda\x69\x5d\x1b\xeb\xa8\xde\xe6\x27\x72\xf4\xd5\x91\x4a\x24\x5b\xe9\xff\xec\xf3\x94\x08\xae\x7b\xf1\xbf\xf7\xc2\x45\x10\x29\xc4\xba\x0c\x52\x25\x16\xe8\x99\x55\xad\x3b\xd6\x99\xcc\xe9\x4c\x74\x40\x81\xa9\xf2\xd6\x0f\x5c\x51\x27\xec\x72\x2f\xa5\x73\x16\xce\xde",
        p,
        q,
        g,
        b"\x12\x39\xc3\x47\xbe\x4c\xe6\xf1\xda\xa7\x21\xfb\xbb\x14\x1e\xe6\xe2\xf7\xc7\x30\x98\xef\xfe\x8e\x71\xbe\xb9\xf1\xab\x72\xd1\xb5\xbd\x3e\x78\xdf\x77\x0f\x7f\xbd\x4b\x3a\x95\x05\x70\x2d\xac\xf1\x02\xee\xb8\xa1\x6f\x11\xb4\xf8\x09\xca\x00\x2a\xe3\x77\x4a\xc0\x40\x7e\x25\x72\xae\x3e\xe1\x71\x64\x58\xe5\xf4\x5c\x49\x3f\x4b\x92\x11\x44\xe8\x58\xd8\x7d\x63\x77\x3d\x02\x37\x45\x51\x2b\x0c\xc0\x2b\x31\xeb\xfe\x5c\x24\xad\x37\xef\xe5\x39\xcd\x39\x3c\xfc\x2b\x95\x1f\xe1\xb6\xff\xad\x2a\x28\x24\xc0\xf5\x4b\xd7\x76\xaa\x0a\xfc\xf9\xc1\xef\x42\x7a\xfc\x6c\xf4\xc4\xb1\x7f\x66\x35\x5d\x68\x57\x41\x32\xe1\xd8\x8a\xde\x37\x22\x51\x3e\x39\x5f\xc6\x2d\x65\xe9\x48\x51\x57\xc8\x20\x64\xc9\x08\x03\xa1\xa9\x1f\x9e\x6b\x10\xaf\x2f\x80\x69\x9d\x91\x7d\xaa\x6b\x81\x41\x5e\x50\x81\x93\x15\x2b\x4c\xcd\xed\x59\x3d\xde\x35\xf6\x45\xe5\x4b\x7c\xba\x44\x57\x75\xeb\x16\xc5\xe1\x90\x73\xf0\xa9\xeb\x53\x69\xbf\x25\x13\xb9\x21\x58\x16\x5b\x94\xde\xa5\x11\xe9\x38\xfb\x6a\x87\x98\xe0\x40\xa0\x5d\xa9\x4f\xdb\x5a\x4d\x44\xbe\xe9\x43\xb9\x5b\x39\xd9",
        b"\x5c\xa2\xe9\x71\xf2\x1b\x70\x12\x7a\x70\xc6\x55\xeb\x87\xe2\x0b\x25\x17\x97\x62\x28\xa2\xc4\xe6\x48\xd5\x49\xb2",
        b"\x44\x03\x6b\x34\x66\x71\x36\xa5\x14\x0d\xd1\x94\x8d\xdc\x2f\xb2\xbf\x67\x9e\xfe\xe2\x1f\x29\xb7\xad\x87\xaf\x7c",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xa3\xf7\x03\x39\x58\xc5\xb7\x79\x07\x2b\x05\x48\xba\xed\xf4\xf8\x8d\x14\xf1\x1a\x6d\xd6\xee\xc0\x18\x1b\x39\x99\x43\xd7\x24\x6a\x45\xd5\x0c\x4f\x7b\x52\x95\xda\xe4\xcd\x3b\xa7\xc4\xc1\x81\xfa\x20\x15\x81\xad\x5c\x4b\x38\x79\x3b\xcf\x45\x4f\x17\x68\x68\xe9\xcb\xe0\x99\x7a\xa4\x19\x87\xb1\xaa\x3d\x5d\xdc\x04\x6b\xe7\xb0\x22\xfb\x51\x30\x59\x4c\x8a\x9d\xf0\x3c\xfa\xa7\xac\xef\x81\x7e\x3b\xa5\xe1\x92\xc6\x9a\x12\x02\x99\x49\x2b\xaa\x52\xa9\xbe\x83\xb8\xe8\x71\xab\xe3\x18\xb4\xa1\xf5\x88\xf9\xed\xcd\xda\xfc\x17",
        p,
        q,
        g,
        b"\x62\xde\x24\x65\xed\xbc\x1e\xf8\x45\x8b\xea\xa2\x05\xf4\x5f\x9d\xc0\xfc\x3d\xb7\x7b\xae\x0f\x2b\x13\xbe\xf6\xd8\x03\xdb\x68\x9b\x8f\x5c\x74\x7e\x3a\x04\x1c\x08\xd3\x26\xcd\x7e\x18\x91\x67\x5b\x02\x2a\x9d\xa3\xbb\xae\xf8\x00\x77\x84\xc5\x6c\x86\xc4\x17\x6c\x0a\xc8\x76\x35\x1d\x10\x62\xd9\xc2\x70\xd5\x48\xc8\xf4\xec\x39\xa4\x55\x6c\x66\xe7\x6e\x50\x7f\xc5\xf2\x54\x0a\xbf\xa7\x7c\x17\x8a\x9b\xae\x15\x34\x35\xa7\xca\xaa\x00\x8f\x36\xb9\xca\xb2\x13\xec\xf5\xe1\x9a\x0f\x7b\x1e\x62\xfb\x9a\x9c\x82\x23\xbb\x68\x9e\x85\x47\xb5\xec\x91\x5b\x04\xa8\x5b\x2f\x53\xcc\xc7\x92\xdc\x0a\x7a\x41\xd1\x72\xe6\xf5\x9f\x5b\x5e\x7c\x44\x03\x50\xac\x6a\x72\xca\x9c\x06\x56\x2d\x4c\xf8\xc6\x0e\x70\x87\x0a\x97\x83\x12\xe1\x9b\xf5\x4c\x24\x81\xc5\x82\x29\x6b\x64\x55\x4b\xd8\x71\xac\xcc\x8b\x25\x1a\x76\x17\xca\x5e\x5d\x2a\xad\xc1\x9d\x48\x4d\x76\xbc\x38\x26\x84\x1f\x88\xfa\xd1\x49\x1d\x80\x67\x92\x43\xe1\x52\x71\x97\xd0\x2a\x40\x63\x48\xb2\x47\xae\x78\x61\x08\xe5\x40\x09\x75\xa3\x8f\x39\x61\x75\x8a\xdc\x07\xce\x74\x0d\x8d\x44\x2f\x15\x2f",
        b"\x18\x23\xf0\xa8\x07\xfb\x9e\x71\xad\x69\xb8\xe9\xfc\x67\x4c\xf7\x6f\x67\xc4\x2c\xad\xbe\xa6\xd3\x4c\xf1\xf1\xcc",
        b"\x66\x7f\xc5\x7a\x44\xb2\x89\xfc\x34\xa1\x98\x55\x61\x17\xaf\xd6\x96\xdc\xbd\x96\xbf\x1b\xaa\xcb\x40\xd3\xf8\xb2",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x68\x0d\x87\x8c\xa6\xee\xb8\x7e\x4a\xe1\x58\xdd\xdc\x37\x32\x78\x40\x13\xeb\xb1\xda\x89\x40\x1a\xcd\xd6\x10\x90\x89\xe5\x60\x1d\x69\x5f\x9e\x4e\x6e\xbf\x16\x02\x6a\xa7\x46\xde\xe8\x0a\x01\x23\x50\x33\xf2\x42\x07\x9a\xf1\xb7\xfa\x69\x65\xc8\x7e\xae\x8b\x32\x91\xa0\x09\xe4\xf1\x9d\x5b\x8f\x13\x94\xd8\x66\xe7\xc9\xb7\x20\x73\xa9\x56\x52\xc0\xee\xd9\x8e\x94\x84\xa1\x5c\x92\x44\x76\x4d\x8c\xba\xab\xd4\x9d\x24\xc2\x07\xc7\x05\x70\x3c\xc3\x5e\xbf\xc7\x68\x3f\x4a\x0e\x6a\xbf\x23\xfa\x07\x67\x83\x50\xa6\xa0\x0c\xde",
        p,
        q,
        g,
        b"\x51\x1a\x36\x08\xc4\xbd\xa7\xc8\x2d\x7d\x68\xa5\xd3\x0b\xd4\xc7\x1e\x45\x7b\x0f\x32\x30\x27\xd6\x01\xd6\x32\x4a\x94\x89\x3a\xb3\xd6\x28\x78\xb1\x2d\x98\xc4\x4d\xcf\x30\xad\xab\x43\x52\xb7\x0f\x4d\xaa\x77\x2d\xf6\xae\xd3\xc0\x75\x87\xe9\x6c\x68\xf8\xa8\x47\xa3\x35\x05\x14\x81\xd5\x39\x03\xd1\xd1\xae\x0c\xf9\x9a\x54\x38\x7b\x00\x16\x9a\x1c\x97\x04\xbb\x62\xf1\xd9\x80\x47\xdb\xa8\xa0\xfd\xda\x73\x4c\xd4\x16\x11\x58\x4d\x50\x55\x4a\xd7\x78\x90\x72\x0c\x8a\xc2\x99\x32\x09\x7c\xf2\xbb\x1a\x8d\x0d\xaf\x86\x63\x24\x1e\x23\x64\x0c\xc3\x96\xf9\xe6\x87\x73\x48\xf0\x14\x07\x3f\x4f\xdc\x5b\xeb\xd1\x15\xa0\xd7\x4c\x2c\xe8\x57\xe1\x00\xae\x3d\xc0\x70\x7b\x95\xef\xfa\x4a\x2c\xd8\x62\x9f\xdd\x9b\xce\x72\x09\x1c\x0e\x26\x12\xd2\xb3\x03\x20\x42\x0f\x42\xec\xb0\x98\x6a\xc3\x28\x92\x51\xb4\xae\x54\xe5\x1e\xd8\x3d\x01\x95\xde\xda\x9d\x4e\x5b\x39\x8b\x03\x72\x13\xd2\xf8\xf0\xff\xdb\xf7\x27\x21\x40\x85\x53\x4a\x32\x4d\x4f\xef\xc1\x65\x36\x42\x03\x5e\xbd\xbe\x81\x67\xb1\x50\xbd\x92\xb7\xcd\xf2\x76\xfc\xf5\xe0\xbf\xfc\xe9\x56\xa4\x7e",
        b"\x7c\xeb\x71\x48\x0b\x5a\x71\x33\x40\x1b\x52\x27\xfa\x22\x53\x33\x2e\x04\xf7\x8e\xa5\xd0\xfe\x23\x7c\x85\x25\xd1",
        b"\x48\x48\x00\xe8\x1f\x7b\x56\x92\xb7\x9e\xb2\x1a\xc2\xff\xf8\x3c\x49\xc9\xf0\xd4\x09\xc7\x56\xc7\x3f\xbd\xd2\xf0",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x69\x7f\x9e\xfc\x86\x53\xfe\xdb\x89\x8c\x77\xf9\x0f\x12\x4b\xea\x5c\x3b\x89\x3c\x49\xd7\xf1\xb1\x16\x47\x9e\x83\xd3\x5c\xb6\xc3\x94\x07\x97\x50\x1e\x7f\x52\x88\x7d\x18\xae\x9f\x40\x55\xe1\xbd\xd1\x24\xb5\x72\xf7\xa6\xfa\xd1\x01\xf5\x8b\x52\xb3\x0c\xa3\x0d\x97\x43\xa9\x01\x6a\xf8\x91\x89\x6d\x25\x35\x6e\x44\xf9\x82\xd4\x06\xea\x26\xa9\xb2\x5f\xc4\xf9\x03\x09\x2d\x7e\x8e\x87\x13\x77\x4a\x8b\xe7\xaa\xac\x93\xa6\x94\x2c\x1f\x2c\x48\xe9\xde\xa6\x49\x84\xae\x54\xf7\xef\x99\x96\x1b\xfd\x9b\x8d\x93\x22\x6a\xf7\x76",
        p,
        q,
        g,
        b"\x64\xb5\x88\x49\x9c\x9d\xb3\xe5\x86\x41\x92\x46\x4d\x32\xfa\x35\x47\xf6\x48\xfe\x67\x6c\x15\x0a\x8f\x9e\x15\x3c\x5a\xf5\x79\x25\xc7\x6d\xda\x4b\x41\x9d\x60\xb2\x2f\xa5\xcd\xea\x0f\xb6\xf0\xb8\x47\x9c\x98\x8a\x32\x4d\x27\x5b\xd4\x2e\xf1\x0d\x89\x98\xc3\x60\x39\xeb\x40\x21\xfc\x0d\x27\x88\xb5\x9a\x75\xcf\x25\xed\x6e\xe4\xd4\x48\x82\xb0\xc5\xc5\xcb\x8d\xcc\x10\x02\xc0\xba\xa4\x79\x81\x07\xe0\xb5\x7c\xd2\x6d\xeb\xbc\xd0\xba\x41\xd1\xb1\xb8\x60\xb8\xeb\x90\xf6\xf3\x05\x00\xb2\xe4\xbe\x7a\x00\xb6\x7d\x93\xc8\x7d\x3f\xf7\xa6\xce\x53\xb9\x77\xa9\x30\x99\x98\x07\xfc\xbe\xf5\x7d\x8d\xc6\x7a\x8f\x36\x61\x24\x99\x13\x89\x32\x8c\xe7\xe7\x0f\x9e\x5c\x22\xff\xde\xdb\x28\x49\x82\x82\xb4\xa9\xa9\xc6\x85\x34\xa2\x38\x32\x2e\x0d\xb6\x08\x8e\xd0\xaf\xa8\xbc\x77\xce\x99\x8c\x81\x44\x71\xab\x56\x76\x7b\x35\xd0\x7b\x94\x29\x0e\xa1\x06\xff\x0c\x99\x8b\x51\xf0\x22\x22\x73\x8e\xf9\x30\x1f\x29\x0c\x6b\x48\x5d\xbc\x4f\x12\xb4\x72\xa1\x19\x2f\xd9\x3f\x2d\x23\x52\x7a\x02\xd9\x5a\xf0\xb4\x22\xbe\x76\x40\xa9\x70\x2e\xca\xac\x26\xc9\xe0\x04",
        b"\x62\x05\x4d\x11\x52\x9b\x99\x3a\x6f\x19\xa0\xd5\x48\x1b\x99\xb4\xb4\x46\x1a\x49\x86\x6c\x29\x53\x4a\x36\x1a\x8b",
        b"\x7a\x7f\xd0\x98\x2e\x4e\x21\x18\xd1\xa0\x69\x78\x7a\x80\xb9\x02\x49\x34\x65\xf6\x62\x0a\x35\x5c\x86\xa9\x48\x67",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xd0\x80\xa7\xdf\xf1\xef\x20\xe3\x38\x32\xb9\x9c\xf8\x3c\x6c\x91\x9c\x07\x62\x0b\xf6\x08\xe0\x80\xaa\x30\x18\x31\xca\x61\x78\xe4\x4e\xf7\xa4\xc1\x15\xe9\x3a\xb6\xd8\x77\xe9\x66\x52\x17\x16\x10\xa5\x1d\x92\x7d\x20\x34\xf4\x2f\x28\x0f\xe8\x7d\x7c\x17\x47\xc4\x80\xeb\xcc\xbf\x56\x5a\x15\x0f\x32\x40\xf6\xd4\xce\x5d\x6e\xb0\xb2\xe9\x64\x41\x67\x91\x37\x6e\xd2\x2b\x35\x59\xcf\x93\xa0\x19\x67\x6e\x9e\x0b\xe3\xc8\xd3\x4f\x0e\x0d\x11\x52\xec\x6c\x32\x6d\x3d\xbf\x1d\x33\x03\xbe\xad\xd1\x88\xc3\xaa\x0d\x77\xe8\xa1\x17",
        p,
        q,
        g,
        b"\x41\x76\x7c\xe2\x6c\x78\x0e\x3f\x20\x19\xf5\xa4\x9a\x70\x15\x70\x14\x8e\x9f\xf3\x38\x22\x03\x83\x3d\x1b\x18\xe9\xd8\xd6\xa0\x0c\x0b\x22\x58\xf2\xe5\x67\xdb\x31\xad\x4e\x8c\xfb\x26\x21\x79\x4b\xac\x87\xd9\xb3\xb5\x3b\x79\x19\x9a\x77\x50\x58\xfe\xbc\x19\x0d\x00\xad\xed\xae\x0f\xd3\x02\x12\x91\xbc\x2d\x1f\xf0\x50\x8b\xf0\x19\xec\xa0\xc5\x73\xfd\x86\x37\x22\xf3\x67\xd5\xd0\x2b\xd9\xfa\x0d\x07\xf7\x54\x06\xac\x20\x4f\xd3\xa5\xca\x16\x32\x5c\x66\x1f\xe8\x54\xfd\x00\xfb\x26\x65\x47\x52\xfe\xbb\xe4\x39\x09\x6d\xd2\x28\x4d\x5a\xb1\x3d\xe9\xeb\x00\x48\x47\xd1\xd8\x59\x9f\xee\x68\x7c\xb2\xec\xd0\xe5\xb7\x61\xd9\x1a\x7e\x9c\x58\xe6\x92\x1f\x10\x30\x24\x21\x5e\x74\xf3\xde\x3c\xc1\x2f\x5e\xd7\x70\x3d\xef\x04\x1d\xd3\x26\x7f\x1c\xde\x0d\x4f\xda\x8d\xd5\xcc\xc9\xc0\x7b\x65\xde\x59\x48\x2c\x47\x84\xb4\xf6\xfa\x85\x66\x71\x86\xe2\xdf\x6c\x5d\xc8\xb4\x95\xbe\x8e\xc6\x13\x79\xf2\x09\x23\x57\x6f\x17\x68\x0c\x4d\xab\x99\x31\x2d\x0b\x64\x41\x30\x6a\xe7\x17\xc9\x5d\x3f\x35\x2b\xa4\xc0\x96\xf0\x1d\x14\xa7\xdc\x05\xb2\x8b\xa9\xa3\xca",
        b"\x44\xe7\x0d\x2e\xad\x3c\x51\xdd\x0c\x54\x61\xdd\x41\x86\x82\x5e\x23\xb4\xe7\x51\xd8\xab\x17\xd0\xb7\xed\xfa\xac",
        b"\x48\xff\xad\xe2\x75\x31\xdb\x47\x8f\x22\xfa\x0e\xc9\x2b\xcf\xd2\xff\xeb\x6d\xb6\x77\x15\xdc\xdc\x79\xbc\xb0\x28",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xf6\xa9\xaf\xe2\x41\xdd\x98\x4e\x3b\xc2\x65\x78\x7d\xcc\x49\x49\x1b\x3b\xca\x67\xfe\xef\x32\xfc\x1e\x07\xfd\xaf\x0a\xf6\xc5\xd0\x6d\xcc\xb4\x7c\xdb\x69\x07\x51\x1c\xb3\x0c\x10\x9f\x62\xe6\x67\x18\xc5\xc4\xbb\x43\xd4\xb0\x0b\x51\x23\x5d\xf4\x32\x23\xd6\x0c\xe1\xf9\xbe\x34\x93\xa4\xdc\xb0\x2e\x25\xed\x3d\xda\xe1\x0d\x13\x1b\x48\x1a\x61\xae\xf3\x34\xb6\x90\xc7\xa1\xec\x74\x86\x59\x54\xb3\x9c\xcf\xa7\xa5\x1a\x9a\x1e\x62\xe6\x54\xbb\x89\x27\x0c\x77\x4f\x08\x2a\xdf\x09\xb5\x79\xc8\x35\x8d\xac\xb9\xdb\x7c\xa1\xc2",
        p,
        q,
        g,
        b"\xb4\x13\x8f\xa4\xe1\xdc\x67\x72\xb4\x7e\x5a\x3e\xd1\x30\xa1\x3b\x82\x23\x94\xc3\xce\x8a\x01\x93\xd1\xdd\xe4\xc9\x0e\x7d\xa1\x17\x8e\x11\x26\xdd\x29\x62\x52\xfa\x7d\x2f\x13\x9a\x14\x8a\xc4\x4d\xc0\x6a\x05\x8b\x84\xec\xb0\x3a\xd8\x27\xe6\x68\x92\xe8\x55\x29\xc3\x62\xce\xac\x2e\x71\x04\xb7\x97\xb2\xe9\x82\x60\x54\xde\x35\x05\x96\xab\x58\x17\x65\xe9\xa5\xc9\xff\x51\x43\x33\x2c\x2f\x3b\xfd\x24\x9a\x87\xfe\x1e\x30\xef\xd6\xfc\x05\x7e\x23\x4a\x1c\xd4\xc1\x9e\x07\x2b\xd7\x1b\x32\xd5\x5e\xf1\x22\xea\x93\x09\x11\x08\x1e\x26\xd9\x98\x49\x03\x76\xe3\xb7\x21\xcc\x32\xfe\xd9\x2b\x82\xd5\x45\xa7\xe6\xba\x6e\x4e\xb4\x34\x06\x3c\x87\xdb\x84\x8d\xf4\xef\x02\xed\xa3\xfd\xf4\xf9\xd2\x90\x5b\x78\xf7\xb1\x6b\x5e\xa0\xb5\x99\x8f\x1f\xbb\x0a\xaf\x62\xa1\x73\x55\x91\x60\x0f\x98\x01\x97\x7b\x1b\x94\x7f\x61\xa9\x1f\xf2\xaf\xb8\x72\x7c\x55\x26\x89\x72\xc8\x72\x16\xaa\xe9\x00\x61\x7a\x56\xf5\x35\xed\x18\xc4\xc5\xdd\xf8\xd7\xa5\x44\x63\x25\x6d\x09\x14\x4d\x88\x9c\x14\x9e\x5b\x09\xbd\xd9\xd8\x50\x93\x14\xb1\x03\xb8\x46\xf3\xe6\xfa\x1b\xb2",
        b"\x55\x5a\x45\x48\x80\x08\x4f\x6c\xb2\x52\x2d\xaf\x33\x99\xfb\x4a\x50\x1a\x94\x3a\x9b\x6a\xac\xd5\x8e\x2c\x7d\x37",
        b"\x73\x0f\xed\xb3\xa5\x91\x18\x44\x14\x60\x98\xac\x56\x03\xe2\xba\xaa\xe7\x69\x62\xb3\x3a\x32\x7b\x50\x42\x0a\x50",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x2d\x1c\x57\x3b\xf3\x24\x02\x8d\xc2\xfe\x00\x92\x8f\x55\xf7\xfa\xc7\x90\x37\xd4\xd9\x9e\xb1\x85\xf3\xb9\x97\xe0\x42\xcd\xf8\x08\xb5\x38\x2d\x50\xa6\xaa\x80\x85\xc5\xd1\x95\x8e\x67\x28\x3d\xf6\x69\x86\xb9\x34\x71\xc1\x2e\x30\x45\xba\x14\x6e\xd5\x96\x5c\x8a\xc5\xb4\x46\x68\xf6\x19\x84\xd2\x17\x36\xcf\x1c\x27\x67\x54\xb8\x48\xe9\xfa\x63\x6b\x63\x15\xb2\x27\x2c\x19\xe6\x56\x26\xbf\x8b\x12\x14\xd7\x09\x89\xa6\x23\xb5\xff\xf7\x80\x3d\x28\xa6\x63\xbb\xbb\xeb\xb8\x4c\x83\x9b\x42\x72\x0f\xd0\xe6\x22\x46\xb3\xb0\x34",
        p,
        q,
        g,
        b"\x5c\xcd\xca\x35\x55\x1c\xf3\x55\xec\x85\xdb\x8d\x68\x01\x0d\xed\x63\x58\x32\x55\xb1\xd5\xfd\x2a\x52\x2e\x29\x51\x3a\xd3\xce\x61\x57\xbe\x30\xea\x1c\x30\x5d\x87\xde\x6c\x27\xfb\xe3\xa3\xfa\x50\x07\x12\x82\x75\xd6\xe6\x18\x3a\x65\xce\xc5\xb6\x94\xbc\x6c\x02\x73\x35\x06\x6e\x01\x27\x3f\xd6\x98\x1c\xc5\xf6\x0c\x3e\x33\x75\x13\x86\xce\x79\x2c\xcb\x6e\x6a\x6d\xb5\xd7\xf0\x73\x80\x03\x29\xf9\xcc\x46\xd1\x9f\x42\x29\x23\xb9\x74\x8d\xcc\xa4\x97\x1e\x43\xa9\xd1\xf5\x9d\x1c\x74\x97\x88\xa8\x52\x7a\xd5\x24\xdf\x74\x15\x0b\x39\xea\xfa\x7f\x4d\x56\x08\xd1\xc9\x72\x55\x65\x44\x56\xea\xdd\x4d\x38\x2a\xc5\x4f\xdd\x12\x53\x8b\x2f\x2e\xf7\x5a\x50\x98\x01\x71\xa0\x4d\x40\x54\xb4\xcd\x79\xc7\x1e\x1c\x4d\xeb\x3b\xc6\xaf\x4c\x87\x4f\x5c\xf0\x27\x38\x96\xd4\xfd\xc5\x84\x7f\xef\xdc\xc9\x7f\x54\x02\xc7\xe7\x64\x84\xd3\xd2\xd7\x0a\xc1\x6b\xda\x41\x99\x6c\xad\xcd\x83\xad\x92\xcb\x37\xc0\xc1\xe9\xd6\x4f\xa1\xab\xd9\xa2\xcf\x00\x5c\x2c\x29\xa1\x73\x7c\xdd\x6d\x63\xaa\x2f\xda\xa5\x60\x79\x9b\x9f\x07\xd4\x48\x76\x06\x78\x47\x76\x29\xf2\x2f",
        b"\x7b\xf3\xc0\xc5\x47\xe2\x18\x46\x21\x2b\xf4\xcf\x3e\x38\x36\x2d\xd4\xd3\x59\xb7\xaf\x64\x20\xf9\x0d\xa5\x79\x07",
        b"\x5e\xbd\x5d\x2d\x88\xca\xe4\x0b\x37\xa9\xa5\xa8\x4e\x62\x18\xd2\x45\x3a\xfa\x14\x6c\x79\xa5\xd5\xf5\xdf\x44\xf4",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xba\xb4\xdb\x55\xbf\x6d\x3a\xbe\xfd\x1b\xb4\xe0\xf7\xbc\xec\x65\xee\x6c\x6d\x8e\xb0\x4b\x7c\x48\x0d\xf4\xe9\xe3\x91\x50\xf1\x0c\x38\xf1\xab\xb6\x3d\xfe\x1b\xb9\x75\x5c\x41\xb3\x89\x55\xba\x38\xba\x93\x8b\x6c\xee\xdf\xec\x02\x00\x1f\xa8\x70\x07\x0c\x59\xdf\x1f\xd2\xd7\x2a\x81\x41\x04\xc5\x14\x33\x76\xa3\x13\x6b\x81\x18\xf7\xb4\x7b\xd1\xff\xab\x53\x35\x9e\x53\xf9\x5c\x66\xee\x12\x70\x5e\x31\xa4\x62\xa8\xca\xae\x48\x15\x56\xce\xff\x60\x7c\xcc\x8b\xf1\x45\x07\x72\xcd\x68\x08\x1d\x3f\x15\xa7\x10\xe6\x56\xae\x56",
        p,
        q,
        g,
        b"\x53\xc0\xb0\xb0\x26\x9f\xcf\x29\x48\x66\x7e\x28\xb1\x1c\xcd\xa9\xcb\xb9\x27\x54\x63\xf2\x1e\xe3\x0d\xa3\x3c\x45\x75\xbe\x5e\x11\x1a\x18\x2a\x6f\x38\xb8\x90\xf2\x0b\x8f\x2d\x22\x4f\x59\x81\x89\x53\x10\xdb\x7c\x47\x03\xc1\xce\xc2\xb2\x57\xf4\x52\xd9\x64\xbe\x50\xc0\x14\xb7\x52\x36\x0e\xe2\x4f\x2f\xe1\xbc\xc0\x23\x47\x7a\x2d\x70\x85\xf5\x82\x14\xdf\x86\x6b\x13\xa8\xd8\xaf\x91\x31\x46\xdc\x0b\xee\x07\x8a\xea\x1c\xe6\x45\x99\x9b\x57\x94\x98\xea\xe9\x27\x7e\xd7\xe8\xb2\xc7\x5f\x49\x4e\xfa\xa7\x3a\x97\x3f\x32\x23\x2f\x08\xce\x7f\x0a\xfc\xba\x31\x66\x23\xb9\x41\x58\xde\x39\xbd\x4c\x0d\x51\x32\x34\xee\x1a\x48\x1d\x5b\x72\xf4\xee\xa3\x77\x49\xb4\x0f\xff\x12\xab\x62\x0f\x11\xaa\xa0\x1e\x35\x58\xe7\xa4\xc5\x50\x70\x7b\x71\xc1\x6c\xb8\xcd\xa9\x8f\x46\xbf\x71\x76\x9a\x47\x6c\x33\x85\xa8\xca\xf7\xc8\x86\xae\x47\xd2\x28\xb1\x77\x1a\x8b\xd4\xb7\xf1\x9e\x6f\x53\x04\x7f\x62\xf0\x29\xc3\x39\xfe\x75\x75\xbe\x93\x08\x0a\xc7\x48\x28\x91\x49\xa5\x7a\x0d\xdc\xed\x54\xd7\x2f\x6d\x4d\x34\x4f\xb8\x74\xcc\xc8\x5e\xa7\xf3\xdd\x21\x64\xdf",
        b"\x11\x8d\x22\x27\xbe\x4b\xd9\x1e\x98\xa2\xef\xde\x15\x60\x9b\x2b\x91\x24\xb2\xe8\x3c\x27\x4b\x63\x23\x00\x43\x2b",
        b"\x3a\x44\x74\x61\x94\x4b\x2a\x59\x27\x8a\x8e\x11\x18\xb4\x06\xbd\x3f\xf4\x16\x77\x5d\x65\x53\x0e\x54\xf9\xe6\x23",
    )?;

    // [mod = L=2048, N=224, SHA-224]
    let p = b"\xaa\x81\x5c\x9d\xb1\xc4\xd3\xd2\x77\x3c\x7d\x0d\x4d\x1d\xa7\x5e\xcf\xc4\xa3\x9e\x97\xd5\xfa\x19\x1f\xfe\xc8\xb1\x49\x0a\x29\x0c\xe3\x35\xe5\xce\x87\xea\x62\x0a\x8a\x17\xde\x0b\xb6\x47\x14\xe2\xec\x84\x0b\xf0\x0e\x6e\xbd\xb4\xff\xb4\xe3\x24\xca\x07\xc3\xc8\x71\x73\x09\xaf\x14\x10\x36\x2a\x77\x2c\x9a\xdd\x83\x8b\x2b\x0c\xae\x1e\x90\xab\x44\x8a\xda\xbd\xac\xd2\xe5\xdf\x59\xc4\x18\x7a\x32\xa2\x37\x19\xd6\xc5\x7e\x94\x00\x88\x53\x83\xbf\x8f\x06\x6f\x23\xb9\x41\x92\x0d\x54\xc3\x5b\x4f\x7c\xc5\x04\x4f\x3b\x40\xf1\x70\x46\x95\x63\x07\xb7\x48\xe8\x40\x73\x28\x44\xd0\x0a\x9c\xe6\xec\x57\x14\x29\x3b\x62\x65\x14\x7f\x15\xc6\x7f\x4b\xe3\x8b\x08\x2b\x55\xfd\xea\xdb\x61\x24\x68\x9f\xb7\x6f\x9d\x25\xcc\x28\xb8\xea\xa9\x8b\x56\x2d\x5c\x10\x11\xe0\xdc\xf9\xb3\x99\x23\x24\x0d\x33\x2d\x89\xdc\x96\x03\xb7\xbd\xdd\x0c\x70\xb8\x3c\xaa\x29\x05\x63\x1b\x1c\x83\xca\xbb\xae\x6c\x0c\x0c\x2e\xfe\x8f\x58\x13\x1e\xd8\x35\x1b\xf9\x3e\x87\x5f\x6a\x73\xa9\x3c\xba\xd4\x70\x14\x1a\x26\x87\xfb\xac\xf2\xd7\x1c\x8d\xde\xe9\x71\xad\x66\x07\x29\xad";
    let q = b"\xea\x34\x7e\x90\xbe\x7c\x28\x75\xd1\xfe\x1d\xb6\x22\xb4\x76\x38\x37\xc5\xe2\x7a\x60\x37\x31\x03\x48\xc1\xaa\x11";
    let g = b"\x20\x42\x09\x4c\xcb\xc8\xb8\x72\x3f\xc9\x28\xc1\x2f\xda\x67\x1b\x83\x29\x5e\x99\xc7\x43\x57\x6f\x44\x50\x4b\xe1\x18\x63\x23\x31\x9b\x50\x02\xd2\x4f\x17\x3d\xf9\x09\xea\x24\x1d\x6e\xa5\x28\x99\x04\xee\x46\x36\x20\x4b\x2f\xbe\x94\xb0\x68\xfe\x09\x3f\x79\x62\x57\x95\x49\x55\x1d\x3a\xf2\x19\xad\x8e\xd1\x99\x39\xef\xf8\x6b\xce\xc8\x34\xde\x2f\x2f\x78\x59\x6e\x89\xe7\xcb\x52\xc5\x24\xe1\x77\x09\x8a\x56\xc2\x32\xeb\x1f\x56\x3a\xa8\x4b\xc6\xb0\x26\xde\xee\x6f\xf5\x1c\xb4\x41\xe0\x80\xf2\xda\xfa\xea\x1c\xed\x86\x42\x7d\x1c\x34\x6b\xe5\x5c\x66\x80\x3d\x4b\x76\xd1\x33\xcd\x44\x5b\x4c\x34\x82\xfa\x41\x50\x23\x46\x3c\x9b\xf3\x0f\x2f\x78\x42\x23\xe2\x60\x57\xd3\xaa\x0d\x7f\xbb\x66\x06\x30\xc5\x2e\x49\xd4\xa0\x32\x5c\x73\x89\xe0\x72\xaa\x34\x9f\x13\xc9\x66\xe1\x59\x75\x2f\xbb\x71\xe9\x33\x68\x90\xf9\x32\x43\xfa\x6e\x72\xd2\x99\x36\x5e\xe5\xb3\xfe\x26\x6e\xbf\x11\x10\x56\x8f\xee\x44\x25\xc8\x47\xb5\x02\x10\xbd\x48\x4b\x97\x43\x1a\x42\x85\x6a\xdc\xa3\xe7\xd1\xa9\xc9\xc6\x75\xc7\xe2\x66\x91\x83\x20\xdd\x5a\x78\xa4\x8c\x48\xa9";
    test(
        HashAlgorithm::SHA224,
        b"\xe9\x20\xfc\x16\x10\x71\x8f\x2b\x02\x13\xd3\x01\xc0\x09\x2a\x51\xf3\xc6\xb0\x10\x7b\xbb\xd8\x24\x3a\x96\x89\xc0\x44\xe2\xd1\x42\xf2\x02\xd9\xd1\x95\xa5\xfa\xef\x4b\xe5\xac\xad\xc9\xff\x6f\x7d\x22\x61\xe5\x8b\x51\x71\x39\xbc\xb9\x48\x9b\x11\x04\x23\xc2\xe5\x9e\xb1\x81\x29\x4f\xfd\xae\x8a\xad\x0e\x62\x4f\xab\x97\x4c\x97\xf9\xf5\xe7\xdc\x19\xd6\x78\xa9\xcb\x34\x29\xcf\x05\xec\x50\x90\x72\x85\x6f\x5a\xdf\xec\x6e\x29\xba\xfe\x8e\x5b\xa9\x55\x93\xe6\x12\x84\x3e\x34\x31\x11\xd8\x8a\x1e\xaf\xf7\xdc\x0a\x2e\x27\x7f",
        p,
        q,
        g,
        b"\x1a\xe1\x0c\x78\x6a\xd0\x90\x2c\x5c\x68\x5d\xae\x5c\x71\x21\x41\x8a\x37\x7b\x88\x8b\x5f\x2f\x2b\xc7\x66\x23\x57\x0f\xd6\x2b\xcb\x19\x0b\x47\x1a\xd5\x35\x9c\x5f\x06\x2f\x88\x19\x28\x9e\x95\x6d\x8a\xa6\xf9\x0d\x1f\x8c\xf1\xee\x72\xd3\xa1\xbd\xfd\x56\xc4\x78\xdc\x29\xa1\x9c\x45\x69\xb5\xa6\x0e\x3a\x8f\x34\xf6\x06\x56\xea\xc5\xb2\x5d\xde\x55\x14\xa5\xc6\x7b\x67\x54\x23\x20\x4f\x6c\xca\xf0\x99\x06\x17\xcc\x73\x55\xb9\xd3\xed\x86\x89\x78\xa2\x52\x02\x0a\x76\x9e\xd5\x9a\x6e\xda\xa6\xef\xe3\x37\x7e\xef\x45\xf3\xf6\xf3\xe6\x41\x79\xcc\x7d\xb8\xb1\x43\xfb\x83\x5c\x5d\x71\xbf\xcf\xa1\xe2\xa9\x04\x9b\xcc\xf7\xfe\x9a\xb5\x75\x46\x22\x0f\xe3\xf4\xb7\x52\x1c\x86\x17\x39\xd1\x38\x50\x7e\x81\xa4\x6a\x69\x93\x60\x54\x41\xdc\xb9\x0d\x6e\xe4\xaf\xbc\x42\xca\xbe\x90\xa2\x54\x44\x49\x68\x10\x9d\x7e\xdd\x96\x94\xa0\x23\x23\x9f\x1d\x56\x17\x5d\xd1\xfa\xc1\x15\x91\x5e\x24\xfa\xb5\x63\xf4\xfc\x3f\x26\x9b\xed\x2f\x30\x08\x32\xd1\x12\x59\x64\x85\xa7\x11\x41\x7a\xa7\x3b\xb4\xac\x72\xa6\x51\xa1\xfa\x5b\xae\xd3\x63\x6c\x72\x0d\x39\x70\x08",
        b"\x65\x10\x2e\x8f\x64\xec\xb1\x1f\x06\x01\x7b\x1a\x0c\x0d\xef\x3c\x29\x89\x7c\x27\x7c\x4a\x94\x8b\x1f\x4d\xa6\xb9",
        b"\x21\xad\x0a\xbb\x27\xbd\x3c\x21\x16\x6c\xb9\x6a\xef\x70\xc0\xdb\xd5\xf3\x07\x9c\xab\x0d\xd5\x43\xd4\x12\x5b\xd1",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xda\x5e\x7b\x05\x1c\x18\x59\xd2\x2f\x2a\x31\x63\x33\x5d\x27\x79\x51\x97\x3c\x17\x2e\x06\x69\x7c\x04\x90\xff\x15\xb5\x92\xc1\xeb\xd0\xfa\x5e\xfa\x24\x63\x11\x98\x04\xa3\xfe\xa2\x24\xb9\x6b\x46\x3e\x30\x08\x3e\x00\x29\x49\xa2\x4e\x92\x20\x31\x76\x4b\xb3\xda\xff\x81\x01\xfa\x08\x8a\xf5\x45\x7a\xf3\x66\x54\xc6\x68\xf2\x34\xa0\x0c\xd8\x28\xcc\x74\x0a\x89\x8c\x0c\xd3\xdf\x09\x31\x5d\xa9\xb3\x46\xb3\x25\xb2\xfb\xec\x47\x52\x10\xb7\x54\x82\xaf\xfa\x61\xa3\xef\xf5\x0c\x83\xc3\xa0\x39\xfa\xe5\xcf\xa8\xd9\x71\xfd\xdd",
        p,
        q,
        g,
        b"\x5e\x27\x69\x87\xb8\x47\xb8\x52\xcc\x37\x2e\x98\x6e\x8a\xba\x06\x33\xdd\x46\xc4\x61\xba\xb5\x8a\xca\xe0\x56\xd4\xd1\xa9\xdf\x03\xa1\x9d\xf1\x14\xf6\x48\xb2\x8e\x03\x85\x06\xfd\x09\xad\x0d\x95\x44\x9d\x9d\x80\x58\xaa\x1b\x24\x1b\x2a\xcd\x3b\xad\xbf\x98\x82\x69\x73\x31\xde\x45\xb4\x52\x34\x5c\x05\x1c\x2c\xd8\x30\xf7\xcd\xd7\x48\x6b\x11\x66\xb9\x38\x91\xa7\x2a\x8b\x7d\xc6\x22\x8b\xad\x70\x87\x20\xef\x33\x23\x58\x01\xc4\xd4\xc3\xc4\xf2\x80\x36\xdf\x60\x29\xa1\x95\xd0\x01\x91\x24\xd1\x6f\xe8\xf7\x6c\x52\x5b\x7e\x8f\x04\xbf\x4b\x8d\x8b\xa6\xef\x60\x8e\x62\x32\x24\xfa\x8d\x98\x84\x20\xf4\x05\x26\xc2\x5a\xe3\xe4\xc7\x9d\x5a\xe7\xfe\xe6\x97\x93\xe0\x2b\xad\x96\x51\xea\x0f\xef\xd3\xea\xdc\x5f\xf1\xca\x2d\x14\x29\x30\x35\x5b\x1f\x3a\xea\x10\x22\x21\xfa\x17\xb7\x35\xa1\x8a\xf3\xb8\x33\x27\xc8\xf3\x3e\xfb\x9a\x49\xb7\x02\x11\x01\x4e\xba\x43\xfa\x65\xee\xaf\x25\xeb\xf4\x52\xbc\x4b\x7d\xc1\xf4\x07\xd0\xcf\x1b\x83\x46\x19\xb5\xf7\x3c\x6c\xab\x70\x51\xc9\x20\x70\xaa\x06\xf7\xf9\x40\x6c\x50\x7d\x1a\x15\xd1\x2c\x11\xbc\x83\x9a",
        b"\x31\x36\x15\x83\x6f\x0d\x33\x8d\x81\xb6\x70\xf1\x16\xa5\x41\x4d\x2c\xe9\x0e\xa5\xca\x53\x08\xba\x4f\x0c\x8a\x7d",
        b"\xdc\x1d\x4c\x3c\x06\x20\x3f\xd5\x98\xa4\x76\xc8\x91\xdf\xe5\x93\x41\x62\xd0\xd3\x5f\x37\xf1\xc0\x9d\xd6\x39\x5d",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xf4\x98\x95\xb3\x29\x0d\x9a\xae\xb4\xaf\x61\x1c\x5e\x30\xaf\xc0\x04\x7d\xd4\x2c\x07\x21\x62\x11\xd5\x49\x77\xd1\x49\x7f\xa4\xee\x6a\xbe\x11\x00\x0d\x6a\xc0\x4d\x24\xb4\xc5\x0f\x31\xe0\x6e\xe8\xa7\x47\x74\xd3\xd3\x04\x13\x7c\xc6\xb1\x14\xd1\x45\x25\x0e\xe7\xe9\x4a\x12\xa1\xab\x59\x2a\xe3\x07\xef\x5d\x93\x0c\xf3\x91\x70\xe9\x75\x6a\xdc\x5e\x7b\xa6\x2a\x54\xab\xb6\xf0\x47\xb4\x50\x0b\x61\x21\xe1\xf4\xa9\x5d\x3c\x6a\x96\xf7\xf8\x33\x3c\xbb\x1e\xbe\xed\x8b\x4d\xb1\xa7\xfe\x75\xf4\x07\x1c\xeb\xfb\xbd\xfd\xab\x90",
        p,
        q,
        g,
        b"\x6d\x62\x25\x25\xec\xf5\x4d\xbe\xca\xa8\x11\x93\x9e\xe0\x7e\xf2\x97\x5d\x9d\xa9\xf7\xa3\xc5\x8b\xbb\x89\x3c\xe3\x88\x06\x77\x40\x4f\x2c\x6e\x59\x63\xb8\xc0\xb4\x49\x26\x01\xf1\x5b\xc6\xfd\xfd\x74\x7a\x00\xab\x83\x34\xe9\x05\x32\x01\xe1\xc9\xfb\xa5\x5f\xbf\xde\x36\xec\x54\x23\x75\x01\xb8\x74\x16\x99\x27\x71\xcb\x5a\xb8\x78\x1d\x0a\x96\x7b\x7f\x14\xf3\xd5\xde\x6b\x16\x65\xf6\x62\x88\x58\x78\xe5\x0a\xd3\x78\x27\xb9\x5c\x8f\x0e\x21\xd6\xbb\xeb\xc9\xdf\xd4\x7b\x29\x57\xd2\xfc\xdd\x1a\x2b\x25\xa6\x16\xe6\x98\x12\x9b\x45\x99\x8b\x6b\x6a\xa2\xa9\x9c\x1e\xbf\x42\x75\x49\x3e\x28\xee\xf1\xae\x34\xe9\xca\x63\xcd\x88\x86\xda\x58\x57\x29\x07\xaa\x9b\x71\x4e\x89\xbd\x36\x44\xa7\xea\x02\x9f\xa3\xa4\xae\x9c\x26\xe6\x65\xc8\x52\x96\x20\x4f\xdf\x86\xb7\xb1\xdd\x78\x66\xbc\x8e\x93\x85\xe9\x51\x8a\x27\x02\x48\x29\x25\x94\xc5\x4a\x4a\x03\xdc\x14\x92\x66\x4d\xda\xe5\x32\x77\xc6\xfb\xb9\xdd\x0c\xdd\x99\xbf\x11\xea\xf6\xae\x31\x92\x3e\x4f\x97\x9a\x7f\x58\x17\x99\xdc\x43\x2b\x19\x40\xf6\x13\xa7\xa7\xea\x68\x55\x23\x7f\x77\x6e\x91\xd4",
        b"\x79\xd5\x44\xcd\xec\xfd\x1e\xc1\xb7\xd1\xba\x63\x22\xa5\xe0\xeb\x85\x8a\xeb\x4b\x76\xd5\xb3\x20\x2c\xea\x23\x3a",
        b"\x0e\xa5\x3d\xea\x4c\xcb\x25\x97\x8a\x0a\xf5\x52\x95\x98\x91\x1b\x47\xc2\x5e\x0b\xa3\xb2\xa0\x50\x5f\xd1\xd7\xfc",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x31\xd7\x39\x56\x69\x14\x54\x9e\xb2\x57\x26\xbf\x6d\x4b\x6c\x67\x4f\x47\x9b\xa7\xa4\x06\xac\xd1\x08\xa1\x06\xf3\x6c\x7f\x52\x14\x97\x6d\xcf\x3a\xdf\x2c\x83\xfd\x26\xb3\x7d\x52\xc0\xb5\xff\x51\xe6\xb3\x81\x1a\x8d\xcb\x02\x6a\x1f\xbb\x52\xf9\x50\x27\xea\x60\x34\xd9\x11\x49\xb3\x0a\xb4\x92\x8e\xde\x26\xdd\xd6\x92\xdd\xb8\xdd\xd9\x29\xfb\xff\x83\xfc\x67\x37\x88\xfa\xa0\xba\x5d\x96\x7f\xd1\x33\x92\x99\xe5\x5b\xe5\x1c\xea\x80\x60\x9d\x2b\x3c\x34\x33\xcf\x71\x3a\x96\x86\xe2\x29\x33\x6c\xfa\x7e\x72\x0f\xd5\x30\x3d",
        p,
        q,
        g,
        b"\x38\x6c\xbb\x8f\x7e\x72\x87\x51\xd4\xf6\xa7\x5f\x89\x05\x02\x98\x9b\x51\x22\x8d\x30\x39\xdd\x1a\xf7\xf2\xdd\x01\x86\xbf\x97\xa9\xff\x76\x3b\x40\x32\x3b\x30\xab\x0d\xc8\x1b\xf0\x9e\xf4\x8d\xb7\x2c\x0c\xfb\xe7\x72\xb3\xd3\x14\x92\x7e\xd1\x9b\xad\xee\x7b\x88\xb4\x9e\xe2\x94\x92\x37\x14\xad\xae\x30\xc9\x55\xd3\x7b\x99\xc1\xda\xdc\x4a\x29\xf0\xf8\xc2\xb9\xd1\x03\x8d\x17\x05\x9c\x58\x6a\x21\x2a\x97\x48\x72\x0f\xde\xc9\x5b\x42\x89\x71\xdf\x19\x23\xf0\x8a\x01\xd3\x58\x93\xd1\x2e\xd1\x7e\x0b\x14\x2e\xd8\xe9\xef\x77\xd4\x40\xa0\x1d\x77\x90\x5b\x92\xc5\x1d\xac\xe1\xb3\x45\xcd\x19\xf9\x16\x23\xa6\x96\x42\x88\xdd\xee\x6e\x99\x08\x19\x7f\x91\xda\x9a\x26\xf8\x06\xbb\x14\xe2\x37\x17\x42\xf8\x49\xcd\xc6\xce\x7a\x04\x5a\x70\x4a\x79\x2e\x57\x60\xd6\x64\x4e\xad\xb7\xcf\xfa\xba\x80\x6b\x05\x45\xfa\xe3\xb9\xfa\xda\xe4\xe3\x6b\xdf\x3b\x69\xc6\xdb\xbf\x0d\x8b\x05\x3d\xa3\x8b\x90\x4e\x9c\x4b\x94\x93\x25\xb2\xa0\x05\xb2\x49\x27\x6a\xc3\x69\x27\xb3\x17\x93\xf8\x01\x15\xb5\xe2\xf2\x10\x7f\x98\x77\x10\x38\x07\x08\xe2\xc3\x22\x89\x4f\xa8",
        b"\xc8\xb8\xa9\x2e\x8c\x10\x15\x05\xa1\x99\x1b\xcb\x02\xfb\x6e\x38\x2a\x3e\xcb\xae\xc8\xf4\x37\x45\x01\xb6\x57\xbe",
        b"\x20\xd1\x61\xce\xfd\x58\x49\x79\x22\x43\x79\xf2\x8d\x82\x7a\xa2\x19\xc5\x72\xf9\x60\x01\x47\xf4\x04\x8b\xa7\xcf",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xd0\xa8\xa1\xca\x0f\xf2\xb4\x4b\x37\xff\x86\x00\x07\x33\x4b\x23\xbe\x49\x34\xff\x89\x05\x1d\x78\x7c\xe6\x9d\x3d\x7f\xa7\x34\xb9\x77\x9e\x2f\x0b\x38\xc2\x35\x39\x1a\x89\x7f\xb8\x51\x4b\x85\x7b\x99\x1d\x10\xe3\x4a\x00\xdc\x25\xb0\xc4\x38\x2d\xfb\x6d\x53\xaa\x87\xec\x17\x84\xf1\xca\xe2\x59\x92\x59\x40\x6d\x47\x56\x53\x98\x67\x67\x9d\x30\x88\x91\x3a\x13\x88\x71\xe2\xa4\x34\x74\x72\x22\xfc\xfa\xb0\x79\xd9\xe6\x55\xba\x25\x44\x63\xcb\x0c\x57\x86\xb9\x85\x8d\xc4\x29\xff\xda\xdf\x4c\x3b\x6a\x25\x3f\x90\xee\xba\x24",
        p,
        q,
        g,
        b"\x72\x47\xd4\xe1\x25\x3f\x0b\x52\xa1\x38\x8b\x79\x48\x15\xdb\x61\xc1\xa3\x54\xcb\x0f\x73\xfd\x19\xfe\xde\x61\x5c\x1c\x30\x25\x84\x0f\xff\x20\x4b\x0c\x6e\x61\x0e\xbe\xf1\x11\x3d\xf5\x6f\x67\x40\x6b\xad\xeb\x99\x44\x58\x91\xdc\xaf\xe1\x8d\x28\xf5\x97\x12\x60\x64\xdd\xf7\xaa\xf2\x03\xb2\xfb\x0d\x35\xd2\xf4\x58\xbb\x74\x34\x1a\xd9\x37\x21\x1e\xdc\x39\x4e\xc1\xa3\xf7\x90\x9a\x3f\x97\x2d\xb2\x7a\xa1\x35\xd3\x1b\xbd\x7e\x36\xc2\xbb\xc3\x60\x58\x5e\x7b\xb6\xe8\x32\x76\x40\x6b\x95\x25\xf6\x88\xee\x59\x95\xe7\xaa\x8e\xf7\xa7\x2c\x27\xe9\x90\xd6\x40\x16\xb9\x9a\x0a\xe4\xd0\x4b\x2f\x1b\x7d\x23\x8a\xf8\x8a\xc4\xc2\xe4\xe0\xf3\x29\x4c\xfe\xe9\xbe\x24\x57\xe4\x89\x55\x94\x8c\xf4\xbb\x3a\x44\x5a\x1d\x77\x8c\xed\xfa\x4b\x86\xf5\x9f\x15\x61\x18\x03\x4b\x2b\x83\x4a\x9a\xa1\x21\xe9\xd4\x82\xd6\x92\x22\x92\x82\x3b\xe2\x99\x1b\x3b\x5b\x42\xc2\x39\x25\xda\x29\x4d\x5e\xa3\x74\x06\xea\xf7\x8b\x7d\xc7\x25\x19\xd8\xf2\x61\x48\x2d\x6a\xff\xf0\xe5\x67\xbf\x6e\x67\x3d\xd8\x99\x60\xce\x73\x4f\x09\x2d\x98\x95\x63\x52\x42\x9a\x91\x84\x56\x94",
        b"\x9d\xab\xff\x22\xa4\x30\x12\xdb\xf4\x7d\x56\xb9\xae\x5a\x09\xf4\xd7\x39\xdd\x69\xfe\x90\x77\x25\xaf\xcd\x84\xf4",
        b"\xb6\x0c\x44\x72\x8e\x4b\x13\x90\xf3\x02\x38\xfb\xa1\xdc\x10\x03\xfd\xd3\x95\x07\xff\x5d\x6b\xa7\xe6\x09\xf2\xae",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xe4\xff\xe7\x2c\x77\xc3\xa4\x3a\xf8\xa6\x1f\x58\xf9\x24\x0e\x1a\x07\xb5\xc2\x89\x4d\x5b\xdb\x65\x4b\x2b\x99\x4d\xc0\xc9\x87\xba\xd9\xb7\x04\x07\x5d\x3d\x0a\x96\x9c\xec\xfc\x98\xb1\xdc\x20\xe7\x6c\xd8\xe0\x12\x28\x58\x19\x46\x22\x26\xa8\x4d\xcd\xd6\x78\x95\xf6\xea\x27\x82\x66\xf1\x57\x5e\xa7\x85\xa2\xc3\x59\xf8\xf4\x59\x3b\xef\x31\xa5\x80\x91\xb6\x4a\xfb\x84\xcd\xfd\x23\xe4\xaa\xff\x29\xd9\x62\x6f\x0c\x82\x3d\x93\x42\x83\xa4\xfa\xaf\xc9\xc6\xcc\x18\x62\x23\x28\xca\xd9\x6f\x77\xd7\x9b\x9b\xa3\x5a\x43\xd8\x25",
        p,
        q,
        g,
        b"\x71\x46\x00\x9d\x12\xb0\x3b\x2f\x32\x30\x5f\x49\x5f\xaf\xcc\x4d\x45\x2e\xfb\x85\xcc\x80\xd6\x71\xff\x42\x49\x49\x2c\x66\x99\xfb\x26\xa8\x9c\xa4\xb2\x24\xd5\x6f\x6b\x8e\x74\x5d\xf9\xfb\xc7\x35\x2c\xa5\x83\x22\x2f\x4d\xea\xb1\x18\xf9\xfe\xc0\xb3\x4e\x33\x40\x60\xbd\xc2\x8d\xb8\x72\xe0\x09\x06\x49\x14\x94\x99\xe7\xa1\xc1\x97\x87\x8d\x3c\x72\x62\x43\x93\x03\xb9\x02\x01\xd0\xb7\xf5\xbe\x94\xd0\xa7\xc4\xeb\x15\x18\x29\x35\x29\x6c\x3e\x3f\xa2\xd7\x7d\x74\xd7\x8f\x41\xca\xda\xa4\x0e\xaf\xd4\x0d\x01\x78\x88\xca\xa0\x2a\x47\x48\x68\xe4\x0f\x49\x6b\x7b\xc1\xce\x36\x7f\x50\x34\x35\xe0\xd9\xa6\x37\x5a\xab\x03\xc2\x31\xd9\xcd\xaa\x15\xde\x23\xc4\x8a\xc0\x87\x8e\xf6\x49\xeb\x14\x4c\xe6\xbe\x4d\x2d\xe1\x1d\xa2\x02\xfa\xe8\x20\x90\x67\x3c\x83\xb3\x28\x40\xa3\x2d\xf6\x17\x6e\x1d\x55\x02\x7d\x7a\x1c\x1c\x56\xe6\x42\xf5\x1a\xae\xcc\xb3\xc9\x90\x89\x80\x61\xbf\xa1\x6b\x3d\xc1\x46\x10\x73\xc3\x33\x33\x7f\xd7\x6a\x31\x03\xf3\xfd\xe8\x21\xbc\x99\x4e\xbe\xdd\x6f\xfd\x79\x74\xd0\xca\x1b\x54\x96\x1d\x7d\xf5\xb9\xee\xbb\xfa\x26\xc3\xd6",
        b"\x4a\x2a\xbc\x68\x9d\x2a\x63\xe8\xb2\x32\x14\xa3\x21\x2a\x5d\x20\xa7\x38\x68\x82\xd5\xe1\x1c\x5d\x5d\xaa\x66\xbc",
        b"\x08\xe0\xc6\x54\x70\x87\xb5\x8b\xc9\x4f\xae\x24\x7e\x96\x2d\xa1\xa2\x89\x78\x88\xd1\xbc\x9c\x8c\xbf\x3a\xd6\xaf",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xf8\xfe\xc1\x92\x88\xf3\xa8\xbd\x1d\x0d\x57\x3b\xbb\xc1\x80\x10\x60\x65\x69\x74\x81\xbe\xd9\x12\xf8\x75\x27\x50\xd3\x31\xe3\xa0\x97\x77\x5a\x12\x27\x6b\xc4\x29\x3a\x78\xa8\x07\x48\xb2\xb2\xc3\x7d\x20\xb8\x00\x33\x5c\x1d\x1b\x43\x0a\x71\xbb\xdf\xd8\xf7\xaf\xee\xec\x82\xce\xff\x2f\xd3\x3f\x26\x24\xe4\x9d\x37\x45\x7f\x26\x2c\xf5\xde\xde\xf9\x02\x5c\xe9\x6e\x0b\x7d\x49\x9f\xcc\x7a\x7f\xf0\x6c\x02\x59\x0e\xa8\x21\xdd\x8e\xd0\x60\xca\xbc\xf4\xfe\xec\x95\x92\xac\xed\xdf\xd3\x2b\x4c\x09\xe4\xd4\x49\x38\x43\x5b\x82",
        p,
        q,
        g,
        b"\x7e\x50\x01\x1d\x42\x29\x86\xea\xe0\x1a\xe6\x89\x43\xdc\xa0\xc8\x7a\xf4\x4f\x7b\x87\x9b\xd1\x25\x6d\x4c\xaf\xfa\x0e\xb1\x92\x50\x29\xc0\x63\x3a\x7a\xc6\x74\x87\xa7\xb6\xf9\x8a\xd7\x7e\xe7\xe1\x44\x2d\x12\x9d\x06\xdb\x47\x5a\x4f\x78\x04\xfd\x8c\x6a\x03\x81\x51\x91\x1f\x81\x39\x7e\x96\x35\x94\xb9\xc9\x1e\x3b\xfe\x94\x32\x8f\x05\x6e\x9b\xdb\xb9\xb1\x1f\x54\x93\x9d\x7e\x23\x7a\xaf\xb0\xc9\x50\xe0\x58\x1c\xab\xfe\x94\xbc\x26\xf0\xe0\xd5\x56\x09\x97\xbf\xb0\xf6\x35\x7b\xbf\x2c\xad\xb0\x10\x8e\xc0\x09\x56\x46\xe4\xca\xa2\x2f\x71\xe1\xf1\x7a\x9f\x34\xe8\xa8\xc4\xb7\x1c\xf0\xb1\x26\x5e\x00\x15\x54\xfa\x91\xf1\x8a\x17\x56\x2b\xc0\x94\x8c\x43\x1f\x25\x94\x59\x62\xba\x7f\xaf\x7d\xcb\x64\xff\x0b\x8b\xdd\xe7\x01\xe1\xdf\x62\x0a\x11\xaa\xd0\x71\x96\xd6\x7a\x95\x6e\xbe\x49\x8a\xe6\xf8\x23\x24\xf7\x5c\xaf\xbe\x80\xed\xaa\xbe\xf0\x03\x7b\x79\xc3\xed\x65\x8d\x9b\xa1\xb5\x42\x2c\x4a\xc0\x53\xba\x69\xbb\xaf\x7f\xa9\xdb\x99\x0e\x8b\x5e\x7f\x9a\xf5\x7a\x79\xf3\xe3\x1c\x07\x61\x1f\x50\x2b\x30\x15\x96\x2b\x02\xb6\xb4\x25\x70\x6e\x0a",
        b"\x2f\x38\xc5\xcf\x86\xaa\x0e\x53\xd1\xfe\xa0\xe6\x5d\xd0\x38\x13\x64\x04\x04\xb8\xd9\xa8\xcd\x6d\x26\x4d\x92\x85",
        b"\x47\x60\x38\x80\xf3\xd6\x7b\xa1\xa6\xea\xbc\x20\x13\x7d\xc4\x88\x2e\x41\x73\x04\xcb\x95\xd6\x22\x17\x7d\xf5\x11",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x75\x59\x46\x5a\xf5\xca\x04\xc1\xe7\x4d\xeb\x9f\x8e\x46\xb0\xef\x17\xde\x4d\x7a\x2a\xe0\xfa\xf4\xe9\x03\xa2\x99\x8b\xca\xa0\x9b\x7f\x17\x30\x39\x33\x20\xeb\xc5\x7d\x05\x2d\x2e\x98\xf5\x48\x6e\x8e\x92\xbd\x1e\xe6\xbb\x0f\xfd\x02\xd6\x9e\x5d\x45\x91\xe2\xfa\x12\xe4\xeb\xff\x8b\x6b\x9d\x32\x70\xfc\x75\x27\x4f\x8f\x82\xe1\xc6\x0e\xdb\x2a\x21\xf8\xd5\x53\x1a\x23\x80\xcb\xeb\xb2\x4f\x64\x57\x17\x6e\x54\x76\x9a\x13\x66\x01\xa9\xb8\x1d\xa6\x8f\xf1\x96\xff\x8c\xc7\x8c\xf0\x59\xc0\x4a\xe2\x24\x59\xce\xc7\xda\x89\xb6",
        p,
        q,
        g,
        b"\x5b\xcd\x42\xe5\x86\xca\x18\x0f\x74\x33\x95\xfc\x39\xe2\xbd\x39\x38\x20\xf5\xb4\xc4\x9c\x7c\xb7\x69\x21\xec\x38\xbb\x53\xe8\x64\xfb\xe8\x09\xa0\x33\x77\x5f\x16\xc7\xf5\xc6\x48\x72\xfe\xdd\xe6\xab\xc5\x60\x48\x8e\x57\x29\x55\xed\xd3\xf9\x56\x90\x92\x07\x1e\x56\xdf\x21\x15\x64\xf3\x31\x85\xdb\xff\x18\x0e\x7a\xb2\x29\x77\x00\xc6\x4d\xb6\xe2\x20\x70\x1c\xb8\xa2\x1e\xad\x2e\xa8\x09\xf0\x6a\x16\x55\x43\x19\xb2\x73\x9d\xe2\xac\xa8\x05\x7a\x62\xd4\xca\xa7\x95\x7a\x2b\x9f\x03\x9b\x3c\x7d\x4f\xb0\x76\x1a\x73\x30\x2a\x6f\xbb\x58\x31\x00\xb2\x39\xd7\x27\x15\x8b\x4c\xdc\x97\x65\xfe\x04\x85\xaf\xb6\xa1\xb0\xac\x0d\xb5\x04\xa9\x47\xf3\xd8\x7f\xaa\x55\x42\xc6\xee\xf7\xa6\x81\xc5\xfc\xd2\x8f\x46\x36\x36\x0f\x55\x93\xbf\xf7\xe4\x33\xb6\xa3\x38\xd7\x7e\x3d\x63\xf6\xce\xff\x69\x53\x6e\x2a\x3f\xf7\x7a\xce\x74\x5b\x65\xa5\x16\x0d\x7f\xbf\x91\x05\xa9\x0f\x46\xce\x1c\x54\xfa\x35\x3c\x8a\xee\xbe\x16\xfb\x23\x8c\x8e\xd9\x98\x61\x7b\x63\x28\x75\x11\x20\x8d\x9d\xb3\xf6\x6d\x50\x33\x74\xbb\xda\x48\xa5\x52\xd0\x4b\x2c\x30\x4a\x15\xba\xc0",
        b"\xc5\xd3\x3f\x5a\x4f\xe2\x28\x0a\x9b\x96\xd7\xa9\xb5\x53\x0d\xc1\x7c\xd1\x05\x4b\xf1\xe8\xcf\x6f\x4a\xa3\xe2\xac",
        b"\xc9\xbf\x1c\x06\x2b\xd1\xe8\x6f\x3b\xd3\xc1\xff\x58\x2c\x33\x27\x05\x37\xfa\x77\x69\xb9\x59\x2a\xef\x12\xe1\x04",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x16\x74\x82\x38\x96\xc5\xa7\x64\xc6\x1f\xd1\x9b\x12\x5a\x7d\x6c\xd5\x8c\x88\x3d\x86\x79\x43\x91\x47\x73\x49\xf0\x36\x16\xd7\x5b\x69\x25\xe9\xdc\xc5\x53\xde\xa3\x70\x47\xf0\xcd\x15\x31\x68\xeb\x26\xe5\xad\x4b\x8f\xe7\xcc\x65\xe4\xfa\x27\x55\x14\xc8\x42\xaf\x63\x50\x7f\x90\x1f\xd1\x10\xb9\x82\x49\x13\x3d\x3d\x12\x66\xd2\xf9\x67\xc8\x5b\x7f\x88\xdd\x76\xc7\xf7\x6b\x78\x6b\x55\x72\xdc\xae\x68\xcc\x64\x6e\x45\x8b\x82\x78\xdb\x34\x6b\x2e\x97\x0c\x78\x70\xcf\xfd\x84\x57\xfb\xec\x06\xbb\xb5\x14\x15\x75\xf4\x0f\xde",
        p,
        q,
        g,
        b"\x5c\x34\x13\x5c\x90\xf9\x7e\xbc\x9b\xf1\xed\x98\x6e\xba\x56\x3e\x32\xce\x8c\x25\xae\x71\x41\xdf\xef\xca\x86\x00\xad\x2f\x3c\xbe\x8e\x45\xb4\xa0\x10\xae\x49\x97\x82\x0a\x38\xb4\x88\x81\x87\xbf\x20\x7b\xde\x43\x8a\x1e\xc7\xbe\xff\xf8\x1a\x64\x26\x5a\x4c\xe9\x90\x0b\x37\xa3\x8e\x4f\xc2\x36\x13\x88\x7b\x63\x8a\x11\x3e\xf4\x16\x65\xad\x2b\x1f\x15\x76\x4c\xb5\x36\x07\xd0\xee\xc3\x03\xac\x48\xc0\x55\xf5\xaa\xda\xbc\xfb\xe2\xc5\xfa\xa8\x5e\x02\x9c\x43\xe1\x60\x7a\x3a\x29\xf6\x58\x02\x95\x9b\x68\x6b\x46\x8e\x81\x07\xc4\x66\xa7\x31\x7b\x50\x63\xe0\x38\x02\x19\x75\xb2\xf0\x17\xf1\xf3\xba\xd0\x7c\xd0\xeb\xb4\x87\x96\x41\x51\xe4\xf8\x2b\xb5\x27\x7c\x35\xa2\x18\xec\x57\x0c\xb5\x68\xad\x04\x04\xa3\x71\x3a\xb7\xfc\xc1\x29\x7b\x1e\xa9\x74\x3f\x85\xac\x5d\x5a\x7e\xc8\x18\xe5\xf9\x0a\x4a\x58\xf2\xc2\x19\x2b\xba\x6d\xff\xec\xbc\xd3\x9f\x24\x5c\xc9\x32\x95\x31\x90\xee\x35\x3a\x0c\xa9\x9d\xc6\x1e\xac\x4b\x4f\x83\x46\x18\x14\x0c\x9a\x32\xec\xa3\x1d\x71\x8c\x95\xee\x03\xb2\x99\x2c\x63\xa6\x83\xb0\x62\x88\x83\xa5\xc2\x22\xfd\xde\xf0",
        b"\xb1\xa9\x46\xfa\x42\xa3\x6d\x83\x6d\xaa\xb5\x6f\xe0\x15\xc9\xf2\x9c\x45\x44\xa4\xa4\x7d\x48\x2e\xa2\xd9\xcc\x5b",
        b"\xe2\x90\x5e\xe7\x0a\x5d\xc0\x99\xb7\xe0\xba\xec\x55\x66\xb2\x29\xe9\xca\x8e\x7e\x00\x84\x09\x66\xcf\x56\xc4\xd5",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x28\x1f\xd1\x4a\xe2\xe7\x02\xdb\xd2\x5f\x77\xd8\xba\x8a\xf0\x9f\xdd\x77\xb1\x83\x96\x48\xab\x9c\x88\x0b\xd1\x19\xd4\x47\x53\x78\xfc\xd0\xd1\x24\x15\xab\xb9\xf2\x6b\xfb\x8e\x26\xf1\x08\xb1\x29\x88\x59\x23\x5e\xd1\x2e\x7f\x9e\x91\x56\x28\xe3\xca\x36\xc5\x98\x6d\x18\x81\x1a\x59\x05\xae\xf7\x87\x8c\x63\x00\xa9\x5e\xa8\x71\x82\x01\x6e\xc5\x95\xd3\x2e\x4d\xfc\x27\x4a\xdb\x47\xc3\xed\x0f\x6c\x38\xec\x89\x3b\x33\x1f\x70\x92\xf1\x9b\x72\x4b\x9f\xe4\x3f\x0e\xf8\xde\xc1\x4f\xb7\xbf\x8b\x90\x41\xb5\x39\x0b\xeb\x44\x08",
        p,
        q,
        g,
        b"\x48\xed\x8f\xa8\x9d\x07\xde\xb5\xf8\xee\x6d\x38\x74\x8a\x4e\x66\x00\x20\x20\xf7\x9f\xf2\x2d\x66\xfa\x53\xad\x91\x3d\x59\x68\x60\xd4\xdb\xcb\x7c\x3a\x66\x33\xcd\x42\x24\xa8\x0e\x5e\x95\x90\x8f\x87\xb1\x8a\xcc\x2e\x36\x4c\x14\xb5\x1d\xe6\xbd\xda\x7a\xd8\x96\x1d\xfd\xa4\x54\xef\x47\x98\xd0\xf7\xa3\x0e\xf1\x0e\xae\x87\xde\x40\x86\x77\x64\xb8\x4b\xc5\x5d\x7c\x02\x83\xf9\xc7\xcd\x2b\xe0\x8e\x18\x52\x48\x75\x12\xff\x43\xa8\xd1\xe6\x8a\x95\x11\x97\xc7\x71\xf9\xe6\xc2\xff\xdf\x2c\x00\xed\x21\x63\xf8\x6d\xff\x52\x41\xf9\xe2\xff\x1c\xdb\x05\xa0\xb3\xe6\x47\xe6\xfd\x23\xcc\xad\xa8\x3b\x9c\x59\x61\xe6\xe2\xfe\xf3\x29\x74\x93\xdd\xb0\xe9\x90\x29\x5d\x38\x40\x5a\x24\x44\x8e\x24\x96\x27\xc0\xa7\x99\x8c\xc4\x07\x2d\xd2\x91\x39\xc5\x33\x6d\x98\x56\x01\x66\x42\x99\x2c\xd2\x45\xc7\x58\xa3\x03\x1e\xc2\x80\x7b\x17\x1a\xba\xee\xf1\x4c\x82\xa3\xda\xb2\x01\x75\x23\x51\xde\x2b\xff\xa5\x08\x5c\x13\x76\x56\xe4\x69\x58\x1f\x63\xf8\x63\x79\xd6\x28\x68\xac\x3e\x3a\xa2\x4d\xf9\x82\x6a\x83\x33\x14\xbd\x41\xe0\xd9\xa0\xae\x56\x80\xe6\xa4\xd2",
        b"\x5a\x77\x63\x96\x63\x66\x4e\x3f\x0b\x19\xfd\x58\x3b\xab\x6e\x68\x06\x88\xcd\x89\xd5\xe0\x12\xdd\xcb\x1e\x06\xbc",
        b"\xd4\x1c\x78\x4b\x58\x3c\xbc\x52\x5b\xce\x87\xc6\xca\xa4\x40\x62\xea\xc8\x47\xbc\xa8\xb0\x05\xc1\x2a\xb5\xe5\x54",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x50\x3f\x20\x42\x35\x8f\x7e\x41\x42\x96\xab\x2d\x41\xf3\xa1\xf3\xf1\x11\x82\xec\xa6\xc8\x2b\x2a\xe6\xee\x83\x3d\xd7\x37\xbc\xb3\x46\x91\x79\x3e\x30\x11\x00\x36\xae\x54\xd4\x03\xa5\xea\x45\xcb\xf3\xe5\x51\x5b\xbf\x80\xb1\xaf\x13\x98\x53\xf5\x06\x79\x2d\xf7\xff\x52\x35\x99\x5e\x08\x0f\x82\xb5\x62\x32\x6a\xda\xf3\x21\x15\x9a\xde\xef\x20\x38\x80\x24\x50\x9f\x22\x5e\x8c\x52\x35\x36\x8a\x7b\x04\x5d\x69\xe4\x72\xe6\xb2\xad\x7d\x47\x0a\x11\xf6\xaa\x8d\x4c\xa6\xc6\xcd\xb0\xf3\xed\x4e\x06\xfb\x9a\x95\xe2\xcf\x20\x0c",
        p,
        q,
        g,
        b"\x7e\x51\x4a\x04\xbb\x57\x5a\xb9\x3e\x71\xb3\x55\x5c\xdb\xac\x63\x4d\x47\x5c\x58\xc1\xd9\xb4\x80\x2e\x15\x3a\x85\x8d\x02\x78\x04\xea\x74\x8c\x29\x07\xeb\x99\x87\xf7\x8e\x41\xc6\x75\x7e\xd5\xcb\xf1\x02\x54\x4a\x71\x46\x99\xa0\x2a\x9e\xf1\x47\x68\xf9\x6d\xbb\xdf\x48\xf3\xb2\xb3\x79\x2e\xfb\x97\x3a\x7f\x91\xf2\x60\xe0\xde\xa2\x80\x34\xc9\x15\xd9\xd5\xa8\x7a\x8f\x98\x6a\x15\xf5\xd6\xf9\x8d\x7d\x6d\x35\xbe\xe7\xe0\x59\xae\xdb\x59\xfe\x59\x5b\xa7\xda\x17\xce\x0d\xb8\x95\xf3\x41\x1b\x83\x2a\x1e\x22\x1a\x83\x1f\x70\x65\x87\x84\x1d\x93\x23\xe0\xc7\xf4\x43\x57\x03\x12\x70\x84\xb2\x0e\xda\x9c\x6a\x24\x97\x28\x01\x90\xa2\xb5\x27\x3b\x23\x1b\x44\x48\x2c\x92\x53\x50\x1c\x66\xef\x11\x22\x25\x3b\xe4\xea\x34\x77\xff\x61\x86\xaf\x87\x18\x69\xaf\x1b\xa1\x0f\x6a\x15\xd1\xc4\x32\x94\x03\x17\xd1\x19\xdd\x76\x1c\xa0\x34\x2a\xb6\x06\xd5\x32\xc4\x71\x78\x3a\x4d\xcd\x6f\xac\x9b\x8a\x67\xa6\xba\xe1\x87\xc7\xdc\x64\xc7\x61\x1d\xed\x72\x73\xdc\x34\x8c\xd7\x61\x3a\x52\xd0\x26\x70\xe8\x77\xe1\x8d\x0b\x60\xc8\xbb\xdd\x1a\xdb\x04\xef\xf2\x13",
        b"\x84\x86\xab\x31\xc8\x27\x8f\xad\x06\x91\xfd\xd6\xca\xc2\xf5\xfd\x79\x0b\x2f\x3f\xed\x52\xb0\x99\x86\x76\x60\x42",
        b"\xb6\x96\x7b\x9e\xac\xde\x5f\x48\x83\x71\x0e\xba\x38\x7b\x3c\x6f\xed\xfc\x91\x94\x4e\xa5\x1f\x6f\xfa\xb7\x25\x31",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x65\x0c\x3c\x40\x9a\x88\x5f\xa6\xd1\xac\x1f\xf4\x1e\x15\xf9\x00\x1f\x6c\xd6\xa1\x52\xc3\x76\xfd\x22\xe2\x85\x1c\x9c\xba\xa5\x35\x0d\x8a\x92\xb7\x40\x10\x30\x80\x93\x95\xcf\x0b\x1a\x0c\xb0\x3a\x24\xdc\x3b\x43\x47\x05\x0e\x85\x53\xda\x0e\x61\xd8\x1d\xee\x44\x02\xb1\xce\xc9\x7d\x89\x8d\xc6\x88\x66\x01\x02\x4f\x6b\xfb\xc4\x8d\x2f\x2c\x40\xbf\x96\xde\x9b\xc0\xe0\x78\xe4\x40\xc7\x71\xf7\x4e\x71\x15\xad\x22\xba\x99\x4a\xe2\xf8\x57\xc7\xfb\x86\x5e\xa7\x50\xb1\x8c\x79\xe7\xb0\x48\x56\x3b\xec\xef\x88\x98\xce\xd3\xdd",
        p,
        q,
        g,
        b"\x55\x18\x6d\xe3\x9e\x6a\x01\x31\xad\xb7\xd8\x41\x70\xa8\xd3\x6a\xc4\xbf\x31\x36\x16\xe7\x50\x22\x0d\xe3\x56\xfb\xb1\x89\x9d\xba\xaa\x65\x0d\x8d\xe9\xa7\xaf\xab\xf3\xc4\xdd\x6a\x3c\x8b\xac\x24\x19\x22\xac\xbc\xc4\xbb\x7f\xa4\xce\x5f\xcd\xb5\xf2\x31\xcb\x17\xa8\xc0\x97\x8c\x8e\x69\xfb\x82\xd4\x46\x83\xeb\xb9\xfb\x17\x89\x8e\x0b\xa4\x93\x91\x96\xed\x99\x80\xeb\xec\xab\xba\xad\x7b\x5b\x34\xcd\x9e\xc0\xea\x6d\xf9\x62\x43\x82\x3b\x1d\x17\x0e\xfc\xcb\x4d\x59\xbc\xba\x24\xce\x5f\xaa\xd3\x2d\x59\x1a\xd6\xec\xe0\x44\x0d\x2b\x62\xa2\x12\x05\x9e\x00\x0f\xb5\x00\x5a\xbf\xec\x12\x7c\x1e\x9f\xa7\xd3\x46\x9c\x72\xb8\x9a\x96\x97\x6e\xb4\x70\x2f\x09\xf9\xc0\xa0\x97\x1b\x30\xdf\xc3\x39\x07\x2b\x5e\x3a\x6c\xe4\x0b\xfe\xa2\xd5\x2f\x2c\x93\x0a\x11\xdd\x65\x5d\xd3\x6a\xc9\xfa\xd8\x6f\xc3\x98\x6b\x48\x71\xe7\xc9\x04\x59\xa2\xea\xa3\xb3\xd2\x2d\xd0\x4c\xb8\x24\x17\x3c\xcc\x08\x7d\x42\x9b\xb2\xa1\x88\xe0\x5d\x8a\xf0\xac\x29\x11\xc9\x07\xfd\x95\x7b\x2b\xb3\x30\xa6\xf3\x98\x7a\x59\x59\x30\xb3\x12\x05\x3c\x4b\xdf\x85\x6d\xe7\x29\x38\x58",
        b"\xa0\xc4\x9d\x3c\x47\x24\x0d\x30\xd2\x6f\x0c\x20\xe4\x50\x8b\x36\x0a\x84\x12\x85\xde\x3f\xc1\x98\x6f\x1e\xf9\xf6",
        b"\x97\xca\xa2\xb7\x6d\x15\xb1\xf9\xf1\x77\xe2\x09\x00\x4a\x2b\x1f\xdd\x23\xa3\x94\x50\x34\x58\x4c\x2c\x15\xbf\xa2",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x64\x12\x91\x53\xeb\x9c\xcc\x74\xcc\x3a\xae\x1d\x59\x99\xc6\xe9\x0d\x98\x6b\xe6\xfa\x40\xc6\xc4\xbc\x00\xb1\xc3\xf8\x07\x2d\x10\xa9\xd8\xe6\xc3\x14\xd8\x2a\x76\x41\xf8\xa3\xae\x29\xd3\xe7\xdd\x19\x42\xdb\xf0\xdc\x52\xb4\xb4\xb3\x5b\xb6\x7a\x99\x49\x42\xaf\xf0\x29\xca\x6f\xa1\x87\x09\x91\x5f\xf7\x20\xab\x8f\x65\xf2\x31\x15\x5c\xb1\xd0\xdb\xcb\xa0\x4f\xc5\x19\x3a\xfc\x71\xa5\xed\xdb\x4a\x03\x86\x7e\x5c\x4b\xb9\x2d\x37\xb7\xef\x77\x1d\xa9\x54\xec\x67\x54\xd5\xfb\xe2\xe3\x72\xb9\x2d\xf6\xa3\xea\x8c\x3a\x4a\xff",
        p,
        q,
        g,
        b"\x23\xf5\x38\xd4\xec\x34\x5f\xaa\x90\x6e\xff\x12\xf6\xc5\x94\x2a\xc1\x66\x91\x4b\xaf\x8e\x73\x7d\xaf\xc7\x1e\x47\x28\x55\x12\xeb\xc5\x7e\xbf\x3e\xc6\x66\x34\x2a\xbc\x05\x9b\x0e\xbd\xdb\x02\x1c\xea\xff\x6e\xf7\x58\x28\xc7\xbe\x37\x66\x25\x7f\x72\x47\xa6\x7e\x14\x08\x23\x9f\xa4\xdd\x1c\xaa\xc2\xb7\x22\x9e\x8c\x1b\xcf\xd5\x7a\xee\xa4\xc0\x4e\x15\x86\x76\x4e\x28\x66\x9c\x36\x12\xd8\xa0\x06\x58\x2c\xf8\xf8\x29\x10\x48\x26\x91\xc1\x0e\x41\x13\x21\x6f\xc2\x4f\xeb\x29\x9f\x84\xba\x58\x70\x0a\x3b\xb6\xfd\xef\xa1\x7a\x7f\xac\x9a\xa9\xbb\x41\x0f\xe4\x11\xfb\x29\x4d\x62\x94\x39\x6f\x7f\x62\x7d\xca\x04\x52\xef\x59\x5d\xc2\x41\x70\xc1\x47\xd3\x86\x3f\xc1\x6e\x23\x64\x50\x19\xac\xa6\x3f\xcc\x11\x52\xb0\xf7\x66\xf5\xf6\x51\xc9\xbb\x69\x9e\x2f\x50\x47\xfa\x1e\x96\x03\x97\x2d\x2c\x75\x51\xb1\x8f\x3b\x16\xc1\x06\xdd\xd6\xcc\x2e\x24\xd2\xd0\x5e\x79\x68\x7e\xfe\x65\x51\x02\xe6\xbc\x15\xbc\x3a\x57\xf6\x0c\x1a\x6a\xd2\x0b\xf1\xcb\xe6\x20\x52\xad\x09\x47\x43\x7b\x92\xb2\xc9\x32\xaf\x5d\x72\x77\x5d\x43\x18\x3b\xbc\x6f\x35\x9a\x4d\xf6",
        b"\x3d\x72\x89\x62\xae\xc3\x58\x22\xff\xf9\x9e\x1b\x52\x17\xd8\xa6\x26\x4a\x7c\x60\x8d\x80\x66\xf4\xfc\xc9\x00\x8a",
        b"\xca\x5c\x8e\x17\x8a\x14\xba\x00\x6e\x93\xcf\x4a\xd1\x19\xf0\x45\xbb\xf8\x2b\x82\x87\x67\xd3\xe5\x83\xd0\xbd\x15",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x9f\xd2\x79\x1c\x41\xa2\xff\xa6\xdf\x26\x10\x98\x04\xea\xf0\x70\x12\x2e\x20\xbb\xb6\x2e\xcd\x98\x11\x55\x11\x36\xaa\x95\x6d\xc1\xc3\x21\x32\x78\x93\xa0\xdd\xe6\xdd\x1d\x5b\x3a\x0d\x2a\x5a\xa9\x7e\xd7\x54\xe5\xbc\x06\x67\x53\x33\x8d\xdd\xfc\x68\xeb\xa2\x17\xd2\x48\x35\x05\xb0\xd7\xc0\xa4\x37\x73\x2f\x80\x46\xcf\x3b\xf5\x93\x0a\x11\xef\xd3\xf6\x59\x9c\x0f\x8d\x46\x5f\xca\x76\x76\xce\x1f\x39\x10\x2c\xc0\xcd\xf1\x32\x81\xb2\xc7\xb9\xcf\x7a\x7a\xfc\xde\x68\x10\x05\xe5\xa2\xe4\xe3\x8c\xf8\x2e\x42\x13\x57\xa4\x1f",
        p,
        q,
        g,
        b"\x14\x7a\xa8\xd9\xe4\xcc\xac\x90\x6d\x6a\x5a\x0b\x65\xbf\xeb\x59\xd4\xd6\x60\x37\xad\x40\xd2\x88\xd7\x53\x4f\xc9\xae\x33\xc5\xaa\x70\x1c\xa1\x8e\x60\xf0\xb6\x89\x08\x28\x05\x62\x11\x0a\xf7\xd1\xd1\xbf\xb5\x38\xc5\x9d\x91\x00\x98\x03\x84\xae\x93\xb7\x7b\xe0\x33\x2a\x03\xcc\x56\x7d\x4d\x63\x4f\x76\x48\xa1\xb9\xfd\x25\xda\xf2\x50\xb2\x86\x96\x83\xe9\x42\x6d\x75\x56\x1a\x5e\x17\x87\xc2\xba\xb7\x11\x32\x75\x7d\xff\xc4\xb7\x66\x51\x43\xe7\xd8\x7d\x50\xf1\x2d\x01\x07\x5b\xef\x5f\x4b\x0f\x14\xcb\x3f\x10\x9d\x15\x99\xe5\xbf\x94\xde\x01\x11\xa0\x1a\xf5\x7e\x8c\x13\xf5\x83\xbe\x4d\xc9\x00\x89\x61\x9c\x72\xd2\x2a\x49\x5c\x45\x25\x6e\xc7\x87\xa5\x83\x2d\x2e\x4c\x4a\x42\xf0\x00\x18\x37\xa9\x75\xac\x8f\xbb\x8c\x56\x5f\x77\xb2\x53\x30\x3b\x1a\x87\x33\x06\xfa\x5c\xf6\xa5\xda\xb6\x2d\x7b\x1b\xa3\xd7\x0d\xc1\x1b\x4e\x4f\x87\x5e\x3e\xda\xe5\x0e\xe8\xe5\x17\x8d\xd0\x9a\x33\x4c\xf9\x26\x0c\x3e\x0a\x10\x91\x1d\x38\x1d\x7f\x56\x01\xc0\xb3\xf2\x69\x46\x68\x20\x18\x62\x99\x22\x94\x6d\xd7\x3f\x81\x24\x08\x16\xae\x96\x06\x91\x1c\xbf\xd6",
        b"\xa7\xcc\x74\x86\xf4\x7f\xe6\x2f\xe3\x25\x4e\xd6\x55\xe1\xc9\x94\x90\x2d\x79\x7f\x0d\x7c\xa9\x3f\xb9\x7d\xf9\xc1",
        b"\x91\x4b\xf7\xd1\x5c\xe2\xc9\xec\xc5\xae\x15\x0d\x63\x08\xfc\x55\x7d\x94\xe1\xef\x18\xc0\x86\x0a\xa6\x8a\xd4\x8e",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x6b\x78\xb4\xde\x5f\x75\x26\xdb\xed\x08\xee\x0f\xf4\xe4\x33\x35\xb6\x0c\xd3\xbc\x37\x1b\x70\xcd\x4f\xd9\xce\x45\xbf\x06\x50\x83\x91\x08\x5d\x14\x2c\xc3\x89\x1b\x17\x91\x67\xc7\x6a\x13\x50\xca\x8e\xf8\xce\x75\x4a\xb1\xd6\x24\x57\x2e\x43\x71\x95\x66\x0f\x00\x4c\xb7\xbe\xd2\xff\x3b\x0f\x7c\x7e\x53\xf8\x53\x30\x5a\x38\x21\xdf\xba\xec\x33\xe2\x20\xdf\x3c\x3e\xf7\xa7\x9f\x34\xe8\x2c\xc8\xff\xf8\x41\x5f\x10\x8c\x00\x0f\x21\xc3\xbb\x21\xa4\xc3\x32\x67\xa2\x13\xcb\x4a\x55\x8e\x3b\x37\x0d\x17\xc6\x39\x24\x7b\xff\xeb",
        p,
        q,
        g,
        b"\x91\x47\x67\x0f\x64\xae\xdf\xa2\x46\x93\x8b\xa7\x7f\xb9\xc1\xac\x27\x1c\xa1\x09\x1d\x86\x3f\x32\xf0\x0d\x5c\xcd\xeb\xe7\x02\x2d\x26\x8b\xa9\x05\x1d\x80\xfe\x55\xdf\xc5\xf6\x4b\x07\x16\xc4\xbb\x8d\xa4\xb1\x1e\x9e\x28\x34\x48\xed\x8b\xe4\x27\x8e\x93\xb5\x2d\x67\x56\x49\xab\xb4\x59\x56\x52\x2f\x92\x63\x4c\x92\xa0\x9a\xc5\xa5\xd6\x03\xaa\xe2\xa6\xd0\x4a\x43\x52\x39\x53\x8d\xe3\x03\xfc\x05\xb9\xed\x5f\xcb\x84\x3f\x05\x36\xa8\xab\x94\x2d\x9c\x3b\xdc\x90\xfe\xed\x97\x44\x9c\xe3\x09\xbe\x8a\xb1\x19\x67\x6a\x96\xc2\xa6\x0a\x06\x69\x2e\x8c\xd5\x9e\x55\xe6\xff\x8d\x91\xfa\x46\x29\x66\x55\x55\x26\xc9\x87\xfc\x44\xba\x42\x0b\xbf\xf7\x68\xf7\xa7\xfd\x36\x36\x38\xd5\xce\x4d\x9e\xa1\xed\xd7\xfd\x39\x9d\x6c\x65\x62\x7b\xbc\x33\x7f\x13\x1c\x73\x45\xb3\xd7\x9b\x4d\xb7\x41\x25\x62\x54\x7c\xa2\xa7\xc8\xea\x55\xeb\xdd\xdd\x05\xa4\xb4\x20\x0c\x72\xab\x2b\x83\x31\x11\x52\xb7\x1c\x99\x30\x6c\x1d\x3b\x3d\x44\x66\x57\xbe\x65\xe5\x8d\x7c\xf8\xa0\x62\xb2\x25\xce\x93\x78\x02\x59\x05\x46\x85\x3f\x19\x2a\x6a\x8c\x8b\x3f\xf7\xa6\x2f\xcf\x80",
        b"\x2f\x85\xee\x5c\x32\xd5\x46\xc6\x8f\x0a\xa2\x69\x8b\xea\xe5\x3e\x28\x48\xc3\x75\x51\x7a\x57\x0e\x0f\x1b\x55\x46",
        b"\x54\x76\x67\xe8\xb1\x3f\x21\x63\x5a\x0b\x10\x6d\x32\x4d\x06\xc8\x5b\x74\xa6\x4c\xe9\x22\x5c\xc5\xe0\x84\x35\x81",
    )?;

    // [mod = L=2048, N=224, SHA-256]
    let p = b"\xa4\xc7\xea\xab\x42\xc4\xc7\x3b\x75\x77\x70\x91\x64\x89\xf1\x7c\xd5\x07\x25\xcd\x0a\x4b\xc4\xe1\xcf\x67\xf7\x63\xb8\xc1\xde\x2d\x6d\xab\x98\x56\xba\xaf\xb0\x08\xf3\x65\xb1\x8a\x42\xe1\x4d\xc5\x1f\x35\x0b\x88\xec\xa0\x20\x9c\x5a\xa4\xfd\x71\xa7\xa9\x6c\x76\x5f\x59\x01\xc2\x1e\x72\x05\x70\xd7\x83\x7b\xec\x7c\x76\xd2\xe4\x93\x44\x73\x1c\xa3\x94\x05\xd0\xa8\x79\xb9\xe0\xdc\xd1\xa8\x12\x5f\xd1\x30\xec\x1e\x78\x3e\x65\x4b\x94\xe3\x00\x2e\x6b\x62\x9e\x90\x4a\xb3\x87\x78\x67\x72\x0c\xbd\x54\xb4\x27\x0a\x9e\x15\xcd\x02\x8c\x7c\xc7\x96\xf0\x6c\x27\x2a\x66\x09\x51\x92\x8f\xdb\xeb\x2d\xca\x06\x1b\x41\xe9\x32\x25\x73\x05\x74\x2f\xf1\x6e\x2f\x42\x91\x91\xd5\xe5\xf1\xa6\xdd\xf6\xe7\x8c\x5d\x77\x22\xcf\xf8\x0a\x9c\x0b\xd5\xc8\xd7\xae\xba\x8c\x04\x43\x89\x92\xb0\x75\xe3\x07\xc1\x53\x4c\x49\xad\x38\x0f\x47\x7f\x5f\x79\x87\xdc\x17\x2c\x16\x1d\xca\x38\xdc\xaf\x3f\xb3\x84\x6c\x72\xc9\x11\x9a\x52\x99\xad\xc7\x48\x95\x1b\x3d\xce\x0d\x00\xd4\xa9\x01\x38\x00\xb2\x00\x82\x03\xb7\x24\x65\xbc\x6a\x84\xae\x05\x9a\x30\xc4\x52\x2d\xea\x57";
    let q = b"\xce\x89\xfe\x33\x2b\x8e\x4e\xb3\xd1\xe8\xdd\xce\xa5\xd1\x63\xa5\xbc\x13\xb6\x3f\x16\x99\x37\x55\x42\x7a\xef\x43";
    let g = b"\x8c\x46\x5e\xdf\x5a\x18\x07\x30\x29\x1e\x08\x0d\xfc\x53\x85\x39\x7a\x50\x06\x45\x0d\xba\x2e\xfe\x01\x29\x26\x4f\xbd\x89\x7b\xb5\x57\x9c\xa0\xea\xb1\x9a\xa2\x78\x22\x04\x24\x72\x4b\x4f\x2a\x6f\x6e\xe6\x32\x84\x32\xab\xf6\x61\x38\x06\x46\x09\x72\x33\x50\x53\x39\xc5\x51\x9d\x35\x7d\x71\x12\xb6\xee\xc9\x38\xb8\x5d\x5a\xa7\x5c\xc2\xe3\x80\x92\xf0\xa5\x30\xac\xb5\x4e\x50\xfe\x82\xc4\xd5\x62\xfb\x0f\x30\x36\xb8\x0b\x30\x33\x40\x23\xeb\xbe\x66\x37\xa0\x01\x0b\x00\xc7\xdb\x86\x37\x11\x68\x56\x36\x71\xe1\xe0\xf0\x28\xae\xdb\xd4\x5d\x2d\x57\x26\x21\xa6\x09\x98\x2a\x07\x3e\x51\xaa\xe2\x77\x07\xaf\xbe\xef\x29\xe2\xec\xee\x84\xd7\xa6\xd5\xda\x38\x2b\xe3\xa3\x5f\x42\xb6\xc6\x68\x49\x20\x2a\xb1\x9d\x02\x5b\x86\x9d\x08\x77\x64\x76\xd1\xab\x98\x14\x75\xad\x2a\xd2\xf3\xe6\xfd\x07\xe3\x06\x96\xd9\x0a\x62\x68\x16\xdf\x60\xd6\xca\x7a\xfd\x7b\x48\x2f\x94\x2f\x83\xb4\x5c\xc8\x29\x33\x73\x1f\x87\xfa\xee\x32\x09\x00\xf2\xaa\x3e\x70\xb1\x86\x7e\x14\x30\xe4\x0b\xe6\x7c\x07\xf9\x29\x02\x99\xef\x06\x7b\x8b\x24\xa7\x51\x5b\x3f\x99\x2c\x07";
    test(
        HashAlgorithm::SHA256,
        b"\xce\xc8\xd2\x84\x3d\xee\x7c\xb5\xf9\x11\x9b\x75\x56\x25\x85\xe0\x5c\x5c\xe2\xf4\xe6\x45\x7e\x9b\xcc\x3c\x1c\x78\x1c\xcd\x2c\x04\x42\xb6\x28\x2a\xea\x61\x0f\x71\x61\xdc\xed\xe1\x76\xe7\x74\x86\x1f\x7d\x26\x91\xbe\x6c\x89\x4a\xc3\xeb\xf8\x0c\x0f\xab\x21\xe5\x2a\x3e\x63\xae\x0b\x35\x02\x57\x62\xcc\xd6\xc9\xe1\xfe\xcc\x7f\x9f\xe0\x0a\xa5\x5c\x0c\x3a\xe3\x3a\xe8\x8f\x66\x18\x7f\x95\x98\xeb\xa9\xf8\x63\x17\x1f\x3f\x56\x48\x46\x25\xbf\x39\xd8\x83\x42\x73\x49\xb8\x67\x1d\x9b\xb7\xd3\x96\x18\x06\x94\xe5\xb5\x46\xae",
        p,
        q,
        g,
        b"\x74\x8a\x40\x23\x72\x11\xa2\xd9\x85\x25\x96\xe7\xa8\x91\xf4\x3d\x4e\xb0\xee\x48\x82\x6c\x9c\xfb\x33\x6b\xbb\x68\xdb\xe5\xa5\xe1\x6b\x2e\x12\x71\xd4\xd1\x3d\xe0\x36\x44\xbb\x85\xef\x6b\xe5\x23\xa4\xd4\xd8\x84\x15\xbc\xd5\x96\xba\x8e\x0a\x3c\x4f\x64\x39\xe9\x81\xed\x01\x3d\x7d\x9c\x70\x33\x6f\xeb\xf7\xd4\x20\xcf\xed\x02\xc2\x67\x45\x7b\xb3\xf3\xe7\xc8\x21\x45\xd2\xaf\x54\x83\x0b\x94\x2e\xc7\x4a\x5d\x50\x3e\x42\x26\xcd\x25\xdd\x75\xde\xcd\x3f\x50\xf0\xa8\x58\x15\x5d\x7b\xe7\x99\x41\x08\x36\xdd\xc5\x59\xce\x99\xe1\xae\x51\x38\x08\xfd\xae\xac\x34\x84\x3d\xd7\x25\x8f\x16\xf6\x7f\x19\x20\x5f\x6f\x13\x92\x51\xa4\x18\x6d\xa8\x49\x6d\x5e\x90\xd3\xfe\xcf\x8e\xd1\x0b\xe6\xc2\x5f\xf5\xeb\x33\xd9\x60\xc9\xa8\xf4\xc5\x81\xc8\xc7\x24\xca\x43\xb7\x61\xe9\xfd\xb5\xaf\x66\xbf\xfb\x9d\x2e\xbb\x11\xa6\xb5\x04\xa1\xfb\xe4\xf8\x34\xec\xb6\xac\x25\x4c\xab\x51\x3e\x94\x3b\x9a\x95\x3a\x70\x84\xb3\x30\x5c\x66\x1b\xfa\xd4\x34\xf6\xa8\x35\x50\x3c\x9a\xde\x7f\x4a\x57\xf5\xc9\x65\xec\x30\x1e\xcd\xe9\x38\xee\x31\xb4\xde\xb0\x38\xaf\x97\xb3",
        b"\x9c\x5f\xa4\x68\x79\xdd\xaf\x5c\x14\xf0\x7d\xfb\x53\x20\x71\x5f\x67\xa6\xfe\xc1\x79\xe3\xad\x53\x34\x2f\xb6\xd1",
        b"\xc3\xe1\x7e\x7b\x3c\x4d\x0a\xc8\xd4\x9f\x4d\xd0\xf0\x4c\x16\xa0\x94\xf4\x2d\xa0\xaf\xcc\x6c\x90\xf5\xf1\xbb\xc8",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xf3\xbb\x27\xbf\x9d\x41\x2f\x13\x22\x9a\x56\xd2\xd1\x53\x3e\xae\x63\xf4\x00\x04\xc1\x43\xc6\xb9\x2f\x6e\x60\x6d\x26\x3d\xd2\xda\x75\x81\xe5\xeb\x20\xb6\xcd\x02\x1e\x3a\xb6\x3b\x49\x8a\xba\xfc\xe0\x1b\x4a\xd7\xac\x86\x28\xf7\xa1\x84\x9c\x4e\x45\x4f\x11\x68\xae\x97\xad\xfa\xb1\xfa\xdb\xd3\x13\xfc\xa7\x38\x17\x26\xf5\x04\x57\x52\xda\xba\xad\x6e\xa3\x25\x0d\x30\x3a\x54\x96\xbb\xa2\xfa\x48\x95\xae\x49\xf0\x6a\x9a\xa6\x45\x1a\xe7\x0c\xf3\x3b\x5f\x06\xfa\x17\xca\xc0\x14\x4f\x28\xbd\x19\xfb\x2a\xc0\x41\xa5\x78\xed",
        p,
        q,
        g,
        b"\x00\xc7\xaa\xbe\x30\xfa\x4c\x3d\x1b\xa8\x5e\x7a\xe0\xaa\xe7\x93\x60\xe5\xea\xb3\x04\x1b\xca\xaa\x5d\x32\x1c\x92\xf3\x47\x1e\x41\x94\xc1\x04\x84\xcf\xf1\x52\xba\xde\x6b\x7d\x61\x9c\xf2\x86\x77\x34\x75\x29\x8f\x88\x3e\xfd\xf6\x4c\x08\xb6\x92\x58\x3d\xe3\x1b\xe0\xa4\xe2\xb8\xe8\xd5\x08\xec\x14\x5c\x65\xa3\x69\xce\x61\x95\x44\x6c\x52\xd0\x23\x72\xeb\xa5\x62\xf9\xa9\xd7\xcb\x24\xd2\xec\x3b\x0a\x1a\xb8\x33\xe4\xd7\x62\x3b\x04\x55\xa4\x1e\xec\x75\x9d\x07\xa3\xc8\xa2\x0d\x88\xa9\x26\x40\x8c\x20\xf1\x67\x56\x01\xbe\x53\xcf\xfd\x65\x61\x7b\x66\xfd\x4e\xb3\x53\xa1\xf2\xdb\x31\xf6\x63\x43\xb0\x7f\xaf\x60\xde\x0b\x6a\x68\x08\x09\xc6\x16\x6a\xdb\xf5\xe5\x04\xc5\xc6\x1b\xab\xb8\x4b\xe7\x2c\x02\xd3\xeb\xee\xe0\x66\xd9\xea\xb0\xd0\xec\xdf\xe0\x1b\x8c\xcd\x67\x28\xee\x91\x23\xb9\xd2\x11\x54\xb2\xbc\x9a\x13\x43\x63\x56\x64\x02\x29\x1a\xc8\xa4\x84\xee\x32\xeb\x88\x40\x46\xd4\x0f\xde\x7c\xab\xbf\x51\xd1\xd1\x20\x6d\xf1\xc5\xec\xf2\x90\xab\x7e\xa7\x2a\xbb\x5b\xd3\xbe\x8d\x91\xc0\x2b\xb6\x3f\x80\x97\x18\xba\x1d\x38\x0a\xf8\x83\x31",
        b"\x79\xa6\xae\xd7\x3c\xe1\x77\xed\x35\x81\xf5\xd1\x81\xa7\x7f\x00\x0d\x63\x58\x51\x4e\xa9\x5c\xb0\x38\x8a\x6a\xdd",
        b"\x2b\x85\x97\xa6\x94\x56\x4e\x26\x7b\x6f\x25\x0a\x4c\x76\x36\x1f\x8c\xdf\x49\x86\x3a\x79\x02\xaf\xa4\x8f\xd6\xd8",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xe7\x14\xc0\x16\x31\x70\x4e\x94\x47\x39\x0f\x5c\x31\x5c\x96\x15\xa7\xa5\x28\x63\xb1\x43\x70\x65\x83\xf6\x61\x59\x5c\x50\x5a\xec\x47\x7e\xeb\x5a\xd6\xd6\x40\xca\x81\x2c\xe1\x17\x50\xb6\x7b\xc8\xbe\xde\x2e\x4f\x96\x18\xdb\xe7\x37\x6c\xab\x62\x31\xb2\x12\x48\xec\x91\x4a\xe1\x82\xdf\x87\x53\x36\x2d\x21\x18\xa6\x5e\x66\xf6\x40\x18\x81\x08\x04\xad\x97\xfc\xc1\xa8\x7b\x8c\x9f\x34\x9d\x10\x01\xe4\xb0\x9b\x04\x69\x91\xe6\xab\xe6\x33\x8f\xbe\xf7\xbe\x48\xf1\xc8\x0c\x35\x0d\x29\x62\xeb\x6b\x8f\xce\x25\xb6\x9f\x8d\xc9",
        p,
        q,
        g,
        b"\x04\xd3\x01\xf0\x01\x82\x1b\x03\xc9\x13\x94\xc5\x20\x83\x9a\xb6\xaa\xa9\x53\x25\xc1\x08\xa0\x2d\xad\x9d\xb4\x8b\x3c\x80\x33\xd6\x44\x3b\xcb\xf0\x50\x45\x23\x0c\xa8\x8a\xaf\x98\xa8\xc4\xcb\x6b\x09\x5b\x35\x2d\x91\xb4\xc4\x16\xf6\x32\xfa\xb4\x9d\x45\xac\x90\x69\x9a\x5a\x41\x96\x30\xa8\x1d\x47\x3b\xc8\x91\x22\xeb\x5b\xac\xb9\x1c\x40\xca\xa4\xe4\xbc\xc4\x76\xf3\xca\x77\xbf\x6a\x21\x03\x7a\x06\xbe\x24\xf1\x1c\x64\x5b\x0c\x21\xb8\x57\xfd\xc5\xc0\x4f\xbb\xf0\xa2\x6e\xfc\x56\x9c\xdb\xb0\xea\x98\x9b\xa0\xe0\x37\xc2\x3f\x22\xb0\xc5\xf1\x64\x3d\x77\xd9\x8f\x2d\xe2\x48\xcc\xc3\x66\x72\xd3\x97\xd3\x0c\x1c\x5e\x13\x19\xfc\x7e\x58\x42\xae\x1a\x9f\xcd\x9e\x96\xfe\x89\x0a\x74\xdd\xee\x91\xa3\x9c\xe7\x32\xe4\xc0\xea\xf7\x09\x4b\x53\xb7\xb4\x09\x30\x38\x60\xb0\xb4\x94\x4c\xc8\x1b\x4a\x42\xd4\x05\x38\xcf\xe5\x12\xb9\x68\x0e\x0a\x28\x1b\x1f\xbb\xf6\x39\x13\x9e\x80\x66\xad\x63\x8c\xf8\x46\xc9\xea\x51\xfb\x4c\x4e\xf8\x49\x21\xf1\x6a\x6c\xa3\xf2\xbd\x15\x81\x57\xc5\x51\x73\x9c\x9d\x02\x3e\x27\x0b\x3d\xe7\xc2\xf1\xd7\x68\x3c\xf8\x09",
        b"\x79\x0b\x4d\xca\xe3\x1f\xe4\x5c\xd3\xa7\xbb\x6f\xa1\x0d\xcf\x9e\xde\x1f\x06\x71\x23\xf9\x3b\xaa\xd7\xed\xb4\x89",
        b"\x71\xe3\xe4\x6d\xfe\x04\x04\x96\xce\x4c\x5e\x49\x0f\x69\x44\xa2\x3c\xd5\xe6\x6c\xe9\xb4\xd9\xac\xbe\x41\x30\xce",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x3f\x6e\x48\x2f\xd4\x84\xed\x3d\x07\xf1\xd0\x76\x1f\x2d\x60\xfc\x96\xd4\x6e\xb0\xec\xd1\x0a\x59\xdd\x4f\x39\x2e\x3d\x3b\x2c\xbe\x18\x40\x10\xe1\x32\x68\x55\x78\xb1\xf6\x30\x32\x39\x79\x8a\x53\x03\xa8\x11\x69\xd4\xf5\x2f\xba\x0d\x20\xa4\x28\x34\xde\x29\x3e\x3a\x7b\x32\x84\x8b\x65\xdd\x30\x8e\xef\x53\x50\xd6\x33\x29\x74\x65\x42\x5b\x7b\x15\x95\xff\xc8\xea\x7b\x12\x58\x96\xf8\x9e\x28\x44\x56\x16\x35\xf5\x2e\xc6\x2f\xab\x2e\xcf\xea\x28\x8d\x23\xf0\xa7\x71\xcd\x63\x11\x80\x61\x03\x13\x51\x72\xcf\x9f\xef\x14\x55",
        p,
        q,
        g,
        b"\x9f\xc1\xb2\x92\xeb\xe1\x55\x31\x57\x9f\x35\xdd\xa8\xd7\x06\xbe\xe0\xda\x85\x7c\xd6\x96\xa1\x0a\xf7\x70\xdc\x35\x62\x32\x73\x6c\xf8\x93\xf7\x41\x1a\x9d\x27\x18\xb3\x9f\x38\x81\x18\xd1\x77\xcd\x8d\x0f\xd7\xca\x3b\x3c\x22\x0f\x3a\xa7\x43\xd8\xb1\x67\x21\x9d\x3c\x2c\x78\x3e\x1f\x09\xd8\xb8\xdf\x8e\xc7\xe1\x75\x78\xc5\x32\x94\x88\xc8\x7a\x89\x67\x8d\x28\x18\xa9\x93\x66\xb7\x85\xd5\x3f\x6c\xa6\x99\x5e\x19\x3b\xa5\xca\x26\xc0\x0b\x84\x9f\x90\x27\xca\x5d\xf5\xbb\x7e\xc8\x7f\xe7\x87\x35\xae\x88\x0f\x1a\x97\xda\xbc\x3c\xa7\x98\x5d\x8c\xbc\x81\xbe\x82\x4c\x1f\xfb\x95\x3f\x10\x96\xbf\x92\x62\x26\xfb\x5e\x9d\x4a\xd4\x3e\x93\x63\xda\x5e\x6b\x73\x8c\x9a\x2f\x95\x1a\xb3\x29\x4e\x2b\x28\x22\xcf\x52\x82\xbb\x41\x34\x15\x8a\xa9\x0a\xb9\xc8\xf0\xf6\x4d\x05\xa0\xd6\x25\xa7\x5b\xc2\xd6\xa4\xae\x3d\xd1\x1f\xc0\x5e\xde\x7b\x66\x47\xae\x7c\x07\x50\xdd\xb2\x73\xfe\x5f\x88\x28\x31\x8a\x91\xdb\x31\x72\xad\x59\x16\x6a\xac\xf2\xda\x4f\x37\x04\xd1\x69\xeb\xc8\x60\xd9\xe1\xc6\x46\x4a\xbc\x2b\x65\x30\x13\x77\x4d\x29\x37\x5b\x77\xba\xc1\xec",
        b"\x3b\x5d\x80\x34\xc4\xb8\xad\x97\x01\xbf\x29\xb1\x00\x06\xdb\x69\xd0\x17\xfd\xe8\x63\x80\x79\xdd\x7b\xbf\xac\xe7",
        b"\xcd\xe0\x1d\xf5\x4a\x66\xce\xf3\xc0\x53\x86\x48\x52\x5b\x25\x0c\xb1\xf0\x87\x07\xf5\xff\x11\x4b\xde\xbf\xf8\xf7",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x31\xa2\x78\xf8\x81\xfd\xd3\x75\x56\x5c\x0f\x28\xff\x75\x75\xf2\x16\x11\x04\x86\xd6\xfe\x08\xda\xe8\xfd\x07\x29\x50\x97\x8b\xdf\xf6\x01\xde\xd1\xef\x22\x6b\x5d\x90\x4c\x47\xf7\x14\x2a\x8f\x46\x65\xe0\x3e\xfe\x58\x70\xda\x2d\xd1\xab\x80\xe4\x49\xf5\xc7\x57\xb3\xb6\x99\x6a\x9d\xc0\xb5\xb2\x75\x0b\x97\xbb\xad\x2f\x55\x3f\xba\xff\x2a\xed\xec\xfc\x9f\xf6\xa9\x70\xd1\x56\xe4\xfe\x38\x52\x97\x9d\xc9\x13\xbd\xb2\x96\xa3\x21\xf7\x66\x36\x72\x39\xde\x45\xe4\x7c\xbe\xf4\xd7\x9b\xfa\x3d\x57\x68\x87\xc6\x5f\x7f\x8a\x60",
        p,
        q,
        g,
        b"\x7e\xc0\xa5\x41\x88\x28\x15\x9e\x3e\xc8\x29\xf7\x93\xb9\x6e\xa3\x46\x03\x28\xde\xa2\x1b\xa1\x57\xd7\x1a\xc3\x06\xf9\xbc\xde\x61\x7d\xb6\x73\x68\xd5\x92\xbf\x46\xd4\x69\x18\xb1\x30\xfc\x7e\x3d\x11\x89\xee\xb7\x99\x6d\x5f\x66\x0a\xce\x30\xbe\x50\x9a\x26\xb2\x18\xd8\x65\xd9\xe5\x6b\xa7\xf6\x19\x42\xe5\x67\xd8\xcd\xab\x96\xa7\x8c\xa3\x03\xc6\xb0\x1d\x98\x9b\x1e\x78\xae\x95\x64\x23\xe3\x5b\x5a\x46\x6c\x16\x07\x4e\x0b\xc9\xe8\x37\x23\x40\xd2\xc1\x25\x16\xc2\x2d\x5e\x1f\xf6\x5a\xbd\x5d\x44\x82\x15\xb6\xba\xf5\x65\xde\x18\x20\x1c\x1f\xd5\xba\x3d\xe8\x7e\x5d\x5b\x43\x7d\x2f\x48\xde\xee\x72\xa1\x2e\x65\x5f\x8c\x7f\xa3\x13\xd2\x4b\xd0\xc8\xc2\x0e\x59\xc9\x0e\xdf\xbf\x5d\xfc\x05\x7c\x6b\x67\x98\x50\xae\x41\x82\x61\x78\xf2\xf3\x04\xca\x3b\x92\xa9\xba\xc3\x1a\xb3\xcf\x74\xdf\xb8\xee\x5b\x64\x3b\x4a\x34\x1e\xbb\xdb\x5d\xbd\x24\xd0\xb7\x82\xc5\xb4\x50\x59\x6a\xbf\xc3\xdf\x9e\xe0\x5f\x45\xd0\xea\x2e\x8f\xf4\x35\x7c\xd3\x60\x5f\x35\x06\xce\x58\xa5\x39\x4f\x1f\x24\x44\xc2\x63\x59\x29\x9a\xf1\x53\x53\x2b\xc9\x0d\xaa\xf9\x54\xae",
        b"\x2b\x47\xe2\x57\xbf\x72\xad\xf3\x4d\x61\x8d\x3a\x6c\x46\x14\x28\x81\xbd\xd0\x68\x9a\x46\xf1\xcb\x31\x99\xee\x6c",
        b"\xcc\x1f\xf2\xfa\x37\x55\xa0\xe8\x1e\xdf\xc7\x53\xbc\xf1\x4e\x63\x74\x13\xea\xee\x0f\x22\xd7\x88\x6b\x05\x8d\xcc",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xa6\xd7\x60\x47\xbd\x18\xde\xef\xe7\x0d\xc0\xa4\xbd\x08\x2a\x10\xfa\x52\x1d\xff\xda\x78\x2a\x93\x64\xb9\xe2\xb1\x1e\x14\x7e\x1a\x36\xa1\x1c\x43\x00\x67\x21\x44\xd9\xb9\x74\x13\x2b\x49\x75\xf2\x7e\xa6\xe8\xe4\x6b\x55\xae\xdd\x67\x23\xe5\x3e\x7b\xc9\xb4\x0d\xce\x24\x49\x28\x5a\x69\x08\x85\xc3\x22\x3b\x63\x6c\xb5\xc4\x87\x3c\x5d\xda\xeb\xb0\xb6\xdc\x5b\x69\x43\x8d\x88\x1a\x52\x59\x05\xa5\x1b\xdb\x97\xb0\x51\xdb\xfe\xc6\xdd\x4a\x7b\x58\x02\x97\xb0\x8f\x2b\xa6\x0f\x2e\xad\x3a\x07\x53\x1c\xf2\x99\x97\x74\x13\xaf",
        p,
        q,
        g,
        b"\x8b\x26\x62\x77\x5b\xb7\xf1\x92\x52\x20\x45\x94\xa8\x4b\x46\x9f\x3d\xc8\xd6\x6e\xb7\x99\x3b\xed\x12\x2d\x8a\x06\x5f\x59\xea\x81\xd4\xc4\x84\xce\xe5\xbd\x76\x6a\x5c\x13\x7d\xd5\x7e\x43\xe9\x41\x33\x98\x52\x15\x05\x09\xac\xbd\xe6\xf7\x95\x7a\x1b\x04\xec\xe7\x18\x56\x5c\xe8\xb6\x37\xea\x03\x1b\xfa\x34\x10\xa5\x80\x74\x4b\x3d\x49\x59\xa5\xe7\x5e\x31\x5d\xd3\x3c\x02\xb5\x2c\x7c\x56\x21\x8b\x7c\xdf\xdc\x24\xf5\x1d\xdb\x4e\x78\x49\xfa\xf2\x89\xcf\x80\x6c\x4d\x3c\x6b\x87\x7c\x63\xdb\xfa\xb5\x69\x92\x0a\x2b\x21\x9c\x39\x21\x5c\x5e\x3e\x63\x8a\x3e\xbe\xeb\xfb\x52\xc8\xb3\x8e\x82\x85\xa8\x5d\x62\x5f\xc1\xb4\x2f\xbf\x0e\x51\x8c\x58\xeb\x8f\x45\xfa\x54\x67\x6e\xd8\xb0\x09\x41\x5d\x26\x96\xee\x9b\x51\x53\xdd\xdc\x5e\xeb\xef\x49\xcc\x76\x59\x81\x0a\x98\xd4\xb5\xe8\xb9\x69\x5f\xb2\xd9\xe4\xbf\x19\x20\x93\x74\x7c\x87\x8a\x95\x65\xb4\x7c\xba\x05\x3c\x48\xba\x7c\x0b\x9b\x1c\xe7\x7f\x8a\x3e\x10\x43\xe8\x7f\xcc\x61\x32\xcb\xe8\xfa\xd7\xc7\x38\xe9\xbf\x79\xbc\xcb\x41\x4e\xf2\x49\x07\x67\x5b\xa7\xcb\x05\x9a\x83\x89\xee\xe7\xeb\xbe",
        b"\xb8\x67\x4d\x1b\xa6\xf1\x33\x98\xf5\xe8\x94\x4b\x82\x15\x0d\x9e\x9b\xc9\xb2\x10\xa8\x14\x95\xb3\x35\x94\x7e\x64",
        b"\x75\xfc\xfe\x96\x92\x61\x86\xef\xa1\x2c\x00\x7c\x09\x85\x20\x51\x47\xcf\x65\xab\xd1\x08\x36\x3d\x8b\x89\x11\x90",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xf0\xd5\xb3\x33\x27\x69\x55\x36\xe3\x51\xb3\x7c\xd3\xfe\xea\x69\x3f\x10\x37\x7a\x5f\x8b\xdd\x91\x34\x02\xc2\xed\x67\xa0\xfc\x1e\x7b\xca\xab\x00\x2f\xa7\x79\x93\x59\x50\xc7\x6e\x42\xa4\x91\xa6\x8f\xa6\xfe\x44\x5c\xd3\x55\x75\xcf\xce\x5f\x37\x6c\x29\xc4\xe8\xc0\xfe\xd5\xa5\x48\x7e\xf4\x18\xb9\x6f\xa5\x75\x2a\x03\x3a\xd0\x79\x59\x65\x3d\x1b\x8a\xf6\x70\x2d\xcc\xe4\x0e\xfe\xf2\x1b\x2d\x64\xcf\x06\xbd\x8b\x03\xda\xdb\x2f\xda\xaa\x73\xfb\x2d\x3d\x75\xb0\x98\x5e\x9a\xef\xa1\xf9\x44\x42\xa5\x49\x1a\xe4\x6d\x7c\x51",
        p,
        q,
        g,
        b"\xa4\x48\xb0\xd4\x48\x24\x9a\x0e\x54\xa9\x45\x86\x88\x29\x85\xa0\x8e\x19\x97\x22\x81\xd1\x0d\x9e\x7f\xb5\x7f\x95\xdf\xee\xbf\x97\x1f\x6d\x9d\xfe\x88\xdb\xd0\xa4\x95\x0f\x52\x82\x00\xbe\x7b\x60\x58\x65\xee\xfd\x8e\xc2\x74\xac\x53\xe4\xed\x5b\x28\x8c\x6a\x00\x72\x1e\x02\x88\x81\xb9\x72\x5f\xb0\xa9\xce\x41\x53\xdc\xc1\xfe\x7b\x5c\xe7\x25\x9f\x16\xea\x8b\x32\x45\x6c\xb0\x3b\xae\x81\xbe\x77\xf3\xf6\xe8\xb3\x9f\x52\x58\x7b\xc9\xdd\x47\xa2\x64\x27\x8d\x5d\x8e\xcb\xe1\xba\x57\x42\x69\x69\x6a\x7b\xb1\xe1\x67\xa3\xae\x71\x10\xec\x05\x7f\x42\x91\xa1\xba\xe8\x25\x7d\x69\xc1\x0a\xe0\x95\xf3\x27\x16\x21\xc6\xd6\xb5\x60\x79\x25\xc3\x49\x81\x89\xd7\x51\xb7\xc9\xbf\x30\xe6\x56\x83\xcb\x39\xfb\x51\xbd\x59\x2f\x1f\x98\x27\x9f\x2e\x7b\x2b\x53\xad\x54\x68\x16\xa8\x50\x8c\x93\xf0\x34\x96\xde\x7c\x47\x16\x5f\x5c\xf2\x97\x68\x7a\xd7\xd6\x0f\x01\x0a\xb9\xfa\xad\x01\x53\x43\x2e\xc1\xcc\xdf\x26\xd4\xf4\x41\xdf\x62\x53\x94\xe2\x10\x42\x08\xbb\x67\x5e\x7f\x97\x2b\x6c\x66\xed\x70\x28\xa1\xe3\xf4\x5a\x67\x1a\xb2\x71\x6c\x60\xfe\xab\xcc\x22",
        b"\x01\xa4\xf4\xbc\x63\x3e\xbf\x84\x2a\x28\xd0\x45\x18\x4d\x25\x05\x29\x92\x0d\xf2\x80\x54\x5c\xba\x00\x50\x1c\xad",
        b"\x09\xfc\xeb\x2d\xf2\x00\xb7\xc0\xa5\x6a\xe7\x96\x9f\x54\x73\xb7\xa1\xf6\xb7\x03\xf7\x43\xf9\x54\xa4\xfb\xdb\xe3",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xf5\x8e\x03\x9d\x66\x6e\xf0\x64\xcc\xcc\x7e\xd0\x15\x01\x7c\x68\x39\x3d\x14\x55\x30\x0d\x0c\x4f\xd4\xf0\xd3\x02\xc4\x3a\x00\x22\x36\x3a\x7c\xb0\x1b\xf0\x67\x3d\x32\x52\x93\xbd\x50\xb2\x7f\x81\x87\xd8\x8e\xe2\xb5\x53\xb1\x59\xa9\x7d\x15\xac\x54\x34\x21\x44\x6c\x2a\xec\x39\x56\x63\x15\x21\x1b\x9b\x41\x08\xca\xcf\x90\x85\xda\xcd\xb4\xde\x94\xbc\xe8\x40\x97\xc0\x89\x2b\x1c\xc6\x5f\x2e\x10\xd7\x4e\x52\x93\xa0\x4a\x83\x7b\x61\x6d\x41\x81\xf3\xfe\x4c\xaa\x4c\xc2\xe7\x44\x91\x6e\x77\x0f\xf0\xab\x13\x68\xc8\x6c\xfc",
        p,
        q,
        g,
        b"\x40\x52\x53\x4a\x77\x26\xcb\xe1\x7e\x34\x55\x56\x48\xe5\xf2\x97\xb9\x63\xf2\x2d\x3a\xca\x24\x97\x85\xad\x93\x2f\x6e\xa1\xfb\x5d\xf3\x1d\x37\x9b\x68\x52\x2f\x8e\xeb\xed\xfc\x9b\x5c\x52\x77\xe9\x15\x74\xfa\x79\xec\xf0\x37\x80\xcc\x44\x35\x1f\x3e\x3b\xfa\x1a\x05\x87\xc8\x8d\x0e\x04\xe0\xa0\x2c\xd1\xee\x9a\xe2\x10\xb3\xc9\xaa\xcc\x65\xc7\x1c\xf1\xb8\x64\x63\x36\x7e\x2b\xe2\x5c\xca\xdd\x9d\x5a\x4d\x1f\xcb\xd5\x87\x72\xf7\xa1\x17\xf3\x67\x3c\x76\xee\x2a\x8d\x93\x44\x6f\xfd\x7c\xda\x7f\x84\x30\x49\x05\x02\xc1\x6b\x1a\x50\x22\xe1\x2a\x3a\x95\xa7\xa9\xf2\x0e\x98\xd3\xb2\x85\xab\xe3\x0e\x8d\xe4\x2a\x11\xc5\x17\xc1\x4e\xf3\xb6\xe5\xb6\xc4\x71\x14\xa9\x61\xd8\x58\xc6\x87\x55\x61\xc7\xd5\xd2\x1b\x7c\x93\xf3\x73\xcb\x33\x08\x00\x72\x8e\xa1\x88\xb2\x57\x8a\x6d\xf3\x47\x72\xa7\xac\xdd\xb8\x29\xc0\x9b\x3a\xcf\x9b\xc5\xb0\x61\x40\xb9\xb0\x35\x26\x7a\x40\xe8\x6c\x1a\xf5\x57\x7b\x3d\x02\xa8\x9b\x20\xa4\x65\x73\xc8\x75\x00\xa2\xeb\xed\x4b\x00\xb1\xfb\x13\xa8\x6f\x14\x3e\x35\x67\x02\xd7\x91\x37\x9a\x90\xdf\xcc\x26\xb8\x07\x19\xad",
        b"\x31\xfd\xe5\xf2\x2e\xbb\x42\x6f\x25\x6b\x17\x50\x57\xa7\x61\x25\xc4\x01\x36\x97\x4a\xd5\x8e\x68\x1e\xc2\xc4\xa9",
        b"\x77\xb0\x61\x4d\xd9\x9a\xcb\xbf\x4c\x43\xaa\x92\x6b\x3f\x0b\xe1\xcd\x52\xd5\x27\x75\xf2\x2a\x40\x8c\x4e\x03\x04",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x14\x77\xaa\x0b\x9f\x1b\x19\x9b\x6a\xa0\x93\x1d\x4d\x3f\x76\x6d\x80\xa3\xaf\x10\xc9\xff\x73\x15\x39\x1f\x15\xed\xc4\xe9\x26\x32\xf9\xd4\xd2\x1a\x80\x33\x21\x5d\x5e\x99\xcf\xf1\x70\xd9\x88\x8f\x02\x0b\x0d\xb0\xe5\xb9\x7e\x12\x3a\x28\x89\x89\x8c\x5b\x0e\xf7\xc8\x32\xd0\x28\xaf\xd5\xe3\x85\x00\x45\x31\xff\x99\x89\x79\x7c\x3b\xd9\x54\xb1\xac\x72\x90\x66\x57\x76\x67\x56\x78\x84\xcd\x4b\xc5\xd0\x55\xa3\xf6\x45\x58\x3d\x29\xcf\x47\x58\x50\x7c\x88\x3c\x5b\xbf\xa7\x44\x44\xb9\xc5\xb9\xb4\x95\x07\x2c\x32\x61\xb6\xec",
        p,
        q,
        g,
        b"\x46\x75\xf1\x9b\x00\x95\xfa\xf8\xec\x96\x88\x8e\x48\x3f\x3a\x0a\xa6\x75\xf5\xb4\x25\x91\x07\x65\x06\x9a\xb5\x7c\x97\xa1\x2b\x7c\x50\x64\x37\xc8\x75\x7f\xef\x54\xec\xc6\xd3\x10\x92\x1d\x71\x59\xff\x39\xf2\xf1\xcd\x95\x35\xb6\x4f\x27\xf1\x36\x91\x37\x15\x77\x5a\x23\x8f\xbe\x01\x23\x7e\x18\x1a\xde\xbe\x55\x1f\xfe\x5d\x21\xe3\xc3\x57\x74\xe7\xad\xe8\xc7\x9d\xf7\x41\xc5\x2d\xab\xd8\xbe\x47\x82\xee\x5a\x3b\x60\x7a\x39\xd1\xb4\x55\xdc\x84\x83\x01\x84\x73\x12\x98\x05\x66\xf5\x5e\xba\x08\x06\x21\xe3\xc1\x23\x14\x2a\x1a\x20\x74\xe2\xe3\x9f\x6c\x06\x30\xb3\x68\x31\xf0\x74\x86\x9d\x46\xa6\x84\x29\xf6\x25\x73\xcd\x2c\x67\x17\x26\x13\x1f\xbf\xd5\x66\xa6\xd0\x71\x93\xdb\x4f\x36\x78\x02\xd7\xde\x8f\x4e\x83\x0a\xa8\x78\xee\x2c\xdf\xb8\x6d\x85\x37\x74\x6b\x71\xc7\x0f\xbc\xb6\xa1\xfa\xd6\x62\x13\xd6\xfb\xea\x68\x24\x1e\xb9\xf6\x17\x47\x8a\xdc\xc9\xfa\xaa\xb2\x6c\xf8\x1b\x91\x20\x89\xda\x0c\x4b\x18\x7b\x49\x6a\x17\xd8\x86\xce\xf5\x71\xe3\x93\xd6\xf1\xf8\x57\xeb\xf5\x17\xc8\x01\xf9\x23\x1e\x95\xdb\x66\x1e\x8c\xb2\x09\x54\x56\xa3",
        b"\xa2\x38\x0b\x5e\xce\x76\x67\x26\x69\xe2\x61\x87\xa1\x7d\xa4\x5a\xd8\x9d\xe1\x72\x6c\x82\x6e\x57\x37\x8a\xf7\x07",
        b"\x9c\xc2\x6c\x34\x56\xc0\xa4\x09\xf4\xcc\x98\xc8\x3e\xa5\x17\x6e\xb2\x93\xec\x71\x57\xe5\x13\x70\x72\x64\x29\xce",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xfc\x82\x37\x25\x66\xef\x2c\x62\x6b\x21\x45\x54\x9a\x5d\xb9\x73\x11\x8d\xff\x4c\x6d\x1d\x7c\x4a\x2e\x16\xec\xc3\x1b\x43\xc1\x4a\xd3\x68\x31\x73\x53\x5b\x0b\x82\x33\x1f\x15\xa1\x83\xe6\xa5\x02\x00\xfd\x1e\x88\xff\x90\x3e\xcf\xc5\x0b\xdd\x4f\x58\x75\xe2\x64\xa4\x49\x9e\xad\xbd\xaf\x80\x7f\x97\x4f\x8d\x81\x04\x47\x7a\x0e\x4d\x30\x46\x3d\xfc\x61\xcd\xac\x5b\xf4\x4e\xab\x96\xc7\x70\xa7\xdb\x91\x2e\xee\x2d\xb2\x48\xcd\xd2\xb9\xb3\x62\x11\xf9\x38\x70\xbe\xae\x6b\xdf\x8e\x0a\xed\x00\x97\x51\x9e\xcd\xe3\x47\x0c\xdd",
        p,
        q,
        g,
        b"\x38\x84\xab\x23\xab\x93\xd9\xd1\xb7\x16\x71\x2c\x8d\xaa\x08\x0b\x26\xaf\x01\x65\x7f\x0d\xab\x71\x5e\xbe\x6b\xd7\x66\xde\xca\x76\x12\xbe\xa6\xa4\xcf\x1f\xf7\xd0\x8a\xbb\x2d\x44\x42\xac\x0e\xaa\xb0\x1e\x68\x57\x0b\xdc\xc2\x22\xf8\x4b\xc3\xdd\x6d\x8c\x54\x90\x13\x2d\x1c\x36\xe2\x39\x13\xf0\x0d\x11\xc8\x03\xb7\x03\xa6\x9a\x51\xa1\xb4\x75\xf5\x6d\xb0\x0f\xca\x47\xd2\x34\xaa\xc3\x07\xb9\xe7\x98\xe9\xfd\x89\x1d\xff\x9c\x12\x57\xbe\xe5\x56\x31\x4b\x02\x1f\xbf\x93\xf7\x5e\xd8\xc4\x34\x33\xaf\xa7\x15\xb8\x2d\x5e\xc6\xaf\x8e\xf9\x47\x1e\x9b\x02\xf9\x55\x4e\xd7\x95\x7c\x1f\x46\xd8\xdb\x35\xa5\x92\x1f\x4a\x83\x72\x7f\x75\x4e\x82\xb6\xff\xa6\xd1\xb8\x25\x95\x22\x08\x76\xd2\x2e\x18\xfb\xaf\xa5\x33\x3b\x26\xc2\xcf\xd4\x7d\x89\x4a\xaa\x71\x64\xa2\x63\x02\x94\xd0\xa3\x85\xfc\x8a\x8c\xf5\x7d\x10\xed\x0f\xc5\x3f\x21\xf1\xfd\x6b\x4c\x27\xe9\xc6\x9e\x65\xa2\x88\x44\x46\x19\xa3\xc2\x48\xbc\xc4\x4e\xc2\x56\x05\x02\x83\x25\x24\x32\x74\xd7\x21\x00\xed\xf5\x60\xcd\x38\x2b\xab\xee\x1c\xa5\x32\xb7\xf0\x6a\x43\x88\xf1\x81\xdb\xbb\x5d\xb5",
        b"\x54\x61\xb2\x07\x04\x45\x3b\x6c\x51\x83\x7f\x7b\x9e\xf5\x83\x61\x31\xb5\x01\xf2\x53\x91\x45\xca\x34\x81\xe6\xaf",
        b"\xb6\x5f\x69\xd2\x91\xff\xae\x2d\x16\xe3\x10\x8d\x69\xae\xb0\x1b\x4f\x92\x02\xaf\xa0\x13\x82\xe5\x3d\xea\x4d\x54",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xe6\x6a\xad\x54\x04\x8b\xec\xec\xa5\x68\x26\x44\xd5\x27\x4c\x18\x06\x83\x63\xe9\x68\xe3\x7e\x6c\x11\xc1\xf8\xa0\xd7\xe3\x20\x57\x85\x14\xe1\x87\x4e\x9d\x4e\xaf\x1b\xd0\x2d\xa6\xb7\x22\xed\x22\xac\xfc\xa4\x8c\x3a\xcb\x67\x0a\x6f\x9e\xe6\x2e\x3a\xa7\x1d\xeb\x18\x09\x75\x08\xf4\x31\xb0\x52\x14\xc1\x99\xc1\x66\xfa\x42\xcd\x6a\x07\x97\xbc\x7b\x4d\x1a\x2f\x33\x0c\xb6\x2c\x2c\x95\x18\x2f\xef\x0d\x06\x86\x25\x42\x84\x5e\x43\x0d\x77\x8c\x82\x07\x63\x87\xad\xad\x43\x55\xc2\x58\xe6\xc5\x43\xcd\x65\x6f\xe3\xcd\x23\x32",
        p,
        q,
        g,
        b"\x06\x24\x5b\xc5\x09\xb4\x95\x54\x40\xb0\xe4\x01\x71\x0d\xdb\x2c\x4e\xa2\xe5\x59\x59\x83\x61\xa3\x66\x6c\x4a\xb1\x2e\x76\x6b\x43\x9f\x21\xb9\x53\x96\x2f\x6e\xf5\xa1\x1d\xbe\xe5\x67\x7a\xb7\xf8\x90\x6d\x8b\x32\x51\x80\xef\x4e\x45\xd0\x5c\x12\x94\xfc\xe5\xdc\xaf\x63\x60\xf7\x1b\x10\xb7\x05\x56\xf3\x06\x99\x3d\x29\x5b\x69\x5f\xfe\x57\x29\xc5\xc5\xbb\xb6\xcb\x48\x34\xad\x03\x7b\xd8\x36\x4a\x12\xc9\x92\xc2\x59\x8e\x8e\xe6\xbe\xb1\x60\x6e\xbc\x0a\xc0\xff\x00\xc0\xea\x2e\xb8\xae\xd7\x5d\xca\x01\xa8\x90\x08\x5a\x40\x0e\xbf\x99\x3e\x58\x79\x38\x2f\xf9\x1a\xbf\x1b\xe2\xce\xed\xd1\xfc\x4a\x87\x43\x42\xb7\x7b\x6c\x55\xff\xe7\xf6\x76\xa1\xc9\x5e\xe4\xec\xc3\x23\x58\xa0\x80\xc9\x23\x61\xcf\xcd\x2e\x34\x26\xf7\x8c\x21\x7a\xe2\x95\x56\x70\x9e\xd0\x29\xb2\x87\xe7\x1f\xea\xe0\x60\x8c\xf3\x93\x88\x57\x04\x0d\x7f\x06\xb0\xf9\x1b\x3b\x4d\xa8\x92\x9d\xf4\xb5\x69\x8e\x73\x4a\x37\x31\x68\x79\xc3\x08\xa8\x1c\x09\x6b\x72\x3b\xf2\x08\x99\x10\xd5\xab\x30\xb8\xef\xf3\x88\x58\xaf\xf6\xec\xf7\x64\xe2\x68\xed\x69\x8b\x70\xe8\xfb\x7f\x3c\x66",
        b"\x86\xd5\xba\xc3\xae\xee\x9b\x50\x1f\x91\xf2\xfa\x71\xb1\x06\x67\x60\xdf\x2e\x0e\xe1\x47\x38\x3f\x14\x5b\xb0\xd3",
        b"\x8d\x6a\x20\x78\x02\xd6\xfd\x6e\x53\x4e\x1b\x8a\x1e\xdb\x99\x7b\x7c\xc9\xa2\x5a\x97\xa9\xe4\xb6\xee\xbd\x0e\x23",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xc8\x57\x47\xcd\xd2\xac\x9d\xa0\x99\x9b\x7e\x5d\x7f\x64\xd1\x1d\xce\x76\x73\xdf\x5b\xc6\x05\x05\x13\x16\xb4\xb9\x4b\xc7\xfc\x77\x6f\xb1\xd3\xda\x5a\x43\x95\xa6\x74\xaa\x8a\x07\x98\xa3\x41\xb3\x1b\x11\xe6\x3c\xdf\xac\x5f\x85\x43\x46\xf6\xa4\xb7\x4b\x49\xf2\xd0\x89\xcb\xb8\x6f\xae\x54\xeb\xfd\x95\xeb\x9f\x05\xa1\xb5\xe8\x43\x06\xe9\x30\x46\x1a\xd7\xf8\x27\xcf\xb9\x10\x01\x4a\x3a\xf4\xda\xe0\xd4\x6e\xce\x91\x2b\xc2\x68\x70\xa4\x33\xf7\x0f\x0a\x38\xbf\x23\xb1\x5d\x98\xcc\x65\x88\x48\xf4\xba\xd9\xc8\x4e\x89\xf0",
        p,
        q,
        g,
        b"\x29\x72\x78\x7d\xcb\xd6\x7e\x5b\xdd\xaa\xf1\xbd\x3f\x05\xeb\xd6\x69\x49\x60\x1d\xda\x44\x23\x7e\xc9\x36\x15\x91\xce\x9b\x80\x9f\x87\x22\xfb\x39\x9e\x6b\x9b\x81\x09\xa7\x9e\xa7\xb8\x3f\xe9\x83\x59\xa0\x7a\x27\xe2\x32\xcd\xea\x8f\x65\x33\xe3\x4e\x37\xdb\x3a\xe5\x33\x09\xf6\x2f\x10\x8b\x2e\xe7\xb4\x89\xa9\x33\xe4\xef\x58\xdd\x4d\xb8\xc0\x10\x8a\x36\x70\xc6\x75\xb9\x8b\x75\x79\x8a\xc0\x88\x4c\xf5\xa4\x61\xaf\x28\x1f\x6d\xd8\xe7\xea\x3d\x41\x39\x6f\x04\x96\x01\xa9\xaf\x2e\x39\x08\x8a\xe0\xa1\xec\x0d\x2d\x10\xfa\xe1\xdc\x1d\xe9\x62\xd8\x4d\x8c\xf0\x42\x15\xfc\x6d\x62\x62\xac\x43\x25\x41\xaf\x2c\x48\xc0\x9c\xd4\xe1\x5b\xd9\x46\x0e\x9a\x7b\xae\x17\xe0\x03\x5a\xf0\xb1\x3d\x8d\xe7\x07\x87\x0c\x54\xbc\x85\x11\x12\xf4\xae\x1d\x69\x07\x47\x12\xc2\x12\xbc\x7e\x13\xf1\x99\xff\xc8\xf3\x77\x23\xcd\x6d\xcf\x53\x9f\x8d\xf8\xcf\x0c\xf1\xed\x4c\x10\xee\xaf\x0f\x44\x48\x04\xf1\xeb\x9d\x9c\x32\x9d\x6f\x19\x97\x3e\xec\x27\x32\x22\xfa\x04\xb5\xf1\xf0\xe1\x79\x71\xce\x39\x98\x69\x58\x20\x27\xb1\xc4\x54\xdc\x1a\xdd\xd4\x84\x90\x2c\xb0",
        b"\x28\xe3\xdd\x71\x09\x8f\xf0\x4d\x1c\xa8\x85\xc2\x77\x4f\x78\xec\xb3\xec\xea\x70\x8f\xab\x2e\x16\xbd\x5c\xec\xe1",
        b"\xac\x8b\x6e\xe4\x98\xee\x38\x3e\x28\x40\x4b\xa4\xb5\x3e\x64\xac\xa0\xfc\xd2\x67\x90\x71\x32\x64\xfe\x3c\xf6\xa1",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xa7\xa5\x9d\xa6\x2a\x93\x91\xcf\xe6\x28\x69\x75\x48\xb0\x5f\x8a\xf3\x9e\xa9\x82\x1d\x76\xc3\x14\x47\x8e\x21\x0f\xbc\xd2\x7f\xbf\x6b\x0b\xf4\x60\xa6\x5d\xbc\xba\xdc\xdd\xfc\x01\x78\xec\xe1\x35\x26\x4a\x7d\x7c\x5b\x70\x53\x20\x8b\xfb\xde\x54\xe3\x33\x8d\x90\x19\x27\xe9\x5e\x1d\xc8\xee\xb7\x3d\x29\x9e\x6f\xa6\x58\x45\x55\xcf\xea\xfd\x19\x25\xe9\x5e\x0b\x35\x58\xdd\xec\x64\x11\x75\xfc\x72\x93\xc0\x31\x02\x66\xac\xe1\x8b\xbb\x16\xf9\x08\x4f\xd4\xac\x22\xad\x2d\xc8\x52\x8c\x3f\x3f\x33\x26\x84\x03\x9e\x74\xb3\x90",
        p,
        q,
        g,
        b"\x0a\xa0\x40\xbb\xb2\x3c\x33\x7d\x58\x87\x4d\x95\xef\xe9\x27\x70\x80\x86\x2e\xa0\x88\x8d\x92\x09\xec\xc2\xf5\xd7\xe0\xd5\x6b\x3e\x84\x44\xca\x93\x38\x00\x45\x0f\x10\xb8\x12\x4f\xf8\x81\x2f\x87\xe1\xbe\xcf\x1a\x31\x7a\xce\x0c\x3a\x13\x76\xd6\x24\x93\x8c\xab\x61\x7b\xb5\x46\xd0\xaa\xd4\xf1\xd0\xaa\x23\xc6\x67\x0c\xfa\xe0\xda\x28\x66\x03\x93\xa9\x09\x11\xb3\xdb\xe3\x84\x7e\xab\x4e\xbb\x7d\xd0\x50\x4a\xeb\x02\x69\x12\x66\x55\xd1\x35\xd2\xe9\x14\x9c\xd8\xac\x52\x21\x15\x16\x40\x91\x4d\x48\x05\x69\xb3\x83\xe9\x83\x64\xcc\x41\xce\xc5\x6e\xa1\x57\xce\x8d\x7e\x73\xa9\x49\xb3\x48\xe5\xff\xd3\xce\xef\xea\x7f\x76\x25\xf5\x99\xaa\x9a\xfe\x2d\xb4\xcf\x3b\x0d\x59\xf2\x70\x0f\x6c\xec\xc5\x4f\x8b\xf7\x85\x38\x92\xf0\x73\x37\xdb\xe7\x6b\xe7\x81\x99\x4e\xf4\xe1\x4d\xf2\xf0\xcf\x7c\xb3\x42\xee\x1c\x8b\x18\x8a\x7d\xcc\x31\x7a\x09\x7c\x9f\x9e\x33\xff\x89\x46\x2c\x26\x46\x5b\xb5\x3e\xec\x05\xd1\x08\x5f\xc6\x15\x6c\xad\x0f\x7c\x9b\x80\xd2\xa6\x89\x53\x50\x1a\x97\xac\xb7\x46\xac\x3a\x2b\x9b\xdc\xf1\x8d\xfc\xea\xa1\x96\x71\x6e\xc7\x73",
        b"\x84\x93\x4f\x3f\x56\xd6\x48\x15\xfc\x66\xb0\xdb\xf3\xb1\xfa\x56\xd1\x38\x7b\xe7\x61\x1a\x1e\x57\x1c\x40\x51\x00",
        b"\x43\x1f\x11\x34\x69\x50\xe7\x7c\x9e\x9e\xd0\x12\x7c\x50\xbf\x62\x0f\x6f\x69\xa6\x99\xcd\x01\x7c\x7d\x87\x36\x8a",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xd4\xc5\xb4\x39\xa1\xcc\xf5\xd9\x8c\xf0\xb9\x31\xf2\x53\xf7\x33\x03\x79\x21\xd4\xef\xb0\x2c\xf8\x7b\x25\x09\xe7\x32\xa5\x6c\xcb\x49\xe0\xc8\x3b\x14\x09\xcc\x00\x9f\x1d\x2d\x1c\xb4\xc0\xc7\xab\x00\xc4\x02\xee\x01\x8e\xc5\x09\x80\x31\xac\x9e\x71\x97\xd4\x39\x5d\x49\x17\x21\x70\x8a\x41\xff\x5c\xda\x5a\x03\xbe\x6a\x11\x69\xbf\x45\x94\x70\xb1\xaa\xf5\x3c\x8a\x96\x68\xac\xae\x13\x85\xb9\x21\xf5\xa2\x6c\x73\x36\x54\x44\x51\x5c\x3c\x12\x6c\x69\x40\xb4\xbf\x57\x59\x1a\x0b\xfd\x6c\x2c\x74\xc7\x24\x42\x6c\xb2\xad\x3f",
        p,
        q,
        g,
        b"\x37\xc5\xf0\x29\x81\x63\x22\xda\x51\x61\xc4\xe2\x0d\xc4\xf5\xab\xde\x9f\x04\xf5\xf9\xdf\xf5\xd5\x81\xb2\x53\x10\x91\x91\xb3\x84\x24\xdd\xe7\x5f\xeb\xac\x32\xd6\xce\x31\xb1\x16\x06\x34\x94\xa7\x0c\x5c\x1d\x9d\x8b\x73\x51\x25\x2e\xd3\x77\xea\x38\xfb\xe8\x5b\x9f\x61\x4e\xca\x13\x46\xbf\xf6\x53\x45\xd5\x7e\x64\x6b\xfb\x03\x2e\x9b\xef\xa9\xe6\xe5\xa8\x9c\x16\xd7\x15\x42\x0e\x24\x12\x9b\x6f\x70\xe4\xf6\x81\xbc\x1d\x38\xad\x17\x37\xdb\x79\x65\x5d\x24\x4b\x4d\x67\xad\x3d\x2b\xd8\x0f\xd9\xd8\x0c\x2e\x15\x24\x02\x14\x85\x9f\xdc\x0b\x6c\x43\xdd\x1e\x80\x5d\xcd\xd2\xa5\xb9\x78\x13\x97\xbd\x4a\x4e\x8b\xc4\xd6\xf9\xa1\x66\x40\x36\xe9\x0c\xac\x55\x0e\x83\xd6\x64\x13\x67\x61\x37\x07\xd0\xde\x4f\x2d\xee\x55\xe9\xa5\xbe\x6d\x3d\xe8\x93\xd6\x15\x61\xf4\xba\x90\xd3\x87\xb7\xab\x48\x80\x10\x86\x01\x6c\x84\x2f\x3e\x0c\xe6\x0e\x6b\x46\xaa\x98\x01\x91\xcb\xa1\x47\x40\x7a\xa4\xcc\xbe\x19\xb0\x0b\x0a\xc7\x16\x48\xd5\x29\x6d\x13\xe4\x8c\x75\xd5\x28\x48\xbb\xd3\x9f\x1d\xed\x98\x8c\x36\x16\xfa\xaf\x64\xf9\x1a\x30\x74\x25\x06\x31\x68\x93",
        b"\x1b\x51\xb8\xd2\xd3\xee\xb3\xd6\x21\x8d\xa3\x49\x47\x14\xd0\xe8\x8c\xd7\x36\x6f\x38\x7e\x6e\xde\x00\xf6\x53\xe0",
        b"\x84\x42\x03\xa8\x1f\xb3\x8f\x57\x50\x5b\xf8\x3b\xc8\xc1\xda\x00\x2a\x39\xe8\x1a\xbb\xdd\x2f\x99\xab\x6a\x4d\x65",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x40\xd4\xd9\x73\x6b\x54\x99\x3c\x1b\xce\xe7\x07\x1c\x68\x23\x90\xd3\x4d\x47\xc3\x5f\x17\x79\x39\xca\x5b\x70\xf4\x57\xb3\x45\x8f\xd5\xec\xa4\xcb\x03\xf0\xef\xe1\xae\xc1\x0b\xf7\x94\xb8\x41\x21\x60\x56\xa1\x55\xda\xb5\x8a\x3d\xbf\xc1\x9d\xdf\x05\xd4\x58\x61\xba\xe6\xee\xa2\xbd\x7f\xfb\x87\xa6\xfd\x0f\xd2\x39\x4e\x84\x7d\xc3\x6c\x94\xc8\x15\x61\xde\xe1\x20\x77\x9b\xbe\xcb\xc3\x22\x06\x32\x7f\xeb\xaa\x17\xc9\x65\x05\xec\xb9\x7d\x56\x0c\x93\x4c\x38\x6f\x6f\x76\x6a\x2f\x51\x54\xf5\x45\xf2\x21\x81\xc1\x9f\xc6\x98",
        p,
        q,
        g,
        b"\x24\xaa\x1c\x7c\x6a\x04\x1f\x6d\x2c\x53\x30\x06\xce\xbc\xc2\xad\x04\x8b\x3d\xc0\x8f\xa8\x62\x82\xf5\x87\x9a\x23\x72\x31\xd2\x30\xcd\x85\x4a\xa1\x01\x58\xce\xbb\x45\xf3\x87\x92\x3f\xad\xa8\xc5\xf4\xb9\x1a\x7b\xc2\xdc\x3e\x2c\x39\x46\x37\x97\xe6\xeb\x19\x58\xab\xc9\xb9\xe7\x48\xbb\xfe\x80\xe3\x60\x23\x3e\x96\x95\x22\x79\x95\x9a\x6b\x80\x61\x91\x00\xf6\xf1\x87\x6f\xad\xeb\x79\x04\x91\x46\x2f\x59\x17\xda\x36\xce\xa3\x79\x3c\x44\xdb\x90\x90\x8c\xb9\xda\x18\xf6\x96\xce\xd9\x0f\x2a\xcb\x82\x63\x55\x10\x4c\x4c\x8f\x06\xc7\x37\xd4\x8a\xcf\x98\x5d\x6b\x8c\x2a\xbf\x31\x80\x72\x82\xb6\xe6\x51\xd2\x96\x7a\x16\x90\x7b\xe3\xd8\xe4\xb7\xf3\x2e\xd3\x4e\xba\x8c\x26\x2d\x6c\x0e\xcb\x13\x19\x46\xd2\x54\x63\x62\xc2\x17\xae\x19\x5d\x05\x65\x6a\x4f\xcf\xac\x73\x71\x7a\xe8\x5a\x57\x1d\x81\x1c\xbc\x99\xe0\xb3\x12\x4b\xba\x76\x7f\xea\xd6\x05\x26\x6d\x99\x02\x1c\xdd\x8c\xb4\xc0\x81\xbe\xf1\x02\x43\x10\x07\xee\x12\x52\x3b\x48\xbb\x83\x86\x98\xa5\x97\x1e\x51\x72\x52\xd6\xd9\x3e\x1c\x7f\xe9\xfb\xe0\x7b\xf4\x34\x16\x4b\xaa\xa1\x02\x6d\xa4",
        b"\x32\x5a\xa7\xb1\x73\xca\xc9\x6d\x58\x65\xaa\x50\xea\x54\xe5\xdf\x45\xa1\x0e\x72\xfd\x5d\xd1\xfb\x26\x5a\xae\x09",
        b"\x0a\x72\x03\xf6\xb8\xfb\xf6\x68\xb8\xf6\x43\x5e\x92\x9f\xd5\x2f\x52\xe2\x3a\xd4\xb8\xa1\x56\xae\x5f\x3c\x9c\x47",
    )?;

    // [mod = L=2048, N=224, SHA-384]
    let p = b"\xa6\xbb\x53\x33\xce\x34\x3c\x31\xc9\xb2\xc8\x78\xab\x91\xee\xf2\xfd\xea\x35\xc6\xdb\x0e\x71\x67\x62\xbf\xc0\xd4\x36\xd8\x75\x06\xe8\x65\xa4\xd2\xc8\xcf\xbb\xd6\x26\xce\x8b\xfe\x64\x56\x3c\xa5\x68\x6c\xd8\xcf\x08\x14\x90\xf0\x24\x45\xb2\x89\x08\x79\x82\x49\x5f\xb6\x99\x76\xb1\x02\x42\xd6\xd5\x0f\xc2\x3b\x4d\xbd\xb0\xbe\xf7\x83\x05\xd9\xa4\xd0\x5d\x9e\xae\x65\xd8\x7a\x89\x3e\xaf\x39\x7e\x04\xe3\x9b\xaa\x85\xa2\x6c\x8f\xfb\xde\xf1\x23\x32\x87\xb5\xf5\xb6\xef\x6a\x90\xf2\x7a\x69\x48\x1a\x93\x2e\xe4\x7b\x18\xd5\xd2\x7e\xb1\x07\xff\xb0\x50\x25\xe6\x46\xe8\x87\x6b\x5c\xb5\x67\xfe\xc1\xdd\x35\x83\x5d\x42\x08\x21\x98\x53\x1f\xaf\xbe\x5a\xe2\x80\xc5\x75\xa1\xfb\x0e\x62\xe9\xb3\xca\x37\xe1\x97\xad\x96\xd9\xdd\xe1\xf3\x3f\x2c\xec\x7d\x27\xde\xae\x26\x1c\x83\xee\x8e\x20\x02\xaf\x7e\xb6\xe8\x2f\x6a\x14\x79\x6a\xf0\x37\x57\x7a\x10\x32\xbb\xc7\x09\x12\x9c\xaa\xbd\x8a\xdd\xf8\x70\xae\x2d\x05\x95\xc8\xfd\xb3\x71\x55\x74\x8f\x0d\xea\x34\xb4\x4d\x4f\x82\xed\x58\xc2\xf5\xb1\xb8\x48\x16\x62\xac\x53\x47\x3c\x69\x34\x10\x08\x2f\xbd";
    let q = b"\x8c\x3e\xe5\xbd\x9a\x2a\xaf\x06\x8b\xd5\x84\x5b\xd5\x5e\xcf\x27\x41\x70\x55\x30\x75\x77\xbb\xc3\x77\x0e\xc6\x8b";
    let g = b"\x43\xb5\xa6\xb6\xd0\xbb\x96\x2e\xc9\x76\x6a\x37\x7c\x32\xcc\x41\x24\xf1\x31\x11\x88\xc2\xec\xf9\x5c\x0c\xd4\xa4\xfa\x09\x72\x25\xb7\x61\x8c\xb1\x27\x6c\x47\x45\x78\xd3\xbf\x56\x4c\x14\x51\x99\xc0\x92\xa1\xb1\x4b\xaa\x92\x9c\x2f\x3f\x0f\x36\xe0\xc2\xda\xe9\x1e\xba\x08\xbe\x30\x99\x2a\x88\x9f\x29\x52\xe0\x44\x2c\x37\xaf\x48\x4a\x4e\xcd\xc3\x24\x3c\xcf\xcb\x9e\x34\x13\xcf\x5c\xdd\x66\x30\xb0\x9f\xe1\x7e\xfb\xfd\xe1\x4d\x87\x25\x49\x30\x19\xb7\xb7\x3d\x1f\x78\x2b\x48\xef\x30\xbe\xc3\x6e\x00\xe0\x2b\xa3\x36\xd2\x25\x4f\xc2\x02\xa6\x96\x12\xcd\x94\x46\xf9\x1d\x76\xb7\x39\xff\xa6\xd8\xb8\x60\x52\xf8\xdc\x5f\x11\x45\x80\x1c\x56\x24\x1a\xf5\xba\x90\x37\x24\x1b\xd8\x9e\x63\x38\xb5\x8e\x01\x31\x06\x71\xc2\x68\xeb\x5e\x33\xac\xb5\x7d\x1f\x99\xf1\x64\x40\xa6\x75\x82\x7d\x40\x17\x75\x4d\x60\x1a\x17\xad\xa2\xfb\xed\xf9\x04\x55\x4a\x90\xb0\x15\x30\xda\x8c\x93\xcd\x14\xce\x29\x3c\xb2\xbd\x3e\x79\x37\xe9\x34\xb7\x9e\x31\x0f\xe4\xd8\x0c\x13\xf9\x2f\x63\x38\x13\x55\xbd\x80\xa1\xab\xee\x1a\x73\xfd\xfb\x6d\xa2\x4e\xf2\x80\x02\xa3";
    test(
        HashAlgorithm::SHA384,
        b"\xdf\x5d\x56\x4d\xb8\x35\x92\xc1\x12\x8b\xe5\xd2\x9b\x70\x36\x88\x0d\x55\xe8\x34\xa2\x91\xa7\x45\xed\x8d\xcd\x43\x8c\x4d\xa6\xb1\xb9\xf3\x94\x12\xb2\xc5\x11\x07\x30\xdb\x83\xc1\xcc\xdf\xe9\x05\x9d\xd9\x6e\xc7\xea\x2b\xbc\xb3\x4e\x3e\xba\x72\xef\x0a\x1d\x47\x21\xc7\xc0\x22\x1e\x29\x27\x9f\x01\x4d\x63\xfa\xcc\x5b\xc8\xf1\x8c\x53\x9b\x92\xff\x2a\xf8\x9e\x56\x82\x25\xd6\xb4\xcf\x59\x9c\xb3\xdf\xf5\xe3\xc6\xdd\xfa\xc0\xa2\x7f\x10\xf6\x36\xec\x22\x0a\xbb\x72\x63\x0b\xae\x9a\x39\xc1\x8f\xd3\x66\x3e\x46\x51\xcc\xac",
        p,
        q,
        g,
        b"\x64\x79\x79\xb7\x96\x0c\xe7\xb9\x71\xff\x0e\x5f\x64\x35\xf4\x2a\x41\xb1\x8c\x9d\xe0\x9a\x30\x11\x14\xa0\x13\xa7\xcd\x01\x18\x3f\x17\x6f\x88\x83\x83\x79\xdc\xb4\xef\xb6\x7d\xae\xa7\x9d\xef\x3f\x04\x2c\xbc\xf9\xcc\x50\x3b\x4c\x21\x51\xa2\x36\x4f\x7c\x94\x37\xb1\x96\x43\xe6\x7e\x24\xa3\x6b\xac\x4a\x4c\xfa\x29\x3d\xee\xdf\x8e\xc6\xb1\x54\xa3\x2a\xa7\x29\x85\xf7\xd8\xde\x23\x53\x34\xb5\x46\xc2\x9d\xef\x45\x8c\x55\xd0\xc5\xc0\xac\x5d\x74\xe2\x02\x4e\xc7\xd4\xab\xc2\xfd\xa5\x16\xa2\xa0\xb1\xa4\xd8\x86\xad\x92\xc2\x04\x70\x78\x28\xa4\xfc\x77\x94\xf6\x0e\xe8\xa4\xbe\x11\x01\xc9\xe5\x51\x8f\x7e\x19\xee\xbd\x47\x5f\x2d\xe6\xf6\xba\x89\xc2\x8b\xd1\x29\xf1\x39\x93\xbe\xfe\x58\x18\x44\x03\x19\xa7\x95\x49\x83\x31\x96\x34\x2a\x31\xdb\xaf\x7d\x79\x49\x7d\xec\x65\xee\x7d\xbe\xf7\x0e\x58\xf9\x9d\x05\x95\xf6\xa7\x11\x40\x9a\xde\x31\x51\xd4\x55\x63\xd5\x3c\x1c\xd0\xa8\xab\x1a\x18\xbe\xff\x65\x02\xcb\xb0\xc0\x69\xb1\x14\xea\x7b\xe7\x78\x98\xd0\xf4\xe5\x49\x99\x1b\xa0\xb3\x68\x97\x1b\x10\x72\xec\xe4\xaf\xc3\x80\xe9\xae\x32\x9a\x50",
        b"\x5a\xb4\x3e\xde\x66\xa1\x56\x88\x14\x6d\x1f\x4c\xd7\x16\x47\x02\xc0\xc4\x45\x7b\xd4\xfd\xde\xba\xc0\x48\x29\x53",
        b"\x6c\x58\xe8\xab\x27\xd2\x85\x12\xc4\x60\x63\xc9\x6b\xf5\xbc\xeb\x8f\xba\xd2\x32\xd8\xf5\xb3\x9c\x47\x55\xd0\xb1",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xeb\xeb\x9e\x2b\x69\x2e\xc6\xc9\xaf\xad\x2a\x0c\x2b\x90\x89\x39\x94\x3f\xdf\x4b\xb7\x43\x8e\x3b\xd9\x28\x8e\x76\x81\x98\x40\x87\xff\xdc\xf8\x65\x02\x07\x9c\x29\x12\x36\xd7\xf1\xad\xb5\x04\xe6\x7e\x0f\x88\xbe\xe6\x1b\x61\x71\x70\x14\xcf\x06\xb5\xfa\xd5\xcb\x36\xf1\xb2\x23\xb6\x39\x12\xcd\xcd\x2b\x94\x16\x52\x4d\x37\xf5\xd7\xb0\x5c\x37\xd1\x78\x96\x69\xe1\x41\xaf\xf6\x67\x0d\xb2\xe0\xde\x31\x67\x3b\x20\x55\xf6\x79\x9a\xc8\x87\x93\x7e\x56\x64\xa6\x59\xea\x02\x54\xa8\xd4\xba\x6f\x20\x4d\xf2\xa3\x8c\x2a\x77\xe4",
        p,
        q,
        g,
        b"\x31\xd3\x1a\x5b\xb8\x28\x74\xbd\xc7\x6c\xab\xae\x3e\xc8\x56\x90\xaa\x51\x03\xca\xcb\xe5\x23\x4e\x0d\x5e\xf6\x45\xee\xf3\x80\xd3\xae\x2f\x62\x39\x14\x4b\x82\xb1\x01\xa7\xef\x47\x44\xaa\xdb\x8f\xc9\x8e\x82\xb4\x13\x72\xe9\x9d\x6c\x90\x5c\xa9\x74\xb8\x1c\x9f\xa5\x21\xf9\x20\xa1\xdf\xfa\xb4\xe2\xee\x15\xf6\x1e\x03\xb7\x42\xf4\x24\x70\xdc\x2f\xa9\xab\x25\x7f\x11\x36\xf9\xfe\x4b\x5a\xa2\xec\xe5\x20\x72\x30\xc4\x90\x6d\x67\xa1\x56\xa3\xff\xef\x47\x0c\xbf\x3a\x65\xe3\x18\x9b\x38\x9d\xdc\x66\xc6\x04\x0a\x79\x95\xc6\x8a\xe1\xdf\x20\x85\x94\x1b\x5b\x1d\xf7\xd9\x57\xfb\xcf\x36\x68\x24\xe0\x29\x1d\xf8\x8e\xae\x55\xd8\xd3\x04\x0d\x8d\x09\xf4\xf6\xff\xee\x34\xcc\xbd\x19\x61\x85\x2a\x5a\x62\xb2\x6c\x8d\xaa\xaa\x56\xa8\xff\x7f\xa8\x63\xb6\x3c\x6d\x60\x4f\xd3\x37\x82\x62\xe8\x15\xf5\x51\x71\xdc\xa3\x5d\x04\x76\x1f\xe3\xd9\xed\xdc\x6d\x32\x65\x7a\x96\xd6\x43\xd4\x60\x8e\xf2\x14\x3b\x19\xf1\xc9\xd8\xc0\x0e\xd2\x65\x47\x1b\x24\x5b\x60\xf3\x1f\x8c\x7e\xd4\x8d\xd6\xb1\x8b\x5b\xec\x1a\x6e\xde\x14\x5d\xea\x40\x28\x32\x30\x72\x4e\xc8",
        b"\x82\xc3\x74\x7a\x06\x58\xdf\x00\x6a\x7a\x20\x5a\x6a\xe2\xae\xdd\x5d\x29\x48\x48\x85\x59\xfc\x3c\xfd\x64\x3a\x64",
        b"\x86\x36\x79\x6d\xf6\x22\xd1\x3f\x07\x0f\xbe\xd4\x18\x4c\x81\x38\x35\x8c\x21\xdb\x30\xc6\x06\xb8\xf9\xbe\x52\x1a",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xdb\xd2\x51\x6b\x03\xfd\xc5\x8b\x32\xc0\x23\x30\x80\xff\xee\xa4\x1c\x0d\x9c\x15\x6b\x30\x33\x2e\xc4\x2b\xe5\xe1\x05\x84\xbe\x3e\x3d\xb8\x5f\xfd\x5b\x5b\xae\x16\xfc\x87\x6a\x0c\x92\x17\x62\x7d\x84\x01\x12\x23\xfa\xb5\x7d\x17\x6d\xef\x61\xe4\x0d\x91\x2e\x7e\xeb\x2b\xf8\x68\x73\x4a\xe8\xf2\x76\xa9\x6a\xb1\x3d\xe5\x58\xec\x42\x61\x41\x67\xc5\xaa\x4c\x60\x35\x7f\x71\xfa\xc5\x89\x80\xe5\x79\x44\x0f\x69\x96\x8d\x22\x80\xbc\x97\x0d\x00\x66\xb5\xbd\x6a\x6f\x50\x02\x48\x15\x10\x25\x6b\x3e\xb2\x1b\xbb\x92\xef\x2c\xdd",
        p,
        q,
        g,
        b"\x6e\x6e\xe0\x31\x9a\xf8\xfa\xfd\x7a\xe0\x20\x13\xf4\x22\x7e\x26\x62\x44\xae\x5d\x87\xfe\x15\x6c\xef\xd4\x51\x8b\xcd\x71\xaa\x73\xf9\x36\x4b\xff\x35\xd4\xd2\x3d\x45\xb0\xf4\x7d\xfe\x93\xa6\x07\xd9\xf8\xb3\x99\xb4\x24\xba\x75\x07\x2f\xdc\xed\x6c\x3e\xd2\x11\x06\x06\xfa\x48\xed\x63\x3f\xae\xf2\x06\x4f\xb3\x36\x06\x9e\xec\x7e\xbd\x8a\xe4\x75\x97\x83\x89\xe6\xe4\x33\xd5\xa4\x35\xd6\x52\x9a\x66\xc4\x89\xce\x15\x39\x40\xd2\xb1\xb8\xc8\x86\xc8\x11\x0d\x8b\x0a\xeb\x64\x1a\x40\xe2\x85\xd6\x75\x1c\xe7\x10\x27\xc3\x0e\xc6\x2f\x4b\x1f\xc1\x4f\x4d\xa2\x0b\x1d\x50\x57\x42\xca\xda\x20\x1c\xea\x81\x93\x0c\x38\x1f\x8a\x6f\x13\xdd\x0a\x42\xaa\xc1\xe0\xbd\x7f\xcd\x19\xc6\xbd\xd1\x70\xfa\xc6\xa4\x23\x76\x7b\x83\x1c\x1e\x28\x9e\x0a\x29\xef\x85\xd8\x17\xad\x23\x8d\x91\xac\x3a\xce\x2f\x40\xa1\x63\xb0\xa9\xbb\xdd\xc6\xf0\x5d\x0b\xdc\xd8\xcc\x27\x4a\x74\xd0\x74\x3c\x9f\xb5\x65\x56\xec\x1c\xb8\xe9\xcb\xa9\x82\xc1\x5a\x9a\x66\xfa\x6b\x69\x99\xb8\x48\x5d\xb1\xa8\x6e\xe1\x8b\xe1\x6e\x06\x8e\x12\xa8\xa1\x65\xe3\x59\x9d\xf9\x66\x69\xa1\xb7",
        b"\x04\x04\x05\x13\x6a\x12\x20\xad\xbb\x64\xab\x75\x1d\xb3\x30\x7f\xaf\xad\x54\x47\xab\x2d\x9b\xcc\x52\xf7\x9b\xe3",
        b"\x1d\x35\xf3\x26\x9c\x77\xc5\x77\x24\x3f\x1d\xb8\xdf\xdb\xc4\xcc\x45\x31\x57\x42\x76\xf0\xda\x1f\x7a\x44\xac\xd4",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x34\xc4\x54\x35\xd0\xcc\x29\x26\x92\x72\xa9\x3d\x43\x32\x06\x98\xe4\x54\xa7\xc2\x87\xdb\x9d\x06\x20\x92\xac\xac\xd7\xca\x08\x64\x55\xe5\x83\xba\xee\x12\x76\xca\xba\x06\x8f\xde\xeb\x52\x18\x33\x96\xd5\x44\x4c\x5a\x14\xad\x52\xa5\xc2\xbc\x08\x2c\xd8\x74\x52\xaa\x8f\x9b\x23\x05\x6b\x5f\x8a\xf2\x63\x8d\x96\x5e\xf4\xfe\x6e\x4e\x68\xe8\x8b\x0f\x50\xe0\x12\x48\xfe\x6a\x6a\x1d\x9d\x6d\x93\xb0\x3c\xd5\x5d\x16\xfd\x83\xcd\x4e\x06\x76\x3d\x92\x6f\x7c\x50\xf2\x0f\x0e\xd6\x73\x06\x13\xf0\xf4\xdb\x57\x1e\x22\xd2\x88\xe4",
        p,
        q,
        g,
        b"\x5e\xbd\x81\x52\x93\x5f\xf2\xa3\xf9\xa6\x1b\x27\x5e\x98\x08\xa0\x41\xaa\xd5\x65\x0f\x59\x3f\x61\x2a\xf3\x3b\xc4\x62\xb8\xc9\x94\x16\x93\x72\xe8\xf8\x0f\x51\xb1\x5f\x5c\xe9\x66\xea\x3e\x76\xa9\x12\xc6\x53\x97\x83\x37\xe9\x62\x21\x9e\x32\x3b\x6e\x92\x2d\xea\x4b\xcc\x23\xc6\x46\xa2\x2e\xec\xde\x02\x43\x31\x26\xfb\xac\xe0\xe3\xa0\x1f\xa6\xd0\xb9\xfd\xea\x92\x45\xd6\x78\x99\xa7\xb7\x45\xb8\x84\x7c\x80\x87\xfa\x7f\x6c\x0f\x3e\xda\xfa\xb4\xc3\xb4\x72\x20\x82\x1f\xe4\x6f\x1b\xcb\x00\xa3\x23\xdf\xf3\xde\xe4\x7e\xe1\xde\x2e\xce\x44\xe1\xfd\xf3\xe6\x4a\xa2\x0c\x9e\x6b\x58\xe5\x34\x48\x2e\x73\x13\xda\xce\x1c\x61\x7d\x8e\xa9\xa6\x5d\xd5\x1f\xd3\x30\x24\xf7\x35\xc3\x84\x4c\x5c\x6b\x4a\x3f\x44\x7e\x71\x4a\xb0\xc1\x7d\xc8\x8e\x33\xf0\x8b\x14\x2b\x72\xe8\x11\xe6\xda\x00\x29\x9c\x82\x89\x8a\xaf\x2b\xed\x5a\xe5\x17\x0c\x1d\xd0\x05\x67\x8d\x2b\x57\x6b\x9c\xe3\xe6\xbc\x6b\x2a\xeb\x04\xc9\xf0\x4e\x44\x4e\x2a\x98\x08\x40\x5f\xf5\x92\x65\x48\xb5\x93\x04\xdd\xdc\xa8\x97\x26\x31\xf7\xfb\x13\x68\x08\xe2\x13\xec\xd9\x3a\xf9\x8e\x2e\x54",
        b"\x66\x48\x1f\x24\x1f\x6b\x44\x31\x48\xf0\xb1\xf2\x45\x9b\xe5\xca\x16\x41\x3d\x94\x7d\x09\x81\x62\x87\x17\xc1\x08",
        b"\x2c\xda\xa7\x35\x00\xd0\xad\x29\x12\x52\xd0\x7c\xef\xf9\xcf\xea\xb8\x7a\x73\x97\x52\x29\x1e\xb5\xdc\xef\xea\x87",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xd7\xac\x5c\xc8\xa4\xc3\xf3\x8c\xfe\x5c\x0e\x10\x68\xea\x28\xf0\xf9\x5d\x32\x50\xd1\xae\xae\x5f\x66\xbd\xc4\xd2\x2e\x23\xe2\x46\xff\x30\x42\x9c\xbc\xba\xd3\xb0\x2a\x62\xa0\xa1\x79\xd4\xd1\x07\x13\x0f\xa3\xa7\x80\xc0\x09\x2c\x32\x9c\x2b\x02\x6e\x12\xe6\x73\x5a\x75\xc4\x95\xb0\x97\xaa\x69\xeb\xe9\x8a\x96\xff\x89\x12\x34\xff\x37\x95\x11\x14\x9e\x07\xc6\xe2\x41\x1e\x58\x97\x6e\xe9\x3f\xba\x7d\x3d\x57\x0c\x91\x1f\x6f\x20\x83\x75\x78\x3f\xf5\xd9\x47\xa3\xaf\x0c\x83\x9d\x21\x0a\x8e\x4a\x8c\x8f\xa4\x1e\xfb\xc5\x7e",
        p,
        q,
        g,
        b"\x7b\x5f\xb0\x22\xb5\x5f\xb6\x1f\x8e\xf8\xcd\xbf\xee\x46\xc0\xfc\x61\xe5\x9f\xc6\x2d\xee\x5c\x14\xd0\xc3\x13\x4b\x4f\x26\x59\x11\x2e\x3f\x4e\x70\x17\xf9\x57\x4a\x27\x24\x18\x8b\xa6\xa1\xce\x77\x7a\x89\x15\xbc\x11\x71\xd7\x38\x75\x4b\x5a\xc1\xdf\x92\x31\x03\xad\x7b\x19\x85\x11\xed\x36\x27\x26\x68\xae\x0c\x2e\x31\x42\xba\x01\x1c\xb4\x5f\x89\x3d\xdb\xf7\xb3\x86\x25\x81\x8c\xba\x9a\x9b\x78\xae\xf8\xd0\x60\x07\xed\x50\x5e\x6d\xd6\xe2\x0c\x92\xd2\x50\x02\x34\xf1\x04\xc1\x28\x3f\x7c\x00\xcf\x2a\x3a\x32\x45\x8d\x97\xf7\xbd\x17\x09\x0f\x76\x23\x5c\x6c\x4f\x8a\xe1\x94\xd5\x2d\x67\xc7\x4a\x85\x49\x73\xfd\x12\x47\x51\xf7\xf5\x80\x4b\x67\x87\x9b\x02\x3b\xb6\xee\xac\x76\xe9\x6f\xe6\x76\xda\xeb\xbc\xb1\xbc\x94\xd5\xd8\x51\xd7\xbc\x56\xbf\xb3\xd2\xa0\xa6\xd9\x92\x31\x37\x86\xd9\xfb\x38\xad\x29\xb7\x62\x34\x94\x51\xd1\x49\xd0\xe5\xfd\xe6\xad\x49\x71\x83\xe3\x52\x82\x8e\x25\x1b\xcc\x7c\x3a\x91\x8b\xe4\xd0\x3b\x17\xaf\x60\xf3\xf3\xef\x6d\x9f\xb2\x45\x5d\xf7\xe8\xb6\xb1\x69\x47\x5e\x5f\x89\xdb\x99\x08\x54\x1b\x56\x7d\x0f\x29\x9b",
        b"\x5b\x6b\xe6\xba\xd7\x25\xaf\xa4\x42\xf2\x9a\xb7\xd3\x43\xd2\xf8\xb4\xb4\x94\x1c\xbd\x23\xd6\x91\x64\xb3\xc5\xfd",
        b"\x3a\x1b\x94\x63\x4e\x31\x3f\xc4\xdf\x82\x92\xe0\x38\xc6\xe8\x76\x33\x6c\xef\x88\xd6\x91\xb8\x94\xc0\xec\xcd\x3f",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x7a\x96\x87\x3f\x07\x77\xe8\xad\xa9\x86\x75\x32\xae\x5f\x51\x93\x8b\xae\x2d\x56\xfb\x47\x1e\x0f\xef\xa6\x93\xb7\x1a\x2a\xea\x25\x71\xc0\x10\x8b\xa5\x9e\x63\x44\x01\xbb\xaf\x20\xa8\x48\xad\x8c\x30\x58\x48\x42\x0c\xee\x65\x4a\x30\x40\x00\x7f\x05\x5d\x4e\x97\x58\x07\x89\x4b\x56\x18\xb9\x39\x23\x63\xbc\x7f\x8c\x88\xd5\x26\xbc\x49\x1a\xdb\xd8\x92\xa9\x37\x51\xa2\x1d\x13\x7c\xee\xde\x8a\x04\x42\x3a\x4d\x0c\xa1\x55\x7b\xcf\x33\x4e\x4f\x85\x5b\x04\x47\x45\x44\x21\x29\x29\xa8\x1d\xc7\x1f\xb3\xfc\x41\xf7\x0d\x6b\x18",
        p,
        q,
        g,
        b"\x05\x31\x51\x81\x77\x08\x7d\xff\x8d\x04\xa0\x66\x6c\x13\x01\xa9\xb3\x84\x27\xc2\xea\x1b\x16\x2e\x6f\xca\x52\x01\x81\xef\x22\xa2\xd2\x05\xce\xff\xff\xb1\x54\x9c\x97\x07\x80\x55\x60\xc6\xc4\xb3\x19\x43\xd5\x25\x56\xbf\x30\x1c\x5e\x0e\x75\x92\x4f\xbe\x6b\x5c\x36\x2f\xc9\x80\x17\x53\xe6\x30\x43\x3a\x9a\x34\x8f\x53\xe6\x2c\x07\x46\xb2\x6e\x34\x8d\xfb\x85\x85\x3d\x1e\xf6\xec\xa0\x2c\xf3\xf3\x43\xe7\x7c\x17\x69\xff\xc1\xc1\x09\xb8\x8e\xce\xa1\x6a\xb6\xcf\x47\x6e\x54\x31\x25\x00\x98\x36\x22\xdf\x41\xe6\x95\xec\x27\xa4\x1c\xa7\xa6\x31\x21\xba\x97\xbe\xe7\xb0\xe9\xd5\x47\xbf\x42\x0f\x64\x7d\x0f\x86\x71\xbf\x41\x07\xa7\x12\xa7\xdb\xc1\xaf\x3a\xa8\xd1\x5b\x98\x54\x8d\x39\x09\xf7\x2b\x9a\x27\xf8\x1c\x46\xe3\xde\xfa\x95\xea\xff\x75\x90\xc6\x26\xb9\xba\x10\x97\x4a\xe8\xb9\xf5\x85\x35\xd0\x9c\xa3\x0f\x9f\x52\x35\x39\xcf\x58\x4f\x9b\xc6\xc7\x41\x85\xc2\xff\x12\x50\x4f\x55\x98\xff\xde\x6f\x86\x02\x1a\xe5\x14\x56\x2f\xed\x38\x81\x19\x7f\xca\x22\xdb\x55\x90\xfc\xf9\x52\x2e\xf7\x60\xed\x0e\x36\x31\xa6\xbd\x79\xf2\x90\x00\xb4\x2b",
        b"\x76\xbd\x6f\xf4\xcd\xc4\xfe\x37\xf6\x70\x5e\x77\xef\xdc\xac\x6f\xbb\x9d\x54\xfc\x0b\x22\x06\x43\xc6\x62\xac\xbf",
        b"\x8a\x12\x4a\x36\x40\xad\x73\x28\x0f\x30\x5a\xfc\x2b\xc3\xe5\x7f\x7a\x2e\x07\x40\x81\xbe\x7b\xc9\x0b\x5b\x1f\xaa",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xd6\x96\x94\xbf\x9a\x93\xac\x0c\xc3\x91\x59\x73\xd4\x0e\x35\x12\x47\xc3\xbc\xac\xa9\x80\x69\xcd\x9c\x1e\x7a\x3c\x58\x50\x63\x6a\x59\x2e\xa7\x5f\xae\x7b\xfd\x38\xb1\x29\x0e\x3f\x4d\x0a\xae\x8e\xe6\x89\xce\x41\x37\xea\x86\x8a\xae\xbb\x17\xda\xfb\x25\x5c\x4a\x20\xe0\xfa\xc1\xf4\x66\x66\x12\xf9\x0c\x46\x32\x0a\x62\x00\x2e\xde\x31\x67\xa3\x4d\xff\x74\xa3\x06\xa0\x84\x24\x27\xcb\x9d\x2c\x61\x59\x9b\x05\xc6\x7b\x67\x31\x44\xf6\xc0\x82\x32\xd7\x71\xf2\xe0\xaf\x38\x25\x3f\x36\xe1\x22\x87\x0e\x04\xeb\xc5\x4a\x51\x2f",
        p,
        q,
        g,
        b"\x9c\x58\x8b\x76\x26\x9b\x2f\x08\x7f\x7e\x7a\xf4\xec\x4c\x0e\xf2\x63\xe9\x63\x6f\x45\xe7\x3e\x60\x45\x02\xd6\x2f\xae\x90\xa2\x51\x01\xbc\x2b\xad\x2a\x00\x21\x27\xd4\xb6\x0f\x5c\x4a\x13\x88\x88\x0c\xad\xe9\x46\x3a\xb5\xf7\x99\x7d\x54\xa0\x2c\x24\xe7\xd5\x1a\x4b\x8a\x7d\x91\xcd\xf6\xaf\xca\x2b\x43\x37\x68\x09\x45\x33\xa0\xde\x08\xde\xc1\xf1\x9e\xcc\xb4\x6d\xf1\x80\x0f\x53\xd3\xdf\xee\xfb\xfb\x76\x9a\x80\xe1\x68\x6e\x8d\x53\xc6\x0e\x8c\x15\x11\xa6\xdd\x4f\x42\xa1\x55\xbd\x85\xf7\x57\x40\xbc\xbb\x7b\x11\x27\x59\x18\x22\x92\x6d\x16\x82\x98\x23\x75\xea\x5e\xc2\x9f\xd1\xef\x4f\x28\x3b\x94\xe0\x24\x23\xa8\x30\xb3\x5e\x97\x3c\xaf\x12\x37\x7e\xe1\x8d\x2c\x6e\xe7\x77\x11\x84\xd7\xa9\x4e\x7a\x0c\x4a\x01\x04\x4a\xfc\x4e\xfb\x2f\xfe\xcb\x69\x5e\x23\x3a\xeb\x80\xc5\x16\xc7\x7d\x1c\x73\x0d\x30\xd1\xaa\x4f\x39\xda\x51\xbc\xc4\x8f\x44\xd0\x7a\xbf\xbe\x75\xf2\x28\xab\xec\x2e\x72\x73\x59\x3c\x98\xf3\x23\xa9\xb0\x03\x56\x2a\x16\x87\x52\xe8\x37\xa1\x23\x2f\x46\x2a\x23\xd3\xb1\x85\xea\x8a\x05\x36\x15\x70\x45\x5a\xad\xd1\x03\x70\x63",
        b"\x10\x8a\x08\x2d\x2b\xf6\x35\x8a\x73\x74\x65\x62\x43\x20\xc4\xfa\x9d\x37\x19\x74\x4c\x2d\xb6\x9d\x18\x96\x3d\x75",
        b"\x42\x0f\x35\x37\xfa\x68\x58\x65\x7d\xb7\xa2\x1e\x72\xe1\x1e\xc0\xec\x8c\xc8\x5a\x09\xa0\xd1\xa4\x45\x94\x49\x80",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x17\x45\x5b\xfb\xb1\x28\xdf\x0f\x96\x54\x4b\xbf\x83\xca\x0f\xf3\x74\xbc\x08\x6b\x2d\xe1\x8f\x74\xf5\x90\x49\xf7\x3e\xff\x3c\x8e\xf3\x2a\x48\x42\x9a\x40\x38\x25\x63\x04\x63\x6f\x30\x32\x19\x27\x95\xba\x28\x07\x40\x7e\xf5\x2b\x8d\x59\xb4\x0b\xfd\x51\x75\x83\xf9\x98\x81\x02\x79\xc0\x21\x17\x71\xd9\xe5\x4f\x2b\x84\xe8\x98\xf9\x89\x2e\xf7\x7b\xeb\xa3\x3f\xf3\x1a\x28\x68\x69\x3f\x1f\x09\x78\xb8\x98\x95\xe3\x50\xd5\xde\xd2\x59\xfb\x13\x97\xe9\xc6\x98\x99\x86\x45\x2a\x0d\x77\xdf\x99\x04\x8f\xff\x84\xb6\xeb\x15\x0e",
        p,
        q,
        g,
        b"\x85\x0c\x0f\xca\xc0\x73\xc5\x63\x18\xa9\x21\x04\x65\x4e\x6a\x8a\xe7\x67\x8f\xc4\x01\x47\x28\x30\x46\x49\xbf\x10\x70\x27\x77\x06\xfb\xd3\x2e\xa4\xd4\x1f\x77\xf8\x0a\x80\xc8\x8f\x27\x01\xe3\x66\x5b\xe7\x3f\x59\xf9\x14\xa9\x15\xd6\x6b\x41\x1b\xb0\x5a\xe5\xc1\x8b\x00\xbc\x21\x62\x51\x39\x97\x32\xfd\xc2\xa6\x8b\xe6\xa2\x1b\x3b\x08\x87\x97\x41\x6a\xe0\x5c\xe8\x76\xb6\x80\x2e\x4f\x94\x1a\x21\xb1\xc6\x61\xe3\xf0\x6d\x50\x1e\xf2\xa1\x76\x59\xf0\x88\xd2\x19\x5d\xd1\x61\xf0\x64\x04\x48\x7a\x27\xb7\x9d\xf1\xec\x57\x4a\xc3\xab\xc3\x0e\xce\x2a\x14\x28\xc5\xe0\xc1\xd4\xc4\x98\x03\x39\x8d\x07\x14\xca\xcd\x98\x53\x85\x4b\x08\x74\x6f\xa4\x53\x56\x15\x45\xe6\xf0\xd9\x6c\xd2\xc7\xce\x1b\x89\xbc\xac\xe1\xc6\x97\xec\x4d\x61\x6b\xf1\x4d\x18\x89\xa7\x9a\x80\x6a\x36\x99\xf8\x4f\x19\xef\xe6\x90\xfa\x13\xa3\xb4\x38\x3e\xbf\x77\x26\x14\x00\xfc\xbe\x30\x9c\x2e\x5e\xab\x0b\x24\xb1\x97\xcb\x85\x6a\xa2\x7d\x7d\x71\xd9\x2d\x32\xaa\xb6\x56\xfa\xec\x5f\xf7\x92\xec\xe5\x38\x74\xc4\x06\x9f\x54\x0d\x94\x8f\x8b\x2e\x55\x99\x08\x2e\x21\xf0\x2d\x72",
        b"\x42\x3d\xe9\xe1\x12\xec\x38\xe3\xa0\x34\xf5\xd9\x67\x5c\x76\xf9\xdc\x85\x36\xb3\x0d\x05\x67\x8a\x29\x63\xec\x16",
        b"\x74\x05\x1e\x79\x69\x9f\xa4\x4d\xe1\x8e\x36\xab\x11\x68\x73\x59\x3a\x31\x0e\x4e\x09\xdc\xe1\x8b\x83\x3f\xc2\xf5",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xde\x1f\x96\x06\x26\x1f\xf8\x22\x18\xc8\xc1\x45\xaa\x4d\x58\x47\x67\x3b\x45\x9e\xb5\x5f\xe7\xe6\x45\x4c\x04\x43\x26\x6b\xbf\x80\x0c\x1d\x09\x05\x1f\x5e\x31\x41\xc4\x37\x0d\x1b\x99\x0c\xf5\xfe\xa9\xd2\x68\x39\x86\xc3\xbd\xd2\x82\x31\x07\x82\x9a\xce\x6e\xd7\x03\x4c\xae\xb2\xf6\x57\xa0\x7b\x25\xb7\xd6\x02\x40\xa0\x20\x50\x26\xc2\xe3\x01\x81\x41\xd4\x79\xc0\x77\x87\xa1\x4e\x70\x26\x22\xf8\xe6\xdf\x70\x9b\x63\x6c\x6d\x3d\x0b\x5f\xd5\x4f\x55\x16\xdb\xad\x97\x03\x8e\x5c\x0e\xb3\x1f\x54\xdb\x12\x64\xd6\x00\xef\xc6",
        p,
        q,
        g,
        b"\x4d\x6e\x89\xb0\x22\xc2\x78\xf3\xbf\x89\x32\xe7\x06\xe4\x18\xec\xb2\x0c\x1b\xba\xb1\x3e\xa8\xc9\x0b\x6b\xd8\x43\x84\xf3\x8b\x31\x1e\x8f\xb2\xc4\xc0\xa9\x4b\xa7\xd3\xaf\xca\x1b\xa9\x42\x52\xa4\xc1\xac\x11\x87\x62\x2c\xd9\xc1\x6a\xa7\x3b\xb1\xb4\xa5\xcf\x55\xb5\xaa\x34\xbd\x93\x52\x6f\x18\x7b\xee\xb1\x17\x00\xe4\xaf\xb8\x8c\x81\x6e\xda\x50\xa5\x0e\x81\x86\x0c\x87\xfa\x66\xa1\xb6\x3f\x5f\xfe\xc3\xc3\xae\x39\xbd\xc0\x09\xd3\x8f\xa1\x3d\xa8\x63\xca\x5e\xc1\x34\xa7\xff\xcf\x5d\xc3\xca\x85\xcc\x34\xd6\x1c\x5d\xf8\xf9\xd9\xbd\xbe\x6a\x54\x10\x45\xb4\x5c\xb5\x12\xef\x64\xd1\xad\x3d\xb7\xb3\x7d\xba\x33\xc6\xe3\xc9\x61\x80\xcf\xb2\x6f\x48\xc6\x33\x73\xa0\xf0\x00\x3a\xe6\x58\x26\x79\xda\x48\x50\xad\x2a\x0b\x89\x9e\x0e\x8a\x18\x47\xdf\x07\xfe\xf3\xa4\x33\x0a\x72\xf8\xa8\x02\xc0\x6e\x8e\x95\x70\x7e\x0c\x7d\xc1\x91\x5f\x6e\x17\x31\xfe\x65\x0f\x1a\xe3\x52\xe7\x82\xd2\xdd\x77\xf5\x4e\x5d\xac\x52\x53\x9a\x10\xa2\x2b\xbc\x2e\xea\x31\xef\xb9\x44\x38\xa0\x30\xc4\xb2\x45\x1b\xbf\xf6\x90\x1b\x5f\xb3\x01\x6c\xd1\x62\xaf\x6b\xf0\xfb",
        b"\x5f\x38\x39\xeb\x66\x3f\x02\x6f\x79\x29\x12\xd1\xcb\x0b\x44\x8f\x5e\x2e\x59\x31\x39\x00\x1e\x83\x9f\x71\xc9\x42",
        b"\x6b\x07\xed\xb6\xa0\x34\xd0\x84\xa6\x1b\xf3\xc0\xa3\x6e\x7e\xe6\x91\x19\x48\xad\x8f\x6e\x50\xac\x68\x44\xb1\xf3",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xc1\xed\xd8\x61\x51\xaf\x66\xc6\x22\x3e\x41\x3f\x17\xe7\x34\xb2\xbc\x02\x4f\xf0\x66\x57\x8c\x55\x30\x8f\x13\x88\xa9\x1a\xb8\x72\x70\xcd\x25\xca\x2e\xfb\xc2\x86\x7e\xb7\x15\xeb\xed\x6d\x10\x01\x2b\x6f\x48\x08\xf2\xde\x19\x86\xff\x7f\x4c\x36\x9d\xaf\x46\xc8\x0a\x61\x87\x07\x88\x8a\xe3\xf8\x6e\x38\xe7\xf2\x5d\x6c\xaa\x50\x91\x04\xd4\x85\x1c\xbe\xef\xbb\x75\x69\x2a\xad\x49\x9a\x33\xaa\x35\xb1\x14\x09\x30\x0e\x49\x5f\xe0\x07\x52\x4b\x4a\xf2\xc2\x0d\x33\xf1\xc8\xc0\x45\x16\xb6\x97\x3a\xc1\xe0\x7d\xf3\xf1\x60\xdd",
        p,
        q,
        g,
        b"\x90\xdb\xbe\x47\x41\xa7\x6a\x5f\xf2\x22\xdd\xc8\x33\xc0\xe2\xdd\x44\x5a\xd0\x17\x26\xbb\xea\x25\xca\xc2\x47\xf9\xef\x9d\xa6\x43\x93\x27\x36\xdb\x07\xcd\x9a\xef\xfe\xb4\x51\x19\x35\x1e\x00\x33\x2d\x9d\xfc\x89\xf5\x90\x3a\x54\x1e\x74\xe2\xe9\x70\x9d\x0f\x85\x2a\xd6\x52\x40\xd0\x61\x59\xfe\x54\x43\x6d\xd8\x20\x1f\x8c\x56\x92\x6e\x8d\x23\xc2\xec\xad\xeb\x8c\xbc\x9a\xeb\xf1\x2d\x52\xbe\x64\x89\xe0\xac\xb0\xe7\x52\x6f\xba\x37\x54\xb7\xec\x16\x3d\xc7\xe2\xfa\x91\x93\x31\x91\x24\xf0\xcb\xb6\x1c\x2a\xb7\xab\x1a\x28\xc1\x4e\x7d\x58\x1d\xfb\x8d\xe2\x3f\x53\x36\x4d\x20\x41\x90\xa5\x8f\xcb\x9e\xa5\xb6\xf6\x1a\x79\x79\xb8\x6b\xb7\xa7\xa4\x26\x3a\x10\x66\xf0\x51\x6e\x58\x70\xde\x42\x3a\x7e\x3b\x90\x6d\x90\x31\x3d\x1f\xf9\x32\x24\x50\xf7\x2d\xdd\xa4\x73\x3a\xc7\x4f\xca\x5d\x4a\xd2\xbe\x22\xc2\x66\x7b\x92\x21\x20\x69\x44\x6b\x42\xa3\x91\x23\x3d\x85\x21\x6a\x88\xc2\x5b\x76\xc9\x47\xd8\xd5\x65\x91\x00\x3d\xf2\x53\x2f\xcd\x7b\x18\xf9\x23\xed\x48\x2d\x46\x4f\xb7\x6f\x2c\x85\x61\x78\x40\xd3\x70\xab\x99\xe3\x20\xe8\x8c\xf9\xef\x8d",
        b"\x83\x6d\x84\xd8\x62\x71\xe1\x64\x84\x66\xd1\x95\x5c\x2b\x60\xb2\xa0\x4c\xc0\x21\x40\x50\x83\x62\x63\x47\xae\xf9",
        b"\x63\xc7\xee\xb5\xe0\x6e\x81\xd8\x92\x33\x56\xf7\x99\x81\x0a\x26\xaf\x67\xc0\xfa\xa1\x8b\x39\x22\x58\xe4\xa9\xa0",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x2b\x5f\xb6\x13\x59\x8c\x02\x91\x6b\xf6\xb4\xb0\xfd\x7a\x6b\x54\x26\xac\x5b\x56\x95\x43\x92\xfb\xa3\x2d\xe0\x0b\xdf\x4b\x70\x95\x3b\xe1\x96\xad\x51\xff\x2c\x09\x7a\x81\xe6\xce\x1d\x17\xcf\x83\x7d\x24\x44\x75\x2b\xe9\x2b\xd4\xa9\xd1\xa8\xb4\x13\x27\x52\x7f\xf6\xbd\xc0\xe5\xc3\xe0\xcf\x46\xf7\xe3\x79\x66\xaa\xe1\x8a\x29\xce\x19\x81\xf2\x12\xd7\x14\xdd\x6c\x0c\xbb\x41\x0d\x3a\x5f\x3d\x00\x6b\xa9\xb5\x93\xda\x15\x0c\xe4\x22\xb5\xcc\x42\x0f\x3b\x56\x1b\xfd\xf1\x1d\xcb\x99\x10\x00\x57\x09\xee\xb1\x29\xe2\x06\x65",
        p,
        q,
        g,
        b"\x95\x94\x7f\xbc\x50\xd5\xa8\x02\x99\xc9\x0d\xd2\x7c\xf3\x91\x00\x91\x42\x0d\x8a\xf8\x49\x24\x0e\xbb\x54\x1a\x21\xb4\x9e\x52\x8b\x0f\x33\x17\xac\xc1\x04\x93\xd5\x0e\x6b\xce\x67\x6c\x43\x3c\x31\x14\x7f\x81\x28\x67\x89\xe6\xa4\x1f\x4b\x26\x03\xba\xc0\xf6\xe5\xee\x7a\xff\xdb\x44\xcc\xeb\x42\x86\x43\x58\x60\x7d\x45\xf4\x65\x5a\x70\x9d\x7d\x67\xf7\x16\xd7\x36\x7b\xb5\xea\xb3\x34\xf6\x1c\xef\x37\x20\xc0\x80\xca\xb1\x75\x12\x32\x9e\x6d\x99\x92\x5b\x47\xe4\x96\x0c\x85\x03\x1b\xfd\xdb\x13\xf0\xc6\x1a\xf8\x0e\xa4\x6b\x7b\x87\x02\xf8\xad\x34\x8d\x57\xd4\x81\xef\xe8\x21\x05\x4f\xc8\x3b\x52\x66\x78\x27\x56\xa4\x2d\xd4\x31\x88\x1e\xa6\xcf\xeb\x7f\x79\x00\xd8\xf7\x47\xaa\xc9\x97\x6b\xe8\x94\x59\x52\xaf\xb8\xa2\x74\xda\xd0\x34\x28\x08\x83\x10\xa2\x45\x6e\xc2\x54\xd1\xcc\xfb\x63\xee\xde\xa5\xd3\x74\xed\x8c\xc6\x37\xa7\xba\xab\xf8\xf4\x22\xe1\xa1\x2d\x5f\xf3\x16\xdf\xf8\xa0\x82\x06\x89\x31\x49\x0a\x47\x06\x50\x3d\x19\xf9\x35\x54\xf2\x52\x43\x75\x1d\xfe\x62\xcd\x87\xcb\x85\x6f\x64\x4f\xbb\x6f\xc4\x6f\xb9\xcf\x89\xaf\x5a\xea\x1a",
        b"\x7b\x45\x5f\xae\x10\x02\xfa\x87\xf3\x6c\xf6\xf3\x45\x71\x62\x25\xd4\xaa\x14\x07\x80\x2a\xf4\x08\x2b\xfb\xb1\x4a",
        b"\x23\x5d\x8b\xe4\xce\xb0\x17\x6f\x5d\x0c\x47\xc1\x19\x9a\xfc\x7e\x30\x41\xc7\xd7\x50\x8b\x9f\xed\xdc\xaa\x0d\x74",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xbd\x7d\x69\xbc\xc2\xe4\xf8\xa4\x2e\x62\x7f\xa2\x1c\x7f\xa9\xfd\xd3\xe5\x74\xb6\xdc\x5a\xd2\x02\x17\xe8\x0b\xcc\x99\x97\xb4\xc5\xef\xb3\x1c\x7b\x65\xdb\xe8\xa0\xa3\x94\xf0\xaf\x58\x03\x87\xb9\x91\x78\x88\x15\x2d\xc4\xf6\x3c\xe5\x2d\x3e\xc4\xb7\x23\xbf\xea\x81\x14\x82\x5f\x9f\x1e\x25\x9f\x67\xb5\xd1\x3b\xca\xa6\x6c\x97\xde\x72\x5f\xae\x4a\xd2\x47\xbb\x92\x24\x97\xeb\xed\x0f\x09\x2b\xba\xc1\x2f\x2c\xbd\x9b\x71\xb2\x29\x08\x73\x78\xe8\xbe\x06\x26\xb8\xd5\xe8\x95\x0b\x0a\x6e\x69\xe0\x51\x29\xf0\xd3\x84\x2d\x27",
        p,
        q,
        g,
        b"\x6f\xa6\xde\xdc\x84\xa1\x47\x9b\xe4\x39\x06\xf2\xf6\x8d\xf0\xe9\x32\x34\xca\x22\x30\xc8\x32\xdb\x07\x9d\x9c\xbd\x93\x42\xb2\xdf\x13\xde\x4b\xff\x10\xbd\xd8\x31\x31\x34\x53\xb3\x3b\x72\x5c\xd6\x16\xac\xf1\xfe\x2f\x79\x27\xea\x32\xd4\x6f\xf1\x0e\xf1\x15\x4e\x50\x3f\x71\x16\x5a\xde\xaf\xfd\xd5\x00\xa8\x3b\xf1\x00\x1e\xd3\x6c\xa6\x5b\xb6\x97\x4d\x03\x72\xcb\x0f\x21\x18\x27\x84\x66\xfe\x12\x86\xad\xff\x3c\x7e\xf7\x19\xc2\xa0\x2c\xff\x9e\xd9\x37\x4f\xbb\xe6\x05\x18\x14\xd2\x68\x48\xb7\xd9\x70\xfb\xec\xfb\xbf\xfe\xdf\x40\xa0\x30\x83\xfe\x33\xd3\x06\x78\x38\xac\xe2\x28\x54\xa8\xe8\x8b\xfc\xb0\x2e\xcd\x76\xc3\x78\xbb\x5c\x8b\xab\xd2\x2d\xfb\xe0\x90\x75\x3a\xbf\x9e\x97\xcb\x6b\xa7\x08\xce\x00\xff\xea\x5c\x55\x0b\x09\xf2\x49\x30\x69\x8d\xf1\x15\xc0\x20\xb1\x30\x1d\x57\x1a\x47\x0e\x5a\x8a\x6c\xcf\xc7\x4a\xd1\x89\x49\xa5\x7f\x61\x4f\xcb\x0f\x7e\x8b\xf7\x53\x0a\x73\x1b\xb6\x09\x1a\x73\x01\xaf\x42\x89\x9d\x9e\xe9\xe4\x5a\xa6\x2c\xa4\x90\x3e\x66\x73\x3e\x47\xd0\x1e\x26\xb2\x99\x74\x6d\xa7\x5c\x7a\x57\xdc\x00\xbc\xeb\x4d\x6c",
        b"\x16\xa2\xa4\x85\x78\xa0\xb5\xb5\x75\x53\xcd\x20\x00\x5b\x7e\x84\x00\xe1\x06\x1c\x4f\xef\x20\xd0\x33\xf7\x2f\x8a",
        b"\x6c\x34\xd1\x76\xe9\x5d\xd4\x92\x71\xee\x48\xa3\x80\x2e\xdf\x42\x38\x40\x10\x84\xbc\x39\x30\x20\x14\x05\x69\x3a",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x77\x66\xe1\xab\x76\x38\xbc\xda\x3e\x6f\xdb\xd4\xc8\x5b\x36\x61\xac\xb2\x76\x3d\x41\x13\x76\xb2\xee\xdb\x4b\x2c\x6b\xff\x5d\x8f\xa2\x0c\x0a\xe5\xb3\xcb\xed\x20\x79\x6a\x6d\x8b\x81\xa1\x09\x6d\xc3\x6a\x39\x82\x6a\x18\xff\xb8\x97\xd3\x6b\xfb\x16\x36\x3c\xca\x76\x32\xec\xb7\x1d\x2f\x99\x6c\xf7\xca\xc6\x66\x69\xbf\x4c\x83\x11\x4b\xd5\x3b\xe3\xbe\x33\x05\xef\xc9\x9d\x22\x76\x91\x88\xf8\x42\x89\xcb\x1d\x11\x50\x1f\x04\x0b\x85\xd1\x58\x90\xd2\x9a\xf2\xc8\xea\xe6\x14\xf7\x4b\xee\xee\xb5\xfc\x91\x5a\xfa\x43\x22\xc2",
        p,
        q,
        g,
        b"\x4c\x2b\x55\x90\x24\xf1\xb3\xff\x5c\x71\x67\x27\x0c\xd1\xf3\x3b\xbf\x0f\x40\xb9\xef\xa2\x5e\x13\x74\x41\xab\x46\x98\x15\x4e\x74\xda\x3c\xad\x34\x23\x6d\xa4\xbd\x1c\x57\xd7\x63\x8e\x42\x77\x27\x8b\x50\x8e\x85\xe3\xa9\x8d\x30\x38\x8a\xb8\x63\x8f\x55\x3e\x2a\x70\x00\x11\x92\x3e\x5d\x15\x4f\x8c\x14\x07\x45\x2d\xc4\xf8\x07\x70\xc9\xc3\x1c\x36\x8a\x21\xe4\x99\xd5\xdf\xb6\xf0\x5f\xd6\x77\x91\xe7\x61\xa4\x94\x20\x07\x10\xaf\x8c\x21\x88\x89\x2c\x2d\x1c\x31\x95\xbe\x4a\x0a\x1d\x67\x55\x1a\xd4\x66\xfe\xe8\x0d\x7e\xdc\x43\x53\x79\xa7\x2c\x3b\xff\xad\x27\x1d\xe3\x1a\xd2\xed\x10\x7d\x78\x4f\x40\xe2\x4c\x5a\x6e\x8d\x5a\xae\x8f\x24\x05\x96\x4f\xe3\xc2\x8c\xc3\x65\x2d\xc3\xc9\x52\x3b\x39\xd4\xb0\x83\xee\x65\xe9\xa0\x7c\xe8\x97\xa1\x7b\x02\xb3\x54\x76\x6f\x1b\x19\xc2\xb1\x22\x9a\xb4\x68\xb0\x14\x8c\xa8\xfe\x89\x48\x4b\x7b\x36\x00\x24\x21\x80\x86\xaf\x56\x40\x37\x07\xbe\xc6\x5c\x52\x28\x1c\xb8\xaa\x53\x46\xcb\x6f\x64\x81\x43\x0e\x8e\x05\x71\x46\xf3\x90\x60\x7c\x57\x2b\x5b\xd8\x42\x6b\x90\xef\x3a\x82\x7c\xb0\xd5\x8b\xd4\x38\xd1",
        b"\x09\xc6\x18\x78\xa9\x91\x71\x77\x05\x8e\x9d\xff\x27\x10\x6b\xdc\xa7\xd0\x6c\x50\x0e\x09\x09\x93\x06\x66\x8c\xbf",
        b"\x7b\x8b\x6c\x4c\x56\x15\x97\x6d\x7a\x73\x5a\xc3\xe1\x84\xcd\xe9\x61\x54\xff\xc8\x7b\x45\x89\x24\xd4\x60\x28\x95",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x84\x09\x52\x78\xf7\xf1\xd5\x78\xe7\x98\x39\x9a\xf0\xbc\x9f\x46\x95\xf9\x30\x2e\xa5\x97\x24\x79\xad\xf9\x0c\x95\xfc\x25\xd5\x9e\x57\x6d\x97\xb8\x9b\x73\xde\xc6\x29\xce\xf0\x5d\x61\x73\xb5\x5d\x01\x5a\x3f\xb1\xd8\x19\x1a\xe5\x40\xd5\x52\x40\x9b\x03\xa7\xa8\xdb\x51\x1b\xad\x09\x51\x89\x6d\xb9\x49\xfc\xc2\x88\x70\xf9\xd1\x73\x14\x73\x4c\xa6\xa3\x47\x26\x83\xd0\x2f\xdc\x8d\xef\xa7\xb9\xd3\x76\x2a\xe9\x35\x7c\xa2\xa6\xab\x62\x3b\x04\x63\x50\xfa\x21\x1d\x52\x13\x78\x71\x27\xd2\x71\x1c\xbd\x91\x40\x5a\xbb\xe5\x0d",
        p,
        q,
        g,
        b"\x4b\x52\xc5\x6f\xc6\x49\x22\xac\x04\xee\x7a\x80\xfc\x5c\x22\x40\x13\xe2\xff\xda\xa1\x67\x38\x12\x57\xe0\x0c\x59\x7b\x43\x36\x41\xce\xad\xbc\x9b\x16\x56\x8b\xbc\x9c\x6d\x31\xd0\x2c\x8e\x36\xdb\x2e\x39\x87\x52\x0c\xe8\x59\x08\x56\xbd\x4a\x84\x1b\x72\x5e\xc9\x5a\x46\x59\xa6\x1a\x00\x86\xf6\x6a\x6b\xfd\xbf\x1e\x4b\xf9\x2b\x44\x19\x28\xcf\x31\x9f\x92\x9a\x64\x28\xf5\xe3\xba\x7c\x89\x12\x3d\xbb\x0c\xac\xc1\x6b\xb0\xe2\xb8\x08\x54\xb0\xf6\x0d\xfa\xa9\x9f\x9c\x4c\xaa\x41\x2c\x44\x3a\x07\x3b\x7a\x51\x25\x91\x25\xf0\x12\xd9\x8f\x0f\x66\x99\xd7\x0a\xde\x66\xdf\x9c\x5e\x18\x18\x56\x72\xe0\xe2\x83\x0e\x05\x85\x41\x3d\xa2\x95\x6c\x89\xd2\x32\x0f\xaa\xc0\x3a\xaa\x83\xfe\x71\x8a\x0d\x6c\xf7\xfe\xb3\x8a\x19\x4e\x43\x62\xd7\xc8\x9e\x4a\x13\x96\x7e\x3a\x2d\x44\x93\xf4\xec\x09\xac\x2f\xc8\x9d\x56\xa5\x95\x47\x2e\x60\x33\x24\x48\x54\x8d\x91\xcd\x6a\xac\x84\xa2\xf9\xb4\xd7\xa8\x04\x62\xdc\x15\x47\x79\xbe\x5f\x9e\x1f\x70\x9b\x9d\x9a\x15\x62\x73\x03\x3f\xe6\xe4\x84\x2e\xc4\x75\x21\x96\x4d\x2e\x2f\xe2\x62\x28\x0f\xdd\xec\x64\x03\xe8",
        b"\x0c\x4d\x45\x27\x81\x5a\x94\xbc\x2d\x77\x06\x3e\xa6\x90\x49\xbe\x6a\x2b\x3b\x3a\x3a\x0b\xad\xd5\xe6\x2a\x8f\x9a",
        b"\x57\x87\xce\xd7\x08\x1f\xad\x3f\xe1\x9a\xb5\xb9\x02\x8e\x9e\x8d\xf1\x86\x39\xe4\x99\x1a\xb6\xe1\xe2\x43\x41\x6e",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x30\xee\xdc\x9d\x63\x0b\x63\x20\x82\xc1\x96\xb9\x69\xd2\x4f\x6e\xb9\xcf\x1b\x1e\x2c\x53\xd2\x44\xe8\xd8\xb5\x0a\x40\x98\x2a\xb5\x3c\x4d\x57\xff\x99\x5f\xa8\x45\x89\x08\xa7\x43\x89\x03\x82\xda\x65\x13\xcf\xe9\xc1\x99\x18\x24\x87\x36\x15\xa8\xa1\x63\x74\xa5\xe5\xdc\x2f\xab\x3f\x5c\xd2\x56\x52\xec\x8a\xa3\x93\x9f\x48\x84\xf7\x4a\xc7\x37\x98\x9b\x6a\xc2\xe4\x3f\x45\xb8\x85\x20\x6a\x31\xe7\x97\xfd\x85\x76\x35\x7e\x4b\x4b\xaa\x56\x62\x91\x81\x5d\xac\x2f\x54\x6f\x4a\xbf\x8b\xa1\xde\x11\x20\xfd\x80\x42\x84\xe9\x59",
        p,
        q,
        g,
        b"\x89\x20\xf6\xab\x95\xb1\xdc\x6b\x93\xe0\x8e\xad\x6b\x08\x14\x1c\xc2\xa8\xf1\xff\xbb\x71\xd5\xec\x59\x64\xf6\xb2\xc3\xd7\x2f\xf3\xad\xad\xe5\x22\x54\x37\x0f\x13\x09\x90\xb4\x34\x87\x77\x5c\x2f\xe0\x17\xa8\x20\x0d\x81\x19\x81\x8a\x15\xed\x7e\x56\x36\xbf\xbf\x31\x64\x04\x2f\x27\xbb\x1e\xa4\x18\x69\x8b\x67\x56\xf7\x5a\x8f\xda\xeb\xf0\xf6\xe5\x42\x3e\x46\x02\x87\xf4\xfd\xd2\xa0\xef\x30\x5e\x65\x87\x41\x37\x3d\x3b\xae\xcc\xe7\x90\x63\x96\x2f\x88\x33\x98\xc3\x14\xe3\x62\x30\xba\x8c\x57\x0e\x66\x7c\x30\xca\xc8\xfb\xaa\x4e\x70\x20\x2a\x91\x57\xd2\x27\x08\xca\x60\x54\x03\x06\x6d\x0f\xc8\x48\x45\xbc\xe9\xb8\xc3\xb4\x1e\xc3\x2f\x40\xc8\x45\xa5\x32\xfd\xff\x4d\xd1\x0c\xf6\x2a\x71\x41\x21\xea\x8a\x61\x88\x50\x06\x45\xaf\xa9\x31\x6f\xb3\xe1\x16\x28\xb1\x63\xd3\x5d\x8c\xfc\xc5\x52\x72\xb6\x50\xe8\x07\x2c\x23\x76\x45\x60\x01\x50\xbb\xb6\x6d\x39\x3c\x1c\x97\x34\x5d\x58\x20\xf1\x78\xdd\x40\x5b\x5d\x46\xfc\x4a\xc8\xa5\xf3\x92\x9e\x6b\x16\x27\x94\x40\x93\x17\x8a\x8d\x65\x10\x10\x59\xfb\xbb\xb7\x08\x11\x74\xf2\x30\x8b\x26\x53\xce",
        b"\x45\x21\x2d\x1c\x8c\x12\x80\x02\xfc\xb3\xce\x35\x58\x3f\xf8\xd0\x83\x63\x71\x1c\x15\x98\x30\x7d\x9e\xc6\xa1\x08",
        b"\x48\x58\x10\x56\x49\xdb\x59\x92\x76\x4d\xd3\x2b\x10\x2d\x9b\x9d\x2b\xc6\xaf\x64\xc6\xa8\x15\x95\x61\x1e\x3e\x20",
    )?;

    // [mod = L=2048, N=224, SHA-512]
    let p = b"\xbf\xeb\xd0\x00\xb2\xd6\xcd\x4a\xb3\x8e\xfb\xa3\x5d\xf3\x34\xdf\x72\x1d\x6c\x2f\x2b\x3d\x95\x66\x79\xcb\xad\x00\x9f\x3d\xfb\xd0\x02\x95\x2c\xc8\x99\xcc\x23\x56\xec\x87\x69\xbd\x3d\x1b\xa5\xa7\x30\x23\x72\x98\x88\xda\x92\xca\x48\xa5\xee\x94\xc9\x7f\x4f\x04\xa2\xe3\xac\xb4\xf3\x3a\x2f\x0f\xb3\x78\x3c\x31\xf2\xc7\x0f\xa7\xc7\x0f\x38\x21\x4a\x27\xda\xde\xc8\xb1\x2e\x67\x99\x6a\x9e\x85\xee\x3b\xb1\x48\x80\x31\x30\x14\x73\x92\xdc\x52\x53\xc0\x4d\x70\x63\x53\x5e\x6c\xd6\x46\xbf\xb1\x86\x98\x4e\x08\xb5\x8b\x74\xa7\xbe\x5b\x33\x3b\xf3\x2b\x0a\xbf\xd5\x66\x53\x60\xe9\xa9\x23\xa0\xc5\x28\xff\x1c\x62\xc7\x25\x34\x58\xf5\x67\x85\x28\x71\x9d\x43\x6e\x50\x14\x87\x41\xf4\x5d\xc7\xdd\x2c\x6c\xac\x71\xc5\x52\x31\xf1\x2a\x83\xfe\xfd\x2e\xd0\xa3\x3e\xde\x1b\x8a\x51\xf5\x66\xfc\xf7\x89\x06\x82\xcd\xc1\x93\x1d\xc2\x07\xc9\x2b\xf2\xef\x4e\x28\xab\x31\x66\x1e\xeb\x77\xf1\x60\x1e\xea\x94\x1c\x95\x91\xf0\x38\xd3\xf0\x0d\x91\x28\x57\xdb\x05\xe6\x4b\x2a\xd5\x69\x32\x00\x61\xc6\xf8\x63\xff\x33\x54\xd8\x42\xe7\xe7\xea\x71\x5a\xfe\xf8\xd1";
    let q = b"\xaa\x98\x6d\xf8\xa0\x64\x27\x8e\x93\x63\x31\x6a\x98\x30\xbc\xfa\x49\x06\x56\xfa\xa6\xd5\xda\xa8\x17\xd8\x79\x49";
    let g = b"\x81\x95\xad\x9a\x47\x8f\xd9\x85\x21\x6e\xe5\x83\x68\x36\x6d\x2e\xdd\x13\xc1\x2b\x3d\x62\x23\x91\x69\xfa\x04\x2d\x91\x15\x64\x08\xb4\x83\x12\x2f\x44\xed\x62\x36\xb8\x30\x8a\x6c\xdb\x52\xf9\xaf\x3d\xe8\x8e\xc8\x9e\x03\x9a\xfa\xd7\xda\x3a\xa6\x6c\x19\x76\x04\x9a\x8e\x0a\x7d\x18\xd5\x67\xba\xf9\x9f\xce\xfe\x31\x5c\xad\xa0\x15\x48\x38\x6b\x10\xb2\x5e\x52\xf5\x2e\xd7\x8e\xb4\xd2\x80\x82\xe5\xe1\xff\xee\x94\x80\xc4\xfe\x2c\xc4\xaa\xfd\x1e\xfc\x9d\x4f\xd2\xcc\x6d\x15\x59\x68\x93\x12\x71\xef\x15\xb3\x24\x0e\x7f\xb0\x43\xa8\x0c\x8f\x62\x8b\xef\xe0\x9d\x64\x50\x77\xc1\x02\x9d\x21\xe0\xac\x8b\xf0\xba\x9c\x27\x71\x4d\x1b\x58\x0e\xde\x59\x4a\xa0\x1b\x3b\x76\xf6\xe7\x45\xfc\x1e\xc0\x7d\xb3\x7e\x2f\xd7\xe9\x8c\x6c\x8c\x69\x15\x22\x8e\x42\x2c\x30\x9d\xe9\xf5\xdb\x16\x8f\x50\x24\x9d\x1b\xe1\xed\x32\x98\x09\x08\x08\xe2\xeb\xb8\x96\xbb\x79\xb8\xc4\xcb\xf9\x4d\x4c\x20\x64\xe3\x7e\x61\x2b\xa4\x44\x9d\x7a\xc2\x10\xed\xde\x21\x14\x16\xd6\x4b\x05\x1d\xd8\x04\x6a\xb0\x41\x73\x26\x65\x41\x1a\x7f\x15\x4d\x31\xb3\xe1\x1a\x51\xda\x7f\xc0";
    test(
        HashAlgorithm::SHA512,
        b"\xe9\xf5\x9c\x6a\x5c\xbe\x8f\x5b\x0c\xf7\x50\x08\xd0\x6a\x07\x6a\x67\x39\xbd\xdd\xb3\x9b\x82\x14\x3c\xd0\x39\x39\xaa\x47\x38\xa2\x87\xc2\xa6\xf3\x18\x29\xbb\xe1\x5f\x02\xcc\x2e\xe7\xd7\x12\x2d\xbd\x13\x28\x25\x97\x0d\xad\xdd\x8a\x4d\x85\x1d\xa8\x6e\x7e\xdc\x89\x40\xcb\x11\x88\x31\x92\x18\xb8\xe0\x24\x8a\x10\x3e\xae\x34\xbc\x68\xd8\x5f\x5a\x32\x83\x0d\x7e\x5d\xc7\x71\x8f\x74\xdb\x5e\x42\x24\xc0\xde\xbe\x1e\x84\x1e\x1e\xea\x1a\x88\xfe\xe0\xf8\x5d\x9f\xb0\x87\xcb\xce\xe5\x5f\x86\x03\x7a\x64\x6e\x38\x34\x6d\x2b",
        p,
        q,
        g,
        b"\xaf\x67\x21\xbf\x75\xde\xc6\xa1\xb7\x6a\xd3\x5c\xa3\x75\x0d\xef\x31\x11\x7c\x5b\x44\x1c\x15\xa3\x06\x83\x5a\x1d\xb7\x4c\x00\x3b\x86\xae\x90\x99\xeb\xfb\x74\x5b\x0a\xa9\xcb\x00\x0c\xf4\x3f\xb0\x21\x51\x3b\x8f\x19\x7b\xc8\x65\xb2\x2b\xf9\x49\xb4\x91\x80\x9a\xd7\x52\xff\xc1\xca\x8e\x54\xbe\xa1\x6d\xc7\xf5\x39\xe4\xc5\x5f\xb7\x0a\x77\x43\xdd\x28\xf2\x62\xf6\x0e\xf0\xf2\xfc\xaa\xc2\x9e\x80\x21\xa7\x93\x8c\x18\xff\xe0\x30\x75\xd0\xb7\xe0\xa2\xb4\xdc\xab\xe4\x6e\xd1\x95\x3d\x33\xe3\x7f\x11\x3a\xf5\x19\xab\x0b\xf0\xb6\x18\x6c\x12\xb5\xf6\x48\x84\x37\xf5\x19\x30\x96\xe2\xfd\x6a\x6a\x18\x35\x60\x47\x94\xc6\x6b\x42\xae\x52\x65\xc1\xcf\x1c\xb5\x3a\xe8\x49\x97\x97\x5e\x03\x18\xa9\x3c\xe4\x1e\x39\x02\xe4\xef\x54\xde\x3c\x56\x55\x5b\xd1\x94\x91\xac\xd5\x3f\x3e\x57\x46\x4e\x1f\x46\x03\x89\xdb\xc5\xfa\x80\x64\x8f\xa5\xa5\xa0\xf2\x95\x6e\x9e\xc3\xb8\xdc\x44\x1b\x53\x5c\x64\x1c\x36\x2e\xed\x77\x0d\xa8\x28\x64\x9b\xfd\x14\x64\x72\xb0\xf4\x6a\x4c\x06\x4e\x45\x9f\x88\xbf\xf9\x0d\xed\xe7\xec\x56\x17\x7a\x9a\x71\xd1\x67\x94\x87\x12",
        b"\x9d\xa9\x96\x65\x00\xde\x9d\x3b\x6b\x7f\x44\x1c\xa5\x50\x23\x3f\xc4\x50\x94\x4b\xc5\x07\xe0\x1c\xd4\xac\xb0\x30",
        b"\x2d\x72\xf1\xf6\x68\x1e\x86\x7f\x7d\x8b\xea\xeb\xeb\xa4\xbc\x5b\x23\x28\x76\x04\xa6\x4c\xfe\xe1\xc1\x64\x59\x5a",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x97\x1d\x16\xd1\x11\xc9\x6d\xe0\xf7\x09\x8b\x25\x6a\xf2\x13\xf4\x47\x5a\xef\x31\x00\x7e\x12\xe2\x97\x4c\x5f\x64\xb2\xf3\x35\xe0\x18\x3c\x19\x6c\x33\xd5\x0f\x64\x45\xc5\xf6\x14\x64\x95\x49\x77\x0b\x18\x74\xdd\x07\x56\xa9\xa8\xe3\x99\x71\xdf\xec\xc3\xf2\x67\xeb\xcc\x1f\x53\x01\x70\x3f\x88\x74\x3b\x0f\x37\x64\x82\xcf\xc0\x6d\x59\x48\xbd\x79\x26\xd9\x6e\xc4\xd7\x31\xa4\x4b\x0c\x0e\xee\x5e\x85\xda\x26\x68\x72\x65\xde\x5a\x66\xcb\x1a\x73\xa7\xe4\xf3\x23\x6f\x60\x64\x7b\xee\x5c\x16\x33\x40\xe1\x95\x05\x57\x7c\xf6",
        p,
        q,
        g,
        b"\x29\x05\x17\x29\x7e\x42\x49\xfc\x32\x12\xba\xd6\x72\x69\xe0\x32\x81\x8d\x76\x0b\x0e\xe0\x52\x5d\xc5\xa1\x7c\x97\x11\x6e\xe2\x9e\xb3\xb4\x50\xb4\x1d\x15\xce\xa4\x05\xd5\xe9\x83\xa8\x55\x81\x84\x06\x7f\x42\x4a\xcc\x49\x86\x76\x41\x5e\x17\x50\x6a\x35\x1c\x12\x4b\x54\x04\xf1\xd1\x71\x53\x27\x26\x19\xdf\x71\x3c\xe3\x4d\x03\xf1\xf9\xee\x28\x59\x2f\x22\xf8\x29\xa3\x19\x93\xb1\x06\xc7\x85\xfa\x6d\xbe\x57\xd0\x04\x9c\x81\x5d\xb5\xee\x2d\xfe\x94\x8d\xde\xdd\x1a\x5e\x2c\xd2\x34\x6c\xf2\xf6\x6f\x04\xfb\xad\x61\x9c\xd9\x83\xa1\xb0\x69\xb4\x71\xef\x9a\xdb\x4d\xf6\xce\xae\xa2\x3d\x09\xf0\xa5\x48\xc3\xc7\x20\x96\x34\xc8\xa0\x5e\x58\x97\x44\x59\x06\xde\xa0\x8a\x52\xe4\x07\x4b\xe2\x2d\x84\x85\xf2\x0e\xaa\xea\xdb\xaa\xb3\x97\x19\x9b\x06\x7a\xa8\x60\x05\x69\x91\xee\x08\x84\x80\xb4\x92\x12\x67\xa6\x98\xa8\xf7\xa0\x37\x77\xf5\x6b\xac\x84\xe5\x09\x03\xe8\x8d\x07\x26\x1f\x24\xd0\xa4\xf3\x17\x12\x8e\x01\xfe\x8a\x92\x24\xf1\x22\x93\x94\x9c\xb6\xc3\xf0\x95\xaf\xd1\x9a\xec\xb1\x6b\x20\x9a\x99\x48\x7d\xcc\x2a\x1b\x83\xc4\x9d\x75\xe3\x51",
        b"\x1f\x44\xf6\xea\xc2\x18\x23\x6a\x1d\x99\xcf\x76\x25\xab\xcf\x5c\x96\x4b\x0a\x0c\x5d\x88\xb8\xd0\x5d\x74\xa3\xc0",
        b"\x71\x01\x5c\xbe\x86\x22\xd2\xa3\x4f\xbb\x5e\x7c\xca\x8c\x59\xe8\x28\xad\xee\x71\xf5\x05\x24\x48\x2d\x9e\x79\x04",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x08\xea\x09\xfa\x5e\xfd\xe2\x15\xbd\x8b\x3c\x4d\x6a\x9c\x90\xee\x93\x87\xff\xb7\xbd\x65\xbe\xcd\xb8\x8b\x40\x13\x2c\x63\x84\x10\x6a\xa6\x19\xb7\xc6\x6c\xa9\x20\x34\xd2\x84\x60\x85\x93\x86\x4c\xe6\xb9\x28\x77\x11\x2a\xa1\x39\x24\x0c\xb4\x4b\x38\x8f\xe6\x8a\x8f\xe0\x50\x1c\xa5\x84\xf6\xa2\xde\x27\xc0\xfb\x65\x8e\x72\xbb\x13\xfd\xdb\x8d\x03\x9a\x6b\xf8\x5d\x63\xa6\xc0\x73\xb2\x66\x80\x13\xce\x8f\xe5\x89\xa0\x15\x0e\x46\xd5\xb1\xd9\xb0\xcb\xb5\xa1\x4c\x10\x0a\xe4\xb2\x0d\x6c\xe8\x1a\x98\x7a\x50\xa9\x49\xf4\x34",
        p,
        q,
        g,
        b"\xb3\xe2\xb7\xe0\x64\x17\x21\xd6\x96\x16\x67\x95\x96\xcc\x75\x09\x1f\xad\xe2\xda\x05\x58\xe3\x10\xb8\xd1\x4d\xb0\xf4\x68\x6f\x1f\xed\x48\xd0\xfb\x7f\x0b\x3b\x27\xbf\x6e\x19\x81\xea\xfa\x77\x37\xa3\xe6\x51\x82\x8d\x1f\xcb\xf8\x83\x87\xd0\x6f\x78\x40\x4a\x7a\xfa\xea\xaf\x8f\xae\x18\x93\xbe\xa3\xa0\x9a\x11\x88\x93\x93\x7a\xe2\xa8\xfd\xef\x33\x20\x94\x2a\x15\x84\x63\xde\x4f\xdd\xc1\x19\x87\xf2\x3f\xee\x96\x33\xe0\x6a\xc2\x39\xc0\x66\x10\xbc\x45\x31\x9a\xba\xfe\x51\x7c\xe4\xae\xae\x62\x47\xea\x78\x9d\x7d\xa6\x0d\x3e\xed\xdf\xdc\x4b\x23\x2b\x4d\x7a\x06\x9b\xcc\x0e\xac\x7b\x99\xfc\x08\x8f\xb7\xec\x19\x46\x03\x4a\x98\xd7\xe6\x9c\xab\x0c\xb2\xb0\x6b\x3d\x9d\xea\xcd\x1b\x43\x3e\xbe\x94\xf5\x47\xa3\x22\x89\x5c\xca\x9b\x0e\xd3\x19\xb1\xd4\x58\xc3\xbf\xb2\x60\xbe\xb6\x41\xa5\x34\x5d\xbe\x3d\x01\xce\x80\x0e\xc2\xc6\xbd\x43\x0c\xe3\xe3\xf5\xf7\x8f\xca\xbf\x91\xa2\x96\x58\x66\x1c\x57\x3b\x9f\x6f\xd3\x81\x2e\x56\x0d\x88\x8b\x6c\xdf\x3d\x57\x67\x3c\x16\x30\xe0\x0c\xa8\x41\xee\x99\x49\x58\xb2\x50\xda\xfb\xc3\xe8\x3b\xcb\x8b\xe5",
        b"\x6c\x03\x63\x7d\x25\x3a\x8d\xcd\x09\x07\xd6\xde\x93\x92\x6b\xdb\x3e\x1e\xa3\x13\x5a\x70\x9d\xa2\x30\x9a\x8d\xa6",
        b"\x23\x6e\x51\x63\xf2\xc2\xeb\xe0\xec\xcd\xbd\x33\x51\xe4\x28\x55\x31\xa4\xf5\x3e\x45\x28\x4e\x41\xdb\x37\xe2\x66",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x95\x7c\xef\x16\x3b\x16\xd8\x07\x3d\x5d\x3f\xe1\x58\xfa\x0c\x73\x38\xbd\x10\x7c\x6a\x65\x3c\xb0\xf1\x1e\xbe\x41\x40\x26\x07\xb8\x22\xab\xe3\x0e\x36\xca\x9e\xe4\xc9\xde\x00\xcf\x72\xdb\x97\xf5\x7d\x78\xf3\xdb\x49\xa8\xe1\x09\x32\x85\x56\x3c\x68\xb0\xf4\xe1\x24\x83\x0b\x9f\xeb\xfa\x3e\x75\xce\x2e\xa5\x9c\xba\x2c\xc6\xd7\x1e\x90\x8b\x5e\x6d\x8f\x46\x39\x54\x92\x2b\x82\xbb\x55\xa6\x9f\xb2\xff\x14\x3f\xfc\xae\x6b\x56\x56\x14\x3c\x8b\x6c\xc2\x4f\x57\xb1\x7c\xfb\x02\x0f\x6e\x15\xbd\xc5\xf2\x54\x36\xd0\x7b\x7f\x8a",
        p,
        q,
        g,
        b"\x3f\xcb\x8e\x44\xd6\x88\x0f\x9e\xeb\xae\xdf\xb7\x59\x94\x60\x5c\x9e\xc0\x01\xf0\x59\x5a\xeb\x5f\x2b\xca\xf6\xb3\x98\x7b\xc2\x8a\x7c\xa9\x05\xe1\xfe\xd7\xe3\xc7\x15\x40\x1b\x5c\x60\x8d\x12\x07\x69\x38\xa1\x80\x13\x47\x3d\x8a\x43\x32\x77\xfd\x9c\xe5\xa5\xca\xe0\x38\x28\x1e\x76\x8f\xf9\x09\xae\xbe\x4d\x25\x7d\xcb\x5d\x93\x48\x80\x22\xd0\x7d\x4c\x28\x62\xaf\xb2\xbf\x8a\x2b\x1e\x97\x4a\x8e\x7b\x6e\x17\x6b\x1b\x0b\x7a\xd6\xf6\x3b\xda\x1b\x71\x42\xe4\x6f\x50\x4d\xcc\xcc\xa7\xd1\xe2\xe7\x66\x27\x58\xf7\x60\xe6\x24\xe5\x95\x28\xc5\xa0\xc9\x56\x3e\xd5\x17\xc6\x91\xfb\xa2\xab\xf6\x68\x99\x24\x11\x78\x22\x3b\xa2\x00\x13\xed\x0a\xb2\x1f\x91\xf3\xe6\xbe\xf7\x55\xc8\x10\x0c\x51\xee\x94\x7b\x7a\x9b\xa3\x85\x70\xf8\x80\xb5\xe4\x2f\x24\xb7\x2d\x53\x21\x13\x2e\x03\x1b\x98\x5a\x0d\xb8\x25\xbf\x3b\xb0\x0a\x77\x71\xa0\x30\x07\x38\x7e\x03\xce\x02\x0f\xc3\x58\xe6\x5e\xd3\xde\x8d\x84\x7f\x5b\xe6\x07\x20\x91\x7c\x06\x16\xa4\x50\xaa\x34\x1a\xe0\x0a\xbe\x0a\x80\x9c\x38\xe9\x73\x14\xf3\x03\xfe\x9b\x0c\x6c\xde\x44\x6d\x02\x17\xcc\x4e\xab",
        b"\x15\x03\x62\xda\x79\x27\x01\x69\x4e\x23\xf0\xb0\xa9\xb7\x03\x54\x37\xcc\x8f\x4f\xaa\x45\xc6\xdf\x8f\x79\x82\xfb",
        b"\x6d\xf4\x32\x1c\x61\x73\x87\x43\xa9\xfe\x78\xec\x76\xb4\x95\x26\x92\xaa\xa3\x72\xd1\xc8\x53\x0f\xba\x0f\xcd\xec",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x20\x4d\x9c\xde\x24\xa2\xf0\xde\x02\xaf\xf0\x20\xf6\x36\x3f\xd6\x8f\x70\x42\x0d\xc1\xa9\xb5\x13\x82\x16\x20\x13\x63\xf8\x32\xda\x0a\xa8\x01\x86\x5a\x75\xa2\x43\x42\x7d\x9d\x6c\x78\xdc\x5e\x60\x41\xb2\x7d\x03\x36\x60\xe1\xe4\x05\xab\xe1\xbe\x27\xc9\x09\x99\x4b\xd6\xfb\x57\x18\x0c\x3d\x6b\x49\x8c\xe8\x79\x3b\xee\x8e\xcf\x51\xe0\x6b\x96\x41\x1d\x00\x99\x62\x09\xf4\x4a\x38\x09\x26\xc7\xb1\x95\xe8\x4e\x78\xf0\x1f\xe0\x2e\x0b\xc7\x03\x2c\xa4\x62\xa5\x18\x26\x83\x47\x52\x22\xf9\xdd\x8f\x3a\xde\x1a\xb8\xfe\xa3\x18",
        p,
        q,
        g,
        b"\x99\xb8\xfc\x6e\x64\xcc\xe2\x62\xed\x74\x1c\x30\xcd\x58\x69\x86\xaa\x2e\x8f\x63\x71\xb8\x48\xa2\x61\x7c\x61\x98\x97\xde\x23\x72\x6b\xb5\x45\x36\xec\xe4\xb4\x60\xcc\x7f\x1f\x39\xe0\xc1\x84\xeb\x19\x29\x1e\x93\x0d\xc9\x14\x0e\x4b\x77\x35\x54\x1e\xee\xf8\xca\x8e\xbc\x81\x79\x0f\xed\x37\xa5\xf0\x8e\x9d\xa9\xab\xc6\x6a\x3a\x2e\x90\x99\x02\xa4\x21\x21\x06\x92\x7d\x08\xab\xec\x01\xf2\x7c\x60\x56\xb6\xe0\x38\x11\x50\xbd\x74\x2d\x40\x9f\x68\x10\xfa\x58\x18\xff\xcb\x3f\x18\x2a\xdf\x89\x4b\xa7\xf8\x06\x78\xce\x88\x3c\x10\x89\xa6\xae\x71\xdb\x3a\x11\x5c\x38\x6d\xd9\x15\x3f\x41\x91\xfc\x36\x54\x61\xac\x86\x83\x8e\xcf\x2f\x3f\x81\xcc\xf2\x83\x29\x7a\x6f\xbc\x64\x4f\x52\xaa\xe6\x64\x90\x1a\xe3\x0c\x96\xfe\x4d\xf9\x30\xcf\x1a\x41\x75\x72\x41\xcc\x4d\x9a\xdf\xcc\xdd\x9a\x6b\xd5\x00\x4b\x05\x75\x74\x43\x59\x88\x56\x40\x0d\xd7\x71\xdc\x08\x90\x95\xc7\xdc\xde\x82\xf7\x21\xf9\x86\xaf\x63\x66\x38\xee\xa2\xc7\x17\x70\x85\x6c\x2b\xa8\x03\x15\xe8\x69\x61\x42\xa1\x1e\x51\xeb\xd7\x55\x9e\x9d\xa6\xa0\x0b\xe3\xf9\xf3\x8c\x61\x4e\xf2\x07",
        b"\x9c\x02\x33\x31\x75\x1c\x79\xd5\xda\x35\x5b\xb5\x8e\x2b\xbe\x2e\x97\x3e\x3e\x4b\x4f\x52\x74\x3c\xe1\xf1\xee\xc2",
        b"\x96\xad\x0e\x8c\xa9\x06\x27\xfb\x7a\xc4\x54\x0c\x9b\x58\xa0\x16\xee\x6c\x4e\x0a\x6f\x0a\xa1\xe7\xde\xf8\x1a\x51",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x1e\x4e\x58\xaf\xb3\x4c\x5d\x6f\x64\x5a\x82\x64\x5b\xe3\x58\xa2\xe2\x28\xcc\x7b\x9c\x23\xdd\x7f\x3a\xa7\x95\x95\x81\x4d\x05\x4b\x92\x3b\x9c\xbc\x6c\x9e\x6c\x6f\x94\x84\x8c\x1a\x4d\x21\x56\x79\x02\x3a\x96\x97\x6a\x44\xe9\xb5\x91\x36\x24\x1f\xdf\x26\xf8\xf7\x1f\xe5\xa9\xbf\x36\x6e\x49\x12\xb5\x93\x1e\x1c\x8f\x63\xc3\x7f\xae\x2b\xf1\xd5\x5b\xa3\x94\x3a\x65\x0b\xb4\x63\xcd\xed\x9a\x7b\x06\x2a\xe5\x5a\xa5\x7d\x9c\x5c\xee\xd3\x23\xfd\x9a\x75\x55\xe4\x8b\x83\x4d\x3a\xd4\x44\x1c\x35\xd9\xe0\x7c\x7c\x6e\x4d\x5d\x0f",
        p,
        q,
        g,
        b"\xb4\xde\xa0\xd5\xb6\x71\xcc\x81\x53\x82\xd0\xec\x6d\xce\x66\x1c\x30\xff\x93\x71\x9d\xc7\xf5\x6e\x7e\x61\xdf\x6e\xb6\xa3\x20\x7a\x05\x61\x79\x38\xc8\x74\xbc\x3a\xb0\x93\xbc\xdb\xbc\x98\x3a\x4b\x0b\x58\x7d\x60\xfd\xeb\x7b\x87\xf7\xb0\xbe\x4a\x65\x68\x83\xf5\x44\x3c\xa7\x86\x45\x41\xcc\xbf\xe0\xd0\x83\x56\x36\xef\x08\xa9\x36\xb2\x32\x1a\x51\x50\x3b\xe1\xee\xc5\xf7\xbc\xcd\x0c\x73\xc9\xcd\x52\x39\x7c\xc2\x14\x31\x8b\x30\xe8\xbe\x1e\xab\x57\x20\x0a\x4d\x4d\xf7\x8a\xf9\x91\xbd\xe1\x83\xe0\x16\x4e\x69\x4d\x83\x08\xb7\xd2\x0d\x06\x7b\xfc\xab\xdc\xb5\x0f\x7a\x2c\x19\x0c\x66\xce\x3d\xd0\xe1\x89\x60\x93\x9c\xb5\x7f\xc3\xa2\xe5\xa6\x04\xf3\xd9\xbd\x6f\xa4\x40\xd5\x4e\x9c\xc0\x38\x39\x58\xa0\xd6\xaa\x2a\xb6\x70\x97\x0f\x9b\x2c\xaf\x86\x6e\xe5\x07\x06\x73\x43\xf7\x51\x3e\x0a\x98\x1f\x3a\x34\x4f\x2f\x75\x3a\xf4\x4f\xda\x26\xd6\x61\x79\x60\x32\xbd\xa0\xf6\xcc\x30\xa9\xa7\x89\xdb\x8d\x3d\x54\x6f\x02\xf8\x98\x11\x68\x05\x18\x0c\x6f\x0d\x2f\x53\x88\xab\x51\x10\xa5\x21\x07\x7d\x88\xd2\x14\xfb\xb3\x2e\xed\x26\x64\x40\x6c\xde\x9b",
        b"\x04\x34\xef\x1c\x12\x72\x07\xd0\xc8\x84\x70\x1e\x75\xd8\x01\x72\x5c\x45\x1c\xe6\x7d\x2e\x71\x53\x46\x38\xb2\x31",
        b"\x0c\x62\x5e\x4a\x33\x4d\xb0\x78\x25\xa4\x6b\x55\xda\x9c\x2e\x8a\x5f\x60\x0a\x36\xb7\x16\x06\x83\x40\x97\xe7\x77",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x5a\x47\x0a\x38\xb2\xeb\xbe\xad\x08\xe0\x10\xef\xef\x74\x61\xf6\xf8\x59\x25\x7d\x91\xa6\x1e\x2f\x0b\xa8\x09\xe2\x8c\x0e\xa3\xd4\x10\xe4\xf4\x14\x77\xa3\x98\xd5\x93\xdf\x58\x03\x9c\x43\x36\x26\x0e\xa7\xd8\xe9\x8c\x9d\x7d\xaa\xd0\xc3\x1e\xcd\x15\x67\xc7\xdb\x73\x01\x79\xe2\xa9\xa6\x20\x07\xbd\x56\xf9\xd9\xda\x48\xde\xaa\x65\x7a\xc9\x22\x93\xe5\xbf\xaf\xbd\xeb\xad\x1a\xfe\x25\xc4\x1e\x1a\xa0\x9d\xb6\x1f\xcc\x19\x19\x71\xc3\x75\x49\x15\x5b\x3e\x67\x95\x69\x13\xaa\xe3\xa5\xf6\x24\x5c\xfc\xb9\xaa\xd5\xdc\x1e\x15",
        p,
        q,
        g,
        b"\x06\xa2\x0d\x55\x71\x29\x6e\xeb\x87\xe7\x9e\xb2\x74\x03\x6d\x81\x9e\x86\x23\xb1\x5d\xe4\x4c\x26\x97\xda\xde\xca\xb2\x99\x6f\x51\xa7\x5a\xa0\x88\x49\x0e\x68\x3f\x34\xd5\xe0\xe7\x1d\x9f\xb8\x73\x4b\xcf\xb7\x1e\x9d\x19\xcb\xda\x3c\xac\xa5\xce\xc4\x17\xfa\x37\xa0\x61\x42\xbf\xc0\x68\x2d\xe5\x6f\x0d\xce\x6e\x82\x6e\xe9\xf3\x0d\x01\x27\x98\x59\xd3\xff\xbd\x44\x33\xbf\x4a\x10\x57\xba\x0a\xd7\x50\x60\xd4\x1f\x96\x8f\x6d\xa8\x22\xc3\x3c\xbd\xa9\xf7\x72\xc2\xb7\x7b\xc1\xb2\x93\x05\xcb\x69\x71\x82\xc0\xd3\x9b\x13\x28\x68\x93\x2c\x64\x01\x6b\xc9\x07\x1b\x30\x92\x0e\xb3\x85\xc5\xae\x41\xc5\xd4\xf6\x31\xbf\x5f\x54\xb1\xeb\x4b\x37\x3b\xb3\xe0\xbf\x6e\x44\x8a\xd8\xc9\x88\xfe\xa1\x6e\x64\x37\x90\x30\x7b\x8b\x85\xf0\x09\xfb\x67\x31\x72\x17\xd9\x14\x8c\x6c\xd7\xa4\x61\x36\xee\xce\x19\x50\xa1\x19\xe5\xa4\x16\xa1\x97\xe0\x0d\x0e\x92\x9b\x04\xa5\xbb\xf6\xc9\x88\xd8\x59\x5a\x0b\x2a\x5c\xa7\x19\x26\xba\x35\x1a\x5f\x76\x74\xaf\x41\x83\xb5\xa6\x89\x79\xbe\xdd\x64\x91\x29\x5b\x0f\x17\x2e\x73\x73\xec\xa7\xe6\x2d\x78\xd7\x44\xfd\xcc\xec",
        b"\x74\xdd\xdf\xa3\x5b\x25\xd0\xc0\xb2\x85\xa5\xd2\x17\x19\xee\x39\xd6\xe3\xf4\x43\x44\x5c\xeb\x90\x55\x6b\x01\x86",
        b"\x47\x48\x65\xd3\xef\x07\xf5\xdf\x49\xe0\xa6\xeb\xfb\x5a\xb5\xc2\xed\xe4\x7c\x4c\x63\x14\xbe\x4c\xcf\x45\x5e\x21",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x08\x49\xd6\x7e\xad\x3e\x8c\x44\xad\x3b\x2f\x94\x9b\xe1\xcd\x9f\x9a\x4b\xf8\xb5\x78\x5b\xd0\x0c\xa6\x60\x38\xe9\xa8\xb9\x37\x27\xa6\x52\xa4\x15\xc1\xd8\xa1\xec\xfc\xad\x77\x78\x2d\x87\xd9\x12\x62\x3c\x2f\xef\x45\xb2\x08\x3e\xc0\xf7\x9a\x26\x4e\xf7\xc5\xbf\xb7\x6f\xde\x5b\x22\xb9\x84\x53\x92\xe7\x59\xa1\xec\x05\xfa\x63\x87\xcc\xd2\x94\x3e\xf1\x27\x7c\x2e\x06\x03\x37\xf8\x2a\xa5\x62\xce\xe5\xbd\x7c\x15\x82\x58\xf2\xe7\x79\xd5\x1e\x47\xe0\x00\xa7\xb0\x70\x60\x77\x49\x09\x76\xa0\x77\x63\xe2\xef\xb2\x75\xb5\xbf",
        p,
        q,
        g,
        b"\xb1\xc6\x14\x42\xd8\xae\xda\xe0\xa0\x4d\xae\xf7\xb6\xf8\xa4\x9c\x6d\x07\xbd\x95\x8e\x8e\xc5\x61\x90\x6d\xdf\x31\xf3\xb4\xff\xd4\x81\xda\x54\x43\xfe\x87\x88\x05\x6c\x4e\xa7\xb5\xdf\xa2\xce\xe6\x47\x4e\x3f\xdc\x83\xfc\x04\x3a\x2b\xba\x33\x3d\x50\x3a\x2a\x93\x88\x65\xec\x3f\x11\x86\x40\xe8\x45\x7c\x7d\x97\x4e\x2a\x65\x65\x9c\xef\x5b\x7a\xe4\xf4\x9a\x05\x4d\x94\xae\x5e\x2e\xb6\x34\x5f\x5b\xda\xf9\x21\x48\xbe\xec\xc1\x09\xc5\x50\x31\xfc\xcd\x90\xce\xf8\x82\x13\xb6\x9d\xdb\x75\x4b\x40\xca\x8d\x8f\x0a\x4b\xfc\x81\xa2\x87\x63\x7a\x38\xc2\x18\x07\xf7\x27\xa6\x70\x25\xff\x67\xb7\xfc\xc5\x44\x18\xad\xad\x40\x8a\x5c\x7d\x1c\xe0\x5a\x1d\xe7\xe3\x09\x88\xd5\x60\xe7\x79\xfd\xea\x1b\x78\x75\x33\x14\xb0\xb8\x0f\xda\xcb\x62\x46\xfa\xa4\xb4\xc4\xee\x8a\xcc\x5a\xe2\x4b\x82\x31\x20\x40\x13\x4c\xd8\xcc\x2f\xd4\xfc\xb1\x91\xfe\x43\xf6\x4d\x14\x06\x24\xa8\xc6\xc2\xac\x5f\xa4\xbf\xdb\xa5\xd6\x25\xd7\xd2\x1e\x3c\x3f\x6a\xcd\x8a\x15\x3a\x04\xfb\x22\xf8\xd3\xb2\x44\xae\x8c\x6a\x1d\xd0\xe6\xe3\xb2\xf7\x3c\x06\x4f\xfa\xbf\xad\x6c\xc4\x61",
        b"\x2a\xeb\x7f\xce\x1b\x77\x64\xd3\x2c\xfb\x7d\x85\x25\x4c\xee\xd9\xf3\xa6\x33\x7e\xe8\xda\xb4\x2c\x8a\xb7\xa4\x15",
        b"\x17\xcc\xe1\x3b\xcb\x91\x7c\xdb\xef\xe0\xc5\x66\x31\x8f\xc9\x74\x20\x4b\x70\x0c\x5c\xdd\xc5\xb2\xb4\x99\xa7\x8e",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xe7\x46\x39\xf2\xba\xd4\x2f\xd6\x39\x3f\x9b\x35\x0d\x6e\x19\xcd\x4c\x1c\xe0\xf4\x1e\x8c\x90\x26\x84\xef\x6f\x86\x79\x0f\xfc\x83\x11\xac\xd9\xb5\x7d\x65\x21\xe8\x03\x39\xb3\x24\x3f\x6e\xc6\xb0\x1a\x06\xea\x89\x9f\xd7\x5d\xa9\x1e\x10\x80\xfd\xf0\x61\x29\xdd\x85\x1a\x89\x5d\x74\xb1\xef\xb9\x83\x72\x89\xc1\x1d\x68\xe1\x30\x8c\x47\xbb\x8c\x59\xd5\xeb\x89\x5d\xb5\x3b\xba\x29\x10\x2a\x5b\x48\xb1\xe7\x5c\x73\x38\x7f\xf2\x2e\x6c\x04\x61\x19\x6a\x7d\x48\x61\x5f\xfd\xb9\xc8\xff\x4e\xc6\x58\x7b\x4f\x68\xd2\x60\xad\x86",
        p,
        q,
        g,
        b"\x9e\x1b\x77\x24\x3a\xba\x08\x86\xf9\xba\xec\xa6\xc1\x1b\xd2\xc5\xc5\x55\x47\xcc\x50\x2e\x73\x1d\x9c\x47\x25\xda\x87\x77\xab\x60\x50\xe3\x39\x9e\x25\x57\x77\x04\xcf\xc6\x61\x63\xf6\xdf\x8d\x74\x91\x42\xa7\xe9\x74\xe4\x9b\x73\x15\xab\x7c\x8b\x85\xad\x5d\x5c\xb2\x71\xcf\x20\x7e\xb7\x2e\x1c\x34\x76\xb0\xd8\x63\x72\x1c\x96\x7b\xe1\x5e\xcb\xfb\xf0\x6e\xad\xc2\x7d\xe3\x38\xea\xa3\xca\xc1\xdd\xe6\x42\xd5\x2a\xa5\x35\x91\x98\xd8\x90\x9d\x23\xd8\x7d\x82\x70\x90\xa8\xad\xa7\xb7\xa5\x55\x36\x42\xd5\x86\x60\x3e\xa2\x46\x4d\xab\xd2\xef\x5e\x18\xdb\x3a\x62\x3b\xe6\x5b\xe7\xb5\xa4\x69\x89\x0f\x9d\xde\x54\xa2\x7c\xa7\x23\xb4\xe0\x5d\x56\xb7\x18\x1b\x28\xd5\xc1\xf6\x54\x15\x68\x8e\xe4\x1d\x53\x37\xa9\x95\x2d\x92\xed\xe4\xd1\x92\xb9\x09\x16\x39\xca\xaa\x60\x33\xe4\x74\x94\x18\xdd\xe1\x5a\xbe\x4b\xad\x62\xc3\x7f\xab\x05\xe3\xbe\xf4\xcd\x73\x98\xa4\x97\x7e\x07\xe1\x21\xfe\xf2\xaa\xc5\x6b\xe7\xe0\x54\x6e\x40\xfc\xa8\x85\x69\x6a\x38\x50\xc9\xa2\x87\x09\xe6\x99\xd5\x26\x11\xc9\xb7\x92\x6e\x7a\xd1\x81\x49\x04\x05\x82\xc9\x97\xdb\x71",
        b"\x51\x5b\x9c\xe5\x3e\xb1\x0c\x3e\x47\x89\x05\x56\xe0\xf0\xfd\x19\xad\xb2\x07\xb9\xc0\x1f\x12\xef\x5c\x6c\xaa\xad",
        b"\x09\x00\xe3\xac\xc4\xc3\x78\xbd\xfe\x9c\xda\x4d\xb8\xf8\xab\x54\x43\x69\x31\xc7\x3d\x8d\x31\x71\xc6\xdc\x8b\xb8",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x4a\x14\x5d\xd5\xcc\x4a\x12\xea\x43\x61\x7e\xc9\x79\x0f\x10\x38\x19\x0e\xd3\xd8\xaf\x24\xbb\xec\x14\xda\x3e\xcf\x5f\x38\x7c\xa9\x76\x4a\x8b\x9c\xbc\x5f\x62\x92\xa5\x3a\x9d\xa9\x53\x3c\x75\x11\x40\xf8\xda\x5f\xb6\xf3\xd4\x8e\xba\x1e\x7b\x98\x66\x27\x34\xd9\xa8\xb1\x20\xdd\x51\x54\x08\xba\x75\x6f\x75\xa5\x75\x52\x12\x76\x4a\xd9\x2c\x3f\x22\x63\x83\x52\x11\xad\xd5\xb4\xcc\x0e\xca\x8d\x4f\xc7\xa8\x43\xf4\x9c\x38\xce\x80\x86\x8f\xaf\x8b\x49\x8f\xb4\x14\xd3\x08\x0e\xd4\x1e\x36\x74\xe2\x85\xd3\xe4\x0d\x62\xf3\x05",
        p,
        q,
        g,
        b"\xb3\xf6\xd4\x4d\xa8\x6a\x51\x5d\x71\x85\xb7\x0c\x5a\xda\xa3\xf6\x05\x9c\x0b\xb7\x99\x5a\x53\x91\x07\x61\xfe\xa3\x62\xd9\x84\x3f\x92\xf2\x27\x1d\xdb\x0b\xca\x0d\x45\x19\xe3\x3f\xdb\x13\xaf\x49\xd8\x55\xcd\x0b\x9a\xb0\xb9\x70\x26\x72\x43\xe4\x68\xd3\xc4\x16\x77\xac\x58\x8f\xdf\xcb\x1c\xb9\xaa\x4d\x23\x3f\x7a\xe0\x17\xe6\x70\x94\xf4\xf4\xd9\x04\xe1\x57\x5e\x76\xbd\xc6\xbd\x82\x99\xb4\x2a\x2f\x39\xad\xef\x63\xce\x04\x78\x62\xaa\xa0\xbb\x8b\xa3\x2e\xc2\x73\x34\x93\x64\x84\x06\xf5\x4f\x5d\x8e\x2e\xb1\x9e\xea\x83\x7f\x4d\x59\x63\xad\x31\x92\x91\x7f\x5f\xe3\xb6\xd0\x27\xb2\x2b\xc1\xbf\x0d\xce\x84\x01\xd6\x22\xca\x72\xb1\xd7\x3a\x89\xe8\x88\xde\x1e\x62\xbe\xad\x2e\x4e\x1d\xa6\xb5\xd0\x4b\x2a\x36\x94\xc7\x6f\xe0\x7a\xd3\xc6\x64\x26\x34\x3d\x67\xbe\x12\xb2\xa7\x2c\x3f\x76\x22\x55\x73\xfc\x05\x4f\x3b\x7d\x73\x59\x15\x23\x8d\x7b\xdb\xcb\x03\xba\x6d\xde\x3e\xdc\x00\xf8\xc9\x83\xb0\xb5\x01\x29\xfa\xb4\x26\x00\x4a\x27\xa0\x38\x13\x9f\x2d\x32\x95\xb5\xb0\x32\x70\x1f\xac\xe3\x4a\x75\x23\x55\x94\x85\xfa\x63\x1c\x21\x92\x37\xf6",
        b"\x5c\xfd\x4b\x9f\x92\xca\x72\x7d\x51\x3a\xc1\x41\x43\xb1\x25\x14\x86\x55\xf1\x64\x2c\x53\xb7\x3c\xc2\x51\x31\xc9",
        b"\x2a\xde\xf9\x4a\xae\x37\x2d\x57\x9c\x99\x62\x9c\xa0\x78\x63\x62\xcb\x02\x47\xaa\x6d\x99\x95\x70\x74\xcd\x7d\x43",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x42\x8a\x20\x79\x0c\xad\x1c\x7b\xa8\x21\x18\xae\x58\x41\xbd\x53\x80\xee\x50\xbe\x5b\x64\xb8\x04\x09\x35\xef\x3d\x6d\xa3\x7a\x26\xe6\xf0\x20\x35\xfb\x19\x37\xc7\xa6\xbc\xd8\x8c\x89\x4f\xad\x7d\x8a\xa4\x8a\xbb\x89\xe0\xc6\x42\x87\xcd\xc6\x37\x45\x4d\xb8\x9e\xaf\x0a\x7e\x69\x27\x34\xc8\xa2\x43\x85\x6d\xd7\x56\x90\xbd\xce\xfe\x55\x4e\x39\xa0\xdf\x84\xe6\xe0\xc9\x6b\x2c\x57\x74\xa3\xe4\xe2\xaf\xed\x02\x8f\xb4\x3d\x79\x98\xd3\xcd\xc9\xa6\x40\x93\x22\xcf\x3b\xfa\x4d\x1e\x36\xf5\xe7\x07\x20\x3b\x59\xc4\x9a\x75\x3e",
        p,
        q,
        g,
        b"\x47\xa9\x34\x0a\xc5\x13\x58\x5c\x83\xbb\x20\xa2\xfb\xa9\x46\x97\x18\x11\x18\x4f\xd2\x00\x65\xfb\x95\xcb\xb2\x06\x25\xb4\x7b\x21\x6f\x75\xe1\xf3\xd8\x97\x97\xf5\x40\xa0\x48\x5c\xfb\xf0\x7b\x17\x16\xa3\xec\xe7\x02\x7d\x86\xf4\x94\x0a\xb9\x0b\xbf\xdd\x8e\xbf\x15\x13\x7b\xcf\x88\x05\xf9\x3c\xea\x25\x9c\x4b\xea\x5a\x2d\x3b\xb3\xdd\xdf\x83\xaa\x29\x0d\x35\x73\xe9\x1a\xa3\x00\xbb\xf1\xaf\xb9\xb5\x25\x54\x2d\x67\xa8\xd8\x60\x51\xae\xd8\xff\x8a\x2c\xfc\x22\x5a\x9e\x51\xeb\x37\x4c\x31\xfe\x10\x3a\xe8\xf4\xa0\xc8\x91\x14\x21\xd2\x25\xc0\x19\xe1\xb5\xc0\x7d\xc1\x49\xba\xbc\x26\xb7\x08\xfc\x0f\xc0\xc1\x3c\x3b\x35\x39\x03\x17\xc4\x09\xfa\xae\x81\xaa\xc9\xab\x5d\x01\xce\x85\xad\xd2\x49\x17\xd9\x4c\xd1\xb2\x14\x1b\x63\x8d\xe3\xa2\x53\xbf\xca\x6b\x7f\x1a\x81\x04\x51\x8d\x15\x72\x21\x1b\xa5\x2d\xd1\x75\x63\x2c\x8f\x3f\x67\x48\x26\x5a\x4b\xf6\xc2\xb8\x36\x3d\x98\x10\xba\x1f\x1e\x58\x47\x94\xf6\x23\x19\xf0\x45\x1d\xa8\x31\xd4\x57\xb5\x26\x9b\xbe\x67\x78\x4c\x47\x4f\xff\xf6\x92\xbb\xe2\xba\xac\xa3\x2d\x3f\x85\xf4\xfe\x39\xe0\x3f",
        b"\x8a\x96\xc4\x19\xe0\xf3\x91\xda\xa2\x9f\xb1\x62\xa1\xb9\x57\x0f\x48\xa0\x08\x10\xaa\x48\x0c\xde\x0f\x27\xcf\xb0",
        b"\x02\x8e\xd9\x16\x55\x22\xfc\x59\xae\xeb\x79\xc4\x91\xa9\x5e\xd8\x42\x7f\xd1\xb6\x95\xf3\xde\xdf\x42\x28\xa3\x28",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x2a\x07\xe2\x8f\xc1\x02\xdf\xe1\x7c\x79\xb9\x36\x8e\x0b\xa9\x24\x14\xd2\xfc\xb4\x07\xd3\x4e\x90\x3a\x0a\x53\x37\x0f\x7d\x2d\x33\xaa\x13\xc0\x2e\x52\x75\x87\x71\x8c\x3b\x39\x66\x61\x25\xec\xa2\xe8\xfd\x4c\x94\xb9\x86\x7f\xb6\xef\x16\xd5\x55\x54\x9d\x8d\xd0\xf6\xe1\x04\x17\xeb\xec\xf4\x8f\x99\x2a\xd8\x4b\x5d\x97\x74\x54\x07\x85\xdd\xcd\x26\x4c\x55\x79\x6b\xc2\x16\x28\x98\xec\xef\x40\x27\xc3\x41\x87\xf8\xc0\xb1\xc2\x0d\x4d\xaa\x10\x8b\x70\xd7\x6c\x40\xdd\xbe\xbc\x1e\x0f\x50\xf4\xdc\x90\x4d\xbf\xbe\x6b\xeb\x9d",
        p,
        q,
        g,
        b"\x05\xf2\x7e\xc0\x35\x62\x78\x60\xc3\x1a\xa5\x97\xc9\x68\x37\x08\x46\x05\xf2\x70\xd1\x5a\x3f\xbb\xdd\xa1\xc3\x85\x3d\xb2\xea\x6f\x6c\x9d\xe4\xe1\x1a\x6f\xbd\x77\x3c\x30\x0e\xba\xd0\xf9\xdb\xc3\x36\x08\xf9\xc4\xc5\xce\xde\xde\x0c\x26\x79\x1c\xbe\xa3\x5a\xf0\x32\x2a\x60\x77\x39\xe9\x7c\x32\x42\xf0\xae\x7d\x36\xaf\xe2\x69\xaa\xe6\x4b\x5f\xb2\xdb\x26\x5c\xd7\x56\xce\xd4\x5d\x88\x8e\xaa\xb0\x46\x5e\x50\x9a\xb7\xf8\x3d\x62\x3f\x69\xe7\x3c\xdc\x0c\x76\x70\x67\x5c\xe0\xc2\x9f\x49\xa1\x9d\x70\x38\x62\x3b\xde\x36\xe2\x9f\xb8\x54\xe6\xfe\x6f\xfd\xb9\x16\xab\xb7\xd6\x1f\xab\x4b\x62\x0d\xc7\x39\xa5\xcb\xd9\x60\x8a\x45\xe8\x6c\x2b\xbf\xb4\x1b\x86\x99\x16\x68\x22\xe8\x32\xbb\x6c\xac\x66\xe0\x04\xe9\x3d\x19\x0b\x95\x14\x24\xed\xaf\x34\xbf\x6b\xd3\x43\xbf\x60\x15\x4f\x73\x9c\x43\x56\x2b\x03\xae\xb4\xd2\x3d\xe1\xf7\x6c\x18\xf7\x4b\x5f\x7a\x73\xc8\x05\xb2\x2a\xf8\xcc\x6b\xdc\x9b\x55\x77\x9c\xcf\x6d\x44\x1c\xfd\x31\x54\x61\x6c\xda\x18\x80\x7a\x9f\x5e\x2d\x76\x59\xe9\xe2\x13\x29\x75\x51\x57\xda\xbc\x62\x2b\xd1\xae\x2d\x50\x97\xc6",
        b"\x91\xa4\x57\x69\x31\xed\x62\x1a\x03\x42\xf1\x4e\xe2\xba\x8f\xa8\xe1\xbb\xdf\x89\x4c\x12\x51\xaf\xdf\x72\x14\x6f",
        b"\x56\x75\x5c\xa1\x63\xf7\xdc\x89\x45\x8a\x7a\x75\xd4\xdd\x3c\xe3\xad\xec\x42\xb4\xaa\x7d\x04\xb2\x85\x8c\x47\xf6",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x7e\x96\x38\x58\x16\xc9\x7b\xd9\xde\x81\xde\x30\xe6\x7d\xb7\x24\x36\xfb\x42\xfa\xa9\xb6\xcc\xfe\xab\x1f\xa5\x28\xc6\x9e\x63\x51\xb2\x01\x2a\x10\x97\xfb\x86\xd8\xc5\xcc\x60\x25\x6e\xf1\x1b\xe1\x8f\x16\x13\x76\x17\xf8\xcd\xd2\x9e\x3b\xab\x94\x68\xc1\x2a\xe3\x43\x36\xba\x0e\x0e\xb6\xc8\x28\x17\x7d\x1d\x55\xb0\x66\x98\xdd\xf7\x53\x75\x6a\xf8\x30\xa1\x0c\xe9\xc9\x9f\x1d\x13\x68\x26\x68\xe3\xeb\x33\x6a\x80\x61\x8e\x66\x62\x80\x09\x64\x17\xc1\xe2\xb0\x05\xb9\x35\x1f\x5e\xa3\x06\xb8\xc6\x3f\xd1\x84\xa5\x91\x32\xb5",
        p,
        q,
        g,
        b"\x2b\x69\xbf\x21\xbf\x68\x9a\x1f\x5e\xd7\x09\x6b\x27\xe4\x47\xc1\xd5\x2f\xc2\x47\x3e\x9e\x43\x53\xdb\xf1\x85\x63\x20\x22\xfc\x60\x5c\xef\xe5\x48\x91\x02\xf7\xcb\xe9\x84\xf0\x0c\x1a\xb3\x2f\x2d\xef\x1a\x84\xf1\xbe\xdd\xdb\xc1\x5f\x87\xae\xd0\xa2\xb1\xe9\x12\xe9\xed\xd7\x4e\xdb\xe2\xc1\x5a\x4c\x37\x53\x30\x14\xb9\xd3\x2b\x05\xf5\xa4\x4d\x32\x3d\xef\x1c\xeb\xae\x0e\x21\x6b\xc3\x5a\x1c\xa8\xa4\x26\x5c\x3d\xb5\x57\x4e\xb2\x3e\x17\xf1\x83\x8e\x22\x5e\x46\x7a\x94\x26\xe8\x79\x8c\x5a\x2e\x89\x65\x36\xc4\x8c\x4e\x24\xcd\x2e\xe9\xda\x1b\x61\xae\xd2\xe2\x5b\x98\xe4\xc1\xf4\xee\x55\xe0\xb4\x70\x5f\xeb\x2b\xb1\x69\x4c\xb1\x8a\x64\x14\xbc\xdc\x1a\x74\x89\xb4\xbf\x89\x67\x98\x54\x89\x31\x6b\x3e\x57\xea\x28\x12\x04\xce\xd3\xed\x88\xad\x1b\x20\x7b\xe7\xd2\x94\x12\x7b\xca\x86\xa9\xb8\x61\xcc\xca\x19\x2c\x15\xc8\x15\xe2\x32\x8c\xbd\xaa\x58\x99\xc9\xdd\x27\x1f\xcd\x6e\xea\x0d\x2a\xb0\x09\xa8\xba\x00\x1e\x67\x25\x13\x9b\xe2\x6c\x51\x51\x87\x5c\xdc\xa7\xf9\x14\x34\x44\x3b\x9e\x5e\x47\xa4\x5c\xdc\x8b\x73\x99\xbc\x5e\x8b\xed\x93\x00",
        b"\x1b\xca\xa2\xca\xf4\x83\xab\xc8\x0b\x75\xf6\x70\x25\x2f\xaa\x2a\x8e\x18\xc3\x23\x01\xba\x6f\xc0\x6f\x37\xc0\x8e",
        b"\x90\x9a\x78\x52\xb8\xd5\xc8\x81\x3e\x17\xc0\x40\x77\x9a\xd0\xdc\x5e\x9e\x05\x56\x61\x20\x56\x83\x5e\x68\xd2\xb8",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x24\xed\x7a\x16\x78\x2b\x5c\x34\xbe\xb5\x8b\xab\x6a\x7d\x20\x28\x71\x9f\x97\x38\xe5\xd1\xba\x69\x78\xef\xac\x4b\x53\xb3\x7c\x88\xe7\xea\x02\xe0\xcf\x0f\xd8\x2a\x3e\x50\x04\x60\x52\xa9\x04\x95\x41\xd1\x29\x93\x25\x4a\x46\xfe\x40\x1f\x40\x2d\x38\x94\x3e\x94\x91\x8b\xf7\xa6\xfe\xcb\x08\xed\x13\x09\xb7\xb0\xf2\x18\x59\x67\xef\x28\x9a\x2e\xfa\x6c\x2e\x37\xa7\x4d\x65\x92\xa2\xeb\x74\x01\xca\x5e\x98\xbb\x86\x45\xa9\x4e\x57\x49\x9d\x36\x2e\x0f\x31\x33\xef\x33\x6e\x11\x95\x61\xce\xe1\xb5\x58\xc1\x55\x08\x78\x18\x68",
        p,
        q,
        g,
        b"\x9d\xcc\xc1\x37\x19\x7b\xb2\x98\x24\xb1\xc1\x0e\x9e\x8d\xed\xd7\x14\xef\xc9\x36\xcf\xf8\x3f\x42\x63\x4d\x64\x39\x1f\x9b\x7f\x4f\xc3\xa2\x31\x95\x4a\x8c\x3b\xfe\x4a\xe0\xf8\x22\x25\xfd\x52\xb5\xdd\xe6\xdc\xd1\x4c\x0c\xe5\x08\x59\x71\xc5\x15\xda\x38\x18\x34\x27\xc7\xe2\xa8\xd7\x6e\x40\xef\xb6\x71\xaf\x79\x7e\x0c\x57\x6e\x38\x81\xd4\x34\xca\x80\x9d\xd5\x53\xcc\xb0\xf7\xcd\x9f\x73\xc7\xae\xa2\x26\x8f\x36\xc8\x41\x70\xab\x0a\xe0\x3b\x2b\x46\xa2\x19\x54\x75\x64\xfd\x21\xc5\x40\xb1\x60\x3a\xd7\x30\x6d\x22\xa9\xeb\x8e\xf3\x7c\xa0\x8c\x2b\x28\xd1\x6c\x5b\x9c\x54\xa3\x28\xeb\xb3\xc0\xf9\x50\x50\x95\xc6\x12\x27\x0d\x52\x63\x7c\xb5\x58\x4e\xd0\x8b\xad\x71\x38\xd3\x38\x8c\x63\x4b\x65\x02\xfa\x64\x73\xa2\xf5\x94\x04\x0b\x9a\xcc\x14\x80\xb3\x43\xd2\x28\x7f\xdc\x70\xd1\x6b\xa1\x4b\x1c\x21\x17\x61\x2d\xcc\x58\x60\xdb\xef\x83\x87\xaf\x9a\xa5\xe1\x62\x1d\x37\xa3\x8f\x6c\xbe\x59\x35\x67\x3e\xa3\xcb\xcd\xe4\xf3\x2a\x24\x9e\xb6\xa5\xee\xd4\x1c\xfd\xca\xa4\xc8\x7e\x8b\xca\xba\xa6\xbd\x1f\xe5\xa8\x79\xd1\x7e\x9a\xe3\x58\x37\xce\x0f",
        b"\x5f\x4f\x54\x49\xb8\xd0\xdd\xa3\xac\x59\x0b\xa1\x64\x0d\xf9\x77\x2f\xf0\x8c\xec\x08\x52\x8b\xc2\xd7\x0d\x7a\xc9",
        b"\x5b\xea\x04\xbf\xd3\x32\x48\xf2\x6a\xee\x98\xca\x85\x96\x77\x4e\x95\xce\x68\x54\x65\x17\x4d\x1c\xae\xd7\xd9\x20",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x49\x06\xdb\xdd\x9d\xa6\xdd\xff\xa1\x52\xfa\x2e\x25\x0e\xea\xd3\xc6\xef\x70\x83\x87\xa3\xad\x64\xd3\x4a\x0e\x05\x74\x59\x47\x1f\x48\x75\x2f\xde\x07\x86\xdb\x28\xa4\xbb\xf5\x81\x14\xd8\xdc\x91\xb6\x9e\x56\xbe\x3c\x49\xec\x1b\x98\x80\xd9\x91\x7c\x73\xab\xc8\x95\x75\x4a\x60\x77\x9b\x18\xbc\x95\x15\x50\xb9\x57\xa7\x7c\x8c\xef\xa1\x59\x90\x81\x26\xcc\x80\x1c\x66\x5d\x1b\x01\x10\x9b\xa6\x04\xbb\x9e\x79\x7c\x7a\x37\x66\x0b\xfc\x05\x93\xba\xb0\x92\x4d\xf5\x80\x6c\xa8\x03\x38\x1b\x24\xb0\x3d\xe3\xd0\x3b\x48\x4d\x49",
        p,
        q,
        g,
        b"\x07\x2c\xb5\x61\x25\x96\xaa\x71\x61\x42\xf5\xf7\x56\xc9\x54\x20\x13\xf3\xf1\x62\x8c\xfc\x54\x97\xeb\x1b\xa0\xaa\x51\xbd\x5a\xdb\x8e\xb8\xad\xfe\x05\x9c\x0e\x08\x82\xe3\xc0\x9a\x17\xd1\xf5\x1a\xcc\xb6\x87\xb2\x43\xfd\x30\x52\xbb\xcb\x81\xb0\x63\xc1\xe7\xd5\xbe\x06\x65\x87\xeb\xca\x07\x80\x06\xf6\xd6\xee\x71\xa6\x9e\xf5\x9b\x63\x65\xcb\xcf\x64\xd4\xcf\x1b\x92\x99\xe7\x40\x30\x09\x27\x20\x26\xfc\x16\x65\xed\x40\x3a\xb8\xde\xe4\x0e\xea\x4e\xe7\xd5\x62\xaf\x00\x19\x51\x92\x6d\xc8\xbf\x0c\x78\x39\x84\x66\x4f\xfe\xf6\x29\xcb\x59\xd7\x09\xb3\xd9\xaa\x06\x80\x5d\x62\xaf\xd7\x94\x54\x1a\x2b\x4c\xe0\xc5\x90\x43\xac\xf7\x3e\x18\xe7\x44\x53\xe8\x6a\x08\x2f\x17\x91\x4b\xa6\xb2\xb0\xfa\x80\xda\x83\x53\xc7\xed\x91\x62\x60\x95\x75\xed\x41\xf8\xeb\x78\xdb\xaf\xaa\x7b\x51\x8d\xe0\xc8\x5b\x17\x20\xe7\xf4\x93\xb9\x14\xd5\xa3\xd2\xd0\x74\x82\x73\xd1\x69\xd5\x5c\x45\x55\x6b\xca\xe6\x70\x57\x5c\x96\xa4\x44\xfc\x1d\x78\x9f\x5b\xac\xfc\x8b\x24\x13\x2b\xfb\xd7\x5b\x30\x61\xfb\xac\xf2\x93\x5a\x21\x9b\x0f\x2a\xc5\xdc\xad\x71\x85\x16\xa9",
        b"\x77\x47\x59\x00\xfc\x7f\x3e\x0b\x80\xf3\x88\x4a\xf8\x60\x4e\xef\x60\xff\xe4\x84\xbc\x6c\xd3\xde\x12\x3f\x79\x59",
        b"\x26\xca\x92\x7d\xa0\xd1\x0b\x43\xdc\x15\x21\xbf\xeb\x58\xff\x34\x7e\xe1\x43\xfc\x38\xdb\x45\x1c\x11\xa0\x35\x10",
    )?;

    // [mod = L=2048, N=256, SHA-1]
    let p = b"\xc1\xa5\x9d\x21\x55\x73\x94\x9e\x0b\x20\xa9\x74\xc2\xed\xf2\xe3\x13\x7f\xf2\x46\x30\x62\xf7\x5f\x1d\x13\xdf\x12\xab\xa1\x07\x6b\xb2\xd0\x13\x40\x2b\x60\xaf\x6c\x18\x7f\xb0\xfa\x36\x21\x67\xc9\x76\xc2\x61\x7c\x72\x6f\x90\x77\xf0\x9e\x18\xc1\x1b\x60\xf6\x50\x08\x82\x5b\xd6\xc0\x2a\x1f\x57\xd3\xeb\x0a\xd4\x1c\xd5\x47\xde\x43\xd8\x7f\x25\x25\xf9\x71\xd4\x2b\x30\x65\x06\xe7\xca\x03\xbe\x63\xb3\x5f\x4a\xda\x17\x2d\x0a\x06\x92\x44\x40\xa1\x42\x50\xd7\x82\x2a\xc2\xd5\xae\xaf\xed\x46\x19\xe7\x9d\x41\x58\xa7\xd5\xeb\x2d\x9f\x02\x3d\xb1\x81\xa8\xf0\x94\xb2\xc6\xcb\x87\xcb\x85\x35\x41\x6a\xc1\x98\x13\xf0\x71\x44\x66\x0c\x55\x77\x45\xf4\x4a\x01\xc6\xb1\x02\x90\x92\xc1\x29\xb0\xd2\x71\x83\xe8\x2c\x5a\x21\xa8\x01\x77\xee\x74\x76\xeb\x95\xc4\x66\xfb\x47\x2b\xd3\xd2\xdc\x28\x6c\xe2\x58\x47\xe9\x3c\xbf\xa9\xad\x39\xcc\x57\x03\x5d\x0c\x7b\x64\xb9\x26\xa9\xc7\xf5\xa7\xb2\xbc\x5a\xbc\xbf\xbd\xc0\xb0\xe3\xfe\xde\x3c\x1e\x02\xc4\x4a\xfc\x8a\xef\xc7\x95\x7d\xa0\x7a\x0e\x5f\xd1\x23\x39\xdb\x86\x67\x61\x6f\x62\x28\x6d\xf8\x0d\x58\xab";
    let q = b"\x80\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x1b\xd6\x2c\x65\xe8\xb8\x7c\x89\x79\x7f\x8f\x0c\xbf\xa5\x5e\x4a\x68\x10\xe2\xc7";
    let g = b"\xae\xa5\x87\x87\x40\xf1\x42\x4d\x3c\x6e\xa9\xc6\xb4\x79\x96\x15\xd2\x74\x92\x98\xa1\x7e\x26\x20\x7f\x76\xce\xf3\x40\xdd\xd3\x90\xe1\xb1\xad\x6b\x6c\x00\x10\xad\x01\x5a\x10\x33\x42\xdd\xd4\x52\xca\xc0\x24\xb3\x6e\x42\xd9\xb8\xed\x52\xfa\xfa\xe7\xa1\xd3\xce\x9e\x4b\x21\xf9\x10\xd1\x35\x6e\xb1\x63\xa3\xe5\xa8\x18\x4c\x78\x1b\xf1\x44\x92\xaf\xa2\xe4\xb0\xa5\x6d\x88\x84\xfd\x01\xa6\x28\xb9\x66\x27\x39\xc4\x2e\x5c\x57\x95\xad\xe2\xf5\xf2\x7e\x6d\xe1\xd9\x63\x91\x7c\xe8\x80\x6f\xc4\x0d\x02\x1c\xd8\x7a\xa3\xaa\x3a\x9e\x4f\x0c\x2c\x4c\x45\xd2\x95\x9b\x25\x78\xb2\xfb\x1a\x22\x29\xc3\x7e\x18\x10\x59\xb9\xd5\xe7\xb7\x86\x2f\xa8\x2e\x23\x77\xa4\x9e\xd0\xf9\xdc\xa8\x20\xa5\x81\x40\x79\xdd\x66\x10\x71\x4e\xfa\xf8\xb0\xcc\x68\x3d\x8e\x72\xe4\xc8\x84\xe6\xf9\xd4\x94\x6b\x3e\x8d\x4c\xbb\x92\xad\xbb\xe7\xd4\xc4\x7c\xc3\x0b\xe7\xf8\xc3\x7c\xa8\x18\x83\xa1\xaa\xc6\x86\x00\x59\xff\x46\x40\xa2\x9c\xca\xe7\x3d\xe2\x0b\x12\xe6\x3b\x00\xa8\x8b\x2e\xe9\xba\x94\xb7\x5e\xb4\x0a\x65\x6e\x15\xd9\xec\x83\x73\x1c\x85\xd0\xef\xfc\xb9\xef\x9f";
    test(
        HashAlgorithm::SHA1,
        b"\xde\x36\x05\xdb\xef\xde\x35\x3c\xbe\x05\xe0\xd6\x09\x86\x47\xb6\xd0\x41\x46\x0d\xfd\x4c\x00\x03\x12\xbe\x1a\xfe\x75\x51\xfd\x3b\x93\xfe\xd7\x6a\x97\x63\xc3\x4e\x00\x45\x64\xb8\xf7\xdc\xac\xbd\x99\xe8\x50\x30\x63\x2c\x94\xe9\xb0\xa0\x32\x04\x65\x23\xb7\xaa\xcd\xf9\x34\xa2\xdb\xbd\xcf\xce\xef\xe6\x6b\x4e\x3d\x1c\xb2\x9e\x99\x4f\xf3\xa4\x64\x8a\x8e\xdd\x9d\x58\xed\x71\xf1\x23\x99\xd9\x06\x24\x78\x9c\x4e\x0e\xeb\xb0\xfb\xd5\x08\x0f\x7d\x73\x0f\x87\x5a\x1f\x29\x07\x49\x33\x4c\xb4\x05\xe9\xfd\x2a\xe1\xb4\xed\x65",
        p,
        q,
        g,
        b"\x88\x0e\x17\xc4\xae\x81\x41\x75\x06\x09\xd8\x25\x1c\x0b\xbd\x7a\xcf\x6d\x0b\x46\x0e\xd3\x68\x8e\x9a\x5f\x99\x0e\x6c\x4b\x5b\x00\x87\x5d\xa7\x50\xe0\x22\x8a\x04\x10\x2a\x35\xf5\x7e\x74\xb8\xd2\xf9\xb6\x95\x0f\x0d\x1d\xb8\xd3\x02\xc5\xc9\x0a\x5b\x87\x86\xa8\x2c\x68\xff\x5b\x17\xa5\x7a\x75\x84\x96\xc5\xf8\x05\x3e\x44\x84\xa2\x53\xd9\x94\x22\x04\xd9\xa1\x10\x9f\x4b\xd2\xa3\xec\x31\x1a\x60\xcf\x69\xc6\x85\xb5\x86\xd9\x86\xf5\x65\xd3\x3d\xbf\x5a\xab\x70\x91\xe3\x1a\xa4\x10\x2c\x4f\x4b\x53\xfb\xf8\x72\xd7\x00\x15\x64\x65\xb6\xc0\x75\xe7\xf7\x78\x47\x1a\x23\x50\x2d\xc0\xfe\xe4\x1b\x27\x1c\x83\x7a\x1c\x26\x69\x16\x99\xf3\x55\x0d\x06\x0a\x33\x10\x99\xf6\x48\x37\xcd\xde\xc6\x9c\xae\xbf\x51\xbf\x4e\xc9\xf3\x6f\x2a\x22\x0f\xe7\x73\xcb\x4d\x3c\x02\xd0\x44\x6d\xdd\x46\x13\x35\x32\xef\x1c\x3c\x69\xd4\x32\xe3\x03\x50\x2b\xd0\x5a\x75\x27\x9a\x78\x09\xa7\x42\xac\x4a\x78\x72\xb0\x7f\x19\x08\x65\x40\x49\x41\x93\x50\xe3\x7a\x95\xf2\xef\x33\x36\x1d\x8d\x87\x36\xd4\x08\x3d\xc1\x4c\x0b\xb9\x72\xe1\x4d\x4c\x7b\x97\xf3\xdd\xfc\xca\xef",
        b"\x36\x3e\x01\xc5\x64\xf3\x80\xa2\x7d\x7d\x23\xb2\x07\xaf\x3f\x96\x1d\x48\xfc\x09\x95\x48\x7f\x60\x05\x27\x75\xd7\x24\xab\x3d\x10",
        b"\x49\x16\xd9\x1b\x29\x27\x29\x4e\x42\x9d\x53\x7c\x06\xdd\x24\x63\xd1\x84\x50\x18\xcc\xa2\x87\x3e\x90\xa6\xc8\x37\xb4\x45\xfd\xde",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x49\x70\x7b\x65\x5b\x6d\x16\x8c\x70\xba\xed\xe0\x38\x66\xb0\xfb\xa6\x02\x39\xad\x4c\xf8\x2f\x53\xb4\x6e\x11\xb2\x6f\xa8\xf6\x27\x6f\xf6\x68\x7d\x09\xe8\xed\x1e\x5d\x96\x3c\x11\xe4\x76\x3b\x2e\x59\xa0\x92\x7f\x01\xe8\xff\xfd\x18\x94\xa6\x26\x23\x27\xc8\x4b\xbb\x42\x98\xd7\xd7\xfb\xca\x66\x06\x73\x12\x8b\xb7\xde\xa4\x61\x78\x14\x64\x85\x53\x9f\x9a\x8f\x88\xda\xc7\x61\xd0\xd5\xd4\x5c\xb5\x57\xcd\xac\x96\x0b\xe2\x3d\xd9\x19\x9a\xcd\x99\xcb\x64\xd1\xfe\xe2\xca\x68\xe4\x23\x46\x1a\x02\xab\xb3\x4c\x1d\xc4\x50\x11",
        p,
        q,
        g,
        b"\x38\x53\x49\xec\xf9\x9c\xe7\x83\xd4\xe7\xa8\x0a\x7d\xd2\xc5\x33\xa3\x62\x3c\x38\x26\x02\x43\xac\x39\x2d\x4e\xab\x6d\xed\xa5\xb7\x9b\x8f\x91\x67\x92\x2e\x8b\x60\x46\x86\x23\xe4\x60\x3f\xa7\x68\x1f\x53\x5e\x20\xde\x67\x35\x31\x25\x5e\x10\x8f\x54\x2a\x26\xd5\xc8\x7f\x19\xe0\x63\x37\x2d\x14\x28\x69\xc5\xee\xf1\x32\x52\x81\xfe\xe7\xf1\xc7\x4d\x2a\x96\x25\x5d\x42\x0f\x27\x13\x86\x4d\x55\xd3\x6f\x81\x39\x19\x4f\x64\x3a\x6e\x98\xb5\xbf\x97\x32\xc8\x59\x74\x45\xaf\x5a\x71\xe2\x3e\x2a\xc5\xca\xe3\x60\x43\x23\xf7\xbf\x09\x44\x97\x86\x97\x4e\xd5\x3a\x57\x17\xf9\xae\xc1\x4d\xd0\x1b\xd1\xcf\x27\x6b\xf3\xc6\x3d\xec\x43\xc3\xec\x8e\xa6\x55\x7d\xe4\x69\x91\x64\x12\xf0\x45\x6c\x90\xf0\x12\x91\xbb\x71\x25\xe9\xf8\x55\xf4\x55\xb3\x60\xc0\x3d\x4a\x7b\x4a\x8d\x40\x90\xe4\x7a\xaf\x11\x11\xf3\x82\xdd\x26\x05\x73\x4f\xb5\x4f\x4b\x8f\xfe\x23\xc9\xde\xd2\x90\x0b\x31\x21\xb4\x97\xbd\x46\xd0\x45\x8a\x09\xa5\xdf\x4a\xa9\xcf\x1b\xe9\x06\xf5\x54\x23\x13\x38\x4f\x93\xd3\x77\xba\x9e\x0a\x76\x2b\x47\x93\x40\x3b\x91\x4e\x52\x86\x5a\xfa\xbb\x67",
        b"\x0f\xdc\x5a\x5a\x4a\x2c\x2f\x3d\xf5\x0c\x86\x83\x83\xba\x80\x03\x96\xae\x25\x26\x5b\xe1\xa1\x47\x62\xd3\x11\x0c\xbe\xb3\x48\x19",
        b"\x4b\x41\x84\x1c\xad\x45\xfe\xde\xa5\xaa\xd0\xa1\x6b\x05\x3e\x88\x35\x3b\x6f\x01\x02\xdf\x74\xc9\xfc\xe0\x9e\x38\xf5\xe6\xc2\x77",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x76\x3c\x1f\x15\xc5\xdd\x8a\x93\xaa\xc4\xe0\x48\x65\x1c\x4e\xa8\x4a\xf1\x8a\xee\x25\x5b\x56\x95\x9e\xae\xb1\x87\x66\x99\xbe\x75\x27\x1a\xf0\xda\x6c\x3c\xa9\x36\xe9\x9b\xe4\xff\x44\x36\x41\x0f\x69\xae\x70\x18\xb6\xc8\x43\xdc\xe9\xd8\xb7\x1a\x91\xef\xa5\x3c\x39\xbe\x55\xf2\x85\xfb\x8a\xd8\x54\x39\x52\xfd\x3c\xa8\x92\x71\xec\x23\xd3\x42\xcf\xd5\x57\xbf\xb7\x2d\xb4\x3b\x43\x4d\x0e\xd5\xb3\x07\x63\x03\x77\x54\xbb\x0f\x78\x2a\xb0\x82\x35\xa6\x4a\xbb\x7f\x0a\x82\x8f\x89\x2c\xde\x7e\x05\xe3\x01\xda\x7c\x21\xc0\x96",
        p,
        q,
        g,
        b"\x0b\xec\xd9\x17\xee\xd0\xbe\x9c\xb5\x8f\xf9\xd2\x59\xa8\xfa\x41\x5b\x81\x6d\xa4\xa2\x5d\x3f\x56\x9d\x7b\x9f\x31\x7b\x3f\x47\xe4\x24\x4c\xde\xf3\x57\x96\xfb\x45\x5c\x05\xc1\x56\x45\x2f\x1c\x86\x60\xf5\x34\x6f\xba\x16\x92\x76\x22\x14\x46\xf8\x2b\xbb\x20\x27\xb0\x56\xb5\x37\xcf\xd5\x9c\x57\x29\x91\x66\xa6\xf2\x08\x71\xc7\x4e\x6c\x1d\x3f\x5a\x37\xb7\x5e\x8d\xad\x6c\xad\xcf\x12\xc9\x09\x58\x6a\x32\xf1\x50\xc6\x8e\x33\x23\x06\xab\xef\x8b\xe1\xab\xd5\x6c\x42\xd3\xc3\x69\x36\xcf\x8f\x2a\xca\xce\xb7\x07\x99\x4a\x3d\x4c\x05\x55\xa0\x15\xde\x89\x20\x37\xaa\xc6\x8e\x33\x81\x3b\xf3\x05\x0f\x0f\x3a\x8d\xf5\xe8\x14\x65\x85\x2f\x6a\x19\x5e\xa6\x88\xac\x5d\x25\x8e\xee\x20\x76\xa6\xb2\x36\x36\x2e\x3d\x79\x2e\x7f\x35\x8c\x6b\xa9\x94\xda\x7a\x64\xb1\x82\x63\x96\x96\x55\x47\x3a\xaa\x37\xcb\x3c\xfb\x00\xa2\x7f\x8f\xb2\x4a\x4b\x73\xb0\x25\xc9\x63\x35\x43\x84\x84\xe9\x58\xad\x08\x48\x27\x7d\xf9\x50\x84\x7d\x46\xa9\x87\x4f\x10\x39\xfb\xea\x7e\x08\xbc\x79\x67\x5e\xf1\xdf\x6e\xf2\x12\x30\xa7\x9a\x3b\x16\x13\x08\xa0\xa4\x60\x0b\x53\x47",
        b"\x76\xe9\xb6\xef\x7e\x8d\x48\xfb\xfc\x43\xbf\x46\x52\x81\x59\x22\x23\xfa\x7e\x0d\x99\x78\x39\x2d\x35\x58\x68\xc8\xa2\x02\x09\xbb",
        b"\x7f\x9c\x8d\xea\xb5\x1c\x60\xbb\x6f\x86\x6c\x76\x45\x01\x38\xe0\xd2\x94\x6a\xca\x6c\x5f\x88\xdf\xe3\x5a\x0c\x1b\xa4\x93\xee\x47",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x67\x85\x1d\xe9\x82\xfc\x70\xf9\x69\xd8\x2f\x65\xd8\x5b\x03\x32\xd6\x67\x11\x4f\x27\xb5\x8b\xb9\xe5\x65\xd2\xe4\x0a\xd0\x11\x98\x3d\x93\x60\x49\xcc\x97\xa2\x16\x26\x0f\xa2\xe4\x10\xad\x6d\x6c\x98\xa5\x48\x75\x9a\xa8\xe2\xd0\x22\xc1\xfb\xc1\xb1\x6b\x10\xd8\x3f\xbb\xbd\x12\x6e\xc4\x3d\x5f\xed\xc4\x07\xc8\x31\x46\x1c\x7f\x33\xed\x94\x74\x00\x31\xec\xd0\xf7\x01\xc7\xb1\xdf\x88\xa2\x49\x26\x5b\x3f\x60\xc3\x8f\x42\x85\xbb\xc9\xba\xe1\x64\xbc\x38\xe1\x62\xc2\x35\xc9\xa9\xdf\xc1\xb1\x50\xea\xeb\x14\x82\xeb\xed\x48",
        p,
        q,
        g,
        b"\xab\x9a\x99\xff\x87\x89\x9b\xd6\x65\x7b\x3a\x9e\x9b\x72\x06\x99\x6b\xbc\x77\x99\xdd\xe5\x7d\xcf\xff\x80\x98\x87\x5d\xc4\x65\x0d\x79\x1e\x90\xbc\x4c\xee\x10\x98\x9b\xf4\x9e\xb5\xe6\x23\x08\x57\xf9\x68\x41\xae\x83\x62\xe4\xee\x5c\xc8\x60\x2f\x6a\x1a\x2c\x6f\x8f\x2f\x68\x0a\xd3\xa7\x2b\x0e\x07\x51\x1e\xad\x30\x1f\x57\x52\x78\xa0\x74\x13\x8a\xa4\xea\xa5\x39\x19\xe3\x4f\x00\x1c\xbe\x2d\xcb\xc3\x45\xc7\x7f\x56\x87\xd0\x71\x98\x1a\x4d\xca\x29\xd0\x26\xbb\x53\xec\x9c\xf0\x3a\x88\xd6\x3c\x52\x20\x6d\x35\x1f\x8f\xca\x10\x23\x9e\x84\xf4\x91\x5c\xe3\x47\xf4\x8d\x65\x0a\xaa\xa6\xb0\x2d\x31\x64\x97\x3f\x82\xfc\x0e\x0f\x83\xa2\xd4\x58\xaf\x65\x73\x6d\x7e\x0d\xbb\x26\x4f\xd7\x79\xff\xd5\xa3\xf0\x66\x58\x44\x94\x59\x85\x26\xcd\x67\xe1\x2d\x6c\x67\x96\x5a\x70\xec\x3f\x09\xe2\xcc\x44\x7f\x17\x7e\xc8\x76\x04\xb5\x31\x48\x66\x83\x02\x5e\x3b\x52\x0a\x26\xe6\x9c\x95\x8c\xf8\x43\x5f\x7c\x6c\xe5\x64\xf0\xa7\x2d\x1f\xc4\x72\x05\xa5\x0b\x39\xd5\x16\xb1\x4a\x47\x6f\x6c\x2d\xca\xce\x50\x33\x9c\xae\x20\xcd\x34\x21\xa7\x5f\x6d\x37\x7b\x8b",
        b"\x76\x3e\x89\xfc\x8b\x2a\x09\x0b\x75\x81\x2a\xef\xa5\x5d\xe7\xb7\xcd\x61\xec\x3f\xdf\x87\x30\xce\x16\xb0\x5a\x7b\x94\x56\xfd\x2d",
        b"\x4a\x97\x08\x6b\x67\x17\xa7\x3a\x6b\xe6\xd4\xa9\x5b\x83\x43\xbd\x20\xb0\xd7\xb5\x1c\x3d\xa1\xd8\x6c\x58\x52\x35\x08\x71\x37\x9b",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x61\x6d\xe9\xdd\x23\xeb\xed\xe4\x28\xe0\x32\xdb\x78\x38\x10\x8a\x22\x4f\x7a\xca\x57\xb1\xdf\x87\xf0\x31\xfe\x1d\x86\x08\x3d\x68\x8c\x5c\x3e\xf0\x78\xe6\x4d\x8d\x5a\x9e\x61\x2d\x39\x83\x46\x0c\xa1\xf8\x16\xf7\x87\xc0\x3c\xa4\x3a\x1f\xd8\xce\x13\x86\x55\xdf\x67\x70\x56\x36\x4c\x0e\xab\x8e\x04\x93\xc0\x7b\xd4\xb2\xb0\x50\x22\x19\x09\x32\xde\x79\x4f\x19\x5d\xbe\xf2\x97\x09\x3e\x7d\xa1\xc4\x30\x4d\xb4\x0b\x63\xca\x53\xe1\xb8\xbc\xda\xd9\x13\xd7\xa9\x02\xaf\x02\x5c\x36\x7c\x48\xde\x38\x7f\x1a\x9b\xcd\x7c\xa4\x2e",
        p,
        q,
        g,
        b"\x58\x4e\xae\xed\x2d\xc7\x85\xd8\xe2\xb8\xc8\x5f\xd0\xe5\xec\x25\x1f\x13\x49\x58\xbd\x9e\xea\xe4\xf7\x9f\x86\x2b\x62\xcf\x60\x2a\xb1\x0d\x22\xec\xa4\x99\x04\x2f\x2c\x87\x5f\x27\x08\xba\x0d\x69\x7a\xf3\x9f\x23\xf5\xe0\xb7\xde\x4f\xf7\x96\x4b\xab\x12\x79\xef\xa2\xaa\x79\x7a\x2d\x21\xe7\x88\xd2\x49\xf4\x26\x93\xcd\xbf\xd7\x1f\xdc\xb1\xaa\x93\xb7\x9b\xac\x0d\xbc\xb5\x87\xbb\xff\x4e\xf1\x5a\x37\x99\xa5\xfc\xa8\xb1\x58\x98\x38\xe3\x00\x96\x06\x9c\xa7\x93\x1f\x74\x08\x81\x5b\x58\x5d\x14\x0a\x74\x7d\xe4\x3b\xd9\x2c\xac\x3f\x9a\x9b\x18\x62\xfd\x70\x46\x73\xe1\xe5\x87\x10\xc1\x6d\xdb\xe7\xe5\x2d\x31\xa7\xdf\x15\x97\x49\x58\xb1\x28\x81\x16\xed\x98\xff\x24\x7f\x50\x28\xce\xc8\x6d\x9e\xb9\x7b\x12\x6a\x48\xad\xc9\x52\xe9\x0d\xc5\x2f\x2b\xd7\x81\x03\x55\xaa\x90\x75\x05\x1f\x26\x12\x9c\x2d\x2f\xb0\xba\x80\x66\xe4\x14\x98\x9d\x92\xe2\x9e\x68\x99\x60\xe3\x3e\xe5\x6c\xa6\x2d\x71\x4a\x42\xcb\x74\x87\xf7\x0c\x0c\x0b\xa6\x43\xfa\x9d\xd5\xf8\x52\x59\xfd\xec\xd4\x9f\xa9\x70\xc8\x32\x26\x82\xb1\x14\xf2\x64\x78\x37\x63\x7a\xbc\x0e\xd2",
        b"\x74\x8f\x46\x6b\x7f\xdc\xdf\xa7\x70\x17\xc8\x65\xa3\x3b\x1d\xad\x4d\xb9\x9d\xbd\x63\xef\xa1\xc8\x73\x45\xc4\x83\x3b\x06\x32\xac",
        b"\x0b\xf9\x93\x8e\x79\x72\xeb\xb0\x0f\xb0\xa3\xc0\xc2\x47\x6d\x25\x09\xdb\x23\xaf\xca\xec\xb1\x7d\xc5\x71\x90\x53\x17\xeb\x8c\xa7",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x11\x5f\x0a\x8b\xe3\x4e\x84\xd0\x9b\xdc\xca\x69\xd1\x9c\xe1\x7d\xd6\x7d\xf7\x39\xaa\x4f\xc6\xe8\x07\x70\x76\x53\x5f\x39\xaf\x83\x02\x88\x14\x71\xa5\xfb\x0e\x18\x39\xa3\xaa\x76\xdf\xda\x4b\xde\x2f\x9f\xa2\x5f\xa5\x82\xb7\x56\xa4\x96\x6d\x75\x32\x0a\xc1\x99\x54\x72\x27\x16\x66\x15\x6e\xa8\x6c\x19\xa2\x39\x89\x5e\x55\x78\xa3\xc3\x9b\x0b\xa3\x25\x88\x27\xa0\x1d\xf1\xf3\x0d\xb2\x2d\xdb\xc2\x67\xc9\xe2\x90\xd5\xd4\x57\xd0\xa9\x4d\x8a\xa7\x3f\x8e\x79\xf3\xac\xd3\x1b\xde\xee\x7a\xa3\x2c\x79\x2c\x22\xac\xb8\x07\xba",
        p,
        q,
        g,
        b"\x2e\x06\x07\x3f\x59\x19\x6d\x3e\x29\xba\x71\x8e\x84\x48\x9b\x6f\x44\x7f\xd6\xf6\x7a\x9e\xe6\x35\x7c\x5e\x8a\x58\xfa\x3c\x4f\xb6\xac\x83\x14\xeb\xdc\x3b\x4d\x61\x27\xf2\xb4\xd2\x11\x2c\x27\x79\x9f\x0c\x1a\xc5\xf7\x94\x6b\x56\x07\x21\x2d\x79\x67\x41\xcc\x3b\xe1\x27\x21\x2a\x12\x5e\xdc\x3a\x7a\x91\xa5\x25\xcd\x62\x15\x21\x99\xb1\x8b\x4f\x1d\xc3\x32\x21\x5d\x65\xd6\x4a\xd0\x60\x98\xff\x21\x80\xab\x47\xbb\x57\x28\x72\x0c\x93\x7e\x12\x07\x64\x9e\xd1\x9c\x88\x33\x31\xea\x41\x5f\xaa\x51\xc5\x56\xd1\x26\x49\x66\x5f\x1e\xce\x88\x0d\x05\x5a\x2a\x79\x3a\xdc\x74\xb3\x8f\x15\xf5\x0a\xa9\xb4\x67\x86\xd9\x07\x01\x7b\x1d\x62\x35\xc4\x3b\x37\xc2\x03\x6a\x16\x40\xf6\xbf\xe3\xbe\xc2\xb9\x5b\x43\x00\xa3\xbd\x78\xf4\x71\xf6\xaa\x56\xe5\xe6\x34\x75\x71\x99\x6f\x77\x86\x70\xad\x94\xef\xaf\x20\x99\x1c\x55\x59\x24\xfd\x55\xcd\x51\x8d\xf0\xbd\x55\x8f\xaa\xc3\xf9\x82\x6a\x86\x5a\x3c\xed\x0f\x59\xcb\xea\x45\xc6\x54\x12\xbd\xdf\x8f\x2a\x8a\xab\x3d\xfc\xa1\xdf\xf5\x03\x74\x16\x3f\xa8\x99\xcc\x7f\x7f\x10\x8b\x19\x4f\xc9\x55\xca\xbe\x9c\xa4",
        b"\x5c\x8d\x76\x44\x07\x35\x05\x5c\x1b\x36\x69\x8d\xa7\x39\x03\xb3\x32\xd6\x4c\xa5\x60\x30\x46\x14\x4f\xb7\x66\x8b\x1a\xca\xc3\x37",
        b"\x11\xc5\x4e\xfb\xd4\x92\xa7\x14\x7a\x1c\x50\xb2\x87\x37\x7b\x52\xd2\x19\x39\x07\xd5\xbb\x63\x61\x59\xc1\x53\x18\xa4\x80\xca\x6a",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x3c\x1f\x2b\x92\xdb\x1b\x43\x15\x83\x7b\xaa\x86\x30\x43\xa9\xb4\x49\x6a\x78\x14\x3c\xa7\x4f\x6e\x67\x18\x1f\xac\xf5\x0a\x6e\x08\xd2\x79\x45\xd0\x0e\x7b\x06\xf9\xc5\x7c\x0e\x2f\x15\x27\xc9\x4b\xce\xce\xa6\x99\x31\x75\xd0\xf0\x9b\xab\x4f\x15\xaf\x55\xab\x7a\xa9\xb1\x6b\x48\xc9\x4a\x6a\x99\xc2\xd7\xe4\x77\xb7\x44\xcd\x27\xcd\xb9\xb0\xbb\xf8\x10\x75\x6b\xc6\x37\x6f\xa1\x5b\xfb\xea\x3c\x93\x76\xca\x69\x79\x75\x2f\xdb\x3a\x65\x5a\xff\xd6\xc0\x18\x6d\x1a\x34\x35\x5d\xae\xa8\xcc\x75\xac\xf9\x6b\x88\x47\xdb\xdb\x8d",
        p,
        q,
        g,
        b"\xa4\x74\x2d\x3c\x7e\x76\x81\xb0\x1c\xd6\xaa\xe1\x74\x23\xcc\x78\x04\x91\xd0\x8d\xf7\x3b\x4a\x71\xed\xf7\xbd\x2e\xe2\x9c\x69\x8c\xd6\x6d\xba\x04\x91\x68\x8f\xc7\xee\xfb\x4d\x70\x91\x47\xbf\xd4\xc8\xc4\xb7\x97\xab\x91\x97\x57\x3b\x5d\x36\x59\x9c\x4a\x59\x2c\x46\x69\x55\xe8\x0a\xe5\xd2\x12\x2b\xca\xa5\xd0\xe1\xd9\x4b\x4e\xd2\xa9\x9b\x1a\xf5\xd0\x8e\xec\x86\xc3\x77\x53\xa3\xc3\x65\x6c\x0f\xef\x0d\x2c\x47\x1e\x4f\xfa\x0f\xb1\x63\x17\x4a\x4d\xf1\x70\x78\x79\xfe\x08\x36\x55\x29\x11\x27\xa3\xbb\xb0\x59\x7e\x23\x80\x2e\x42\x4e\xfe\x40\x16\x36\x03\x64\x50\x6c\x8a\xb4\x08\x1f\x0a\x95\x69\x2c\x26\x29\x53\x7f\x05\x30\x61\x81\xdb\x66\x9b\xcf\xaf\x01\xc1\x53\x95\x61\x42\x38\xa2\x30\x94\x29\x19\x95\x55\x14\x26\x39\xb3\x44\x3e\xf8\x5a\xf7\x4b\x5e\x88\xb7\xc7\x0a\x81\x67\x33\x4f\x27\x29\x4a\x8b\xa1\x26\x66\x95\xa3\x69\x37\x2b\xad\xcb\xa7\x62\x3a\xa5\x8c\xbc\xf2\x5b\x4b\xbe\x66\x3d\x4e\xce\xd1\xa1\x8e\x77\x53\x39\x1d\x6c\x53\x85\x4c\x4a\x8d\x0e\xe1\xa7\x90\xa1\xa2\x10\x71\xf1\x38\x6c\x23\x5a\xc2\x61\x82\xd0\x1a\x1e\x81\xec\xf8",
        b"\x31\xc1\xc6\xae\xe7\xed\x54\x1a\x28\x1f\x37\x63\x2b\x27\xba\x88\x53\x6f\x36\xbc\xd9\x2f\xcc\x36\x0d\xa0\x41\xf4\x19\x7f\x7f\x95",
        b"\x45\xe1\x01\x9b\x2a\x17\x02\xb5\xdf\x1e\xef\x4f\xb7\xdf\x6a\x53\xaa\xa6\x6e\xcb\x8b\xe5\xcd\x2e\x28\xb3\x53\xc8\x70\xe0\x1f\x41",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xad\x38\x9f\x53\x23\x5d\xeb\x06\x8f\x70\x97\x78\x03\x30\x74\x64\x93\x60\x7f\xdb\x7e\x11\x70\xbd\x1f\xe0\xda\x01\x27\x14\xb8\xf1\xb1\x28\xc6\x9a\x53\xd7\xdd\x26\x46\xb0\x97\x20\x88\x3e\x23\x87\xdd\x15\xd4\x65\x64\xad\xff\x66\x42\x37\x2c\x83\x82\x87\xba\xfa\x5f\x43\x43\xa2\x7e\xc8\x06\x97\x70\xe5\xc3\x67\x54\x88\x33\xfd\xdc\xc5\xf8\x61\x7a\xaf\x41\x28\x9d\x96\xdd\x40\xf1\x09\x8d\xed\x9f\xbb\x11\x0a\xeb\x14\xd6\x92\x72\xdf\xb2\xdd\x7d\x75\xe7\xa8\x8d\xc4\x14\x7f\x27\xc6\x4e\xb1\xbf\x0a\xa0\x56\x9b\xbd\xa3\x20",
        p,
        q,
        g,
        b"\xbf\x4a\xa2\xd8\x67\xb4\x33\xf9\x34\xd1\xd5\x67\x01\x0d\xbe\x06\x79\x05\xf4\xe3\x5d\x7c\xe5\x68\xb5\x5a\xba\x69\x4d\x12\xdf\xba\x95\xc2\x35\x07\x84\x61\xaa\xab\x81\xf1\xe4\xdf\x32\x31\x9e\x57\x59\xc5\x26\x3e\xbf\xbe\xbf\x79\x60\xc5\x7a\xed\x79\xbf\x2d\xe3\x89\x48\xf8\xff\x79\xef\x26\xd6\x6a\x7f\x98\x38\x41\x17\xdc\xe1\xf3\x86\xae\xcc\x43\x69\xaf\xb2\xe0\xde\x77\xcc\xd2\xe7\xde\xc3\x28\x61\x42\x43\xef\xfa\xc6\x07\xc8\xd5\xfc\x5c\x7c\x0b\x11\x43\x96\x35\x73\xd9\xf1\x06\xfc\xec\xf2\xe1\x5c\x67\xa3\xbf\xf6\x90\x8b\x28\x6d\x0e\x41\x31\xfb\x81\x62\x2f\xff\x9e\x10\xf5\x77\x1a\xfe\xde\x22\x76\xe8\x34\x4d\x9a\xe2\xf4\x93\xfb\x48\x56\xd1\xba\x57\x60\xdd\xae\x38\xaf\x7d\xdc\xa4\x09\xe7\x90\x72\x68\x69\x1b\xaa\x33\xdf\xcb\xfd\x69\xe9\xaa\x9f\xaa\x79\xcf\x30\x3a\xc8\xb1\xfa\x07\xc1\xd4\x0d\x1c\xea\x01\xe8\xba\x0d\x65\x26\x5f\x4c\x6a\xab\xb1\x6e\xbe\x2f\x6e\xf5\xaa\xac\x25\xc0\xc2\x73\x0c\xbe\xed\xc1\x77\x66\x7e\xe0\x2b\xf4\x52\x34\x18\xa9\x86\xd5\xb8\x7a\x9b\x75\xec\x20\x1a\xf0\xf1\x96\x1c\xd5\x1b\x85\x87\x91\x47\xe6\x07",
        b"\x2f\x94\x84\xaa\xed\xa9\xdc\xb8\x8d\x2d\x36\x44\xdb\x2c\x58\xee\xfe\x2e\x76\x95\xa6\xc8\xbe\x9a\xbe\x97\x17\x3e\xfc\x9c\x0b\xc3",
        b"\x01\x66\xa7\xbf\x4e\x8b\xda\x6b\x86\x39\x69\x43\xa7\x4a\x8e\xbf\xc6\x03\xa8\x5e\xd2\x87\xbf\x3f\x5a\x30\xdd\x0b\xbe\x49\xcd\x8b",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x12\xf9\x58\x2e\x3a\x1a\x76\xf2\x99\xd7\x2d\x9b\x15\x02\xb9\x90\x60\x80\x26\x60\x22\x6b\xc4\x7b\x71\xe5\x4e\xc9\x38\x8e\xac\x32\x59\x02\xac\xbe\x2b\xd7\x10\x9e\x19\xf3\x77\xc9\xd2\xb4\xd2\x80\xcd\xfa\xa4\x88\x88\xb9\xcf\x4e\xd0\x6c\xcf\x5a\xd8\x66\xd6\x93\x2d\x40\x25\x92\xf6\xbe\x6e\x68\x76\xdb\x5a\x62\xbe\xea\xf3\x73\xb6\x02\x38\xab\x96\x82\x92\x43\x75\x9b\xdb\x58\x6f\x45\xec\x4a\xe2\xcb\x22\x24\x8a\xb0\xb6\xaa\x7a\x75\x83\xa6\x1d\xd3\xb8\xf1\x19\xcd\x84\x04\x79\xa4\xa9\xaf\x8a\x43\x9d\xb9\x04\xac\x14\xec",
        p,
        q,
        g,
        b"\x72\xd8\x10\x06\x92\xe1\xa3\x0a\x32\xe3\x7c\x90\x9e\xb6\xc7\xba\xea\x72\x58\xb0\xb7\x86\x68\xe7\x59\x15\x07\x00\x37\x47\x9b\x88\x4f\xa9\xf1\x80\x66\xdf\x89\xb4\x90\xf9\xa2\x69\x6a\x85\x05\x03\x69\x77\x60\x4d\xad\x26\x8e\x90\x55\x28\x35\xfd\xca\x33\x39\xb3\x23\x60\xc9\x43\x58\xff\xcd\x0b\x1e\xa1\x10\x66\x12\x2e\xfd\x01\x7c\xd6\xfe\x1e\xcd\x0d\xd6\x67\x80\x81\xb8\x4c\xb6\xe1\x44\x47\x1d\xae\x76\x36\xb4\xa0\x92\x9c\xa7\x1a\xa4\x7b\x40\x86\x66\x5d\x66\xd4\x03\x4c\x18\x8d\x64\xd3\x8b\x69\xf0\xca\x17\x1c\x85\x92\x5c\xad\x28\x40\x27\x7d\x28\x87\xa7\xf7\xb8\x1e\x6b\x12\x87\x0c\xc3\xc6\x9e\x18\xca\x9c\x22\xc3\xd3\xa3\x9e\xe2\x86\xca\x65\xd2\x3f\x3e\x81\x11\xaa\x7c\x6e\xa9\xa0\xd1\x4c\x84\xdd\xf7\x6a\xbd\x44\xdb\x3b\x98\x33\xd6\x9c\xb9\x9b\x52\x4c\x98\xfd\xb9\xd0\xff\x20\xc9\xd2\x68\xe8\xe7\x17\x5f\x13\xc1\x1c\x57\x95\xd0\xfe\x0b\x38\x99\xb7\x4c\x0d\xca\x91\x47\x6f\xeb\xcb\x50\x9f\x7f\xd5\x07\x02\x39\x88\x14\x52\x42\xdf\xc8\x09\xce\x95\xc6\xf1\xb3\x1f\x67\xe0\x16\x50\xdd\x45\x87\x8e\xfc\x7e\xa8\x9c\xf6\xe3\x17\x1e\x43",
        b"\x38\xcf\x6b\x8c\xba\xe8\x2e\x62\x95\xf8\x33\x16\xa9\xc4\x9d\x2d\xc7\xc9\x2c\xb9\x0b\x19\xa2\xc2\xd4\x56\x49\x94\x93\x54\xd9\x30",
        b"\x35\x6a\x58\x50\xd0\x7a\xec\x6e\x9d\x4a\x4d\x7f\x79\xd9\xb0\x35\x2b\x08\x7d\x7e\xf4\x83\x94\x12\x8c\x5a\xe4\x99\x3e\x82\x59\xb8",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xb6\xac\x84\xc4\x9f\x6b\xd6\x01\xd5\x86\x8b\xa0\x6d\x49\xb8\xcb\xa8\x7a\x9d\x6e\x79\x05\x24\x75\x41\xfd\x33\x2c\x2b\x03\x74\xcf\x57\xd4\xa0\xdc\x0b\x5a\x6c\x3f\x8f\x7e\x24\xbe\x3a\x1e\xed\xc4\xa8\xc5\x75\x84\x7c\x02\xe4\xed\xd4\x74\x50\x40\x68\x56\x70\x05\x89\x96\x25\x0f\x73\xe2\x98\xa4\x3b\x39\x1a\x4a\xd5\x67\xf0\xc9\xbc\x4b\x6a\xbf\x6d\x1e\x5c\x56\xb2\x2f\x4e\xab\x36\xaa\x1a\x81\x2a\x1d\xae\x8d\x28\x73\xcb\x2c\x2a\x52\x1d\x32\x00\x19\xc7\xca\xb1\xef\xb1\x1f\xa4\x59\x5c\x53\x4c\xe5\x27\xd4\x3b\xa6\x05\xf7",
        p,
        q,
        g,
        b"\x06\xda\xb4\x8a\x07\x6e\x8c\xec\x27\xd4\xc4\xfb\x98\xe7\xc0\x0f\x36\xbe\xd7\x3f\x11\xe4\x91\xd9\x13\x86\x4c\xae\x0f\xdf\x88\x34\x68\xd7\x35\xde\xee\x52\x51\xdd\x38\xa1\xf8\xb1\xd2\xbc\x19\xd3\x7f\x31\x87\xa4\xef\x69\xc3\x3d\xc9\x52\x88\x01\xa2\x3a\x98\xd9\x6f\xd3\xf1\x29\xb8\xca\x29\x41\x42\x1b\xa1\x82\x8e\x0c\x4f\x8d\x88\xc5\x31\x93\x93\x02\x92\xa0\xdf\x11\x47\xb0\x7c\x20\xaa\x72\x6c\x71\x77\xef\x66\x0d\xdd\x4e\xcd\xd7\x33\x15\xd4\xb9\x35\x60\x13\xe1\x15\xf0\x67\xe8\x43\xc8\x96\xc1\xa5\x4c\x81\xff\xab\x1b\xfe\x7c\x78\x5e\xde\xc3\x2f\xba\x65\x2b\xab\xfd\xaa\xa0\x39\xb0\x56\x8c\x6b\xeb\x7d\x13\xfb\x4e\x45\x88\x14\x0e\xd6\x26\xb1\x87\x49\xb0\xf7\x9f\x66\x9f\x6e\x70\x45\x73\x8c\xf5\x0a\x6d\x00\x28\xba\x11\xfe\x18\x45\xa2\xdc\xbd\x9c\x1b\x02\x33\x6f\xb3\x0e\xaa\xa3\x97\x41\x8f\xe1\x7e\x14\x98\x29\xca\xb1\x3d\x2c\x2e\x6b\x90\xe5\xcc\x81\x83\x4e\x32\xfc\xa8\xa1\x73\x63\x4e\x01\xf9\xa9\x73\xe0\x29\x64\x4f\x01\x65\xb3\x03\x3d\xfb\x05\x4d\xd2\x1d\x65\xe0\xc0\xe1\x37\xb4\x8c\x34\xd4\x21\x34\xc4\x7b\x97\x24\x33\xcc\xde",
        b"\x1d\x60\x0a\x74\x5a\x1d\xec\x93\x38\x68\xdc\x53\x5a\x19\xee\x9f\x1a\xf8\xbf\x09\xb5\xab\xee\x15\xdc\x4f\x7c\xbc\xb9\x5a\xc8\xc5",
        b"\x23\xb8\x10\x97\xd5\x83\x34\x2e\xbe\x4a\xed\x36\x4a\x7a\xf9\x88\x2f\x74\xe6\x45\x18\xaa\xed\xce\x34\x6c\x91\xd6\xd7\xac\x47\x0b",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xa9\x2e\x2d\xdb\xfd\x18\xcd\x30\x73\x73\xfc\xb3\x9d\xff\xc3\x3e\x0b\x91\xa4\x8c\x62\x07\x1f\x2f\x7a\x8e\x50\xdb\xf2\xc2\x90\x88\x93\x07\x97\x5b\x6a\xcd\x64\x2c\x8e\x3d\x34\x44\xac\xac\x98\xc2\x2e\xd0\x65\x51\xfe\xc5\xdc\x7c\x9f\x22\x43\xb6\x81\xcc\x9f\xa4\xfc\xc1\x2c\x31\x82\x37\xe9\xa5\xdf\x0a\x77\xac\x22\x40\x20\x39\xce\xf3\x1b\x1e\x62\x3a\xf5\x82\x12\xa2\x2e\x7e\x60\x41\x9b\xb3\x6b\x77\x7c\xf6\xce\x65\xdd\x1f\x56\x96\x3e\xb2\x8b\x77\x06\xf1\x37\xc0\xf7\x36\x3a\x00\x2d\x82\x7e\x45\xba\xdc\x20\x23\x3c\x16",
        p,
        q,
        g,
        b"\x51\x41\x22\x3f\x46\x97\xde\x27\x22\x69\xf3\xd9\x94\x37\xc4\x8d\xba\x5a\xb7\xf1\x37\x3f\xc6\xba\xd8\x16\x10\x18\xc5\xd6\xfc\xe2\xbc\xcc\x40\xca\x78\xe4\xd7\x3b\x6e\xeb\x09\x6f\x17\x5c\x4c\xd0\xc8\xe9\xf3\xe9\x31\x19\x51\xd5\x1e\xa2\x44\xfd\x33\xd9\xe4\x7d\xe7\x5f\x10\x00\x24\x8f\xdc\x00\x3b\xc0\x7b\x50\x1c\xe5\x8f\x6e\xc1\xae\xd1\x75\x4c\x36\x82\x6c\xd9\x19\x76\xb4\x08\xeb\x7a\xa9\xbc\x42\x44\x80\x58\xff\xd3\xb4\xe5\x13\xc6\x58\x9f\x8e\x1b\xc1\x45\xa4\x7b\x24\x70\xe7\x24\x1e\x23\x25\xe5\x43\x02\x25\x5c\x3d\x6d\x97\xab\xc5\xc6\x05\x62\x66\xa9\x52\x3d\x46\x1f\xc7\x44\x14\x6d\xa3\x5c\x04\xa4\xfc\x0b\x09\x58\x81\xcb\x94\xfc\x4c\x03\xbb\x86\x23\x95\x39\x28\x49\x0d\xbe\x7f\x84\xef\x68\x66\x7f\x23\xd4\xcb\x3e\xd8\x87\x44\x9f\x77\xae\xb1\x58\xa2\x6d\x1b\x39\xb4\xe6\x29\x7f\x23\xd4\x9f\x5b\x41\xf1\x70\xe7\x2f\x72\x13\xee\x40\x36\x4c\x1c\x9a\x63\x98\x5f\x69\xe4\x4e\xac\xdf\xdc\xb5\x8c\x35\xda\xce\x8b\x93\x5d\x07\x89\xa8\xc0\x66\x9a\x23\xd6\x73\x92\x9b\x2a\x58\x2d\x6d\x3b\x2f\x9e\x67\xbe\x89\x18\x90\xda\x12\x36\xc6\xf0",
        b"\x34\xa6\x5e\x99\xbf\x01\x69\x8b\x5a\x68\xf2\x15\xb9\xc2\x92\x11\x5d\x17\xb3\xc2\x02\xea\x1f\xda\x17\xfc\xd8\xa0\xcd\x74\xb6\x36",
        b"\x7e\x67\xd4\x42\xb8\xf9\xac\x29\x74\xe8\x4b\xa6\x5a\xef\xf0\xdf\x5f\x83\xc2\x71\xec\xe7\x92\xa8\xda\xb9\xc4\xae\xe8\x7b\xfe\xa8",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xb5\xaa\x1c\xfe\x23\x48\xd5\x7f\x0e\x53\x33\xfc\x70\x27\x6d\x24\x18\xdd\xda\x49\x12\x2f\x4a\x88\xe8\x01\x0f\x6f\x78\xdc\x82\x9b\xa5\xc7\xcc\x68\xdb\x66\x40\x80\x94\x5c\x43\xee\xb7\x05\xc2\xef\x13\xde\x6e\x4b\x8f\x4d\xe1\xd0\x4f\xb3\x3d\x5b\xcd\x78\x93\xd8\xca\x8b\xfd\xe3\x8c\x9f\xec\xa6\xc4\xec\x03\xb2\xce\x7b\x35\xed\x60\xa6\xa4\x3f\x7f\xc9\xed\x08\x06\x1a\x09\x9b\x3e\xee\xae\x7f\x0f\x15\x16\x14\x9d\x17\x5a\x95\x3f\x52\xc8\xc5\x18\xf3\xad\x24\x7c\x9f\xba\x23\xf1\xf8\x29\xd5\xca\xe6\x26\x73\xee\x20\x1a\xda",
        p,
        q,
        g,
        b"\x0b\x66\xef\x2c\x7a\x34\x20\x5d\x70\xfc\x36\x40\x49\x57\x04\x3c\xf4\x6b\x28\xac\x4f\x08\x3e\xba\xc3\x78\x7f\x55\xe8\xdd\x1f\x75\xd9\x19\x3a\x84\x27\x59\x37\x6f\x05\x08\xc9\x4c\xc7\x52\x8d\x66\x11\xb5\x0a\x73\x26\x1a\x4a\x5c\xff\x73\x0d\x99\x85\xbb\x34\x1d\xfd\x73\x9a\x4e\x96\x3d\x1c\x40\xf1\x14\xd7\xa7\xac\xe8\x9e\x81\xdd\x70\x86\x1e\xfe\xf2\xba\x9d\x1c\x64\x25\xd5\xf8\x58\x09\x05\x9e\x8e\xf3\x1f\x45\x3c\x97\x74\x3f\xcc\x94\xd3\xb1\xbd\x62\x08\x4e\x97\x57\x90\xb3\x71\x93\xeb\x40\x58\x45\x4a\xb2\x83\xfe\x2b\xaf\xaa\xe8\x03\xde\x89\x28\x79\x55\x4a\x34\x0b\x9a\x3e\x25\x32\x93\x1e\xb9\x5d\x3a\xc5\xeb\x3f\x29\x0a\x3f\x56\x93\x69\x51\x28\x8e\x1c\x05\xbd\xa1\xfa\x74\xdc\x78\xd6\x31\xc2\xe7\xa5\x63\x67\xec\x57\x81\x01\x9d\xfe\xe7\x14\x53\xea\x6b\xbd\x90\x77\x8e\x92\xfe\xa8\xc2\x6b\xd6\xa8\x23\xfb\xca\x71\x57\x7b\x63\x35\xf3\xbd\xf4\x0a\x30\x83\x6e\x94\x8d\xb0\x32\xdb\x5a\x46\x03\xdd\x31\xb8\x51\xec\xbb\xdf\x76\xb4\xa6\xc9\x95\x1d\x21\x92\xb9\x7f\xf0\x1d\xaa\x5c\xb0\x30\xe1\x5a\xd1\xd4\xcf\xf3\x67\xf7\x00\xe7\x9f\xfb",
        b"\x51\x7f\x7d\xf4\x83\x1f\xbd\x01\x90\x8b\x92\x18\xb1\x7a\xe1\xc4\x0e\x00\xc5\x34\x04\xb3\xbd\x72\xb6\x4f\x67\xce\xe7\x52\x15\xf2",
        b"\x19\x03\x43\x4a\x72\x7c\x8e\xf0\xe8\x0a\x43\xdc\xe2\x83\x4b\x80\x78\x39\xef\x43\xc2\x2a\xfb\x50\x2b\x35\xa3\x81\x78\x2b\xb6\x39",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x27\xaa\x81\xd2\xbc\x49\x60\x1c\x3f\x6b\xce\xb0\x87\x0b\xb5\x5d\xd1\x0e\x7b\xa6\xd1\xf8\xac\xad\xa7\x0b\x5f\x90\x2a\x0f\x40\x62\xeb\x93\xae\x72\xcd\xfd\x3f\x94\x30\x99\xcc\x2a\x10\xa3\xda\x7b\xdc\x9f\x24\xb0\x0b\xf3\x6a\x29\xd7\x51\x36\xaf\x10\xbb\x71\xec\x9c\x19\x32\x05\x8e\x22\xec\x9c\x06\x00\xd1\x73\xd3\x79\x70\xd5\x8a\xe1\xf6\x6c\xef\xd2\x7e\x29\x05\xaf\xdd\xe4\x22\x39\x79\xb4\x04\x1f\xd7\xd7\x16\x6e\xa3\x26\xbe\xfd\x5d\xd8\x96\xef\x47\xab\xc6\xd0\x45\xc1\xca\x23\xc1\x95\x3a\x6e\x12\xcc\x3c\x54\xb4\xf6",
        p,
        q,
        g,
        b"\x93\x2b\x9c\x0f\x2d\x31\x0b\x6b\xfe\xe8\x00\xc0\x74\xa0\x96\x9e\xfa\x24\x62\x44\xfb\x06\x2a\x74\x5a\x9a\x3c\xfe\x6f\x53\x36\xa3\x13\x19\x2e\x92\xa2\x02\x7e\x1d\x2c\x3c\xfa\x93\xaa\xc5\x3d\xfe\x05\xcb\x8f\x83\x21\xac\x88\x2a\x63\xbd\x37\x5a\xf0\xf3\xd9\xec\xc7\x3a\xee\xbe\x12\x67\xf4\x73\xa9\xf9\x0b\x94\xf5\xb6\xde\x43\x57\xb7\x4e\xb3\x0c\xd4\x1a\xea\xfc\x25\x9e\x85\xca\xc7\xd3\x65\xee\x33\x38\x2a\x58\x4e\xec\x63\x71\x9e\xa3\x25\xa2\x41\x4e\x11\x6f\x84\xd2\xaf\x96\x54\x26\x8e\xc4\x4d\x6e\xa2\xe9\x81\x58\x1d\x45\xd8\x05\xb3\x83\xd8\x5c\x13\x0d\x2d\xcd\x1c\x71\xfa\x68\xd9\xc7\x6d\x79\xaa\x81\x96\x15\x2c\x1d\x94\x40\xc3\x3d\x99\xde\x45\x1a\x35\x9e\x0d\x2c\x51\xd6\xaa\xec\xb2\x67\x95\x40\x6e\x52\x8f\x5d\xe3\xe0\x09\x47\xd3\xda\xcc\x69\x5c\x08\xa9\x60\x88\x9a\x2e\x94\xec\xf0\xa4\x61\xc0\x2a\xfc\x58\xb5\x1e\x00\x36\x9c\x73\xc8\x14\x0e\x8b\x92\x38\x8c\xaa\xbd\x1f\x37\xa6\x2d\x1b\x21\x0e\x0f\x31\x41\x27\xf4\x6b\x57\x6a\x4b\x8e\xde\xb3\x47\x13\xaa\x41\x36\xb8\xa1\x87\x5b\xba\x8a\x59\x37\x06\x65\x44\xe3\x4c\x20\x6a\xa4",
        b"\x05\x05\x7a\x98\x2a\xb4\xa2\xe3\x22\x38\xef\x2e\x3e\xdb\xa0\x7f\xd1\x93\xd9\x0c\x5f\x05\x3c\x83\xa9\xf1\x76\xe2\x1a\x9d\x52\x08",
        b"\x03\xc2\xb2\x6c\xf4\x6b\x7f\x72\x69\x1a\x72\xd7\xcb\xf3\x36\x53\xdf\x34\x7f\x02\xb0\x68\x3e\xbc\x6c\xb7\xea\x7e\x72\xdc\x8a\x0a",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x75\x27\x53\x3f\x2d\x10\xc1\x80\x78\xf5\xa8\xde\xc3\x50\xcd\xfa\xd0\x6d\x31\x57\x87\x1e\x4f\xf7\xd7\xc2\xb7\xab\x11\xdf\xf2\x32\xd3\x4f\x07\x69\x92\x78\xf0\x75\x44\x2e\x1d\x4e\xe0\x0c\xd6\xe8\x7c\x19\x31\x33\x38\x41\xc3\x99\x57\x6f\x4e\x58\x7a\x25\x16\x84\xe7\x31\xf7\xc8\x36\x9f\x71\x26\x56\xbc\x1e\x6c\x2d\x20\x9f\x51\x11\x79\xda\x09\x36\x8d\x93\x29\x0e\x05\x8e\x0c\xe9\xb6\x53\x0a\xc6\xc5\xe4\xcf\x0a\x1b\x22\xd5\x88\xd9\x8f\x32\xb3\x4e\x85\x20\x6e\x09\xaa\xc0\x4a\x0e\x1f\x2a\xe2\xa5\xcf\xda\xc4\xe6\xe2\xb3",
        p,
        q,
        g,
        b"\x72\xc4\x65\x05\xe4\xb0\x71\xf4\x6e\xd6\xb6\xd5\x30\x80\x16\x64\xa4\xfd\x51\x8e\x4c\x6b\xe8\x46\x8a\x38\xc2\x2b\xf7\x4e\xd9\x66\xfd\xc7\xbf\xd7\xc5\x72\x21\x89\x98\xfc\x4c\x14\x4b\x59\x46\x2a\xf7\xe2\x94\xbd\xf5\x79\x7e\xce\xa5\xcb\x2e\xdf\x8c\x8d\x2d\xab\xba\x88\xd0\xb8\x4c\xf2\x85\x24\x36\x9c\x50\x40\xb5\x8f\x09\x07\x72\xda\xc0\xfe\x45\x3c\x32\x90\x7e\x9b\x6c\x74\x0f\xb2\x4e\xd4\xda\xcb\x8f\xdd\x25\xe0\x66\x1b\xc0\xd7\x9d\x41\xf1\x03\xfb\xc8\xf9\x6b\x3e\x3a\x47\x08\xa5\xa7\xf5\xdb\xff\xc9\x8f\x34\x4b\xb7\xcc\xf0\xd5\xed\x07\xaf\x2c\x2f\x0d\x5f\x40\x7b\xcf\xef\xb5\x4d\x9b\x94\x76\x04\xe7\xa7\x83\x56\x87\x4c\x01\xb8\xc1\xfd\xd7\x49\xf6\xa3\xd6\x19\xd1\x09\x0c\x83\x72\x5e\x72\x57\x06\x84\x6c\x16\xbf\x9d\xfd\xf3\x9f\x21\x80\x62\x3f\x4f\x58\x54\x02\xcc\x7d\x6e\x2c\x10\xb5\x7c\x83\x00\x54\x36\x86\xa3\x86\x05\x6a\x93\x1b\xe6\x33\x6b\xb6\x17\x3d\x9f\xda\x8b\x10\x2c\xf3\x29\x89\xcf\x09\x78\xf9\x56\xd9\xae\x0d\x8f\x30\x75\x2f\x15\x6f\x9f\x92\xd2\x95\x4e\xf1\x31\x00\xa7\x5d\x9f\x7f\xf9\x6f\xe1\x5d\xf0\x7e\x79\x93\xe3",
        b"\x6a\xa6\xc4\xd7\xaf\xda\x30\xff\x2d\x71\x78\xb5\x2a\x3e\x43\x7e\xd5\xb0\x74\x5a\x24\x7c\x9c\x9e\x12\x0b\xd3\xe8\x33\xa1\xdf\xac",
        b"\x26\xe0\x88\x79\x11\xbb\x5e\xdb\x6a\x56\x6a\x2a\x12\x76\x35\x33\x91\xb1\xe4\xab\x8a\xe0\xb2\x59\xc1\xbb\xb3\xaf\x3d\x85\xb4\x39",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x99\x4a\x49\xe5\xe8\xa5\x69\x8f\xda\xc9\xa7\xfa\xac\x01\xfb\x09\xb2\xc6\x11\x3a\x18\x66\x77\x67\x6d\x11\xe6\x04\x9d\xc9\x8c\x93\xc5\x1e\xb5\x14\x4a\xf1\x81\xe1\xef\xbf\x44\x43\x9a\x13\xd2\x95\x65\x38\x54\x81\x36\x71\xf0\x32\xaa\x62\x25\x8c\x14\x19\x5c\x48\x64\xaf\xae\x0b\x5d\x15\x4f\x97\x56\x5c\xef\x07\x5b\xbb\x6d\x97\xe3\x41\x81\x41\x03\x09\xff\xe9\x8b\x45\xc1\xf8\x74\x32\x63\x43\xc3\x6c\x14\xf5\x5f\xa0\x58\x48\x9d\xff\x3b\x49\xdc\x78\x88\xf4\x5a\x09\x9c\x3c\x91\x9b\x25\xed\xac\x17\x06\xbb\x90\xf1\x64\xca",
        p,
        q,
        g,
        b"\x05\xe2\x33\xac\x49\xc1\xfd\xa2\xa0\xc3\xc7\x8b\x0b\xc7\x2f\xa3\x96\x74\x05\x5d\x18\x8a\x12\x4a\x58\xab\x38\x50\xd9\xa8\x88\x86\x1c\x2f\xe4\xd0\x46\xc3\xe7\xc7\x5e\xe2\x54\xde\x70\xcd\xb1\xc3\x15\x02\x01\xc2\xe0\x47\x33\xeb\xcc\x25\xb8\x87\x70\xfc\x2a\xa8\x2f\x60\x52\x6b\xc6\x64\x04\x7a\x02\x6c\x22\x90\xfa\xd8\xe9\xf8\x1c\xed\xdd\xde\x7f\xe3\xba\x40\x65\x35\xbf\x27\x10\xd7\x9d\xa0\x1b\xd2\xd4\x2b\xb5\xf4\x09\x9c\x3f\x8b\xc2\xac\x86\x4b\xe7\x89\x2a\xeb\x6a\x1f\x34\x02\xc8\x14\x74\xda\x23\xe0\x79\x5c\xd6\xc2\x13\x67\x50\x9a\x54\x15\x91\xee\x1e\x63\x64\xf7\xe7\x55\xb1\x41\x9e\x90\xaf\x86\x99\x30\x15\x2f\x34\xde\x51\xf0\xf0\x6c\xa3\x07\x6e\x68\xc3\xe3\xea\x7f\x4f\x1b\xf1\xd3\xcd\xe3\xa0\xdf\xf0\xcf\xfa\x1b\x58\x42\x75\x23\x47\x08\x2d\xda\x34\x75\x99\x2f\x15\xa7\x4d\x29\x85\x24\xe6\x36\x22\x0b\xc9\xfa\xed\x08\xaf\x7a\xa5\xe4\x81\xba\x78\xd2\xd2\xfd\x8e\x51\x94\x2c\xfd\x08\x4e\xfe\x0e\xbd\xdd\x75\x00\xef\xc9\x5a\x6c\xad\x37\xfc\x49\x23\xf9\xbf\x65\x29\x78\x05\x84\x08\x76\xc6\x89\xee\x07\x9b\x7f\xa6\x16\x97\x68\xfa",
        b"\x3c\xc2\x69\xbc\x7b\x89\x58\x64\xa0\x32\x31\x31\x8c\xf3\x93\x79\xae\x33\xc7\x18\x0a\x18\xc0\x8b\x5a\xef\x74\x14\xfd\xac\x05\x8f",
        b"\x6a\x6e\xb8\x3c\x5f\xab\x10\xe3\x4f\x04\x16\x62\x8c\x82\x1a\x6d\xe0\xad\x0c\x20\x24\x43\xc6\xdf\x03\x2c\xc9\xd8\xe4\x94\x8a\xc6",
    )?;

    // [mod = L=2048, N=256, SHA-224]
    let p = b"\xd0\x22\x76\xeb\xf3\xc2\x2f\xfd\x66\x69\x83\x18\x3a\x47\xae\x94\xc9\xbc\xcb\xcb\xf9\x5d\xdc\xb4\x91\xd1\xf7\xce\x64\x35\x49\x19\x99\x92\xd3\x7c\x79\xe7\xb0\x32\xd2\x6e\xd0\x31\xb6\xba\x44\x89\xf3\x12\x58\x26\xfa\xfb\x27\x26\xa9\x83\x33\xeb\xd9\xab\xdd\xe5\x92\xd8\x69\x3d\x98\x59\x53\x6d\x9c\xc3\x84\x1a\x1d\x24\xe0\x44\xd3\x5a\xce\xd6\x13\x62\x56\xfc\x6d\x6b\x61\x5c\xf4\xf4\x16\x3a\xa3\x81\xeb\x2b\x4c\x48\x08\x25\xa8\xec\xcc\x56\xd8\xdd\xcf\x5f\xe6\x37\xe3\x8a\xd9\xb2\x97\x4b\xd2\xcf\x68\xbf\x27\x1e\x0d\x06\x7d\x24\x65\xa8\xb6\xb6\x60\x52\x4f\x00\x82\x59\x89\x45\xad\xa5\x8e\xa6\x49\xb9\x80\x4e\xb4\x75\x34\x08\xc2\xc5\x97\x68\xc4\x6a\xbb\x82\xe3\x29\x5f\x3d\x9c\xa4\x69\xf8\x4c\xc1\x87\xf5\x72\xdc\x4b\x5a\x3b\x39\x34\x6e\xc8\x39\xdf\xad\x6f\x07\xd6\xd1\xf0\xe2\x15\x20\x9b\xb0\xec\xc0\x5c\x76\x7c\xf2\xe7\x94\x3a\xc9\xcf\xb0\x2e\xee\x1e\x9e\xf5\x94\x6e\x8c\xe8\x83\x16\xb5\xe1\x5f\xdc\xf9\x5a\x13\x2e\xf2\xe4\xbb\x08\x17\x13\x65\x28\xcf\xa5\xdd\x96\x53\x2f\x9c\x3a\xbe\x5c\x42\x16\x20\xed\xb6\xbc\xbd\x52\x23\x4c\xa9";
    let q = b"\x80\x00\x00\x00\x12\x99\x7e\x82\x85\xe4\x08\x97\x08\xf5\x28\x07\x0c\x6d\x7a\xf8\xa0\xbd\x01\x40\x9e\x7a\x07\x9c\xdb\x6f\xc5\xbb";
    let g = b"\x77\x84\x53\x04\x9e\xf2\x62\x14\x7f\xed\x7b\x59\xb0\xee\x67\x64\x60\x7c\x51\xe7\xb5\xb5\xfc\x6f\xea\x7a\x7a\x7b\x1d\xd6\xbb\x28\x3f\x4a\x9a\xe9\x8e\xfd\x39\x64\xb1\x55\x67\x58\xcb\x15\xb2\xa5\x3a\xf8\x61\x9e\x74\xd8\x58\x98\xbe\xc7\x7d\x3b\x3f\x38\x24\x94\xae\x59\x61\xa1\x3f\xfc\x74\x5d\xa3\x86\x18\x22\x91\x51\x98\x00\xf9\x9d\xd7\x10\xe0\x0a\xeb\x15\xad\xee\x08\x8e\x27\x98\xee\x2e\x46\xf5\x98\x52\x6c\xf0\xf4\x66\x70\x55\xd1\xba\x00\x97\x50\x04\x1d\xc5\xcd\xd2\x72\x5f\xf1\xd9\x7d\xd3\x40\xc8\x51\x8a\xf7\x67\x1b\x87\xd3\x9d\x67\xae\xce\xd8\x4b\x66\xf8\x4e\x07\x01\xef\xc8\x2a\x5c\x9e\xf9\x54\xee\x57\x6d\x24\xc3\x85\xb1\x4d\x63\x03\x7f\x0d\x86\x6f\xd4\x24\xb4\x97\x5b\xdd\x54\x85\xed\x74\x0c\xb9\x32\xe8\x43\xf9\x06\x68\x3f\x7c\x7b\x2c\x74\x77\x5d\x90\x1c\x36\x1b\x84\x7b\x51\x9c\x0d\xa6\x99\x63\x8d\xa4\x0b\xd7\x36\xb7\x83\xd2\x71\x0b\x2c\x2c\xc2\x6e\xf9\x12\x71\xbf\x4e\x2c\x19\x29\xf8\x76\xe9\x02\xe2\x05\x71\x64\x22\x3b\xc7\x8d\x6a\x2b\x9f\x6c\x0c\x7a\x7c\xb8\x59\x22\xf7\xd6\xc4\x28\x7a\xe2\x38\x61\xf8\x12\x88\x48";
    test(
        HashAlgorithm::SHA224,
        b"\x39\xf2\xd8\xd5\x03\xaa\xe8\xcd\x17\x85\x44\x56\xec\xfa\xd4\x9a\x18\x90\x0d\x43\x75\x41\x2b\xc6\x89\x18\x1e\xd9\xc2\xcc\xaf\xea\x98\xdc\xa6\x89\xa7\x2d\xc7\x5e\x53\x67\xd3\xd3\xab\xfc\x21\x69\x70\x0d\x58\x91\xcf\xf7\x0f\x69\xd9\xac\xa0\x93\xb0\x61\xb9\xf5\x05\x7f\x94\x63\x6b\xc2\x78\x31\x15\x25\x43\x44\xfb\x12\xe3\x3b\x16\x72\x72\xe1\x98\x83\x8a\x87\x28\xe7\x74\x4e\xa9\xa2\xe8\x24\x8e\x34\xd5\x90\x6e\x29\x83\x02\x47\x26\x37\xb8\x79\xde\x91\xc1\xa6\xf9\xf3\x31\xa5\xcf\x98\xa5\xaf\x29\x13\x29\x90\xd2\x74\x16",
        p,
        q,
        g,
        b"\x7b\xb3\x1e\x98\xc7\xa0\x43\x7f\x97\x8a\x73\xd5\xdc\xfb\xdf\xbb\x09\xcc\x24\x99\xdf\xaf\x1e\xb5\x25\x6b\xcc\xd6\x35\x8c\xab\xb5\xf6\x7d\x04\xa4\x28\x23\x46\x3b\x7e\x95\x7f\x2b\x92\x13\xf1\xfa\x8e\x5a\x98\xd6\x14\x48\x47\x01\xab\xb8\xc7\xd6\x76\x41\xfe\x6e\xd0\x6f\xa4\x52\x7b\x49\x3d\xda\xb2\xe7\x46\x40\xfd\xe3\xde\x70\xda\x69\x3f\x1d\xb2\xb8\xe2\x64\x17\x04\x0a\xf0\xee\xa6\xca\xb4\x51\xa7\x95\xa5\x2e\x18\x7d\x2e\xe2\x41\xb9\x3f\x65\xc8\x6c\x6d\x66\xf4\x58\x34\xcc\xe1\x65\xac\x5e\xb6\x70\xd4\xf0\x09\x5c\x23\xce\x97\x57\xe3\xbd\xc6\x36\xf9\x91\xee\x00\x73\xd9\x0a\x09\x20\x2e\xdb\x35\xcc\x3e\xa1\xcf\x9a\xdc\xa1\x61\x7f\xa0\xbf\xfd\x9c\x12\x62\x29\xa6\x04\xa1\xd3\xbf\x49\x31\xdd\xf0\xb9\x94\x2d\xfc\x8a\x2f\x8c\x09\xfc\xc9\x70\x32\x56\x4a\x79\xae\x1e\xbe\x1e\x2c\xe4\x9f\xf5\x78\x39\xe7\xc4\x3f\xa6\x0b\x16\x03\xd1\x5a\x45\x08\x98\xaa\x4e\x4a\x1e\xe8\x06\x57\x94\x12\x6d\x64\xf0\x13\x36\x70\x96\xa8\x36\x86\xb9\xf1\x58\xc3\x3b\x10\xf5\xf3\xb3\x6c\xf1\xf6\x35\x8b\x3f\x34\xf8\x4b\x10\x1d\xc2\x6d\x3d\xb6\x8b\xcc\x95\xc8",
        b"\x05\x9b\xee\x9e\x70\x8b\x7f\x20\xc3\xf7\x91\xa6\x40\xed\xee\x96\x4e\x0a\xa6\x72\x89\x3c\x48\x47\x99\x71\x58\x17\xb3\xa8\xf6\xd4",
        b"\x4b\xd4\x1c\x84\xa7\x24\xcc\x86\xe4\xf0\x19\x4e\xc0\xfb\xf3\x79\xe6\x54\xd0\xd7\xf6\xa1\xf0\x8b\xd4\x68\x13\x94\x22\xa5\xc3\x53",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x05\x77\xee\x4a\x9b\x8d\xbe\x3c\x6f\xb9\x72\x51\x74\xe8\x99\x40\xb2\x7e\x8a\x98\x92\x17\xb6\x44\x17\xe6\x6f\x39\x6a\x35\xe5\x82\x4f\x21\xe5\x82\x36\xb2\x79\x10\xa3\xbe\x6b\x57\xd3\x11\xaa\x77\x8b\xef\x63\xdd\x02\x5d\x94\x35\x30\x1a\xef\xc9\x22\x23\xc1\xaa\xbb\x03\xd3\xd5\xd3\x85\xb1\xa3\xd1\xf9\x37\xf0\xf1\xf7\xf8\xba\xba\x91\xa0\x11\x20\x74\x80\xb5\xc2\x3a\x78\xeb\xae\xa6\x9a\xe8\xad\x43\x73\xb2\xb0\x52\xd6\x0c\x54\x61\x11\x14\x79\x59\x1f\x83\x30\x12\x3b\xf7\x43\x70\xfb\xa6\x6b\xc7\xe2\xb4\x00\x19\x2c\x47",
        p,
        q,
        g,
        b"\xc5\x4a\x57\xb0\x8f\x25\x5d\xb1\xc7\x76\xbb\x21\x26\xea\x3c\x1e\x60\x22\x9f\x1e\x19\x81\xe4\x3f\x1d\x6b\x91\x10\xf9\x50\xed\xd8\x24\x5e\xec\xa7\xd5\x5b\xa0\x64\x68\x04\x08\x55\xb7\x36\xdb\x50\x2f\x01\xd6\xb3\xcb\x2d\x9d\x62\x1c\x4d\xb4\x4c\xf8\xcb\x39\x0a\xb2\xae\x33\x2b\xca\x21\x9e\x09\xbb\xbb\xc2\x25\x54\x1d\x4a\x0e\xc0\xb4\xf1\x1a\x59\x1c\x07\x7f\x23\x82\xf0\x4b\xd9\x3b\x36\x4c\x94\xfb\x1c\x61\x47\xff\x77\x84\xe8\x25\x58\xe5\xfb\x68\x42\x74\x59\xfa\x9a\x69\xd7\x8a\x9f\x60\x51\xbd\x94\x31\x88\x7a\xce\x46\xfa\x49\x70\xf0\xe2\x2d\x75\xd2\xbe\xfa\x5a\x22\x8e\x48\x9e\x00\x9a\xf9\x7c\xe9\x21\x14\x08\xb4\xe5\xbf\xe3\x7d\x3e\x07\x00\xb2\x58\xb5\x41\x74\xa5\x12\x5e\xb6\xbb\xec\xa3\x88\x05\xda\x53\xb1\xf5\x82\x9d\xfd\xec\x8c\x4c\x93\x76\xbf\x23\x5b\x7b\x0e\xb7\x11\x9d\x3d\x69\x76\x8b\x80\xee\x02\x23\x45\x89\xb8\xd9\x5f\xaf\x80\x62\xa8\xe1\xe9\xc3\xa6\x86\xb6\x35\x0e\x30\xfa\x53\x5e\xaa\xe7\x1d\x75\x3b\x7c\x3b\x04\x8f\x8e\x97\x22\x25\x4d\xed\xbc\x22\x0a\xc9\xc9\xaf\x07\x84\x53\x20\x32\xab\x65\xe4\x8c\xcf\xcf\xd6\x23",
        b"\x33\xc1\x98\xea\x68\xbe\xc4\xa7\xfe\xda\xf0\x30\x9c\x31\x7d\x33\x6b\x97\xd1\xeb\x1f\x1d\xc4\x4e\xba\xf5\xc8\x5c\x5a\x3a\xfa\x98",
        b"\x5c\x9b\x23\xc1\x3b\xb6\x07\xbe\x54\x73\xb3\x2a\xe2\xb5\xe8\xf2\xa1\xe1\x8f\x59\xdf\x8c\xa7\xfd\x93\x03\xf7\x6e\xd8\xe6\x80\xe3",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xc6\x43\x69\x5d\x29\xb2\x82\x10\x01\x7a\xa5\xa7\xd1\x6e\xbe\xd8\x1b\xa0\x0a\x86\x9d\x66\x81\xd1\xc0\xfe\x90\xa5\xe8\xbe\x9d\x59\x73\x29\xea\x15\xd2\x4b\xa1\x2d\x77\xe4\xc3\xf2\x16\x0b\xcb\xe8\x08\x84\x0c\x6e\x77\xb0\x52\x8b\xf9\xae\x58\x87\x38\xe2\x2f\x41\x91\x0a\x80\xa7\xc6\xe3\x34\x0c\x12\x7b\x9d\xe1\x79\x45\xe7\xf9\x22\x99\x53\xe2\x85\x02\x17\xb6\xd4\x86\xf7\xcc\x80\x4e\x72\x0d\xe2\x14\xce\xf0\x2d\xf4\xa8\x92\xf7\xe4\x28\x98\xf1\x5c\xaa\xd2\x6b\xb3\x0b\xfa\xf4\xb0\x55\x1a\xee\xa1\x40\x35\xcb\x75\x6b\x11",
        p,
        q,
        g,
        b"\x17\xff\x2a\x5e\xff\x39\x26\xee\x15\x20\xd5\xa6\x3a\x13\xb4\xf7\x01\xdc\xee\xd2\x5a\x65\x39\x66\xf5\x25\x45\x0b\x3a\x63\xb0\x32\x29\xd6\x15\xec\x54\xcf\x4f\x6d\xdb\x86\x8b\x54\xdf\x36\x3f\xee\xcc\x95\xeb\x8a\x3a\xb2\x58\x7f\xc4\xde\x9c\x93\xdc\x8f\x8d\x7f\x38\xf9\x90\x82\xd2\x86\x7b\x23\xd0\x73\x58\x4c\x83\x1b\xaa\x09\x61\x65\x1e\x07\x1b\x43\xf9\xd5\xda\x97\xb6\x0e\x7b\x5b\x7a\x93\x5f\x6c\x1d\xc8\x82\x79\x60\x8e\x2b\xec\x5c\xac\x61\x62\x48\x80\x85\xd0\x92\xa9\x7c\x6b\x6f\x24\x53\x65\x89\xb8\x01\xb6\xb4\x8d\x47\x87\x96\xb5\x2c\x05\x56\x4e\x90\x4b\xc5\x8a\xc1\x50\x50\x74\xdb\x37\x34\xfc\xf3\x57\x5f\x79\x95\x2b\xa0\xa2\xa0\x69\x7e\x55\xe5\x79\xd5\x08\xa4\x00\xeb\xfb\x2d\x46\x94\xb7\x20\x80\x4a\x9d\x00\xf8\x84\x5e\xf0\xa8\xe6\x90\xe6\x75\xb4\xc1\xce\x07\x99\x6d\x64\xe6\x66\xb0\xd6\xa1\xd6\xfc\x6b\xbc\x3c\xd9\xb5\xcc\x38\x64\xe5\xe8\x88\xe3\xc3\x35\xe0\x5e\x83\xc6\x7c\x00\x33\xba\x5e\xfc\x3d\xcd\xec\x04\x46\xd3\xb4\x07\x93\x23\x6c\xa0\x74\xc5\x4d\x2a\x74\xda\xd2\x96\xd7\xc6\x39\xde\xc9\x38\xe3\xbf\x1c\xa0\x85\xdc",
        b"\x4d\xdd\x2a\x1f\x41\x1b\x57\x0f\xef\x6d\x91\x84\x40\x9b\x4f\xd5\x5d\x12\xc5\xe4\xbd\xdc\x2a\xc7\x21\x12\x35\x87\x33\x22\x15\x5d",
        b"\x40\x43\x95\x2c\x10\x8e\xf8\x4a\x25\xa1\x68\xea\x5b\x64\xa4\x38\x6f\x7a\x48\x33\x66\x05\x4c\x5d\xfb\xfc\x5f\xa9\x85\x79\x43\x2a",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x2f\x64\xd1\x1e\x29\x02\x75\x98\x7b\x7d\x74\x30\x24\x22\x89\xaf\xd5\x4f\x1b\xe0\x28\xcf\x36\xf8\xf5\x5d\xb5\x4b\xe7\x0b\x8d\xd5\xad\x74\xae\x26\xe0\x79\xd0\xed\x31\xa3\x61\xc1\x16\x95\x1b\xde\x94\xd6\x86\xab\xf1\x5a\xc5\xed\x14\x70\xc3\xe9\x02\x46\x1c\xea\x8e\x5d\x58\xf4\x07\xd2\xe0\xc0\x72\xee\x61\x56\x7d\xa7\xb3\x53\xf6\xc4\x7e\x69\x4c\xd6\x07\xf3\xae\x89\x4a\x97\x05\xe8\xea\x2b\xf9\xce\xec\x3a\xcf\xa6\xd2\x0b\x23\x8b\xf0\xa7\xa7\xea\xc7\x6c\x44\x62\xb7\xe4\xe4\xe8\x68\x17\x4a\x88\xa6\xa6\xc9\x47\x6c\xdf",
        p,
        q,
        g,
        b"\x41\xcd\xb2\xc1\xbd\xfa\x36\x52\xee\x49\x69\x5d\x5e\x5e\xee\xc0\x0f\x64\xb5\x4b\x56\x76\xee\x27\xf0\x43\xb4\x3f\x24\x13\x3f\x61\x42\x5b\x0c\xeb\xaa\x1f\x88\xda\x07\x2c\xc6\x88\x65\xc1\x27\x90\xc4\x32\x85\xb7\xe1\x9c\x38\x44\xfc\x7d\x81\xd0\x64\x42\x3f\xf1\xe1\x92\x66\xf6\x9f\x7d\xcb\x3d\x02\x03\x73\x9f\x84\xd7\x3b\xf0\x0c\x52\xd6\x0b\x28\x75\x17\x12\x16\x67\x8d\x59\xfb\x55\x75\x53\xed\xc9\xeb\xa6\xb8\x41\x27\x16\x9f\xe5\xdd\x2f\x81\xfc\x90\x2c\x97\x0d\x1d\x8d\x9c\x47\x79\xdf\xa1\xb1\x43\x09\xf8\x10\x06\xee\x64\x17\x76\xa6\xfa\x36\x33\x9e\x96\x31\x17\x44\x7a\xce\xb8\x23\xc9\xca\x33\x67\x17\x2e\xdd\xaf\x6e\x36\x18\x29\xda\xe4\x3c\x40\x38\xcd\xb9\x0e\xbb\x68\xb5\x3c\x0a\x22\xd4\x10\xb6\xf1\xbf\xa7\xc4\x74\x96\xea\x3a\xed\xdc\x36\xbf\x24\xf2\x19\xb8\x59\x17\xa2\x4d\x30\x84\x7c\x77\xd8\x7d\x22\xa7\xf7\x48\x6c\x66\x84\x75\x5e\x04\x5d\xdf\x72\xd4\x16\x50\xe9\x7b\x64\xa6\x4b\xec\xad\xfc\x47\xd5\x35\x55\x12\x7f\x8b\x7a\xb7\x8d\x48\x05\x29\x57\x19\x96\xee\xde\x46\x18\x88\x2d\x83\x8b\xd6\x95\xef\xc8\x7e\x74\xd6\x8c\xa5",
        b"\x4f\xe6\xe2\xa7\x5d\x9c\x72\xe8\x1a\xc6\x0d\xd3\x3d\x31\x18\x0d\xf8\x29\xb3\x1a\x0d\xbd\x5f\xd2\x0b\x7e\x28\xc4\xfe\xe2\x7d\x5b",
        b"\x3c\xe4\xa0\x6b\xfa\xf7\x0c\xb6\xcc\x93\xf3\x3f\x95\xa4\x3a\xd7\x7e\xd7\xad\x7c\x77\xa1\x67\x4b\xf8\x49\xe9\xeb\xbc\x5e\xda\x29",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x17\x3c\x4a\x23\x62\x1c\x32\xc3\xe4\xb1\x57\xef\x96\xb0\x2f\xc1\xbb\x46\x6a\x25\x37\xd3\xf6\xe5\x1a\x58\xe5\x10\xc4\xae\xf3\xaa\xe4\xbc\xe4\xc0\xb4\xd5\x9b\xb1\xc0\x0e\x7a\x35\xf9\x89\x45\xca\x9d\x7f\xdf\x1f\x0b\xac\x73\x2d\x42\x50\x43\x06\x2b\xc6\xd3\x20\x15\x23\x3d\xfb\x29\x5a\xe0\x8a\x32\x4a\xc7\xc1\xe0\x2a\x11\x7c\xe4\x36\xd7\x7d\x4e\x46\xd0\xb7\x94\xaf\x04\xb1\xdb\x82\xa2\x70\x9d\xa1\xc4\x44\x9c\x29\xcc\xba\x93\xdb\x8e\xc4\x8e\xb1\x79\x21\xcb\x38\x9f\x6e\x0a\xe3\x29\x95\xd7\xfe\xe1\xfa\x07\x17\x7a\x7a",
        p,
        q,
        g,
        b"\x67\x3e\x34\x9c\xf6\xd0\x5c\xaa\x16\x75\x1d\x97\xba\x6e\x34\x4e\x40\xe1\x58\xe6\xa7\xfc\x53\xea\x2d\xb8\x78\x91\x34\x1e\x64\x99\x82\x5b\x5b\x9e\xdb\xce\x91\x90\xbd\x87\xc3\xea\xdf\x7c\x6d\x5b\xf0\xa7\x93\xaf\x2c\x3a\x1c\x8d\xed\x79\x0b\xc3\x19\x44\x93\x94\xc6\x43\x84\x30\x58\x64\x72\x3a\x8a\x7b\xfe\xf2\x6c\x08\x20\x30\xab\x36\x0b\xf9\xab\xb1\x11\x17\xe6\x1b\x00\x54\x97\x26\xd7\x72\x22\x1f\x6f\x67\xc4\xa6\xa1\x10\xcd\x9a\x96\x58\x78\x1e\xa8\xf7\xef\x2f\x17\x6c\x6e\x88\x16\xa8\x65\xaf\x39\x6d\xb9\x5d\x84\x15\xb5\x41\xcf\x0f\x83\xe4\x5a\x41\x73\x74\xcf\x3a\xcf\x5c\x6b\x4a\x98\x39\x05\x22\xe7\x14\x0c\xc8\xaa\x3f\x9d\x2d\xd2\x63\x41\xd4\xeb\x79\xe4\xd9\x31\xa1\x78\xe3\xd5\x7d\xc5\x2b\xfd\xf9\x01\x15\xe0\x1b\x76\x09\x4a\xd0\x29\x49\x79\xd3\x5d\x92\xb5\x74\xce\x7b\x0c\x62\x7f\x08\xbe\x66\xf9\x9e\xff\xad\xc3\x3a\xed\x0f\x63\x4f\x6a\x89\x50\x74\x55\xd7\x34\x1e\xe6\x41\x83\xaa\x61\x0d\x8b\xb3\x23\x71\x47\xbd\x90\xdc\xd9\xc1\xa0\x3d\x89\xb2\x6e\xe3\x1d\xbe\xf5\xae\x7e\x76\x4b\xa9\xf7\x7b\x6a\x74\x34\xad\x2a\x8f\x96\x6c",
        b"\x39\x3d\x68\x1c\x3e\xdb\xa2\x8f\x7c\xb0\xf3\x05\x93\xb9\x4f\xc1\x5c\xca\x65\x9a\x80\xcf\xbc\xb3\xb2\x36\x45\x37\x22\xd5\xb4\x02",
        b"\x44\xf7\x42\x1b\xce\x1e\x52\x73\xa3\x0e\xc0\x16\xbb\x99\x69\xb7\x57\x19\x79\x87\x54\x8e\x43\x4e\x39\x5a\xb3\xde\x1b\x0e\x7b\xa2",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x7d\x6f\x2a\x97\xe1\xeb\x08\x5c\xb9\xe8\x3a\xa2\x40\x47\xaf\x9b\xa3\x0a\x05\xd7\xba\xb5\x64\xa1\x49\xb9\xcd\x23\x66\x51\x8e\x8f\x19\x91\x34\xfc\x2c\xa4\x03\x94\x7f\x2a\x61\x4c\x03\x63\xed\x4b\xc1\x34\x9d\xc4\x96\xa8\xec\x74\xd8\x80\x57\x84\x75\xe4\x74\x27\x62\x8b\xb0\x23\xf0\x27\x22\x08\x87\x6a\x3a\x73\x33\x30\x7a\x59\x6c\x15\x8e\xba\x64\xce\x42\xa3\xc7\x90\xe7\x16\x7b\xa4\xa3\x27\xac\x71\xaa\xba\xd2\xf3\x63\x41\xed\xea\x12\xce\x5b\x2b\x73\x58\x07\xb3\x4b\x71\x4a\x49\xa0\xaa\x47\x68\x93\x57\x8f\x06\x45\xdb",
        p,
        q,
        g,
        b"\x77\x7c\x25\x10\x67\xc8\xab\x16\xcc\xe2\xc4\xa4\xd7\x84\xc7\xe8\x06\xfd\x29\x6c\xbb\xba\xb0\x13\x2e\x2a\xb9\x16\x23\xac\xec\xd8\x30\xe7\xcc\x7c\xde\x03\xe5\x44\xb5\x1f\xb1\xd8\xf0\xb2\xee\xc0\x9f\x55\x95\x39\xaa\x9d\x63\xeb\xc0\xc1\xe3\x25\x79\xf0\x95\x47\x3d\x12\x71\x7c\xe8\x8f\x66\x71\xec\x7e\x3d\x25\x81\xf6\x1b\xfd\xe6\x6c\xf9\xbe\x21\x6d\x6a\x20\x80\x86\xcd\x7b\xea\x77\x01\x50\xa9\xbb\x0a\x5a\x7a\x0d\xac\xe8\x2b\x46\x41\x80\x24\x12\x02\xa3\x0b\x26\xad\x5f\xb9\x33\xc8\x23\x5a\xc2\x91\x8e\x29\xbc\x53\xa5\xc0\x1e\xbc\x1e\x30\xb1\xb4\x6e\x37\x12\x4a\xec\x59\x6f\x8d\x1a\x73\xba\xea\xe5\x88\xce\x7d\x4a\xef\x1a\xe8\x4e\x9a\x97\x66\xc2\x43\x67\x32\x1c\x04\x7c\x3c\xab\xa6\x29\xf5\xd9\x18\x5f\x0f\xfb\x3a\xf7\xe5\x0e\xeb\xd1\xba\x0e\xb7\x7e\xb1\x21\xb9\x80\x73\x79\x4c\xbc\x66\x22\xb6\x78\x26\x2e\xd3\xe2\x29\xc6\xce\xeb\x60\x72\x74\xce\x34\x96\xf3\x70\xb4\x82\xbf\x8f\x68\xc2\x73\x66\x81\x84\x86\xb7\x2a\xdf\xc8\x10\xb2\xf5\x79\x77\x9a\xdc\x9c\x25\x00\x2e\x27\x76\x41\xdd\x9f\xfb\xc5\xdb\x52\x39\xf6\x77\xba\x1a\x9c\x1d",
        b"\x46\x3b\x1f\xd6\xef\x29\x86\xf7\x5f\x96\x20\x77\x9b\xb6\xf4\x7e\x0b\xea\xfa\x93\x40\xe3\xe5\xee\x58\x9d\x92\x42\x8a\xcd\x4f\x2c",
        b"\x27\xed\xd3\x39\x17\xe4\x9b\xf7\x71\xf3\xfa\x13\x55\xcd\x39\x28\xd0\xbd\x40\x1a\xa7\xbf\x05\x41\xf3\xaf\x16\x43\xef\xd7\xb6\x77",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x7f\x87\x85\xe1\xc4\xf8\x2b\xc0\xbb\x75\xf7\x8d\x8c\x41\x13\xe0\x88\x7e\x76\x1a\x86\xb4\x8d\xfa\x43\xa3\x68\x3b\x2b\xb8\x86\xba\x53\xf5\x60\x3c\x8d\x94\xa0\x52\xaf\x36\x71\xc5\xc1\xe7\xc2\x32\x90\x8e\x10\xfa\xa6\xcd\x54\xef\xc7\x9c\xcf\xd6\x48\x11\x13\x1a\xcd\x7d\x60\xa9\x30\x97\x29\x45\x5a\xa7\x04\x43\xae\x8f\x32\xa3\x45\x80\xf9\xa1\xaa\x7d\x89\xe5\xfa\x8c\xd4\xe9\x58\x09\xa5\x73\xec\x6d\xfe\x9f\xe3\x5b\x11\x30\x57\x19\x82\xa0\xdd\x46\xee\xeb\xb6\xa1\x6f\x85\xee\x63\x14\x93\x18\x39\xe3\xa4\xc2\x9d\xc7\x00",
        p,
        q,
        g,
        b"\x28\xc0\x6e\x5a\xb3\xc8\x60\xbe\x8c\x13\xf7\x4f\x28\xb5\x79\x2b\x39\x48\x7b\x79\x54\x7f\x4a\xfa\xf6\xf7\x7a\x5c\x3a\x43\xe8\x81\x32\xed\xf9\x44\xee\x00\x15\x0a\x78\xb5\x8a\x78\xcf\x92\xed\x94\x15\x78\xec\x67\x9e\x10\x67\x67\x01\x4e\x5b\x27\x9c\x0e\xae\x9c\x40\x8e\x6e\xd6\x06\x87\xee\x14\x64\x98\x8e\xa5\x45\xf5\x5b\xe3\x67\x3e\xcd\xa1\x0c\x63\xfb\x0b\x19\x08\xe7\x96\xd6\x71\x5a\xbd\x54\x51\x84\x3d\xa6\xe6\x3b\xf8\x80\x2c\xca\xda\x32\xc7\xc5\x34\x23\x74\xab\x26\xee\x70\x1f\x9d\xb3\xd3\x4f\xc9\x6d\xe9\xd2\x30\x21\xb9\x8a\x93\xdf\x68\x77\xf8\x4f\xad\x67\x41\x16\x40\x55\x69\x6f\x3b\x72\x05\x03\x43\xea\x3e\x5c\xca\x01\xa3\xd5\x7e\x29\x72\x7e\xbc\xf8\x58\x31\x18\x14\x6c\x27\xf4\x2a\xda\xf6\x23\x65\xb9\x69\x7c\xf0\x3b\xdd\xc6\x9d\x0b\xd1\x51\xf7\x15\xb2\x3b\xfa\xaa\x27\xa3\x68\x11\x4b\x3d\xfb\x54\xc0\x84\xe0\x6d\x43\x43\xff\xde\x1c\xd2\x20\x58\xe9\x62\x3a\x70\xe9\x94\x2e\x09\x0e\xdc\x73\xdb\x06\xdd\x31\x80\xbb\x96\x0f\x0d\x7f\xed\x00\x5b\x14\x9b\x69\xd6\xd4\x5f\x40\x36\x8f\xc2\x5a\xe0\x43\x21\xed\xa4\x6d\x52\xa5\x92",
        b"\x31\x65\xb1\xcf\x3c\xa9\xbb\x89\x15\x4a\xd6\x84\xe0\x89\x36\x4f\x91\xb6\xe5\xd5\x94\x52\x60\x72\xf7\xb9\xdb\x3b\x23\x58\xe7\x11",
        b"\x49\xe1\xc8\xc3\x47\x24\xac\x55\x32\xff\xf1\xc7\xd2\x43\xb4\x86\xa2\xcd\xc0\x87\x2a\xb8\x4f\xda\x6c\xf2\xba\x96\xf9\x58\xf4\x6a",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x3e\x17\xea\x8b\x9f\xeb\x2f\x4e\x55\xc1\x03\xe5\x8c\x4e\xad\x96\xb5\xcb\x89\x2d\x09\x82\xab\x2b\x0c\xb1\xee\xb9\xe1\xdd\xde\x99\x90\x23\x3a\x22\x58\x84\x73\x42\x1a\xad\xf5\x27\x67\xa8\xdf\x52\x4b\xc6\xe6\xed\x85\x7a\x9f\xd5\x94\x2e\xf9\x76\xb1\xfd\x8b\xca\xd3\x1e\x40\x3b\x1f\xeb\xb8\x65\xd2\x87\x2a\x7b\x34\xec\xdb\xab\x8b\x24\x5a\xda\x45\x24\x3a\x49\xc7\xbe\x67\xaa\x09\x78\x80\x29\x77\x9d\x61\x9d\xe3\x0d\xea\xd9\xf7\xd8\xc9\xc4\x21\x53\xb8\x65\xb1\xa9\xe8\x11\x80\x38\x0e\x27\xa3\x05\xa6\x39\x2f\x4b\x2a\x0b",
        p,
        q,
        g,
        b"\xb7\x1d\x0a\xb2\xd4\x05\xa5\x01\x2d\x69\x4e\x0a\x4a\x82\x76\x92\x56\xcb\xdb\x49\xc1\x81\x12\xef\xee\x81\x53\xc8\xe8\x16\x31\x04\x86\xa1\x7b\xce\x19\x74\x8b\x11\xf3\xd5\xd1\x8c\xb4\x49\x98\xeb\x32\x9b\x95\x1c\x23\xa5\x7c\xac\x47\xec\x99\x73\x83\x9b\x13\x0f\x3a\x98\x0e\x62\x70\x5c\x07\x02\xe4\xd6\x84\x25\x84\x5d\x54\xe1\x52\xe2\xe8\x36\x46\xb5\x6a\x67\x57\xcd\xe0\x6f\x85\xba\x37\x79\xee\xa5\x85\xdf\xe8\x30\x2f\x12\xae\x77\xfa\x58\xcb\xc6\xdc\xca\x70\xb4\x61\x02\x4b\x7d\x17\x65\x10\xa3\x93\xec\x02\x7c\x76\x9c\xfe\x49\xb6\x98\xe5\x75\xfc\xf9\x9c\x60\x29\x3a\xf2\xad\xe3\xdc\x4d\xf2\x3f\xf3\x38\x6f\x13\x77\x73\x06\xc5\x2d\xe9\x7e\xd1\xa8\x86\xb8\x24\x78\x88\x63\xff\x72\x63\xbb\xbb\x5b\x5f\xa0\xd4\x68\x1c\x16\x94\x22\x72\xf5\xe4\x41\xbd\xf4\x9e\xec\x75\x56\xc1\xfd\x40\x9c\x78\xe3\xaa\xff\xeb\x95\xc1\x26\x7d\xee\x12\xc2\x4c\x04\x5e\xf6\x7a\xa7\x0e\x9a\x3d\x92\x44\xf2\xcf\x1a\xc6\x8c\xd9\x18\xdf\x5f\x62\xa3\xdd\x3d\xe7\xbc\xde\xaa\x3f\x61\xde\x51\xcc\x01\xaf\x63\x6b\xd6\x65\xc0\x09\x9d\x13\x93\x8e\xb4\xfc\x28\x9b\x42",
        b"\x11\xb7\xec\xfe\xb3\x39\xd6\x01\x49\x48\xde\x5a\xd4\xc9\x6f\x4b\xa5\x17\xa2\xcd\xdc\xa6\x11\xc8\x88\x7f\xc4\x4f\x14\xac\x9a\x63",
        b"\x13\x28\x7a\x22\xcf\xfd\x82\x53\x02\xb0\xfd\xc0\x95\x54\x58\xd9\x18\x72\x70\x92\xc7\xbf\xb3\xec\x4c\x3d\x7a\x83\x8e\xa6\xc4\x91",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xc3\xe1\x90\x3c\xec\xcb\x2a\xf5\xb0\xdc\x6b\x1f\xba\xaf\x1b\x2e\x96\x47\x7e\x00\x1c\x43\xee\xe3\x04\x6e\xed\x06\x12\x8c\x4c\x81\xeb\x2b\xc9\x17\xaa\x8a\xc3\x0d\x07\xe6\x6c\x9a\x94\x69\x51\x8e\x3c\xab\xc2\x64\xd6\x93\x6e\x5d\x72\x4a\x61\x3b\xf9\xa4\x4d\x60\x79\x7b\x89\x0c\xc5\xce\x0d\x04\x62\x9e\x5f\xaa\x1d\xd5\x3e\x7a\x12\x5a\x14\xa2\x6d\xf3\xcd\xd9\x87\x8d\x9c\x67\xe7\xe1\x8a\x46\x55\xa1\x88\x88\x53\x63\xdd\xab\xd7\x3a\x17\x65\x9d\x19\x1e\x51\xfa\xfb\x6d\x41\x71\xff\x6c\x4b\x65\x11\x68\xce\x16\x7a\xda\x01",
        p,
        q,
        g,
        b"\x42\x9e\x6b\xa2\x0b\x02\xcd\x69\xa2\x9b\x4a\x97\xa6\xea\x56\x4e\x5b\x88\x74\xad\xa1\x95\xa4\x9c\x3a\x52\x93\xc9\xbc\x8d\x19\xe0\xa3\xa3\xc4\xac\x85\x47\xbf\xdc\x7a\x20\x9b\xf3\xa6\x03\x7e\x5b\x0b\xb7\xaa\x29\x1d\x59\x40\xd2\x35\xc7\x87\xa2\xaf\x79\xa9\xcd\x7f\x83\x08\x4b\xa7\xdf\x85\xc0\x36\xad\x8e\xa2\x3c\x4f\xdb\xf9\x1d\x28\x5c\x7c\xaa\x64\x97\xaf\x38\x80\x17\xbd\x58\x1f\xf3\x08\xd9\xb5\x67\x99\x02\x9e\x21\x40\x0c\x0c\x99\xd1\x03\xa2\xca\xec\x19\x5e\x40\xc9\x0d\x24\x4d\xac\x89\x7b\xd4\x18\xae\x01\x6d\x25\xf7\x1e\x98\x9a\xf5\x16\xd5\xe2\x49\x1e\x1e\x4b\xc2\x59\x14\xec\x3a\xd0\xa9\xf8\x59\x68\xa6\x77\x7f\xbe\xbd\xc7\x3b\x1a\xc6\x81\x44\x96\xd9\x42\x1d\x2b\x7c\xdf\x17\xd5\x3f\x00\x62\x40\x10\xed\x66\x18\xf1\x25\x8d\xa1\x94\xf7\x7c\x28\x28\x62\x25\xd1\xb1\x6d\xa3\xfa\xb7\x6c\x9b\x70\xdb\x1f\x7d\xbc\xba\xcf\x4e\x60\xb6\xb9\x1a\x1f\x47\x50\x07\xee\x4d\x2c\x5e\x37\xfc\x31\xe8\x9a\x0f\xa8\x08\xf8\x9e\x8a\x4e\x54\x6b\xc9\x0e\x69\x6f\x45\x47\x21\xbe\x71\xc0\x73\x1f\x99\xee\x36\x8a\xfc\x69\x98\x76\x1a\xf9\xdd\x9d\x6d",
        b"\x77\x47\x0f\x0d\x39\x23\xff\x40\x7e\x71\xa8\x6f\x03\x36\x81\x1b\xdd\x63\xe1\x79\x89\x1f\xd3\x0e\x34\x52\xda\xc1\xe5\x17\x50\x81",
        b"\x4b\x96\x9f\x77\xc7\x0b\x5e\x6f\xf9\x35\x0c\xa2\x5e\x7d\x95\x1a\xca\xae\xe9\x07\xfa\x7b\x83\x0a\x32\xdc\xe4\xf9\x1a\x89\xaf\xa4",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x4b\x7c\x08\x28\xb7\x15\xec\x2d\xa1\xe0\x92\x20\x4f\x55\xdd\xd6\x5d\x13\xf1\xcd\xd6\x4c\x10\x94\x78\xd3\x84\x74\x87\xbc\x48\xa8\xcb\x02\x99\x22\x2a\x74\x95\xef\xff\xa6\x3e\xa1\x58\x25\x3f\xae\xdc\xb5\x31\x48\x81\xab\x41\xb5\xe7\x73\x33\x76\x62\xcc\x2f\x50\xdb\xcc\xc7\x36\x97\x4e\x31\xb3\xd0\x80\x46\x75\x89\x95\x1d\x51\x10\x32\xe4\xcb\xa6\x64\x7f\x94\xc6\x79\xaa\x26\x9f\xca\x6d\xb9\x27\x15\xa4\xda\x28\xff\x98\x03\xa1\xdc\x61\x67\x5f\xa5\xac\x11\x4e\x37\x6f\xa4\xda\xdb\x37\xc1\xb0\x9e\xd5\xc3\x1b\xc5\xae\xe8",
        p,
        q,
        g,
        b"\x09\xa1\x6e\x0a\x60\x03\xf4\x5a\xaa\xa3\xc6\x31\x1a\xa9\x86\x62\x17\xd4\xa7\xc8\xcb\x50\x93\x51\x49\x76\xf6\xa3\x41\x26\x0e\x5a\xba\x7c\xb0\x0a\xb2\xad\xb7\x46\x2a\x47\xa8\xcf\xee\x4f\xdc\xae\x5a\xcc\xda\x6d\x42\xa3\x14\x47\x92\xa1\x46\x31\xbb\xe8\x55\x34\xc1\x11\xd2\xff\xcd\xbc\x15\xb6\xdb\x9d\xbf\xc4\xbc\x71\xd3\x00\x32\x4f\xd3\x10\xc4\x65\x44\x3c\xb2\xa6\xf2\xae\x33\x70\x1f\x39\x66\x8b\x11\x8c\x38\xef\x56\x2e\x85\x54\xfe\xa6\x61\xa3\xef\x80\x45\x56\x99\xc2\x34\x30\xd2\x8b\xa6\xdc\xf0\x42\xfc\x92\x0a\x67\x7c\x29\x71\xb2\xdf\x8c\x67\x29\xc5\xb3\xb1\xbe\x6c\x5a\x04\x7a\xc1\xbc\xc8\xcd\x8d\xc5\x19\xad\xa2\x21\xbd\x92\xca\x68\x93\xc1\xcc\x1d\xc1\x58\xf9\xd4\x72\xf8\x9a\x8e\x02\x64\x94\x40\xdd\xed\x0f\x72\x34\x85\x55\x8e\xff\xe8\xcf\x9d\xf1\x21\xc9\x69\xa2\xd1\xb7\x6a\x37\xdc\xbf\xfb\x17\xed\xf3\x12\x1d\x43\x38\xd4\xab\x68\xb1\x54\x22\x6c\x00\x72\xd8\xbd\x51\xf2\x3e\x56\x59\xa2\xaf\xe5\x20\xdd\x5e\x91\x00\x5a\x6f\xc1\x15\x7f\x07\x97\x36\x10\xc5\x57\x78\x24\xbf\x16\x66\xcc\xf8\x51\xd6\x9e\xfd\xe3\x47\xf0\xb9\x96",
        b"\x1b\x8b\x8d\x67\xb6\x40\xaf\xda\x26\xfb\xe6\x7c\xfd\x4b\xea\x52\x13\x75\x52\x6a\xd5\x8a\x22\xd4\xd9\x7d\x7a\xf1\x34\x38\x4f\x4a",
        b"\x66\xd6\xc2\x40\x99\x22\x56\xee\xbe\x07\x82\x65\xc3\x02\x9a\x88\xc3\x40\x95\x14\x21\x34\xdf\xc3\x1f\xf0\xa2\xd8\xbb\xd6\x09\xb5",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xba\xea\x89\xdc\xc1\x02\xcd\x64\x91\x35\xd6\x3a\x5f\x52\xdf\x43\x7a\xf7\x84\x0d\x69\x9a\x9d\xaf\x13\x1e\xaa\xc3\x81\x34\x8d\x45\xb4\xe6\x04\x77\xfe\xa8\x88\x03\xfc\xa3\x1b\x54\x82\x9c\x58\x06\xc7\x03\xeb\x8f\xdf\x41\x23\x06\xff\x7a\x79\xb5\x5a\xab\x90\x64\xbc\x37\xcb\x26\xbf\xfa\xa6\x71\xde\xbb\x74\xc2\x28\xba\x2d\x2a\x06\xda\x36\x2f\x61\x3b\x78\xe5\xb1\xf0\xa0\xb5\xc5\xfe\xbf\x6b\xc3\x26\xb0\x21\xbd\x7f\xc7\x04\x71\xb2\x5e\x15\x3e\xa5\x1d\xe1\x01\x0b\x87\x11\x0e\x01\x49\x7a\x7f\x1a\xc3\x9c\xf4\xd4\x24\xc3",
        p,
        q,
        g,
        b"\xcb\xd4\x65\xce\x9c\x3d\x0a\x13\x7e\xe3\xd5\x82\xa5\x17\x21\x83\xb8\xa6\x3c\xfe\x41\x40\x70\xb2\x47\xda\x36\x74\x56\x20\x3f\x98\x6e\x67\x86\xff\xb8\x3a\xd7\x64\xab\xa3\x09\xc2\xef\x74\x42\xce\x38\x73\x5f\x49\x2c\x0c\xe6\xd9\x2e\xaf\x9a\xe6\xb1\xcc\x87\x3a\xb6\xff\x58\x31\x7c\xd1\x66\xa5\x10\xc3\xff\xd8\xd4\xe6\x00\x88\x25\xb5\x8c\xae\x21\x7f\xa3\x5c\x94\xc9\xbb\xd1\x2a\x4d\x63\x8c\x20\x11\x63\x98\xb2\x1b\x59\x29\xdc\xa1\xd4\x9a\x7b\x74\x89\x70\xe4\x5d\xe0\xd4\x32\xfc\x91\x2f\x76\x19\x91\x37\xf1\xbb\x0c\x0d\x2c\x95\xbd\xcb\xa0\xd3\x03\xec\xdb\xf4\x89\x84\x9b\xe8\xe6\x30\xff\xff\x06\x03\x94\x8c\x87\xa7\xe5\x81\x31\x65\x5c\x9f\x40\x77\x08\xe8\xa9\xd6\x75\xe2\x8e\x9b\x57\x72\x9f\x03\x46\xc0\x28\x7f\x43\xed\x67\xf9\xc0\xc0\xce\x15\x42\x98\x48\x51\xcc\x3b\x52\x1a\xfa\x5b\x9b\x8f\xa5\x36\x80\xbd\xb2\xd7\x3c\x2b\x6b\x09\x0e\xf0\x85\xa7\xe7\xc6\xf7\x6a\x2e\x50\x10\x64\xc8\x52\x59\x1d\xf6\x04\x39\xa9\x6d\xd8\xd6\x63\xb5\x64\xc9\xe5\xc2\x53\xee\x8d\x8e\xe5\x8a\xb2\x7d\x83\x32\x11\x3b\xdd\x51\xd8\xb4\x1a\xc7\x3c\x14\x3a",
        b"\x76\x89\xb5\x24\x9f\x19\x43\xe6\x85\x09\x51\x06\xd3\xf6\x83\x59\xcd\xb7\x6b\xe5\xd9\xa5\x0e\xbf\xdf\x36\xe7\x31\x57\x5f\x8b\xda",
        b"\x04\x9d\xa4\x2d\xe5\x1e\x61\x7c\xdc\xde\xf1\x7c\xdf\x60\x59\x34\x5b\x8e\x18\x1b\xac\x64\xc4\x71\x23\xd4\x7b\x5e\xfe\x10\x5e\xbb",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xb1\x30\x37\x68\xbe\x17\x4d\x83\x57\x84\x07\xdd\xe1\xab\x91\xcf\x02\x11\x24\xa3\x4c\x4a\x35\xea\xfa\x45\x12\x70\x7a\x36\x60\xd1\xf8\x84\xfa\x6c\x3d\x7d\xf2\x99\x59\x80\x18\xdc\xa2\x2f\x27\x3f\x60\x2b\xab\x37\x15\x92\xb1\x1f\x45\x74\x88\x57\x41\xab\x3f\xe2\xaf\x5b\x71\x23\x7d\x00\x57\xae\x59\xf3\x7b\x61\xdf\xd1\xad\x5e\xa2\x7c\xf8\xf0\x5f\x5b\x69\xf2\x93\x6e\xc7\x9d\x10\x4f\x4a\x46\xc9\x02\xfb\x67\x90\xdf\xdc\x75\xb9\x76\x8c\xc7\xdf\xba\xe0\x11\xc7\x95\xe6\x46\xf9\xa2\x34\x72\x87\x07\xfb\x11\x2c\x46\x10\x07",
        p,
        q,
        g,
        b"\x56\x02\xdd\x57\x9f\xbe\x37\xf1\x87\xd4\x9d\x76\xfd\x59\x36\xfc\xde\xf2\x36\x9f\x7a\xf2\x9d\xa4\x3c\x64\x56\xa6\xac\x83\x17\xb3\x9e\x4c\xd6\x79\x14\x3a\x4d\x97\x75\x1b\x80\xce\x1c\xb4\x51\x86\xda\x7b\xee\x99\x1e\x25\xeb\x9a\x1a\xed\x14\x90\xfd\x74\xf6\xab\x50\x79\x40\x82\x1a\x1a\xdf\xbc\x30\xe1\x9a\x93\x3c\xc4\xd2\x17\x69\xcc\xdf\xc5\x7c\x96\xf0\xd2\x19\x44\xf8\xa0\xf1\x31\x62\x6e\xd0\x13\xb3\xe5\xc0\x13\x13\xa1\x75\x6b\x67\xb7\xd2\xa2\x1e\xda\xc4\x86\xcb\xc3\xcd\x1d\x2b\x6f\xcf\x20\xc8\x2d\xd7\x0b\x4f\x72\x92\x9c\x14\x99\xad\x79\x6d\xe8\x94\xdb\x8a\xf1\x03\xd9\xb9\x1c\x25\x73\x70\x73\xd9\xdf\x62\xe6\xb6\x24\xb9\x0f\xb3\x52\xdb\x78\x1c\x7f\x2f\xf8\xd3\xa2\x0a\x70\x63\xfb\x51\x27\x23\x95\xcc\x7d\x35\xef\x79\xc2\x7b\x76\x34\xe3\x9f\x74\xeb\x15\x29\x75\xfd\xf3\xb9\x03\xc2\x39\x90\xee\xde\x8a\xa5\x8d\xf9\xa2\x99\x54\x33\x3a\x3f\x52\x5d\x5b\xaa\xfd\x37\x9d\xd5\x7f\xe3\x96\xa5\x18\x76\xf2\x5d\x9e\x82\x65\xcf\x69\x71\xed\xc6\x27\x8c\xe9\x96\xbd\xee\x20\x68\x83\x44\x8a\xf1\x84\xfa\xe2\x3a\xf2\xa6\x95\x72\xb2\x00\x90",
        b"\x18\x00\xb6\xbd\x5c\x94\xa0\x31\xd9\x77\xb9\xd0\x17\x54\x17\x90\xa9\xfe\x7e\x41\x4c\x90\xfa\x4d\x38\x03\xd5\x6e\xf1\x6a\x64\x79",
        b"\x07\xec\xe1\xb6\x47\x11\xc9\xb3\xec\xa4\x89\xe7\x5f\x2e\x63\x43\x8e\x09\x74\x98\xe2\x89\x0d\xd0\x27\x37\x29\xa5\x5d\xf0\xd2\xdf",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x25\xca\x3d\xc8\xe6\xea\x4e\xbb\x93\x6f\xa0\x1b\x1c\xcc\x08\xbb\x1d\xe9\x23\xbe\x62\x92\x42\x1f\xf9\xf7\x73\xaf\x9c\xc7\x39\x35\x10\xdf\x2f\xcb\x6e\xc1\x88\xb2\x7c\x26\x88\xc7\x2f\xdc\x2f\xf6\xc9\x0f\x0a\xb0\xed\x59\xc9\xc3\xa6\x50\x3f\x53\xe3\x27\x78\xb9\x54\xea\xe5\x82\xc9\x58\x03\xc5\x11\xff\x39\x18\xad\xda\x02\xe6\x8e\x2c\x3e\x73\xf8\xa6\xad\x60\x7a\x89\xd8\xeb\xa0\x05\x9e\xb8\x7f\x4d\x9b\x00\x81\xf2\x96\x96\x1e\xc6\xea\x78\x85\x3a\xa5\x3d\x24\xa4\x70\xa7\x4a\xcf\x16\xa2\xf8\x67\x48\xa8\xda\x34\xfb\x90",
        p,
        q,
        g,
        b"\xbf\x2e\x14\x0f\x8b\x8d\x99\xd2\xdf\x10\x52\xe9\x81\xfa\x0a\xc5\x33\xc0\xd4\xea\x9f\x26\x6f\x92\x67\xcd\xe7\xba\x03\xcf\x10\x01\x5d\xa1\xcc\x13\x61\x2d\xcf\xc9\x20\x30\xb7\xc7\xd1\xc0\x57\xe2\x8a\x6f\xb4\x57\x48\xee\xb9\xc4\xbd\x2e\x6e\x79\xb2\x17\xf4\xb6\x8e\xf0\x3f\x96\x59\xc8\xe8\x4a\x20\xee\x92\x0d\x29\x71\x13\x81\xce\x39\xfe\x0a\xfc\x9a\x7f\xe2\xfb\xdf\xce\x63\x24\x96\x51\x23\x0f\x3e\x72\xee\xd5\x79\xf0\xd3\x65\x9c\x2b\xff\xc7\x0f\xb5\xd8\xbe\x88\x9a\x34\xbb\x67\xf1\xa9\x04\xc3\x18\x56\x83\x94\xb9\x46\xfd\x40\x38\x37\x82\xcb\x5e\x48\x09\xd0\xc6\x01\x9d\x20\xaf\xad\x09\xf2\x9f\xbb\xc9\x94\xd2\x8f\x4e\x41\xda\xf4\x66\x62\x98\xf3\x51\x89\x8d\x8d\xef\x40\x47\x12\xc4\x09\x74\x5a\x88\x96\x2e\x4a\x61\x8c\x23\x49\x76\x64\x55\x59\xc9\x0c\x54\xfe\x76\x4e\xea\x46\xfa\x03\x54\x3e\x4c\x4f\x25\xc8\xd2\xc3\xc1\x97\x9f\x95\x24\x58\x17\x7d\xc6\x96\x3e\x3f\x34\x6a\x7f\xdd\xbe\x0c\xdf\x23\xdd\xc7\xd2\xfa\x8a\x34\x55\xcd\x5b\x54\x6e\x47\x16\x99\x12\xce\x7f\x33\x3a\xc6\xf0\x1e\x64\xae\xc5\x96\x08\x0b\x5d\x3e\x0f\x25\xad\xb9",
        b"\x7b\x1d\xfc\xf3\x9b\x62\x4d\x64\xdb\x08\xa3\x97\x4c\x8e\x14\x17\x31\x05\x01\x0f\x2b\xd5\x13\x5e\x92\x6f\x28\x84\xe3\x0b\x46\xfa",
        b"\x69\x7e\xea\xb6\x69\x67\x74\x69\xf6\x2c\xca\x46\xd3\xe6\x8c\x84\x9f\x44\x78\x81\xe2\xc9\xf7\x42\x94\xf4\xe8\xad\xa4\x42\x6c\x7d",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xd5\x8a\x8f\x5a\xb4\x4f\x9d\xf9\xed\x93\x6a\x13\x18\x65\x7c\x32\x4f\xb1\x39\x9c\x25\x10\x54\x98\x6d\x19\x21\x4c\x15\xce\x95\x1f\x87\xcc\xb3\x51\x0a\xed\x90\x85\x41\x1d\x9c\x5a\x67\x40\xdf\x51\x60\xf3\xe5\x7e\xa8\xc9\x42\xd3\x35\x47\x31\x7c\x7a\x38\x7c\x60\xc7\xac\x2f\x0e\x14\x17\x1f\x0b\x77\x19\xab\xa7\x6a\xc4\x18\xd1\x57\xa4\xe3\xbe\xc6\xb7\x99\xb5\xda\x10\xbd\x3e\xcd\xda\xe0\x85\x7a\x29\x67\x0c\x99\xd3\x78\x10\x34\x9b\x82\xb7\xbb\x37\xc0\x93\x7b\x0d\xd2\x73\x4d\xa0\x8b\x8b\x1c\xb7\xbe\xec\xd4\x3c\xb6\x15",
        p,
        q,
        g,
        b"\xba\xa1\x36\x52\x64\x2d\x95\x0d\x8b\xce\xc1\x6c\x62\x4a\x07\x99\x9f\xb5\x57\xfb\x40\xa2\x66\x29\x7c\x15\x65\x97\x55\xfd\x61\x5c\xc7\xe2\x12\x5d\x4e\x8c\x8a\xf8\xc4\x33\x35\x53\x90\x05\xe9\xe2\xf2\xd4\x04\x28\xe7\xc8\xcc\x05\x5f\xf3\xf6\xfe\x3b\x3d\xf6\x04\xac\x12\x8d\x99\x5c\xfb\x9c\x86\x7e\x2a\x96\x07\xaa\x3b\x77\xcf\x0f\x69\x17\x38\xb7\x84\xd4\xbe\x2f\xea\x47\x39\xfd\xa1\xf0\x67\x42\x60\xf2\x1f\x66\x6a\xce\xf5\xbd\x56\xa7\x80\x0b\xbe\x95\x07\x92\xba\x05\xee\xe4\x2e\x80\xa2\x57\x8d\x2c\x50\xec\x28\xd4\x4a\xfb\x6b\x68\x76\x52\xbb\x94\x52\x40\x8f\xca\xf2\x57\xc4\xb5\xcd\x56\x4d\xdc\x4e\x63\xce\x9c\xa1\x3d\x4c\x74\x73\xf5\x1b\x01\xac\x8e\x4c\x3f\x79\x9a\xfc\x90\x8e\xae\xac\xca\xd0\x62\xb0\xf9\x7d\x95\x8a\x30\x08\xca\xe2\x20\x62\xbb\x16\x6c\x73\x00\xdf\x0b\x43\x86\xba\xec\xd5\x99\xfa\x8b\x08\x3f\xba\x6e\x7e\x4e\x5b\xa1\x19\x86\x02\x68\x51\x7d\x79\xeb\xdc\xbe\x02\x43\x7b\xf4\xeb\x5d\x91\xa8\x43\x72\x5d\xb0\xed\xa6\x6e\xed\xd4\x6d\x66\xb7\x81\xac\xed\x0d\xcc\x23\x15\x4e\x4b\x8a\x8f\x04\x53\xb2\xf4\x66\x03\x3b\xd9",
        b"\x18\x76\xb2\x09\x26\xd8\xed\xe7\x8d\x28\x17\x4e\xeb\x4c\xb0\xc1\xaf\x8e\xe2\x06\xfc\x8d\xb4\xa8\xcd\xeb\xb5\xdb\xfb\x0c\x15\xcf",
        b"\x23\x1a\xf0\x7a\xeb\xa9\x9f\xfd\x00\x65\x93\x94\xab\x6e\xd1\x9a\x5e\x9f\x9e\x60\xe2\x19\x7f\x65\xfc\x88\xc8\x15\xbe\xae\x7f\xe0",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xaa\x13\x4e\x9d\xb7\x39\x82\xe7\xa3\x7a\x10\x34\xaa\xb8\x2b\x50\xd5\xe5\x8e\x03\x4a\x56\x37\x08\x1d\xc8\x80\xa6\xe2\x65\xeb\xc7\xb3\x53\xdf\x21\x03\x04\xba\x00\x77\x1c\x5b\xab\x44\x5d\xc6\xc2\x49\x99\xfe\x8e\xaf\xde\xfa\xbc\xdd\x46\xf7\xa9\x1f\x30\x72\x1a\x68\x96\x33\x3c\x3f\x30\x1e\x19\x7f\x96\x19\x44\xf5\x45\xe4\xfe\x07\x30\xcd\x96\x77\x90\x50\x4c\x49\xb0\xab\x5b\x89\x08\x09\xbe\x5c\x7c\x1c\x3f\x8a\x2e\x52\xd9\x2a\x2c\x19\x9b\x98\x1b\x64\x8f\xdd\x52\x8e\x76\x8e\x6a\xb3\x92\x57\x9b\x54\xc7\x2c\x41\x61\x7d",
        p,
        q,
        g,
        b"\x69\x1d\xfe\xa1\x44\xe5\x1b\x9e\x0f\xf7\x53\x65\x57\xb5\x8a\xce\x87\x16\x26\x3a\x70\x55\x4e\x2f\x46\x76\xd1\x72\x33\x2a\xed\xaa\x67\x73\x6d\x72\x66\x7d\x32\x81\x70\xac\xa0\x70\xe1\xbb\x89\x86\x8b\xf4\xcc\x98\x96\x2d\x87\xeb\x05\x99\xf1\x08\x28\xc6\xea\x24\xcf\xfe\xde\x8e\xd7\xb3\x9a\xbb\xa6\x66\xbd\x6d\x0d\x35\x02\x4a\xde\x6a\xaa\x06\xfe\x6a\xe4\x5d\xc4\xb3\xa9\x1c\x21\x9d\x47\x2d\xb0\xef\xed\x46\x9d\x69\xcb\x5f\x11\xd4\x01\x58\xea\x81\x67\x2b\x1a\xe1\x16\xff\x2c\x30\x16\xf2\x45\x25\x4e\x98\x4a\x59\x94\x5e\x4e\x3b\x3d\x37\xad\x12\x05\x8d\x84\x08\x29\x55\xc7\x68\x64\x3e\x7d\x80\xc0\x55\xc1\x70\x3a\x88\x3f\x2a\xbb\x07\x5a\x24\xc2\xe9\x30\x56\x69\x73\x40\x93\x1c\x25\x89\x4d\x1d\x2f\xfa\xc4\xb1\x02\x20\x12\xc1\x5c\xb7\x07\xfb\x35\x96\x83\xad\x04\x08\xb6\x68\x77\x9e\x9d\x9b\xa2\x19\x89\xba\xa6\xa6\xb0\xb2\x56\xa3\x4e\xfb\x47\x51\xbc\xaf\x42\x85\xb1\x56\x35\xd4\x09\xfd\xa9\x93\xc0\x43\x8a\xcd\xdc\x9d\xa0\x06\xc3\x90\x36\x03\x04\xab\x12\xda\x76\xb4\x44\xd6\x4e\x11\xcc\xf0\x5d\x96\x3f\xfb\x7f\x38\x9b\xee\x83\x1d\xc7",
        b"\x04\x1d\x22\x93\x49\xce\xc7\x5f\xb2\xbd\x8c\x35\xc2\x49\xf9\x19\x6a\x18\x96\x2c\xa7\x5e\xbd\xb4\x2d\xca\x61\xd2\x1c\xb0\xe9\x10",
        b"\x77\xbb\x79\x75\xa5\x44\xc5\x1b\xf2\x49\xde\xe2\x35\x95\x23\x07\x28\x63\x93\x44\x97\xd1\xa4\x79\xd6\xe4\xb2\x45\xd4\x56\xeb\x2a",
    )?;

    // [mod = L=2048, N=256, SHA-256]
    let p = b"\xa8\xad\xb6\xc0\xb4\xcf\x95\x88\x01\x2e\x5d\xef\xf1\xa8\x71\xd3\x83\xe0\xe2\xa8\x5b\x5e\x8e\x03\xd8\x14\xfe\x13\xa0\x59\x70\x5e\x66\x32\x30\xa3\x77\xbf\x73\x23\xa8\xfa\x11\x71\x00\x20\x0b\xfd\x5a\xdf\x85\x73\x93\xb0\xbb\xd6\x79\x06\xc0\x81\xe5\x85\x41\x0e\x38\x48\x0e\xad\x51\x68\x4d\xac\x3a\x38\xf7\xb6\x4c\x9e\xb1\x09\xf1\x97\x39\xa4\x51\x7c\xd7\xd5\xd6\x29\x1e\x8a\xf2\x0a\x3f\xbf\x17\x33\x6c\x7b\xf8\x0e\xe7\x18\xee\x08\x7e\x32\x2e\xe4\x10\x47\xda\xbe\xfb\xcc\x34\xd1\x0b\x66\xb6\x44\xdd\xb3\x16\x0a\x28\xc0\x63\x95\x63\xd7\x19\x93\xa2\x65\x43\xea\xdb\x77\x18\xf3\x17\xbf\x5d\x95\x77\xa6\x15\x65\x61\xb0\x82\xa1\x00\x29\xcd\x44\x01\x2b\x18\xde\x68\x44\x50\x9f\xe0\x58\xba\x87\x98\x07\x92\x28\x5f\x27\x50\x96\x9f\xe8\x9c\x2c\xd6\x49\x8d\xb3\x54\x56\x38\xd5\x37\x9d\x12\x5d\xcc\xf6\x4e\x06\xc1\xaf\x33\xa6\x19\x08\x41\xd2\x23\xda\x15\x13\x33\x3a\x7c\x9d\x78\x46\x2a\xba\xab\x31\xb9\xf9\x6d\x5f\x34\x44\x5c\xeb\x63\x09\xf2\xf6\xd2\xc8\xdd\xe0\x64\x41\xe8\x79\x80\xd3\x03\xef\x9a\x1f\xf0\x07\xe8\xbe\x2f\x0b\xe0\x6c\xc1\x5f";
    let q = b"\xe7\x1f\x85\x67\x44\x7f\x42\xe7\x5f\x5e\xf8\x5c\xa2\x0f\xe5\x57\xab\x03\x43\xd3\x7e\xd0\x9e\xdc\x3f\x6e\x68\x60\x4d\x6b\x9d\xfb";
    let g = b"\x5b\xa2\x4d\xe9\x60\x7b\x89\x98\xe6\x6c\xe6\xc4\xf8\x12\xa3\x14\xc6\x93\x58\x42\xf7\xab\x54\xcd\x82\xb1\x9f\xa1\x04\xab\xfb\x5d\x84\x57\x9a\x62\x3b\x25\x74\xb3\x7d\x22\xcc\xae\x9b\x3e\x41\x5e\x48\xf5\xc0\xf9\xbc\xbd\xff\x80\x71\xd6\x3b\x9b\xb9\x56\xe5\x47\xaf\x3a\x8d\xf9\x9e\x5d\x30\x61\x97\x96\x52\xff\x96\xb7\x65\xcb\x3e\xe4\x93\x64\x35\x44\xc7\x5d\xbe\x5b\xb3\x98\x34\x53\x19\x52\xa0\xfb\x4b\x03\x78\xb3\xfc\xbb\x4c\x8b\x58\x00\xa5\x33\x03\x92\xa2\xa0\x4e\x70\x0b\xb6\xed\x7e\x0b\x85\x79\x5e\xa3\x8b\x1b\x96\x27\x41\xb3\xf3\x3b\x9d\xde\x2f\x4e\xc1\x35\x4f\x09\xe2\xeb\x78\xe9\x5f\x03\x7a\x58\x04\xb6\x17\x16\x59\xf8\x87\x15\xce\x1a\x9b\x0c\xc9\x0c\x27\xf3\x5e\xf2\xf1\x0f\xf0\xc7\xc7\xa2\xbb\x01\x54\xd9\xb8\xeb\xe7\x6a\x3d\x76\x4a\xa8\x79\xaf\x37\x2f\x42\x40\xde\x83\x47\x93\x7e\x5a\x90\xce\xc9\xf4\x1f\xf2\xf2\x6b\x8d\xa9\xa9\x4a\x22\x5d\x1a\x91\x37\x17\xd7\x3f\x10\x39\x7d\x21\x83\xf1\xba\x3b\x7b\x45\xa6\x8f\x1f\xf1\x89\x3c\xaf\x69\xa8\x27\x80\x2f\x7b\x6a\x48\xd5\x1d\xa6\xfb\xef\xb6\x4f\xd9\xa6\xc5\xb7\x5c\x45\x61";
    test(
        HashAlgorithm::SHA256,
        b"\x4e\x3a\x28\xbc\xf9\x0d\x1d\x2e\x75\xf0\x75\xd9\xfb\xe5\x5b\x36\xc5\x52\x9b\x17\xbc\x3a\x9c\xca\xba\x69\x35\xc9\xe2\x05\x48\x25\x5b\x3d\xfa\xe0\xf9\x1d\xb0\x30\xc1\x2f\x2c\x34\x4b\x3a\x29\xc4\x15\x1c\x5b\x20\x9f\x5e\x31\x9f\xdf\x1c\x23\xb1\x90\xf6\x4f\x1f\xe5\xb3\x30\xcb\x7c\x8f\xa9\x52\xf9\xd9\x0f\x13\xaf\xf1\xcb\x11\xd6\x31\x81\xda\x9e\xfc\x6f\x7e\x15\xbf\xed\x48\x62\xd1\xa6\x2c\x7d\xcf\x3b\xa8\xbf\x1f\xf3\x04\xb1\x02\xb1\xec\x3f\x14\x97\xdd\xdf\x09\x71\x2c\xf3\x23\xf5\x61\x0a\x9d\x10\xc3\xd9\x13\x26\x59",
        p,
        q,
        g,
        b"\x5a\x55\xdc\xed\xdd\x11\x34\xee\x5f\x11\xed\x85\xde\xb4\xd6\x34\xa3\x64\x3f\x5f\x36\xdc\x3a\x70\x68\x92\x56\x46\x9a\x0b\x65\x1a\xd2\x28\x80\xf1\x4a\xb8\x57\x19\x43\x4f\x9c\x0e\x40\x7e\x60\xea\x42\x0e\x2a\x0c\xd2\x94\x22\xc4\x89\x9c\x41\x63\x59\xdb\xb1\xe5\x92\x45\x6f\x2b\x3c\xce\x23\x32\x59\xc1\x17\x54\x2f\xd0\x5f\x31\xea\x25\xb0\x15\xd9\x12\x1c\x89\x0b\x90\xe0\xba\xd0\x33\xbe\x13\x68\xd2\x29\x98\x5a\xac\x72\x26\xd1\xc8\xc2\xea\xb3\x25\xef\x3b\x2c\xd5\x9d\x3b\x9f\x7d\xe7\xdb\xc9\x4a\xf1\xa9\x33\x9e\xb4\x30\xca\x36\xc2\x6c\x46\xec\xfa\x6c\x54\x81\x71\x14\x96\xf6\x24\xe1\x88\xad\x75\x40\xef\x5d\xf2\x6f\x8e\xfa\xcb\x82\x0b\xd1\x7a\x1f\x61\x8a\xcb\x50\xc9\xbc\x19\x7d\x4c\xb7\xcc\xac\x45\xd8\x24\xa3\xbf\x79\x5c\x23\x4b\x55\x6b\x06\xae\xb9\x29\x17\x34\x53\x25\x20\x84\x00\x3f\x69\xfe\x98\x04\x5f\xe7\x40\x02\xba\x65\x8f\x93\x47\x56\x22\xf7\x67\x91\xd9\xb2\x62\x3d\x1b\x5f\xff\x2c\xc1\x68\x44\x74\x6e\xfd\x2d\x30\xa6\xa8\x13\x4b\xfc\x4c\x8c\xc8\x0a\x46\x10\x79\x01\xfb\x97\x3c\x28\xfc\x55\x31\x30\xf3\x28\x6c\x14\x89\xda",
        b"\x63\x30\x55\xe0\x55\xf2\x37\xc3\x89\x99\xd8\x1c\x39\x78\x48\xc3\x8c\xce\x80\xa5\x5b\x64\x9d\x9e\x79\x05\xc2\x98\xe2\xa5\x14\x47",
        b"\x2b\xbf\x68\x31\x76\x60\xec\x1e\x4b\x15\x49\x15\x02\x7b\x0b\xc0\x0e\xe1\x9c\xfc\x0b\xf7\x5d\x01\x93\x05\x04\xf2\xce\x10\xa8\xb0",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xa7\x33\xb3\xf5\x88\xd5\xac\x9b\x9d\x4f\xe2\xf8\x04\xdf\x8c\x25\x64\x03\xa9\xf8\xee\xf6\xf1\x91\xfc\x48\xe1\x26\x7f\xb5\xb4\xd5\x46\xba\x11\xe7\x7b\x66\x78\x44\xe4\x89\xbf\x0d\x5f\x72\x99\x0a\xeb\x06\x1d\x01\xcc\xd7\x94\x9a\x23\xde\xf7\x4a\x80\x3b\x7d\x92\xd5\x1a\xbf\xad\xeb\x48\x85\xff\xd8\xff\xd5\x8a\xb8\x75\x48\xa1\x5c\x08\x7a\x39\xb8\x99\x3b\x2f\xa6\x4c\x9d\x31\xa5\x94\xee\xb7\x51\x2d\xa1\x69\x55\x83\x43\x36\xa2\x34\x43\x5c\x5a\x9d\x0d\xd9\xb1\x5a\x94\xe1\x16\x15\x4d\xea\x63\xfd\xc8\xdd\x7a\x51\x21\x81",
        p,
        q,
        g,
        b"\x35\x6e\xd4\x75\x37\xfb\xf0\x2c\xb3\x0a\x8c\xee\x05\x37\xf3\x00\xdf\xf1\xd0\xc4\x67\x39\x9c\xe7\x0b\x87\xa8\x75\x8d\x5e\xc9\xdd\x25\x62\x46\xfc\xca\xeb\x9d\xfe\x10\x9f\x2a\x98\x4f\x2d\xda\xa8\x7a\xad\x54\xce\x0d\x31\xf9\x07\xe5\x04\x52\x1b\xaf\x42\x07\xd7\x07\x3b\x0a\x4a\x9f\xc6\x7d\x8d\xdd\xa9\x9f\x87\xae\xd6\xe0\x36\x7c\xec\x27\xf9\xc6\x08\xaf\x74\x3b\xf1\xee\x6e\x11\xd5\x5a\x18\x2d\x43\xb0\x24\xac\xe5\x34\x02\x9b\x86\x6f\x64\x22\x82\x8b\xb8\x1a\x39\xaa\xe9\x60\x1e\xe8\x1c\x7f\x81\xdd\x35\x8e\x69\xf4\xe2\xed\xfa\x46\x54\xd8\xa6\x5b\xc6\x43\x11\xdc\x86\xaa\xc4\xab\xc1\xfc\x7a\x3f\x65\x15\x96\x61\xa0\xd8\xe2\x88\xeb\x8d\x66\x5c\xb0\xad\xf5\xac\x3d\x6b\xa8\xe9\x45\x3f\xac\xf7\x54\x23\x93\xae\x24\xfd\x50\x45\x1d\x38\x28\x08\x65\x58\xf7\xec\x52\x8e\x28\x49\x35\xa5\x3f\x67\xa1\xaa\x8e\x25\xd8\xad\x5c\x4a\xd5\x5d\x83\xae\xf8\x83\xa4\xd9\xee\xb6\x29\x7e\x6a\x53\xf6\x50\x49\xba\x9e\x2c\x6b\x79\x53\xa7\x60\xbc\x1d\xc4\x6f\x78\xce\xaa\xa2\xc0\x2f\x53\x75\xdd\x82\xe7\x08\x74\x4a\xa4\x0b\x15\x79\x9e\xb8\x1d\x7e\x5b\x1a",
        b"\xbc\xd4\x90\x56\x8c\x0a\x89\xba\x31\x1b\xef\x88\xea\x4f\x4b\x03\xd2\x73\xe7\x93\x72\x27\x22\x32\x70\x95\xa3\x78\xdd\x6f\x35\x22",
        b"\x74\x49\x8f\xc4\x30\x91\xfc\xdd\x2d\x1e\xf0\x77\x5f\x82\x86\x94\x5a\x01\xcd\x72\xb8\x05\x25\x6b\x04\x51\xf9\xcb\xd9\x43\xcf\x82",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xac\x30\xfb\x15\x51\x04\x95\x4b\x9d\x71\x39\xde\x93\x46\xd5\x4c\xa0\x51\x78\x95\x40\x53\xfd\x36\x1c\x97\x19\xce\xa5\x30\xd2\xd2\xe1\x73\x7f\xc4\x6b\x0e\xe2\x73\x57\xce\xcb\xd4\x7e\x0f\xd4\x7a\xda\x0d\x52\x36\xa9\xd7\x7d\xd6\x1a\x1b\x0d\xb5\x2e\x62\x8b\x14\x58\x8f\xdb\xa8\x77\x48\x82\x86\x6b\x04\xb4\x9c\xf5\x20\x5d\xb4\x94\x45\xa8\xa2\x02\xa5\xfc\x3f\xcc\x36\xef\xe0\xbd\x0c\x1e\x51\xeb\x08\x61\x6c\x4a\x7a\xfe\x12\x00\x77\xea\x08\xca\xf1\x67\xe9\x04\x46\x86\x22\x98\x01\x1a\xd9\xa1\xf1\x1c\xef\xb5\xf7\x43\x35",
        p,
        q,
        g,
        b"\x84\x74\x1b\xef\x3d\x9f\x9d\xab\x0e\x3f\xae\x78\x39\xd3\x9c\x1a\x19\x66\xab\x82\x79\x8d\x71\xaa\x46\xb7\xde\xf4\x65\xe3\x9e\xa5\xe7\xad\xae\xed\x2d\xfc\x92\xc9\xbe\xa7\x2d\x65\x26\x8b\x8d\xf9\x55\xf9\xb7\xe7\xb6\x92\x3d\x2b\xf0\x0e\x7e\x43\xf8\x3a\x0e\x54\xca\x94\x42\x75\xdc\x39\xc0\xfb\x0c\x8a\x00\xcc\xd0\xb2\x9b\x79\x0d\x9d\x8f\x34\x96\x05\x43\x90\x41\x0b\x4a\xe5\xc6\xea\xf2\xe2\x1b\xdb\x52\x42\x11\x79\x97\x0f\xa1\x3e\x09\x48\x28\x0a\x06\xa5\x76\xcd\xff\xae\x6f\xdb\x23\x9e\xbd\x48\x6b\xf4\x69\x92\x70\xe2\xbc\x08\x79\xbe\x25\xa6\xa0\xc2\xf7\x28\x0e\xa3\x3e\xeb\x32\xc5\xd2\xea\x60\x93\x38\x1f\xc4\xc8\x3c\x8f\x9a\x59\x1b\x0b\x0e\x72\xfc\xc1\x49\xc6\x85\xb0\x13\x81\xa7\x4a\xf4\xcc\xb9\x02\xc0\x05\x0e\x05\xba\xf7\x32\xba\xcd\x16\x06\x53\x3e\x2a\xcc\x63\x08\xc7\x77\x20\x1e\xec\xdc\xdc\xbe\x93\x51\x49\xc4\xe5\x72\xa1\x5a\x20\x5d\x2b\x80\xe7\x5e\xf2\x47\x31\x60\xf8\x5e\x64\x2d\x28\x37\x0c\x0f\x19\x46\x41\x25\xc6\x87\xc9\x69\x66\x5b\x13\xb0\x95\xaa\x87\xba\x47\x68\x02\xd7\x2c\x35\x4e\xbc\xbc\xd8\x9f\x28\xef\x00\x1c",
        b"\x28\xc6\xbf\xca\xdb\x5f\x52\x32\x4e\x39\x90\x3b\xf7\xa0\x4f\xae\xfb\x89\x38\x3f\x47\x3d\xaa\x43\x2c\xab\x91\x78\xf2\x47\x0d\x3c",
        b"\x4e\x88\xf6\x5f\xf7\x76\x94\x0b\xaf\xbb\xfb\x35\x64\x3b\xcd\xae\xb4\x3b\x25\xb4\x5d\xe2\xde\x3c\x01\x1f\xf1\x44\x9c\x8b\x8b\x32",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x22\x25\x03\x1f\xd2\x6a\x6b\xb4\xfd\x99\x90\x34\x7b\xc2\xc8\xea\x4b\xa4\x5b\xd7\x5d\xf6\x84\x76\xf9\x83\xdf\xfb\x55\x31\x89\x9f\x13\x17\xd9\x5f\x7c\xbb\x49\x3d\xe4\x5c\xd2\xf1\x19\x04\xcd\x5c\x5d\x5a\x74\x8b\x4a\xa1\x27\xca\x73\x0f\x89\xa9\x28\xdd\xcd\x25\x0a\x65\x51\xc2\xf7\xcc\xe1\x09\xe6\x4d\x3a\xb7\x4a\xfb\x2d\x4f\x4f\x7e\x34\x94\xeb\x7d\x55\x70\x60\xa1\xf2\x9e\xcb\x5b\x75\xf6\x48\x48\x37\x09\x02\xbd\x6a\xe2\xfb\xf6\x80\x2b\x2f\x9c\x37\xf3\x48\x36\xad\x71\xdd\x2e\x2a\xbf\x6a\x0a\x47\xdf\x4f\xd5\x57\x3d",
        p,
        q,
        g,
        b"\x04\x96\x4c\x09\x3f\xdb\x85\x2c\x97\xb1\x65\xe1\x79\xf7\xef\x3b\x39\x35\x0c\x25\x88\xe6\x0a\x01\x77\xbc\x2e\x89\x0a\xb0\x8f\xfd\x73\xd8\xa5\xa6\x69\x2c\xfe\xbd\x0c\x91\x2d\xe2\xd5\x0b\xf0\x21\x39\xbf\x01\x7e\xc7\x15\xc2\xdd\x7b\xe1\xaa\xd9\xd0\xb9\x6c\x47\xd6\x46\x5d\x4e\xb0\xea\x02\x47\xff\x65\x59\x59\xd9\x4a\x34\x09\xe9\xf9\x26\x2d\x87\x70\x75\xf6\xf0\xc7\x78\x3a\x8d\xf3\xcc\x11\x5c\x52\x87\xc6\x9b\xdb\xf0\xff\xe0\xed\x37\x19\xe4\x18\xff\x99\xb5\xdc\xd5\xf0\xcf\xc1\x06\x5e\x40\x4a\x21\x6e\x09\x50\x86\xa6\xe2\x19\x7a\x69\xc4\x77\x74\x37\x72\x03\xd9\x9a\x23\x4e\x7b\xe6\x1c\xc4\xa9\x5a\x80\x9f\x9b\x9d\xd0\xa5\x50\xb7\x12\xbc\xe5\xd1\xcf\xda\xfd\xa2\x32\xd7\xc8\x31\xec\x52\x88\x47\x01\x15\x5a\x3d\xf2\xb0\x86\xbe\x87\x0a\xf8\xe8\x75\x55\x75\x18\xb0\x35\xc8\x49\x57\xc1\x74\x2b\x8c\x02\xb0\xd4\x6b\x64\xa7\x73\x01\x28\x09\xbf\xa4\xc5\x40\x7c\x3f\xbf\xed\x3b\x96\x08\x16\x60\x4c\xf4\x2b\x2d\xef\xb4\xfe\xea\xbc\x17\x2a\xfb\xfc\xbc\x82\x83\x6b\x44\xb9\x27\xe0\xcd\x4c\xa6\x3a\x1d\xae\xb3\xee\xb3\x0d\x1d\xe6\x08\x12\x7b",
        b"\x55\x68\xd8\x10\xba\x66\x4a\x08\xb3\x01\x26\x6d\x08\xc6\x9e\xac\xcc\xec\x5a\xae\x87\x0a\x6d\x57\x9e\xda\x51\xa3\x1b\x18\x46\x55",
        b"\x9e\x81\x88\x68\xe0\x67\x87\xfb\x95\x19\xb5\x05\x46\xee\x21\xd0\x54\x6e\x16\xbb\x1b\x59\x20\x31\x1b\xa4\x47\x69\xdc\x69\xc7\xa6",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x4b\x1f\x93\x35\xfd\xfe\x88\xc0\x86\x6b\xb6\x48\xc0\x58\x57\xb7\x9c\x2f\xda\x92\xa9\x87\xb3\x59\x28\x2b\xbf\x08\x22\xdb\x74\x7a\x39\x40\xfe\xe0\x5a\xeb\x3c\xc0\x81\x23\x1e\x29\xb9\xd4\x60\xef\x30\xa5\x5f\x0f\x88\x70\x2a\x4e\xcd\xcb\x84\x2b\xee\xb3\x6a\x97\x61\x36\xc9\x24\x1f\x2e\xb5\xc2\xd9\x3f\xe3\x8a\x15\x80\xcd\x58\xfb\x93\xed\x13\x7a\x7d\x05\xea\x22\xd5\xe8\x73\x45\x63\x3a\x0e\x39\x3f\xee\xa6\x16\xea\xf8\x36\x84\xc3\xba\xca\x4f\xc5\xbf\x80\xa8\x7d\xbe\xc3\xa9\x78\x7d\xac\xce\xc4\x79\x66\x1a\xf0\xb9\x68",
        p,
        q,
        g,
        b"\x57\x76\x7c\x34\x8a\xb0\xc6\x1e\xab\x4f\x2e\x08\x94\xbb\x62\x23\x64\x5a\x33\x1c\x5b\xe2\x49\x0d\x76\x48\x39\xfa\x4d\xac\x81\x4e\x05\xe7\x09\x25\xd7\x20\xd0\xe0\xab\x5f\xaa\x3d\xb6\xdc\x58\xba\x57\x3b\x4e\x0b\x7b\xc1\x3e\x4c\x04\x4b\x96\x25\x93\x85\xfc\xd1\xea\xde\x0d\x7c\x51\x74\x49\x8c\x70\xba\x8f\xb8\x66\x1e\xd5\x24\xfa\x81\x71\x57\x0f\xd5\x2f\xaa\xc9\x91\x5d\x94\x7b\x51\xf6\xcf\x5b\x74\xe3\xed\xfa\x06\x4a\x51\x61\xc7\x62\x3e\xc6\xe8\x0d\x29\x96\x0b\x57\x3f\xb9\x8d\xe9\xe7\x10\xc5\x6e\xe4\x5a\xab\xc4\x02\x23\x57\xf6\xc3\x71\x29\x62\xad\x19\xe4\x3a\x41\x48\x95\x7c\xc6\xb9\xc8\xf6\x91\x87\x7a\x59\xf4\x31\x62\xd8\xf9\x8f\x24\x72\x69\x9e\xa5\x10\x10\x93\x05\xf8\xf9\x8a\xa3\xf3\xf3\x1e\x43\x02\xeb\x05\xe5\xf1\xa4\x62\xd0\xf3\xbf\xdc\xd0\xc8\x4e\x76\xbf\xdd\x14\xb7\xc9\x0b\x98\x2b\x8c\x0e\xc7\xc7\x8c\xf3\xe6\xc2\x16\xed\x1d\x20\xb5\x2a\x13\x2f\x53\xc9\x74\x7c\x7f\xbe\x39\x09\x2d\x5c\xcf\xcc\x01\xa1\x19\xc9\x2f\xaa\x3f\x13\xd4\x64\x3e\x5d\xb2\x2c\xa1\x68\x1d\x65\x36\xbc\x7b\x70\x4b\xb0\x9b\xf6\xc6\x21\xc2\xff\x06",
        b"\x7a\xc9\x5d\x3e\x09\x36\xcd\xe4\x41\xe4\xa2\x90\x71\x1c\xc0\x44\xe6\xe9\x8e\x8a\x8d\xe6\x82\x98\xbf\x7f\xb9\x0e\xef\x58\x9e\xb2",
        b"\x14\x0e\x9d\xe3\x7e\xc5\xae\xb3\xfb\x79\x5b\x01\x6f\x51\xea\x3e\x92\xd6\xf1\x98\xc5\xa0\xe5\xa5\xd2\x36\x67\x1c\x91\x04\x2c\x94",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x3b\x87\x10\x9b\xf2\x15\x71\xfc\xfa\xe9\x2b\x85\x96\x49\xbf\x37\xdd\x23\xd5\x9f\x76\xd5\x0c\xf2\x6f\x4b\x2e\xbf\x7c\x5f\x4a\xe0\xb3\x77\xbf\x3b\xf2\xc7\xe0\x15\xa7\x4e\xfc\x80\x84\x33\x04\x7a\x71\xbf\x1e\xd4\xba\x90\x25\xf4\x56\x1d\xcb\x94\xbe\xf2\xc2\xa2\xc9\x4b\x3f\x55\xed\x61\x1c\x43\x2f\x98\xa6\x83\xab\xad\xc2\xc3\x1d\x00\x2e\xac\xa9\xb0\x70\xf2\xb2\x13\x19\xd0\x72\xdf\x75\xc6\x23\x85\xd7\xd0\x28\x97\xa0\x0f\x86\x3c\x28\x82\xb2\x89\x7a\x33\x13\x32\xbb\x95\x68\xb2\xfd\xfa\xcc\xf5\x0b\x3d\xe4\xb4\x2e\x8a",
        p,
        q,
        g,
        b"\x7c\x16\xa9\x64\x4c\x18\x25\x79\x11\xb8\x26\xda\x10\xb5\xb1\x01\x15\xff\x77\x67\x5b\xdc\x3c\x9f\x77\x09\x71\x62\xfc\x05\x9e\x86\xb0\x4c\x1f\xae\xed\x3c\x66\x30\x6c\x7e\x5f\xe2\xd5\xc6\x3e\x8f\xa5\xfa\x2b\x82\x56\x5a\xc6\x06\x54\x45\xde\x58\x19\xa2\xe4\xa5\x69\x25\xbd\xcc\xe1\x38\x65\x4d\xfb\x49\x0a\xc6\x24\xa3\x8a\xd6\x58\x49\xbe\x4b\xa7\x4d\x14\xc8\x29\xef\x10\x22\x48\xa1\x81\x93\x93\x33\x35\xea\xf0\xc7\x3b\x7b\xfe\x77\xd6\x69\xf8\x57\xef\x3a\xdd\xb1\xf4\xca\x42\x4d\xbf\xde\xdb\x9e\x2d\xe1\xfc\x0c\xc2\xd9\x77\x7e\xe8\x34\xa0\xac\x7d\x0c\xac\x1b\x2a\x61\x38\x90\x07\x14\x90\xef\xe5\xcb\x20\x97\xac\x83\x0f\xbc\x27\x88\x1f\x9f\xa5\x1d\x3b\x02\x47\xc5\xe1\xb7\xf6\xbe\x13\xc3\x0d\xd3\x1c\x2c\x59\xb7\x68\x3c\xe6\x0a\x0e\xbd\x66\x63\xde\x97\x87\x0a\xf2\xdd\x17\xd9\x14\x31\x32\x3a\x46\x86\xbf\x32\xe1\xe3\x97\x32\xda\xe1\x30\x0c\x57\xbd\x60\x0b\xe7\x90\x59\x3b\x2e\xfa\x04\x5b\xbf\xca\x95\x67\x68\x15\x7b\x47\x24\xca\x0a\x14\x72\xfe\x6c\x8d\xcd\x82\xa3\x80\x24\x76\x63\x41\xd1\xf5\x48\xad\x8f\x36\xdc\x67\x66\x76\xfb\xe3",
        b"\x1e\x21\x9e\xef\xd6\x16\xca\xac\x54\x9a\x85\x9d\x45\x18\x6b\x5c\x52\x86\x27\x57\x39\x58\xfe\x55\xcf\x57\xfb\xbd\x16\x61\xf7\xb8",
        b"\xb0\x95\x45\x84\x3d\xc0\xf6\x29\x9b\x48\xf1\x43\x11\x50\x36\x05\x50\x28\x68\x85\x9e\x8c\x43\x86\x7f\x80\xdf\x3c\x23\x91\xc7\x62",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x04\x23\x65\xb1\x25\x69\x31\xa1\x11\xfa\xcc\x6c\x40\xf6\x18\xc4\x28\x80\x1b\x03\xe4\xf2\x22\xa1\xe1\xb7\x76\x3c\x3b\x02\xa6\x21\x4e\x4c\x51\x7b\xeb\x58\x7a\x4e\xa6\x9f\xdb\xd4\xea\x2d\x5d\x5f\x45\xaf\xde\xd9\x6d\xda\xc8\x7d\xc8\x99\x55\x61\x3a\xef\xf7\x64\x4f\xc6\xa5\x8b\xb8\x59\xa8\x52\x21\x31\x8f\xbc\x5e\x17\x5c\x69\x85\xb1\x9a\x1d\x16\xab\x6a\xd3\xca\x8f\xa1\x90\x3a\xcc\xa4\x2b\xc6\xd9\xef\xbe\x88\xfd\x6f\x2a\x86\x50\x42\x5b\xe9\x7b\xab\x9c\xb6\x70\xb2\xe3\x9f\x36\xd5\x26\x27\x8e\x0b\xcf\xcb\xff\xc3\xc6",
        p,
        q,
        g,
        b"\x81\x54\x11\xac\x6a\xa1\xb4\x95\xc4\xba\xc8\x02\x80\x6a\x1a\x35\x92\x92\x4f\xd9\xc0\xa3\xcc\xa4\x1e\x07\x6d\xb2\x93\xd8\x15\xc2\xf2\xb0\xa5\x3e\x97\xcf\x65\x7c\x89\x51\xb8\x56\xcc\xa1\x16\x6a\xd4\x33\xbe\x58\x29\xb0\xb6\x36\xca\x9d\xe4\x91\x11\xce\x5c\xec\xce\xde\xdf\x36\xd7\x95\xed\xef\xef\xee\x1d\x55\x32\x50\xfb\xcd\x5b\xd0\x5b\x4d\x99\xde\x55\xf1\x47\x77\x3a\xb3\xa0\xf7\x54\xd0\x90\xca\x7b\x6f\xf7\x5c\x16\x0e\xef\xd1\x70\x9a\x5d\xf3\xcd\x8a\x0c\xae\x3e\x34\x1f\x22\x75\xfa\xae\xe3\xe3\xe3\x17\x37\xe7\xe9\xc7\xe7\x48\x45\x65\x1f\x4f\x83\x9c\x9d\x08\xda\x6b\xfd\x00\xf2\xc2\xb9\xc6\xed\x9a\xcb\x78\xd1\x11\x75\xfa\x6d\xed\x7a\xb9\x5d\xbb\x2b\xfe\xf1\x8f\xeb\x14\x9b\xc9\x4f\x6d\xe0\x5a\x20\x52\x21\xba\x04\x06\xc9\x6f\x63\x97\x2a\xef\xec\x1b\xee\xf0\x30\x13\x70\x11\xe6\x79\x6a\xf2\xe4\xeb\xaa\x10\x01\x50\xd5\x8c\xaf\x40\x82\x17\xac\xb1\x18\x3a\x1a\x46\xe0\x63\x68\xcf\xf6\xfd\x74\x4d\xa7\x01\x9e\x7c\xa1\x09\xac\xf1\x24\x4a\x76\x3c\xc2\xb2\x18\x6f\x49\x27\x2b\xa3\xae\x04\x25\xf2\xeb\xcd\x30\xe7\x7e\x9f\x7c\x95\x7a",
        b"\xe7\x14\x5c\x70\xe0\x03\x8a\xe7\xe7\xd9\x01\xb4\x88\x28\xb0\xb8\xbc\x96\x0c\xc4\xfa\x29\xa5\x2e\x11\xff\xc9\xab\x08\xee\xe7\x26",
        b"\xb9\xc5\x4e\xf6\xcb\x3e\x1b\x04\x98\x95\x22\x99\xd1\x46\x5e\xd2\xc5\xd4\xe6\x70\xcd\xfd\x25\x06\x46\x24\x66\xc3\xb0\xfc\xc5\x38",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x98\xff\xb2\x89\x9f\x17\xc8\x0a\x83\xe8\x2c\xa6\x26\x5e\x6f\x36\x17\x33\xa6\xbb\xc6\x3c\xdf\x88\x80\xdc\x75\x6b\xc7\x68\xb3\x5b\x90\xdb\x73\x90\xcf\xff\x74\x5e\xc1\xb5\x6f\x16\x55\xd8\xd9\xa2\x9a\x6e\x8a\x63\xbe\x0b\x1b\x2f\x9a\xa7\x43\x62\x09\xa1\xfa\x06\x1a\x7a\xec\x28\x62\x2c\x47\x2b\x3d\x02\x85\xa7\x01\x65\x5a\x49\x65\x46\xe8\x91\xa8\xab\x29\xd9\xf4\x0d\x2e\x74\x8d\x0a\xa2\xba\xbc\x06\xcf\xca\x64\x1b\x30\x0b\x7a\x21\x9c\xaa\x9e\x5b\xae\x3b\xf6\x89\xf6\x05\x67\xf9\x22\xe7\x79\x6f\xe4\x7b\xb7\x2f\xfb\x64",
        p,
        q,
        g,
        b"\x14\x11\x1d\xca\x30\xc0\x13\x87\x61\xfd\x2f\x55\x97\x2b\x98\x46\x04\x1e\x5c\xa8\xb9\xbc\x6b\x2d\xc8\x20\xf2\xa2\xf5\x10\x0a\xba\xab\x33\x7c\x7e\x0d\x1b\xc5\x9d\xe5\xae\x58\x6b\xbd\xcf\x4d\x4b\x14\xaa\x23\xbe\x40\x09\x52\x93\x12\x3b\xad\xbb\x11\x91\x9b\x78\xcd\x64\x12\x54\x8d\x9f\x9d\x15\xf6\x14\xb6\x92\x87\x13\x34\x41\x48\xfd\x7d\x30\x98\x5f\xd2\xc5\x09\xb4\x4d\x39\x6c\x56\x72\xa0\x82\xde\x41\x83\xfe\xe0\x3e\x45\xa9\x0e\xef\x6a\x08\xb0\xd9\xd4\x71\x32\xc8\x2a\x2c\xcf\xef\x05\xe2\xad\x0f\x34\x0d\xcc\x06\xd9\xe2\xe9\x79\xec\xc4\x38\x44\xc6\x05\x4e\x4f\xa5\xfb\x8a\x73\xa1\xe3\x87\x3f\x21\x45\xb0\xfd\x40\xf3\xec\x79\x46\xf1\xf4\x3d\xe8\xb8\x05\x7c\x1b\xe5\xbf\x04\x63\x0a\x12\x45\x3d\x62\x3c\x9b\x8d\x9f\x0e\x30\xc8\x8c\x30\x43\x42\x15\xd4\x8f\x77\x34\x8e\x6b\x04\x7f\x16\x93\x4e\xa0\x97\x43\xdd\x3b\x00\x9c\xeb\xc4\x9d\xbc\x3a\x3d\x35\x67\xc3\x32\x15\x55\xec\x96\xb2\x16\x0c\xaf\x78\x70\x97\x0a\xc3\xcd\x82\x94\x47\x7a\x06\x43\xad\x52\xc2\x3d\x9d\x98\x7d\xbf\xff\x64\xae\xd1\xa8\x83\xc3\x0a\x49\xf1\x4f\xf0\x62\x00\x95",
        b"\x45\x51\xb0\x96\x44\x6d\xb6\x76\x1b\x70\x8f\x35\x20\x9e\xdb\x91\xcc\x51\xee\x4e\xf9\x6a\x74\x95\x40\x7a\xb4\x16\x7a\x05\xc7\x91",
        b"\xcf\xe4\xc5\x8b\xdb\xf6\x1c\xaf\x09\xa4\x2a\xdb\x1a\xa5\xd9\x8b\x4c\x45\x9c\x01\x12\xc5\x78\x23\xbc\x15\xb5\xb9\x90\xd9\x2f\xf1",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x58\x98\xcc\x0b\x42\x2b\xb8\x9f\x06\x6d\xab\xbd\x30\xf5\x9e\x9a\x35\xa3\x92\xbd\xd7\xad\x31\x5e\xc8\xad\x32\xb8\xf0\xf3\xd0\x28\x64\xe7\x0e\xa3\x6e\x90\x76\xc3\x95\xf0\xba\x9d\xe1\xab\x60\x80\xdf\x3c\xf4\xa1\x47\x0e\x2b\x99\x90\xb8\xe7\x61\x4b\xb8\x31\x2b\x07\x5c\x0b\x2a\x13\x2d\x7e\x47\xde\xd9\xe4\xc0\xa1\x36\x84\x55\xb9\xd1\xa6\x7b\xc4\x4a\xf2\xf3\x74\x28\xf4\x8f\x7e\x08\x9a\xb4\x1d\x04\x63\x78\xb6\xd4\x8d\x9c\xb1\x35\xee\xe4\x57\x40\x72\xab\xea\x93\xbd\xa7\xeb\x4f\x15\xa2\x06\xcd\xaf\x3b\xbb\xeb\xd3\x18",
        p,
        q,
        g,
        b"\x76\x6d\x7e\x4f\x8b\xc3\x25\x4d\x92\xcf\x6a\x64\xab\xd5\x04\xd0\x1c\xdc\xf6\xc2\x39\x17\x8b\x0a\xeb\x3f\x69\xc9\xbf\x20\x2b\xff\x75\x66\xec\xa0\x9f\x29\xcf\x5d\x6f\xa4\x73\x6d\x57\xc0\x82\x05\x50\x0d\x64\x83\x36\x40\x9d\xf0\x6e\x7f\x2c\xf9\x91\x78\xb2\x0a\x7e\xc2\xb5\x12\x4b\xcf\xfc\x61\xad\xb6\x6f\x6f\xaf\xc5\x1e\x32\x52\x1d\xea\x21\x24\xe5\x78\x1c\x38\x3b\x11\x6d\x06\xa6\xa6\xe8\x9d\xec\x46\xb5\xe4\xad\x69\xf5\xa1\xe8\xdd\x7a\xc5\xe1\x60\xda\x33\x6c\x11\x86\x0b\x60\x1e\x7e\x6d\x58\x89\x5e\x67\x97\xdb\x5a\xa9\x2d\xeb\x7b\x94\x2f\x2e\xdf\x58\xd4\x3d\x3d\xac\x92\x09\x55\x7a\x6a\xa0\x7b\x22\x8e\x73\xa8\x0f\xf0\xe9\x2e\x4e\xc4\x60\x3d\x36\x2e\x1c\xca\x7e\x92\x8d\x94\x59\xc2\x14\x05\xaa\x0f\x65\x48\x73\x2c\x0f\xc5\x01\xce\x50\xf0\x89\x6f\x07\x63\xf6\x33\xc8\xc1\xa8\x53\x13\x21\xe1\xa0\xf4\x71\x34\xa0\xd2\xd8\x67\x6f\x45\xf1\x3e\xa5\x76\xe6\x4c\x78\x70\x02\x80\x33\xa4\x26\x1b\xdf\xce\xc9\x48\xeb\xb1\xaa\x25\xb0\x21\x34\xd0\x25\x9d\x73\x02\x4a\x01\xda\x0c\xad\x1c\xe6\x75\x71\xe3\x69\x63\xdc\x13\x04\x96\x16\x0e\xbf",
        b"\xa2\x37\xd2\xc3\xd2\x37\x06\xca\xf0\x04\xa2\xe9\x4d\xe2\x9f\x04\xc7\x48\x93\x6b\x62\xab\x54\x31\xfe\x73\xc7\x24\x85\x81\x42\x65",
        b"\xb4\x8b\x9e\xf9\xcb\xd8\xbd\xf7\x99\xb7\x06\x05\xf0\x05\x50\xb8\x1b\x30\x9c\x15\x73\x32\x15\x3b\xe9\x70\x7a\x39\x9f\xbd\xd6\x7f",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x04\x18\xe0\x12\x36\xca\xed\x0f\x80\x24\x1c\xe8\xc6\x30\x7d\x02\x6f\x5e\x25\xf4\xa9\x22\xbb\xdb\x4a\xaf\xb8\xd9\xdb\x95\xa1\x81\x75\xf9\xdc\xea\x9a\xcb\x4d\x37\x6f\x36\xff\x7b\x7c\xb5\x98\xe0\x73\xde\x95\xad\x20\x12\xeb\x9d\x11\xe1\x5c\xb3\x94\x1c\x6d\xd0\xdd\x69\x42\x2e\x78\x51\x2e\xbf\xfb\x19\xcc\x8a\x40\x3a\x9a\x7d\x1f\x17\x20\xab\x0f\x2d\x25\x62\x75\x80\x36\x60\x93\xe2\x1a\xc1\x53\x7f\x93\xde\x90\xa9\x45\x08\xf1\xd7\xa7\xa1\xdb\x5a\x7b\x13\xc9\xfd\x00\xb8\x2b\xe0\x44\xc3\xa3\x5e\xc0\x45\x1c\x30\x9b\x82",
        p,
        q,
        g,
        b"\x4c\xf4\xce\xe4\xd5\xab\xc2\xc9\x2d\xb5\x22\x92\x8b\x6d\x7e\x43\x6e\xa0\x08\x84\x00\x94\x97\xed\x58\x8e\x93\x28\x1c\xf0\x5b\x37\x47\xca\x00\x48\xb9\x17\x70\x82\x79\xcd\x02\x77\xce\x85\x60\xc2\x27\x75\xd2\xaa\x0e\x7e\xed\x1b\xba\x77\xbe\x45\x41\x7f\xa7\xaf\xd7\x76\xb8\xe5\x60\x67\x9c\x49\x3a\x52\x0a\x0e\x62\x6a\xcd\xc8\x3d\xf0\x21\x35\x16\x69\xbd\xf9\xda\x19\xb1\x2b\xef\x29\x26\xb5\x25\xfa\x4c\x8e\x3d\x1f\x20\x83\xea\x6b\xbb\x48\x98\x80\xf5\x94\xe6\x79\x34\xd1\xf3\x55\x81\xad\x18\xe0\xdb\x46\x2a\x1a\xc9\x44\x06\x6c\x65\xdd\x74\x3f\x35\x74\x1c\x6c\xf5\x88\x91\x8d\x83\x36\x70\x23\x29\xc6\x21\x13\xe9\x48\x6b\xfa\x49\xca\x54\x25\x91\x45\x26\xa9\x65\xe3\xc1\x97\x58\x24\xf4\xb3\x9f\xa5\xfe\xf8\x9c\xf6\xf9\xea\x51\x2f\x7f\xfc\x91\x38\xe7\x2d\xbd\x0f\x71\xb0\x1a\x70\x97\x53\x12\xea\xca\xb1\x11\x18\x47\x11\x15\xee\x3f\xc8\x10\x52\x29\x36\xc9\xdf\x35\x97\x75\x09\xb1\x96\xd8\x67\xfa\x11\xf6\x07\xb7\xef\x9a\xb7\x8c\xb7\x48\x21\x3a\x67\x63\x43\x9c\xe5\xe7\x64\x1b\x05\x35\x96\x70\x61\x22\x03\xa4\x7d\x4d\xe9\xc5\x38\x84\x05",
        b"\x83\xee\x96\x0e\x6f\x90\x26\xfe\x24\x54\xd8\x59\x46\x2a\xc3\x34\xa1\x38\x96\xe7\x51\x79\x85\x8e\xf4\x0e\x2e\x9a\x06\x5c\x53\x6a",
        b"\x7c\xe8\x69\x9c\x6c\xcb\x18\x4d\x42\x40\xb8\x70\x9d\xa1\x14\x51\x32\x8c\xf1\xa7\xe0\xca\xfe\x6e\x1c\x8a\xb5\x3d\x7d\xe6\x7d\x9e",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x92\xc9\x49\xfe\x23\x42\xf9\x1a\x38\x7b\x67\xc1\xb1\x2b\x1d\x04\xd0\x72\x12\x03\xca\xed\x59\x3c\x9c\x46\x4e\x5f\xda\x09\xfd\xcc\x91\xd3\x32\x1d\x29\x85\xee\xc0\x8a\xb2\x02\x6d\x1e\xc3\xfc\xfa\x83\x8c\xb6\xaf\x45\x29\x0c\x08\xdc\x30\xb9\xc1\x4c\x44\x45\xd7\x83\xb6\xf4\x84\x09\xa0\x04\x90\xf4\xe3\x08\xdb\xc8\x7f\xd1\xb2\xf8\x78\x38\x52\x12\xe1\xf4\xc3\xe1\xcf\x81\xc5\x6d\x71\xe7\x3f\xd7\xa0\x95\xb5\x6b\x4a\xbe\xc1\x5c\x57\x10\x74\x20\xfb\xdf\xa4\x44\x77\x07\x8c\xcf\x45\x19\xf9\xf6\x04\x4f\x07\x44\x05\x20\x35",
        p,
        q,
        g,
        b"\x25\x6d\x23\x1a\xc2\xba\xe6\x50\xd2\x59\x99\xb2\x70\x6d\x4c\xb6\x3a\x89\xb1\x46\x8e\x0d\xf3\x6d\x67\x75\x35\xfa\x7a\x0e\xa8\x90\x59\x0d\x32\x90\xd4\xb5\x0b\xdb\x39\x9f\x33\xdc\x41\x5e\x44\x69\xc9\x7c\x6c\x0c\xee\x82\x05\xee\xc9\x62\xd7\x15\x3c\x4c\x85\xab\x88\xf7\xcf\x80\x97\x9d\x4a\x1f\xfd\x8c\x74\xe6\x81\xc1\xd2\x8d\xa0\x77\x32\x11\x6c\x32\x10\xee\x4b\x69\x33\x09\x33\x36\x86\x24\x6d\x66\x70\x74\xc7\x17\x20\x35\xfd\x60\x91\xb2\x84\x0b\x11\x39\x70\xb4\x59\x83\xd4\x74\xf5\x4b\x95\xd2\x63\x94\xb7\xa4\x3e\x81\xb4\x49\xa2\xee\x94\x23\xaa\x1c\x27\xf4\x59\x2b\x51\x6c\x12\xd5\x43\x3e\x2b\xa7\x24\xf5\x46\x3b\x41\x69\xa2\xb0\x94\x0e\x1b\xcc\xd6\x0c\xca\xb9\xb5\xa3\x82\x48\xac\xb6\x05\x82\xab\x8b\xbc\x01\xc5\xe7\x5f\x9e\xf7\x47\x42\x73\xfb\x51\xaa\x63\x16\xe6\x49\xf4\xf2\x24\x52\xdc\x70\xbf\xd4\xc3\xda\x07\x2c\x03\xea\x82\xee\x00\x9d\x42\x72\xa8\x49\x61\xc9\x8e\x51\x7a\xb9\x47\x74\x1d\x81\x21\x16\x01\x1d\xec\x03\x73\xca\x8f\xba\xc5\x57\x6c\x20\x69\xb0\x67\xf8\xb0\x05\xd6\x0a\x36\xec\xa4\x4f\x56\x01\x9a\x64\x83\x5d\x76",
        b"\x84\xca\xce\x71\xa8\x0e\xd4\x74\x94\x57\x0f\xc8\x48\x39\xf2\xe3\x50\x19\x1b\x74\xf0\xee\xff\xf2\xd7\xab\x2c\x68\x9d\xb7\x7b\xae",
        b"\x9c\xac\x33\x59\x4e\x19\x34\xb6\x8f\x62\xac\xa0\x5c\xa0\x40\xf3\xc8\x21\x10\xc1\x0b\x73\x79\x87\x8b\x78\x94\xb0\x91\x9a\x0f\x2f",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xdf\x6a\x4e\xb7\xca\xd4\xff\x9b\xdd\x83\x56\xd3\x56\x8f\xcf\x02\x85\xc1\xa4\xe3\xc3\x10\x9f\xaa\x09\x1b\x58\xa9\xbd\x90\x7c\x62\x9d\x54\xaa\x7a\x23\xa7\x48\x70\x54\x5a\x09\x42\xa2\xd2\x39\x14\xf2\xf1\x67\xd9\x65\x73\xf0\x6f\x35\xea\x05\xef\x70\x4c\xac\x80\x14\xdd\x21\xb9\x61\xd3\xda\xcf\x7b\x93\x0b\xbd\x7e\x35\x55\x0f\x72\x10\x94\xc8\x63\x33\xe0\x3e\xd4\xda\xb7\xbc\x1b\x64\x16\xad\xd9\x57\x8d\x27\x9e\xda\xee\x37\x50\x4f\xd2\x5e\xc0\xc5\xe8\xa3\x7a\xc9\xec\x19\xbf\xb1\xe3\x77\x8e\xd6\xd9\xc6\xb6\xe3\x5e\xc7",
        p,
        q,
        g,
        b"\x2f\x4b\x0c\x01\xe4\xb1\x5e\xb5\xee\x7a\xfa\x98\x24\x09\x33\x30\x73\x8b\xe2\xf3\xf0\x6c\x42\xb2\xb7\xc6\x96\x8f\xa5\x4b\x98\x7c\x18\x4e\x7f\xa8\x9e\xff\x16\xda\x02\xb9\x3f\xf6\x1b\x9c\xe4\x8e\xeb\xe7\xea\xb0\xf7\xe2\x03\xad\x11\xc7\x1e\x7b\x29\x7d\x23\xf2\xd5\xa5\x99\x82\x72\xc3\x0c\x2e\x17\x24\xb5\xe9\x63\xbf\xd6\xf8\x32\x39\xf8\x74\xd8\x8e\xa0\x89\x43\x5b\x89\x6d\xd2\x10\x9b\x6a\x14\xb2\xd8\x48\xf9\xed\x7e\x92\x14\x3c\x06\x49\xf9\x7f\x4f\x2e\xb0\x5b\x8c\x5a\x07\xe9\x9e\x49\x7d\xbc\x75\x2d\x44\x3e\xba\x93\xd7\xf3\xdc\xdc\x32\x40\xa2\x71\x4e\xa0\xe3\xe7\x62\x7f\x21\x6e\x47\x01\x14\x8d\xd2\x11\x92\xf2\x74\xf1\xed\x5d\xf0\x5c\x60\xb1\x57\x6d\x3a\x0b\x7f\x69\xa7\x76\xb5\x01\x04\x04\xac\xd5\xaf\xaf\xd3\xd7\x0f\x57\x76\x3f\x2b\x77\x8d\x0c\x36\x1e\x5f\x7f\x0b\xbe\x17\xaa\xfa\xa5\xcd\x39\x33\x29\x17\x1d\x06\xec\x03\x20\x39\xa9\xff\xb3\x7c\x3a\xb8\xcd\x85\x8e\xa7\x88\xa7\xb9\xf5\x01\x99\x6b\xaf\x95\x9c\xa8\x5c\x7d\xaf\xe0\xcd\x3e\x30\x95\x76\x40\xef\xf1\x05\x89\x4c\x43\xf8\x66\xbc\xc4\x22\x69\x8d\x12\x8d\xca\x08\x87",
        b"\x1d\xd2\xda\xea\xf3\xe8\x9f\xd6\x44\xc6\xcc\x94\x23\x11\xea\x50\x56\x41\x3d\x8a\x24\x08\x77\x87\x67\x5c\xef\xfd\x3d\x6c\x15\xe4",
        b"\x3e\x12\x78\x13\x96\x55\x85\x60\x45\x5c\x4e\x70\xf6\x10\x52\x2a\xb2\xb1\x0f\xc2\x53\x43\x29\x68\x18\xef\x7f\xfb\x03\x78\xfa\x47",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x4f\x16\x68\x1e\xaa\x5d\x97\x67\x3a\x7c\xca\x02\xee\x8a\x73\x74\xb7\x54\x11\xe0\xb5\x70\x4a\x94\x7f\x04\xd1\xa5\xb1\x4b\xe0\xb5\x06\xf3\x1c\x2f\xa3\x29\xe3\xca\x51\x6f\xa4\xf1\x62\x6a\x9b\x5e\x08\x0b\xda\x7f\x35\x3f\x85\x03\x65\xea\xc7\xc3\xd2\x59\x6f\x50\x2a\x5d\x70\xb1\x54\x22\x76\xc1\x2d\x4e\xa4\xa2\x2b\x53\x25\xb9\xeb\x3e\x94\x2e\x55\x67\x69\xb7\x96\xc4\xf5\x24\x59\x5f\x1c\xc6\xce\x17\xf9\x9f\x9d\xbf\x51\x33\x14\x53\x22\x8e\xad\x32\x7b\x61\x4f\x44\x38\xd3\x5d\x61\x42\x84\x29\xf7\x8c\x8c\x93\x77\xaa\xaa",
        p,
        q,
        g,
        b"\x2e\x33\x60\x4e\xd9\xe6\xc0\xf1\xba\x40\x3a\x8c\x3c\x3f\xe8\xe8\xf4\x88\x59\x18\x13\xaa\x3d\x2f\xcc\xcd\xf8\x8f\xe8\x08\xf7\x0a\xdf\x17\x3f\x0f\x14\x3a\xbd\xaa\xd4\x3b\x80\x76\x9e\x30\xff\xc5\x74\x9e\x8a\xd3\x59\x99\x95\x3d\xef\xf4\xf6\x1f\x4c\xa0\x73\x13\x60\x9e\x23\xac\xae\x7b\x35\xf7\x79\x34\xfd\xbb\xe1\xc3\x80\xb2\x72\x7b\x1c\x38\x99\x25\x0a\xf5\xb4\x39\x9b\x65\x8b\x79\x08\x67\x6d\x64\xd1\x17\x63\x78\x53\x73\xb2\x16\x98\x36\x61\x1d\x72\xa9\x57\x31\x99\x36\xc8\x4e\xfd\x72\xb7\x2f\x92\xbd\xd2\xdb\xe0\x00\x0d\x88\x41\xab\x6d\x8d\x0d\x66\x6e\x79\x36\x1a\xbb\x23\xb6\x00\x73\x48\xdb\xbe\x7a\x94\x93\x6d\xc6\xb0\x26\xf3\xb7\x10\x00\x81\xf5\x47\xb9\x94\xe0\xe0\x77\x8c\xb7\x61\xeb\xd4\x3a\x29\xd8\x76\x4c\x7f\x96\x2a\x74\x7e\xcc\x92\xe4\xa2\xa6\x28\xf5\x2d\x8a\xbf\x43\xf6\xe3\x27\x8a\x0d\x32\xea\x67\xc2\xd7\x9d\x04\xc8\x33\x87\xdd\xc7\x09\x36\x5c\x0a\x0b\xac\xc8\x3d\x75\xc9\x46\xe2\x83\xe0\x73\x92\x33\x58\x14\x41\xae\xdd\xb0\xd7\xd7\x65\x03\xd6\x21\x40\x5d\x27\xef\x66\xfa\x8b\x53\x79\xd1\x78\x61\x7d\x4b\xb5\xad\x59",
        b"\xe2\xff\x3f\xc4\x41\xdb\x45\x40\x19\x4a\x7f\x5d\xa1\xea\xd8\x49\xc2\xc3\xc4\x8d\xcc\xf8\xb2\xc1\xb3\xb3\x59\xa7\xb1\x6e\x16\xab",
        b"\x52\xfb\xdc\xd5\xc6\x2a\x99\x9a\xab\x46\x14\x7f\xef\x9e\x18\xcb\xfc\x7d\xaf\x68\x0a\x7d\xdb\x89\x2e\xdf\xa4\x4d\x28\x5e\x21\x58",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x09\xe4\x8a\x36\x52\x3b\x52\x89\xec\x41\x85\x9f\xaa\x14\x1e\x2a\x29\xb3\xe8\x8a\xb2\xd6\x35\x1e\x20\xde\x00\x1e\x64\x24\xb8\x53\x37\x67\x5f\x0c\xe2\x6b\xe2\x24\xfa\x4f\x8d\xf0\xef\x97\x10\xea\x28\x56\x35\xb2\x7b\x29\x7d\x68\x8e\x33\x8b\x54\x61\x82\x0b\x57\xbe\x4b\xee\x21\x64\x5b\x04\x95\x7c\xa2\xf6\xcd\x7a\xf9\xa6\xa5\x2b\x3c\x97\xc5\xb9\xdb\x1c\x2f\x7e\xa8\x17\xcd\x6d\x3c\x85\x22\xd4\xe6\xa9\xde\x86\x9a\xef\x26\xec\x0d\xbd\xd2\x69\xc7\x9b\x38\x80\x69\x27\xbd\x3a\x51\x00\x73\x5e\x6f\x9f\x65\x5c\xa9\x4d\xae",
        p,
        q,
        g,
        b"\x7e\x38\xcb\x66\x8d\x64\x7e\xe1\x5f\x71\xac\x5d\x2b\x55\xc1\x1f\xd4\x73\x1e\x1a\x6c\x03\x1d\xd7\x59\x4d\x61\x4f\x2f\x1e\xd2\x56\x23\xff\xfd\xc5\x95\x6f\x52\x56\xe6\x35\xc9\x14\x20\x5a\x29\x37\xa6\x07\x4c\xfe\x1f\x3e\x44\x3b\xbe\xb3\x23\xa2\x3b\x0f\x0f\xbc\xcf\x8c\x17\x70\xad\x18\xba\x97\xd0\xac\xbe\xa1\xe8\x46\xe1\x2c\xf1\x2c\x37\x06\x25\xb1\x55\x5d\x71\x09\x05\xee\xe9\x43\x53\x9f\x22\x41\xb8\xfb\x49\x0c\x9d\x6b\x44\xf3\x61\x39\x22\x6b\x4c\x1f\x00\xe9\x5f\xfe\x59\x50\x14\xf6\x1b\xf5\x79\x83\x6a\x14\x21\x2c\x07\x23\x1a\x5e\x9e\x87\xde\x4a\x9a\xaf\x0f\x46\xf3\x4c\x92\x29\xf2\xea\xbb\x71\xd4\x0d\xe2\x6a\x1c\xbe\x10\xdb\x06\x45\xce\xc3\x7d\x48\x57\x5a\x11\x54\xbb\x5a\xcc\x94\x7b\xec\xb2\xa7\x4b\x07\xe2\xa0\xe4\x5b\x90\x3b\xe3\x75\x02\xf9\x1b\x07\xfb\x4e\xcd\x7f\x21\xfb\x13\x0c\x6d\x63\x9e\xf0\xfd\x84\x44\xfa\x12\xde\x85\x9a\xbe\x95\x54\x88\x01\xf6\xa3\xc4\x0e\x7a\x65\xfd\x15\x18\x22\x1a\x27\x4d\x7b\x65\xed\x41\x75\xf6\x6c\x04\xd9\x19\xc8\x6d\x2a\xe8\xc3\x74\xb1\x47\x09\xe9\xc8\xa3\x9e\x1d\x0c\x4e\x99\x35\x54\x0b",
        b"\xe5\x50\xdc\x65\xaf\x27\x5e\x47\xbe\x48\x0f\xd6\x47\x36\x6e\x2b\x05\x5c\x79\xea\x33\xde\xd4\xf5\xa9\x55\x71\x21\xe0\x82\xaf\x26",
        b"\xe2\x6b\x1a\x5f\x27\xcc\x6c\x87\x86\x3e\x31\xef\x7f\x1e\x61\xbe\xa4\x76\xfc\x5d\x7c\x25\xfd\xf2\x2f\xe7\x40\xf2\x3a\xa9\xa7\x52",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x88\x37\xbb\xce\xef\x57\x75\x11\xf2\xd0\xc0\x8f\x79\x0d\x5d\x2e\x85\x62\xd9\x3d\xf3\xd8\x2d\xd4\xc2\x82\x7c\xd9\xa9\x11\x53\x08\x11\x4a\x18\xc4\x52\xdb\x27\x85\x56\x10\x81\xeb\x52\x36\x85\xae\x2b\x3c\x8b\x09\x0e\x0d\x44\xdd\x40\xd2\xfc\x0c\xdf\xc8\x8d\x6f\x90\x63\xa7\x70\x7d\xf6\x09\xed\xf0\xa8\xc5\x50\x34\x81\x5e\xa9\xf1\xd8\xb0\xbc\xbc\x92\xfb\xa5\x13\xba\x81\xee\x64\x6b\xf9\x8a\xd4\xeb\x22\xbe\x26\xa4\x58\x2b\x1b\xe2\x89\x9c\x91\xee\xbc\xbc\x9f\xba\x58\x25\xe0\x21\xe9\x9b\xe0\xc9\xd2\x86\x42\xd1\x3f\xa4",
        p,
        q,
        g,
        b"\x77\xd7\xa4\x0a\x7b\xab\x3f\x57\x78\xf8\x5d\x4f\xc4\x8b\x3e\x28\xce\x28\xb2\xdf\x9e\xb8\x7c\xc9\xcf\x39\x4e\xf2\x8e\x80\x64\xf3\x9a\x96\x90\x10\x39\x80\xa6\x6d\xa2\x19\xcb\x50\x22\xc1\x01\xf2\x20\x11\xa8\x15\x7a\x75\x68\xc5\xff\x2e\x97\x8b\xa2\x20\x13\x67\xd1\x7c\x22\xa8\x67\x86\x5d\x00\xc2\xa4\x37\x38\x56\x27\xbd\x08\x8b\xfc\xf7\x21\x92\x51\xbf\x6a\xe1\x58\x26\x9f\x4e\xf3\x5d\xa7\x09\x5a\x53\xc2\x4f\x37\xd6\x1b\xcf\xb7\xc0\x43\xfe\xb6\xe9\x38\x32\x34\x3f\x9e\x90\xee\x71\x04\xc8\x04\x86\xec\xd0\x87\xbe\x1b\x67\xf1\x8c\xda\xaa\x37\x5e\x03\x9c\xb7\xad\x60\x3c\xb0\xcd\x85\x56\x23\xe9\xfb\x48\xe4\xee\xde\x14\xea\x3c\x76\xa0\x36\x4a\xac\x00\x66\x50\xd3\xb5\xcd\x9b\x47\x4b\x56\xf8\x58\x4b\xe5\x8a\x72\x1b\xf3\x4d\xd0\x80\x8d\x33\x4c\xd8\x63\x2e\x80\x85\x36\x79\x1f\xcb\xea\x96\x1f\x71\x63\xda\xd2\x83\x53\xc1\x15\xeb\x3e\x85\x67\x37\xdb\xbe\xe0\x34\x36\x72\x16\x37\xa4\x77\x54\xa8\xa1\xfe\x0f\xed\xf5\x47\xb3\x58\xa7\x3d\x05\xb7\x69\xa9\x5b\xde\x34\x40\x00\x7c\x07\x73\xa3\xc7\xc8\xdc\x97\x14\xe1\x1c\x3a\x10\xee\x01\xd7",
        b"\x7b\x6b\x3e\xae\xf6\xcd\x5f\xe6\xda\xed\xe8\x6d\x63\x94\x34\x78\xc7\x71\x58\x24\x83\xbe\x0b\x92\x6e\xe3\x02\x2d\x22\xef\x91\x2e",
        b"\x39\xd9\x28\xb5\x9a\x69\x04\x50\xd1\x33\x59\xa2\x9e\xfe\x20\xcb\x98\xbf\xd3\xfc\x97\x26\xf8\x0e\x51\x48\xf0\x59\x66\x3f\xfd\x08",
    )?;

    // [mod = L=2048, N=256, SHA-384]
    let p = b"\xa6\x16\x7c\x16\xff\xf7\x4e\x29\x34\x2b\x85\x86\xae\xd3\xcd\x89\x6f\x7b\x16\x35\xa2\x28\x6f\xf1\x6f\xdf\xf4\x1a\x06\x31\x7c\xa6\xb0\x5c\xa2\xba\x7c\x06\x0a\xd6\xdb\x15\x61\x62\x1c\xcb\x0c\x40\xb8\x6a\x03\x61\x9b\xff\xf3\x2e\x20\x4c\xbd\x90\xb7\x9d\xcb\x5f\x86\xeb\xb4\x93\xe3\xbd\x19\x88\xd8\x09\x7f\xa2\x3f\xa4\xd7\x8f\xb3\xcd\xdc\xb0\x0c\x46\x64\x23\xd8\xfa\x71\x98\x73\xc3\x76\x45\xfe\x4e\xec\xc5\x71\x71\xbb\xed\xfe\x56\xfa\x94\x74\xc9\x63\x85\xb8\xba\x37\x8c\x79\x97\x2d\x7a\xaa\xe6\x9a\x2b\xa6\x4c\xde\x8e\x56\x54\xf0\xf7\xb7\x45\x50\xcd\x34\x47\xe7\xa4\x72\xa3\x3b\x40\x37\xdb\x46\x8d\xde\x31\xc3\x48\xaa\x25\xe8\x2b\x7f\xc4\x1b\x83\x7f\x7f\xc2\x26\xa6\x10\x39\x66\xec\xd8\xf9\xd1\x4c\x2d\x31\x49\x55\x6d\x43\x82\x9f\x13\x74\x51\xb8\xd2\x0f\x85\x20\xb0\xce\x8e\x3d\x70\x5f\x74\xd0\xa5\x7e\xa8\x72\xc2\xbd\xee\x97\x14\xe0\xb6\x39\x06\xcd\xdf\xdc\x28\xb6\x77\x7d\x19\x32\x50\x00\xf8\xed\x52\x78\xec\x5d\x91\x2d\x10\x21\x09\x31\x9c\xba\x3b\x64\x69\xd4\x67\x29\x09\xb4\xf0\xdb\xee\xc0\xbb\xb6\x34\xb5\x51\xba\x0c\xf2\x13";
    let q = b"\x84\x27\x52\x90\x44\xd2\x14\xc0\x75\x74\xf7\xb3\x59\xc2\xe0\x1c\x23\xfd\x97\x70\x1b\x32\x8a\xc8\xc1\x38\x5b\x81\xc5\x37\x38\x95";
    let g = b"\x6f\xc2\x32\x41\x5c\x31\x20\x0c\xf5\x23\xaf\x34\x83\xf8\xe2\x6a\xce\x80\x8d\x2f\x1c\x6a\x8b\x86\x3a\xb0\x42\xcc\x7f\x6b\x71\x44\xb2\xd3\x94\x72\xc3\xcb\x4c\x76\x81\xd0\x73\x28\x43\x50\x3d\x8f\x85\x8c\xbe\x47\x6e\x67\x40\x32\x4a\xaa\x29\x59\x50\x10\x59\x78\xc3\x35\x06\x9b\x91\x9f\xf9\xa6\xff\x4b\x41\x05\x81\xb8\x07\x12\xfe\x5d\x3e\x04\xdd\xb4\xdf\xd2\x6d\x5e\x7f\xbc\xa2\xb0\xc5\x2d\x8d\x40\x43\x43\xd5\x7b\x2f\x9b\x2a\x26\xda\xa7\xec\xe3\x0c\xea\xb9\xe1\x78\x9f\x97\x51\xaa\xa9\x38\x70\x49\x96\x5a\xf3\x26\x50\xc6\xca\x5b\x37\x4a\x5a\xe7\x0b\x3f\x98\xe0\x53\xf5\x18\x57\xd6\xbb\xb1\x7a\x67\x0e\x6e\xaa\xf8\x98\x44\xd6\x41\xe1\xe1\x3d\x5a\x1b\x24\xd0\x53\xdc\x6b\x8f\xd1\x01\xc6\x24\x78\x69\x51\x92\x7e\x42\x63\x10\xab\xa9\x49\x8a\x00\x42\xb3\xdc\x7b\xbc\x59\xd7\x05\xf8\x0d\x9b\x80\x7d\xe4\x15\xf7\xe9\x4c\x5c\xf9\xd7\x89\x99\x2d\x3b\xb8\x33\x6d\x1d\x80\x8c\xb8\x6b\x56\xdd\xe0\x9d\x93\x4b\xb5\x27\x03\x39\x22\xde\x14\xbf\x30\x73\x76\xab\x7d\x22\xfb\xcd\x61\x6f\x9e\xda\x47\x9a\xb2\x14\xa1\x78\x50\xbd\xd0\x80\x2a\x87\x1c";
    test(
        HashAlgorithm::SHA384,
        b"\x8c\x78\xcf\xfd\xcf\x25\xd8\x23\x0b\x83\x5b\x30\x51\x26\x84\xc9\xb2\x52\x11\x58\x70\xb6\x03\xd1\xb4\xba\x2e\xb5\xd3\x5b\x33\xf2\x6d\x96\xb6\x84\x12\x6e\xc3\x4f\xff\x67\xdf\xe5\xc8\xc8\x56\xac\xfe\x3a\x9f\xf4\x5a\xe1\x1d\x41\x5f\x30\x44\x9b\xcd\xc3\xbf\x9a\x9f\xb5\xa7\xe4\x8a\xfe\xab\xa6\xd0\xb0\xfc\x9b\xce\x01\x97\xeb\x2b\xf7\xa8\x40\x24\x9d\x4e\x55\x0c\x5a\x25\xdc\x1c\x71\x37\x0e\x67\x93\x3e\xda\xd2\x36\x2f\xae\x6f\xad\x1e\xfb\xa5\xc0\x8d\xc1\x93\x1c\xa2\x84\x1b\x44\xb7\x8c\x0c\x63\xa1\x66\x5f\xfa\xc8\x60",
        p,
        q,
        g,
        b"\x5c\xa7\x15\x1b\xca\x0e\x45\x7b\xbc\x46\xf5\x9f\x71\xd8\x1a\xb1\x66\x88\xdc\x0e\xb7\xe4\xd1\x7b\x16\x6c\x33\x26\xc5\xb1\x2c\x5b\xde\xbb\x36\x13\x22\x4d\x1a\x75\x40\x23\xc5\x0b\x83\xcb\x5e\xcc\x13\x90\x96\xce\xf2\x89\x33\xb3\xb1\x2c\xa3\x10\x38\xe4\x08\x93\x83\x59\x7c\x59\xcc\x27\xb9\x02\xbe\x5d\xa6\x2c\xae\x7d\xa5\xf4\xaf\x90\xe9\x41\x0e\xd1\x60\x40\x82\xe2\xe3\x8e\x25\xeb\x0b\x78\xdf\xac\x0a\xeb\x2a\xd3\xb1\x9d\xc2\x35\x39\xd2\xbc\xd7\x55\xdb\x1c\xc6\xc9\x80\x5a\x7d\xd1\x09\xe1\xc9\x86\x67\xa5\xb9\xd5\x2b\x21\xc2\x77\x21\x21\xb8\xd0\xd2\xb2\x46\xe5\xfd\x3d\xa8\x07\x28\xe8\x5b\xbf\x0d\x70\x67\xd1\xc6\xba\xa6\x43\x94\xa2\x9e\x7f\xcb\xf8\x08\x42\xbd\x4a\xb0\x2b\x35\xd8\x3f\x59\x80\x5a\x10\x4e\x0b\xd6\x9d\x00\x79\xa0\x65\xf5\x9e\x3e\x6f\x21\x57\x3a\x00\xda\x99\x0b\x72\xea\x53\x7f\xa9\x8c\xaa\xa0\xa5\x88\x00\xa7\xe7\xa0\x62\x3e\x26\x3d\x4f\xca\x65\xeb\xb8\xed\xed\x46\xef\xdf\xe7\xdb\x92\xc9\xeb\xd3\x80\x62\xd8\xf1\x25\x34\xf0\x15\xb1\x86\x18\x6e\xe2\x36\x1d\x62\xc2\x4e\x4f\x22\xb3\xe9\x5d\xa0\xf9\x06\x2c\xe0\x4d",
        b"\x4f\xd8\xf2\x5c\x05\x90\x30\x02\x73\x81\xd4\x16\x7c\x31\x74\xb6\xbe\x00\x88\xc1\x5f\x0a\x57\x3d\x7e\xbd\x05\x96\x0f\x5a\x1e\xb2",
        b"\x5f\x56\x86\x9c\xee\x7b\xf6\x4f\xec\x5d\x5d\x6e\xa1\x5b\xb1\xfa\x11\x69\x00\x3a\x87\xec\xcc\x16\x21\xb9\x0a\x1b\x89\x22\x26\xf2",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x02\xbb\x64\xd2\xd5\x03\x2f\x54\xf1\xac\x9e\x9e\xe1\x64\xdb\x83\xaf\x0c\xb0\x36\xd8\x8d\x41\xe9\xb2\x11\x8c\xfc\x39\xd1\xb4\xb4\xdc\x2c\x49\x75\x49\xc7\x98\x2c\xca\xcf\x66\x5d\x1b\x00\x11\x26\x82\x46\xc7\xc1\x7f\x56\x2e\xcb\xa2\x5e\x26\x54\x89\x87\x3e\x0d\xd9\x26\x8e\x9b\x06\x88\x0b\xa7\x4e\x74\xb5\x6f\x50\xc7\x32\x4d\x29\x37\x38\x53\xe3\xa0\xf3\xff\x78\x7e\xba\x4e\x5e\x7f\x94\x37\xf8\xec\x8a\x5e\x86\x83\x24\xe9\xc1\x7f\xb3\xd0\xe1\x2d\xe2\xd3\x1d\x43\x8c\x5b\xf3\x8b\x27\x16\x7d\x43\xae\x43\x11\xb1\x10\x62",
        p,
        q,
        g,
        b"\x11\xf3\xa7\x16\xfb\xda\x7a\xf3\x5b\xdb\x62\xd1\x28\xaf\x6f\x21\xec\x2e\xd4\x89\x6a\xa8\x1e\x87\x69\xc6\xee\xa9\xc2\x1c\x81\xae\xf2\x3a\xe0\xf5\x25\x26\x9d\xc4\x05\xac\xce\xf0\x98\x37\x7f\x65\x27\x30\x96\x8a\x33\xb5\x0f\x0a\x4c\x77\x84\x34\x52\x80\x65\x1c\xaa\x03\x4d\xf8\x73\x42\xca\x89\x73\xad\x86\xff\x7f\x0f\x87\x73\xa9\x4f\x95\xdd\x2b\xfa\x80\x2d\x26\x8d\xbf\x3a\x21\x03\xb1\x27\x6e\x06\xdb\x2d\x73\x43\x99\xf2\xab\x7b\xdc\xca\x09\x76\x16\xfc\x46\xed\x24\x78\xe5\x2c\xef\x04\x9d\x19\x44\x45\x86\xe7\xb7\x5d\x6a\x56\x74\x1d\xa2\x27\x0f\x54\xd2\xc7\x39\xec\x8d\xb9\x96\xc7\x1f\x06\xa3\x9a\xf2\x38\x3c\x61\x14\x99\xbe\x0f\xb3\x48\x09\xb1\x71\x25\x4e\xf2\x73\x51\x6c\x33\xe1\x7e\x14\x04\x8e\xf2\xd2\x1d\x60\x0a\xa1\x53\xbc\xf7\x37\x7f\xba\x94\x05\xc6\xb2\xe5\xf2\xaa\xf0\xf2\xf3\x46\x7d\x74\x61\xf6\x2e\x81\x4a\x2c\x46\x1e\x8a\xc9\xdb\x0d\xf3\x70\xe1\x8e\xc6\xee\xd8\x21\x2a\xca\xec\xf1\xe7\x24\x1b\xcb\xcb\xca\x67\x10\x60\xe5\x0c\x29\xf9\x66\xf1\xea\x1e\x92\xaf\x69\x03\xf8\x1c\x7a\xb9\xee\x09\xf6\x05\x77\xbf\x30\xc1\x86",
        b"\x7a\x5d\x20\x16\xaf\xe8\x78\x83\x49\x1b\xd6\xcd\x16\x6e\xdd\xdf\x13\x8c\x1c\x89\x96\x1e\x4a\xf6\x87\x6b\xe0\x8b\x0e\x06\xad\x74",
        b"\x34\xef\xbd\xa1\x84\x9d\xed\xd0\xd1\xaa\x77\x5d\xab\x2a\xa2\xb1\x4c\x9b\xa0\x20\x65\x92\xfb\xc3\x4e\xb4\x7b\x84\x46\x46\xad\xc2",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x4f\x1c\x00\x53\x98\x4a\xb5\x5a\x49\x1f\x36\x18\xdb\x1b\xe2\x37\x91\x74\xa4\x38\x59\x74\x82\x5f\xcb\xe5\x84\xe2\xb6\xd0\x70\x2a\xbb\x82\x98\xdd\x91\x84\xee\xf1\x74\x0b\x90\xa5\xea\xe8\x50\xe9\x45\x2b\x4e\x4a\xb2\x19\xe1\x87\x86\x0f\x0f\xb4\xad\x2b\xe3\x90\xef\x2b\xa7\xd7\x6c\xde\xdc\xaf\x10\xae\xaf\x4f\x25\xe4\x97\xb4\xda\x95\x13\x75\xb6\x87\xa8\xd6\x70\x12\xd3\xf9\x9c\x7b\x5c\xa8\x2e\x9b\xd0\x63\x0d\xff\xcd\x63\x5e\xcd\x82\x09\xcd\xdb\x87\x2d\xa5\xbf\x47\x36\x30\x97\x83\x34\x5a\x35\x37\x6b\x4f\xce\x4b\x91",
        p,
        q,
        g,
        b"\x10\xe6\xf5\x0f\xd6\xdb\xb1\xca\x16\xf2\xdf\x51\x32\xa4\xa4\xea\xbc\x51\xda\x4a\x58\xfe\x61\x9b\x22\x25\xd7\xad\xab\x0c\xea\x3a\xfc\x2d\xb9\x0b\x15\x8b\x62\x31\xc8\xb0\x77\x4e\x0f\x0d\x90\x74\x51\x7f\x33\x6c\xa0\x53\xae\x11\x56\x71\xae\xe3\xc1\xde\x0f\x85\x72\x8c\xff\x99\xde\xeb\xc0\x7f\xfc\x9a\x63\x63\x19\x89\xa9\x27\x7e\x64\xc5\x4d\x9c\x25\xa7\xe7\x39\xae\x92\xf7\x06\xee\x23\x7b\x98\xb8\x70\x0a\x9d\xf0\xde\x12\xd2\x12\x4e\x2c\xfd\x81\xd9\xec\x7b\x04\x69\xee\x3a\x71\x8a\xb1\x53\x05\xde\x09\x9d\x9a\x2f\x8c\xec\xb7\x95\x27\xd0\x16\x44\x7c\x8f\x6f\xe4\x90\x5c\x37\x18\xce\x52\x34\xd1\x3b\xf4\xed\xd7\x16\x9b\x9d\x0d\xb9\xa6\xb0\xfc\x77\xb7\xd5\x3b\xdd\x32\xb0\x7d\xc1\x5b\xc8\x29\x62\x0d\xb0\x85\x11\x45\x81\x60\x8a\xc9\xe0\x93\x77\x52\x09\x59\x51\xd2\x89\x85\x5d\x0b\xcc\x9d\x42\x1b\x94\x5c\xc4\xf3\x7f\x80\xb0\xcb\x25\xf1\xff\xee\x9c\x61\xe5\x67\xf4\x9d\x21\xf8\x89\xec\xbc\x3f\x4e\xd3\x37\xbc\xa6\x66\xba\x3b\xa6\x84\x87\x4c\x88\x3f\xe2\x28\xac\x44\x95\x2a\x85\x13\xe1\x2d\x9f\x0c\x4e\xd4\x3c\x9b\x60\xf3\x52\x25\xb2",
        b"\x00\x6b\x75\x9f\xb7\x18\xc3\x4f\x1a\x6e\x51\x8f\x83\x40\x53\xb9\xf1\x82\x5d\xd3\xeb\x8d\x71\x94\x65\xc7\xbc\xc8\x30\x32\x2f\x4b",
        b"\x47\xfa\x59\x85\x2c\x9a\xe5\xe1\x81\x38\x1e\x34\x57\xa3\x3b\x25\x42\x00\x11\xd6\xf9\x11\xef\xa9\x0f\x3e\xac\xed\x1d\xee\x13\x29",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x42\x19\x91\x86\x43\x4d\x6c\x55\xbc\xef\x26\x9b\xee\x68\x5c\x4e\x15\x80\xe2\x43\x02\x7e\xd1\x28\xca\x99\x49\x20\x33\xa5\x29\x54\xbd\x1c\xa8\xec\xc5\x04\x38\x20\x72\x5a\x3c\x0d\x71\xa1\x81\xa0\x5a\xab\xcb\x4e\xcd\xa7\x18\x0d\x86\x85\x5e\x7b\x4d\xfa\x9a\x44\xc7\xaf\x4c\x98\xfb\xf1\xf0\x62\x40\x58\x80\x4f\xd8\xea\xae\x49\x90\xd4\xd7\xbb\x75\xf0\x17\x41\xce\x36\xcf\xc9\xc1\x37\x25\x4c\xab\x06\x5a\x46\x17\xd0\xd0\xcd\x5f\x58\xea\x56\x86\x8a\x40\xf3\xe0\xba\xf7\xdb\x5d\x25\x57\xf4\xb9\x77\x5c\x18\x20\xdc\x1d\x41",
        p,
        q,
        g,
        b"\x63\x64\xa3\x5a\xe9\x94\xf2\x77\x03\x31\x9c\x36\xd9\x07\x93\xc8\xf2\x65\x11\x84\x6b\xa0\x60\x38\x99\x5b\x65\x56\xe4\x44\x3a\xa6\x1e\xb0\xf8\xef\xcc\x3d\x47\xf7\xc5\xf8\x52\x76\xea\x92\x1d\xa0\x78\x4a\x67\x99\x82\x53\xc9\x92\x97\x5f\x9e\x13\x84\x7c\xca\xd0\x99\xd9\xc1\xe5\xc9\x4c\xfb\x19\x54\x88\xe1\x29\x3e\x23\xb7\x4d\xb0\x06\x03\xe8\xbd\x68\x14\xc9\x46\x90\xbf\x0c\xcc\xc1\xc0\xe4\x7f\x0c\x66\x09\xa4\x8e\x14\x45\x87\xec\xe1\x78\xf7\x2c\x85\x14\xa4\x35\x90\xbc\x4c\x21\x9d\xa9\x5c\xbe\x89\x66\xf4\x40\x4f\xe9\xc2\x88\xf2\x3c\xd0\xf9\x73\xe7\x7e\xc8\x4b\x4b\x0f\x16\x3b\x50\xa3\xc5\x56\xcd\x1d\x39\x51\xfa\xeb\xd9\x82\xaf\x44\x44\x7e\x60\xd7\x83\x4b\x93\xb6\xd9\xc3\xff\x09\x61\xfc\xcb\x90\x83\x12\xa2\x43\x76\xee\xdc\x50\x8f\x80\x66\x68\xd6\x61\x7b\x77\x49\x1a\x01\xd5\xd0\x69\xd6\xcc\xd5\xf2\x1b\x5e\xb3\xc3\xa3\xd4\xa0\x47\x95\x93\x84\x5c\x72\xf7\x20\x15\x7b\x18\x8d\x2d\xfa\xe4\x40\x1c\x57\xa6\x00\xb1\x42\xb6\xbd\xe2\xa6\x9f\x1a\x0a\xfb\xa2\xf5\x07\xa6\x3c\xd6\xdf\x05\x6b\xb5\xb3\x4f\xdf\xce\xe0\x12\xd3\x41\xb3\xf1",
        b"\x25\x51\xd4\xf8\x55\x17\x4f\x7b\x28\xa7\x82\xb8\x96\x97\xd4\x8f\xbc\x31\x4c\xfe\xb1\x7e\xc4\xc9\x90\x2a\x8e\x55\x7c\xc6\xf6\xb9",
        b"\x27\x8b\x78\x6f\x9e\x28\xee\xcc\xd0\x05\x86\xb4\x45\xe7\x5f\x48\xcf\x26\x49\xf3\xf1\xb7\xbf\xf7\x2b\x0e\x76\x7f\x34\x43\xdc\x58",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x4f\xdd\x88\x87\x56\xac\x68\xf4\xc2\x9c\xd5\xb1\xde\x42\x75\x67\x94\x57\x0c\xa8\xf1\x8f\xf7\x95\xf6\xf0\xfc\x85\x67\x72\xb6\xa2\x18\x9b\x5e\xd4\xa9\xb7\x54\x73\x28\x07\x5b\x56\xc2\x8d\xdf\x50\xb8\x4c\x27\x20\x5c\xee\x57\xb2\x9d\x0b\x38\x79\x70\xe8\x9a\x6a\x22\x36\x29\x3b\xbc\x9e\x39\x90\x13\xd1\xdd\x3b\xd5\xa1\x0a\xb0\xd2\x59\xf7\xfd\xa7\x04\xf7\x1c\xbe\x3b\x8b\x87\x52\x80\x6a\x0c\x84\x66\x8d\x85\xe4\xd7\x39\xce\xc6\x28\xdf\xf6\x33\x71\xd2\x4a\x4b\x14\x13\x73\x82\x75\x9b\xa4\x00\xdf\x0e\x2c\x25\x94\x7d\x18",
        p,
        q,
        g,
        b"\x5b\x61\x98\x45\xba\x96\x9f\x1c\xa5\x96\x3f\xcf\x04\xc0\x3a\xa4\x0e\x98\x92\x22\x77\x4e\x95\x7a\x54\x19\x1a\xcf\x9d\xdc\x40\x7a\x54\xa1\x61\xe2\x2a\x5a\xc5\x0c\xa5\xd6\x1e\x66\x01\xcc\x79\x95\xbf\x0d\xb3\x8f\xf0\xfa\x1f\x77\xb2\x44\xfe\x98\x14\x8c\x81\xf2\x08\xdc\xa2\x9f\xfa\x30\xf1\x13\x1c\x76\xdb\xbe\x43\x03\x42\x5e\x91\x80\xb4\xa4\x8f\x22\xc7\x57\xed\x8e\x38\x8b\x61\xbd\xc6\xd5\x55\x19\x52\x3d\x00\xc3\x1a\x5f\x83\x76\x64\x0d\x46\x88\xe6\x0d\xcc\x17\x2d\xee\xce\x73\xde\x28\x43\x7e\x90\x0c\xb1\x9a\x53\x11\xa0\xc9\xca\x9a\xf6\xcc\x6e\xeb\x68\x44\xe9\xb8\x35\x9e\x3e\xf1\xcb\xe0\x37\x84\x10\x7d\x2d\x0a\xeb\xec\x7c\x1d\x70\xd9\x38\x5a\x4d\x2b\x80\x33\x85\x1f\x5d\x5b\x7a\xa1\x8e\xf5\x70\xaa\x03\x7f\xcb\xd3\xe3\x0f\x2f\xc2\x01\x3f\xfb\xfa\x07\x87\xbe\x6d\x59\xff\xa1\x61\x6e\xed\x5e\x12\x1e\xe4\xdb\xee\x04\xa9\xed\xe0\x04\x95\x60\x75\x46\x5a\x76\x88\x70\x1e\x04\xec\x9b\x21\x53\xf5\x2c\xaf\xbf\xf7\xff\x92\x26\xe6\x93\x97\xc7\x08\x3c\x3a\xa5\x36\xd7\x10\x9e\xe4\x30\xa6\x54\x48\xb1\x0c\x18\x18\xc7\x05\x10\xa3\x39\xc1",
        b"\x4b\x90\x99\x3d\x70\x7f\x33\x71\xd0\xa0\xcc\x87\x25\x5e\x99\xa8\xfb\xa1\x8c\x3b\x58\xdd\xdd\xc1\x06\x7c\xd3\x94\x17\x23\x66\xcc",
        b"\x4b\x26\x12\xd5\x06\xfb\x85\xe5\xaf\xf9\xfc\xd5\x6c\x09\xbd\x12\xbf\x60\xf7\x8a\xb7\xdf\xd0\x21\xa7\x42\xff\x85\xdc\x50\x7a\xe2",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x85\x07\xdb\x5f\x1d\xf9\xd2\x2f\x44\x7c\x20\xe4\x32\x0f\x90\xd9\xb3\x07\x22\x19\x71\x96\xd1\xa2\x41\x8d\x06\xdc\xa4\x1b\x33\x05\xf6\xfb\xe5\x2a\xb5\x8c\xc0\xb6\x0e\xf1\xa1\xd2\x57\xfc\x2f\xb2\x06\x2f\xe6\xc5\xf2\xa2\x5f\x02\x93\xca\x39\xd0\xc0\x83\xcf\xd5\xe4\xbd\xad\xf2\x16\x9a\xd4\xed\x17\x8c\x88\xec\xb5\x55\x4f\xfa\x2b\x53\xaa\x43\x98\x11\x5c\xde\x62\x7d\x30\x14\x4a\xce\x93\x25\xb2\xd7\x9d\x7d\xce\x95\x15\x09\xd7\x34\xaf\xb0\xff\x6d\x92\x65\xb9\x02\x67\x2e\xb5\x88\x4e\x9d\x8a\xcf\xf0\xea\x22\xc7\x69\x38",
        p,
        q,
        g,
        b"\x43\x88\x31\xcb\x0e\xb0\x9a\xab\x24\x27\x54\x54\x35\x4c\xe4\x2b\x9a\x2e\xed\xb3\x1f\x42\x12\x19\xde\xf7\x46\x87\xe6\xf9\xc9\x2f\x0b\x19\x82\x35\x5c\xad\xb2\x6e\x09\x5b\x7c\xa2\x5d\xe5\x30\xaa\xba\x63\xe6\x4f\xc2\x3a\xcc\x3d\x1d\x1f\x1b\x70\xcb\x72\x61\x56\xca\x0a\x79\x9b\x59\x09\x4b\xcc\x3b\x89\x98\xa4\xae\x77\x44\xd2\x15\xd6\x3b\x88\x70\x82\xf4\xc8\x41\x28\xe7\x4b\x9b\x99\x99\xc6\x0c\xad\x3b\xc6\xbb\x6f\x72\x72\x84\xb4\x31\x1a\x92\x9b\xbd\x96\x4c\x9a\x70\x74\xe8\x60\x62\x22\x4d\xce\xdb\x58\xb9\xb5\x98\x54\x6a\xc9\x5b\x3b\x43\x4e\xa1\x14\xab\x0d\x67\x85\x41\xd6\xca\xec\x0c\x56\x00\x9b\xc3\x47\xa4\x25\xf1\x67\xcd\x32\xa3\x4e\xec\xb7\x19\x24\x24\xd5\x7b\x0e\x54\xb4\xa9\xe8\x2f\x42\x51\x38\x70\x3c\xe8\x9b\x18\x90\x39\xe9\x2a\x77\x0b\x51\x49\x7f\x8f\x10\xea\xe9\xc3\x45\x9e\xd8\x7e\x51\x01\xf5\xab\x1b\x62\x71\x48\x5f\xdb\x2d\xd3\xdb\xc4\x21\x7f\xcf\x67\xc7\xe9\x2d\x00\x96\xdc\x7d\xa9\x72\x7f\x5a\x43\x4b\x75\x45\x28\x4c\xd8\xa2\x83\x07\x0b\x5a\x49\xd7\x11\xdf\xfa\x85\x90\x43\x11\xe0\x34\x5a\x99\x14\x7a\x16\x8e\xa0",
        b"\x1d\x27\x81\xf5\xf9\xd0\x8a\xb2\xfe\xb1\x68\x39\x42\xc2\xc2\x9a\x66\x31\x88\x39\xa7\xdf\xef\x9a\xee\x9c\xd7\xa8\x9e\xfe\x2a\xb0",
        b"\x3a\xdc\x7b\xe9\x68\x50\x2e\xad\x10\xfe\xec\x19\x1e\x21\x2e\xa0\xe0\x7d\x44\x90\x06\xe7\xf2\x2d\xdf\x86\x9a\x9f\xae\x71\x18\x34",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xc7\x84\x49\x60\x96\x65\x84\xc8\xe3\xa5\x9d\xc3\x7d\xf3\x7b\x7e\xb3\xad\x33\x31\x48\xa3\x2b\x86\xc1\xec\x18\x07\x2f\x3b\x31\x6c\x59\xcd\xef\x98\xba\x4d\xc4\x6f\x53\x2a\x42\x80\x20\x0c\x22\x5f\xac\x6c\xd1\xad\xf0\xa4\x53\x82\xc2\xd8\x80\x54\xe4\x47\x74\x04\x54\x97\x6e\x52\x72\x33\x0c\x74\x87\xeb\x42\xa0\x95\xf7\x31\x41\x39\x93\x8c\x74\x19\x19\x3b\x1c\x12\x80\x54\xc1\xbb\xf1\x0d\x06\x34\xe2\x2c\x6e\x02\xd8\xe1\x22\x79\xca\xc0\xbf\xa0\x1d\x30\x58\xe0\xf8\xd5\x54\x7b\xa0\xf7\x15\x29\xc2\x7e\x00\x84\xd4\xbd\xe7",
        p,
        q,
        g,
        b"\x2d\xe9\xd2\x7f\x1a\x03\x01\x99\xff\xbb\xa7\x70\xe0\x8a\xeb\x1f\xf3\x70\x8e\xdf\x8e\xbb\x3a\x8e\x66\x4e\x3b\xd1\x51\x1d\xb1\x26\xed\x87\xbc\x44\xc2\xd2\xaf\x40\xb9\xd5\x12\xc5\x0a\x4d\x6c\x10\xb2\x3e\x3c\xa6\x18\x19\xf5\x84\x1c\xbf\x5d\x0b\xd6\xc8\x8d\x46\xf1\xac\x64\x74\xec\x20\xb9\x10\x0b\x32\x8c\xc1\x55\x87\x91\x66\xf4\x6b\x6d\x71\x14\x0b\x0c\xfb\x2b\x07\x25\xb6\x4a\x38\xd7\x0a\x91\xca\x8f\x0e\x3b\xae\xec\x61\x25\x26\x2c\x52\xa9\x5d\x5c\xa5\xd5\xff\x6f\x44\x82\xb1\x82\x50\x06\xcd\x46\x9f\x9e\x7f\x31\x76\x9a\x73\xed\xdb\x5f\x70\x17\xf1\x8b\xc7\x47\xae\x4f\xce\x45\x0c\x42\x74\xf4\xab\xb9\x60\x57\x7d\x13\xb6\xa7\x7d\xd9\x9e\x67\xd1\x1e\xdb\x41\x3e\x42\x8e\x50\x72\x6f\x70\x52\xe5\x35\x65\xfa\x1d\x6f\xde\x91\x85\x95\x73\xc9\x28\x92\x89\xff\xef\x05\x98\x80\x28\x08\xec\xc5\x50\x1c\xb3\x00\xe0\x64\x05\xed\x0f\xeb\xc3\xdf\x23\xf4\x0a\x1f\x65\x32\x41\x0f\x7d\x90\x49\xb9\x20\x21\x6f\x7d\x5c\x7a\x72\x8c\x8d\xd6\x3a\x8d\x00\x60\xfb\x53\xb3\x54\x3d\x62\xa6\x36\x66\x17\x50\xfd\x43\x77\x5e\x80\xb5\x09\x00\x43\x51\x47\x5f",
        b"\x09\xe6\x54\xb1\x7a\xb7\x75\x95\x96\x28\xe7\xca\xd0\xe2\x70\x53\xee\x49\x5b\xcc\x29\xcc\x2a\x5e\x3b\x02\x96\x60\xa7\x7b\x13\x30",
        b"\x26\x1a\xd4\x1d\x6b\xce\x6d\x04\xd8\x91\xa4\x3c\x16\xec\x2a\x81\x14\xe5\x1f\x0e\x47\xb4\x8b\x1d\xd1\xf3\xd6\x26\x15\x03\x38\xfb",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x6f\x3f\x74\x38\x8c\xc9\x0b\x29\xc1\x09\xec\xbd\xa0\x8c\x79\x34\x9d\xff\xde\xb9\x07\x22\x97\x4d\x79\xd6\x40\x62\x09\x49\x44\x8f\x66\xae\x67\x3e\xaf\x4d\x4a\xf8\xc4\x3d\xa6\x73\xa4\x5e\xd1\x52\xea\x66\xfc\x97\x16\x6b\xaa\x7c\xe8\xbe\xb6\x66\xbd\x57\xca\x43\xda\x68\x01\xc0\xee\x5a\x5a\x9b\x50\xc5\x04\x79\x35\xd7\xa8\x55\x2c\x38\x1d\x93\xea\xf0\x3c\xbb\xbb\x88\xed\x0d\x3b\x5a\x25\x21\xb6\x76\x12\xa4\x40\x51\x20\xef\x02\x05\xe8\x9a\xeb\x48\xd5\x77\xbc\xda\x3a\xd2\x0e\x0a\x7c\xd0\x7f\x8c\x9b\x21\x5c\x84\x5d\xd8",
        p,
        q,
        g,
        b"\x08\x0c\xa4\x12\xbd\x19\x7c\x5a\xaf\xa2\xc6\xdf\x59\x33\xa6\x21\x0f\xa5\x40\x89\x82\x68\x28\xd5\x49\x6b\x45\x36\x09\xa5\x6b\x7d\x55\xd2\x32\xfb\xe6\x50\xdd\x9f\x62\xc0\x5c\x05\x0c\x02\x6a\x87\x17\xa7\x8b\x5d\xb0\x16\x14\xa1\x93\x01\xc6\x10\xd2\xb9\x96\x4a\x7e\x33\x57\xc7\x22\xa4\xc5\x53\x27\x3b\xf2\x7f\x87\x1b\x4b\x92\x41\x67\x8c\x33\x4e\x20\x82\x7a\x5f\x51\x1f\xe9\x31\x9a\x07\x5d\x12\x75\x3a\xc0\x96\x0d\xf6\x08\x70\xa0\x8a\x12\xf0\x9b\x9d\x35\x93\x78\x17\x81\xa0\xcd\x75\xe9\xd8\x1c\xc6\xb9\xb0\xd5\x06\xd1\x00\xfe\x97\x21\x65\xb6\x82\x97\xe6\x07\x0d\xb2\xd8\xb6\xea\x32\x17\x6d\x15\x62\x08\x4f\x6a\x06\xe0\x8e\x29\x29\x15\x5b\x25\x5d\x33\x85\x3d\xe6\x54\x9e\x79\xf8\xb5\x60\x49\xa1\xd0\x2f\x29\x16\x6d\x5f\x91\xcf\xbd\xe5\xaa\xf6\xbc\xae\x56\xf5\xd2\xd9\x0a\x9b\x4e\x8f\x6f\x45\x00\x80\xca\xe8\x25\x6c\x66\x19\xe9\x15\x55\x23\xc2\xb2\x05\x22\x55\xa8\xf6\xd9\xf5\x3d\x8a\x89\x7b\xe5\xb0\x47\x60\x02\x41\x0b\xf7\x98\x25\x6f\x62\xbb\x1a\x81\x82\x7c\x2c\x3f\xc4\xec\xf9\xab\xfd\x77\xe7\x41\x74\x78\x73\x70\x86\x4f\x05\xf9",
        b"\x43\x99\x3b\x68\xe8\x47\xf6\xba\x61\xd5\xad\x4d\xc8\xf5\xad\x70\xda\xbc\x31\x7a\x7b\x68\x11\xc2\x3e\x7f\x21\x5f\x95\x41\x5e\xd5",
        b"\x1e\xa7\x27\xaf\xdb\x90\x7d\x1d\x5b\x23\x37\xc1\xec\xea\x46\xc7\x1e\xb0\xfc\x83\x63\xaf\x23\x86\x5a\x34\x52\x02\xa7\x62\xa7\xc5",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x74\xa4\x33\xc2\xd3\x13\xf6\x62\x32\x32\x4d\xf8\x75\xb8\x25\x63\x80\x5d\x7e\xd6\x82\xb2\x66\xea\xf9\x62\x37\x5e\x42\x2b\x3a\xbb\xfe\x3d\xce\x7f\x3c\x19\x60\xa1\xe4\x10\x0f\x33\x3e\x16\x8d\x02\x19\x68\xb4\x83\x97\xe8\xcc\xe9\x00\x5e\x95\x1f\xdc\xb0\x96\xa9\xab\xea\x34\x2c\xb5\xb0\x8b\xab\x79\xef\x0c\x43\x1d\xd3\xa4\x3d\xe7\xd5\xbd\x6b\x86\xbe\xa8\x87\x2b\xa0\x38\xb4\x3a\x23\x6a\x73\x56\xb0\x3f\x89\xb0\x90\x04\xba\x2d\xef\x66\x3e\x6d\x29\x97\x63\xb6\xca\xfc\xb6\xb1\x50\xa5\x7f\x82\xb8\x90\xff\x6d\x56\xf8\x32",
        p,
        q,
        g,
        b"\x44\x4f\xaf\xab\x58\xdb\x4d\x6f\x52\x83\xc3\x44\x3d\x64\x78\xb5\xb7\x8d\xaa\x63\x1b\xd4\xc3\xd9\xa2\x8e\xd1\x72\x81\xda\x4c\x1c\x2e\xf4\xd5\xed\x57\x6d\x66\xbf\xe5\x31\x4e\x11\xfe\x68\xab\xff\xe4\xdf\x40\x6f\x60\x33\xed\xb8\x4f\x36\xa3\x8a\x3c\xe6\x14\x60\x1b\xc2\x58\x41\xf9\x41\x9a\xfb\x28\x67\xd9\x91\xe8\x7b\x44\xc4\xb7\x44\xe3\x9b\x64\x07\x9d\x9a\xad\x4b\x58\x5d\x79\xc8\xe2\x1c\x8f\x90\x99\x05\x40\xfe\xc8\xae\x98\x1f\x74\x83\xdc\x55\x23\xd2\x16\x08\x8a\x55\xcf\x23\x80\xea\x8e\xb5\x24\x67\x81\x29\x05\x59\xea\x1b\x20\x8a\xd4\xd0\xf5\x87\x1c\xb4\xd1\x3c\xdc\xa6\xef\x34\xfd\xf2\xde\x63\xe2\x09\xaa\x32\x0c\xdf\x14\x18\x5b\x8f\x5f\x60\xcc\xf9\x3f\x39\x8c\x1a\x6c\xf8\xb3\xce\x3d\x98\xda\xf0\x5e\x4c\xf9\x0c\x39\x80\x1c\xe3\x5f\x01\xec\x76\xa9\xf6\x03\x5c\xe1\xb5\xba\x10\x7a\x5f\x66\xcf\x25\x3b\x71\xfb\xa3\x83\x3e\x99\x69\xc3\x14\xeb\x6d\x50\x00\x05\x74\x92\x31\xf7\x99\xb0\xc7\x9a\x55\x5a\x10\xcd\xd6\x9f\x8e\xec\x4c\x11\x7d\x7c\x8b\x4e\xc6\xf6\x0a\x1e\xe5\x57\xb7\x0c\x0d\xea\x38\x0a\xf5\x3b\x92\xfd\xde\x88\x23\xca",
        b"\x3b\xda\x5b\x0c\x9e\x3d\xa2\x2f\x0b\x3e\x29\x35\x6a\x2f\x7d\xda\xce\x6e\x9b\x24\xa0\x63\xeb\x3f\x5a\x7d\x75\x5f\x2e\xea\xff\xb5",
        b"\x4c\xbb\x81\x53\x20\x31\x4a\x06\x53\x8d\x2a\x67\x40\xe6\xbf\x9d\x02\x2e\xac\x9a\xa2\x5c\x75\x08\xf6\x59\xf0\xf7\xc1\xf5\x9c\x45",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xf4\xea\xdf\xea\x11\x7f\xd3\xd6\x70\xce\xa2\x8a\xa9\xd2\x60\x2c\x95\x1e\xd8\x43\xe2\xe8\xcb\x28\x64\x07\x4c\x8c\x9b\xcc\xb0\x60\x6c\xed\x83\xae\x29\x80\x59\x8c\xc3\xe1\xb0\x47\xfc\xa8\x65\x91\x27\x40\x6d\x8f\x59\xf5\xb7\xbb\xfe\x8e\xce\x6d\x3e\x42\xf8\x7f\x4e\x42\xeb\xe9\x2a\xda\xa1\xe6\xe9\x2c\xed\x3d\xca\xcc\x2e\x0b\x2c\x98\xea\xde\x7c\x9c\x99\xda\x88\x7e\x74\xdb\x5a\x59\x13\x2c\x1d\x7d\xf7\xcd\xe8\x66\xcb\x2f\x3c\xa7\x50\x85\x2b\xa5\x3e\x26\x5e\x62\xbf\x7a\x93\xfd\x69\x3e\x4a\x13\x75\x1e\x18\x6e\x9d\x6b",
        p,
        q,
        g,
        b"\x10\x4f\x44\xfd\x76\x69\x60\x76\x44\xec\x55\xe6\xca\x40\x96\xc9\xa2\x79\x47\x27\x52\xa1\x75\x3d\xbb\x9f\x2a\x69\x41\xb8\x12\x22\x74\xc8\x7d\x16\xf6\x3d\x75\xdd\xa9\xeb\xcf\xd6\x58\x4b\x0c\xb3\x74\xfd\x17\x58\x13\x53\xd2\xa2\x46\xec\x0b\x37\x8d\xe6\x0e\x96\x13\x13\x16\x83\xc0\x56\x8b\xb5\x4d\x74\x45\x7a\xd7\x3d\xe8\x59\xa4\xf0\x24\x45\x34\x4d\x13\xee\x92\x8f\x3c\xda\x51\x34\x20\x2a\x93\x88\xe6\x4c\xf0\x5f\x81\x90\x04\x9d\xf4\xe7\x77\x70\x98\x38\xd0\xc9\xd3\xbc\xb3\x7e\xec\xdc\x38\xc1\xa5\xd2\xb4\x71\xc4\xb9\x10\xcf\xaa\x9a\x9b\xa8\x1f\x69\xb4\xb4\x5c\x40\x34\x40\x29\x95\x8f\xa4\x00\x00\xe5\x68\x81\xbc\x6a\x14\x86\x43\x30\xd5\xb3\x51\xc1\x61\x20\x86\x76\xcb\x85\x2b\xf4\x79\x70\x26\x8d\x37\xd4\xbf\xe9\x7b\x3b\x26\xef\x5b\x78\x5f\x50\xeb\xc8\xc4\x79\x49\xdc\x9b\xd0\xb2\xe6\x73\xfb\x04\x0e\x26\x78\x9f\x3f\x5c\xdb\xce\x8e\x4b\x78\x38\x99\x92\xbb\x83\xee\xb2\xb0\x63\xe9\xe1\xdb\x06\xa9\xed\xe9\x33\xfa\xef\x7e\x63\x5e\xff\xe5\xe1\xb1\xe2\x11\x53\xdc\x69\x34\x19\x7e\xfa\x1f\xd6\x8f\x18\xa4\x0e\xd5\x69\x74\x6c\x83\x74",
        b"\x36\xc0\x86\x07\x03\x68\x26\x5f\x73\x6e\x7b\xba\xd5\x4a\xaf\x24\x82\xd2\x61\x61\xf8\x05\x7a\x97\xa4\xb8\xcd\x2b\x4d\xdd\x78\x55",
        b"\x31\xd9\x9d\x73\x6e\xa6\x70\x14\xfe\x59\xcb\x22\x12\xc4\x7e\xb9\x20\xf2\xaf\x44\xe3\x2b\x65\xdb\x15\xaf\x83\xcb\xe8\xe6\xaa\x70",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xcb\xc3\x7a\xfc\x75\x17\x7a\x83\x86\xdc\xe2\xc4\x0c\x33\xb8\xf5\xde\xdc\x23\x11\x3b\x45\x12\xcb\x96\x79\x0f\x2d\xd7\x40\x66\x10\x3e\x0c\x45\xa9\xc6\x17\x6f\xf9\x6b\x7d\x71\x91\x62\x00\x3c\xee\x10\xfa\xd6\xcc\xc1\x98\x55\x0a\x38\x92\x75\xd2\x1e\x70\x8b\x69\x61\x52\x32\x72\xec\xd5\xef\xab\x56\x80\xed\x74\x1c\x2d\xe0\x25\xb0\x2b\xbd\xc5\x63\x15\xa4\x42\xe4\x37\xc4\x3e\x3b\x37\x8e\x6d\x62\xea\x88\x78\xfd\x97\x89\x85\x8a\x8c\x68\xa5\x04\xbf\xf4\x95\x16\xe7\x62\xa2\x2a\xe5\x13\xa2\xdc\xeb\xa9\x25\x3b\x36\xf5\x53",
        p,
        q,
        g,
        b"\x35\x6c\xc7\x37\x0c\x84\x0f\xa2\x6b\x0d\x10\x6c\x47\xa6\x26\xe0\x28\xa0\xc9\x67\xc0\x93\x81\x0b\x52\x06\x39\xbd\xda\x0d\x33\x9b\x7f\xc2\x9a\xdc\x0d\x90\x36\xb9\x71\x03\x58\xef\x9f\x8c\x6c\x05\x25\x2b\x27\x82\x81\xb2\xaf\xe7\x95\x38\x86\x42\x9e\x85\xd2\x28\xfb\x54\x74\xac\xfd\x65\x21\x31\x51\xe9\xda\x0a\xef\x86\xa6\x6f\x9f\x9c\x59\xfa\x88\xfd\x48\xcc\x3a\xdd\xc8\x3d\x7a\xdf\x4a\xfb\x16\x65\x04\x9e\xd0\x94\x02\x02\x19\xc0\x19\x58\xb6\x97\xf2\x2e\x65\x21\x52\xe5\x3b\xf4\xe8\xf6\x8f\x47\x6a\x58\x18\x1d\xdd\x3f\x64\x34\x4e\x9b\x87\xa0\x8c\x5d\x0d\xe4\x9e\x7b\x3c\x29\x95\x84\x0c\x20\x00\x84\xe9\x0a\x76\xd2\xc0\x5f\x8b\x5c\x68\xe7\x71\x92\xd0\x67\x6b\x42\x19\xd4\x57\x9c\xb2\xde\x0f\x2a\x93\xa9\x16\xb4\xf9\xcf\xe0\xd8\x11\x3d\xc4\xbb\xd9\x7e\xd1\x2d\x8c\xe0\x44\x7f\xcf\x9d\xf1\x2e\x92\x2c\x63\x83\xca\x69\xc9\xde\x9a\xd3\x20\xf9\xc5\x33\x1a\xdb\x6e\xb1\xd2\x23\x07\x91\x96\xa2\x93\x9c\xc0\xa7\x25\x9c\x51\x2c\x47\x8c\x94\x3f\xe0\x57\x36\x71\x0e\x27\x3e\x4b\x58\x67\x17\x4d\xe7\x2e\x70\x3b\x5e\x7b\xf7\xaf\xdb\xc0\x64\x27",
        b"\x56\x45\xef\x65\xe8\xe9\x23\x6d\x87\x4d\x45\x9e\x7a\x58\x09\x92\x3c\x05\xd6\x4b\x22\x75\x7b\xfc\x5b\x56\x21\x07\x9e\x84\x81\x9c",
        b"\x65\xf4\xc8\xfe\xba\xf3\xe9\xd4\x65\x81\xb1\x76\x85\xc4\xf2\xec\x9b\x95\x64\x21\xd0\x34\xa2\xc1\xaa\xab\xee\x94\xb7\x87\xa4\xf1",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x8e\xb3\x68\x5c\x3f\x40\x6c\x56\x15\xe8\x8a\xcc\xf4\xc0\xc7\xd2\x07\x1b\x6c\x7b\xde\x52\x44\x99\x4f\x73\xdc\x04\xf3\xcc\x0a\xb7\xe2\xb6\x66\x4a\x19\x94\xe6\xee\xc5\x2b\x62\x79\x0a\x04\x32\x8e\x43\x6a\x2b\x4a\xf3\xcb\xe3\xba\x6e\x4c\x8f\x36\x3a\x39\xb2\x52\x9e\xf5\x54\xc0\xc6\x27\xf9\xf6\xb2\x55\x92\x8a\x39\xa4\x65\xe6\x0a\xc5\x0c\xcf\x01\xf3\x2c\x7b\xa4\x83\x64\x03\x44\xb6\xa8\xf5\x83\xc9\x08\x76\xb8\x4d\x19\x55\x4b\x0a\x4b\xaa\xbc\x2c\x24\x0e\x29\x6b\x12\xc8\x19\x41\x0c\xac\xff\xe7\xa7\x46\x44\x19\xbe\xe0",
        p,
        q,
        g,
        b"\x94\xba\x48\x69\x77\xf5\x98\x2f\x2a\xe7\x5e\x98\x6b\x7e\x19\x44\x61\xcc\x3d\x65\xcd\xbf\x26\xf9\x36\x80\x5d\x12\xd7\xf8\x50\xaa\xd7\x58\x02\x06\xd7\xdc\x54\x4c\xd1\x2c\xa1\x89\x1c\x9d\xc4\x06\xc9\x49\xe5\x2b\x9f\xeb\xfa\x88\x83\x6f\x15\x66\xd5\x21\xa1\x10\xbb\x54\x5e\x07\xba\x28\xca\xf0\x7e\x1b\xbf\xa3\xb1\x76\xcc\x91\x7c\xc4\xbb\x45\xda\xe7\xf8\x73\xb7\x2d\xfa\x90\x00\xe9\xab\x60\x83\xe7\x05\xc0\x16\x7d\x85\x3d\xda\x11\x4c\x42\x9f\xd8\x12\xa0\x59\x61\xfc\x2e\x78\xba\x9e\x68\xcc\xdb\x9d\xc6\x7b\x11\x6f\x10\x53\x20\x34\xd9\xf0\xf7\xd3\x99\x01\xdc\x64\x31\x27\xc4\x30\x90\x58\xf8\xeb\xf4\x3b\x28\xa5\xce\x53\x4e\x29\xd6\x22\x7c\x4e\xc2\x7c\xcf\x77\x7b\x00\x08\xdf\x5c\xe8\xb8\xa1\x9b\x57\x71\x72\x5c\xb0\xf9\xf2\xa6\x2b\xb4\x1f\x01\x06\xc3\x90\x80\x3a\x30\x7c\x60\xac\xbe\xd6\xc2\xe1\xe0\xdb\x50\x36\xe0\xe7\x9d\xdc\xc3\xf7\x18\xb2\x9c\xa5\xaa\x02\x2f\x2f\x0b\xbe\x81\x5f\x9c\x0e\xb5\x04\xfc\x9f\xf8\xd1\x8a\x2d\xa9\x99\x02\x3a\xf8\x10\x5c\xdd\xfc\x67\x94\xdf\xdc\xc4\x13\x33\xbc\xcd\x44\x6a\xd7\xb8\x2a\x0a\x7b\xfe\x38",
        b"\x27\xb4\xe3\xc3\xa4\x5e\xfa\x61\x31\xc3\xd0\x05\xca\x92\x4d\xff\x11\xfd\xcc\xf4\x09\xc2\xa6\x99\x3f\xcb\x50\x54\x77\xb6\xe4\x00",
        b"\x68\xa0\x85\xbd\x13\x0c\x4e\xc0\x8a\xa9\x67\x3c\x49\x5b\xa5\xaf\xd4\x6c\x9d\xda\xd2\x05\x2b\xa7\xab\x39\x63\x29\xd9\x00\xd8\x6c",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xf2\xb0\x2a\xc6\x27\xb3\xf6\x6b\xaf\x4e\xba\xa5\x2b\x89\x9a\xdf\xd7\x07\x1a\xf5\x3e\x78\x92\x31\x82\xd8\xb4\xd5\xf3\xa9\x47\x42\x51\x30\x8b\x4d\xbd\x15\xfb\x6b\x65\x7b\xe6\x50\x28\xa1\x89\x35\x39\x12\xd7\xc1\x6d\x6d\x49\x89\x98\x5c\x15\xce\xdc\x43\x43\xf0\xce\xb6\x80\x61\x7b\xc7\x27\x85\x11\xf9\x06\x8a\xbd\x61\x37\x18\xa8\x62\x51\x3e\xe5\x14\xfd\xf8\x0c\xd2\x5b\x6f\x84\xc4\x88\x51\xe6\xa7\x85\x0f\xea\xea\x57\xea\x20\xde\xb1\x12\x3c\xa4\x20\x6b\xde\x8a\x93\xff\x99\x9e\xf7\x89\x58\x3e\x2c\x85\x0d\x9e\x06\x35",
        p,
        q,
        g,
        b"\x4e\x16\x0d\x69\x70\x68\x3f\x4d\x84\xeb\x88\xc5\x5b\xa2\xda\x58\xd7\x7f\x63\x74\xfc\x51\x27\x27\x3d\x65\xe8\xef\x96\xcc\xff\xf5\x1d\xf6\x9b\x0e\x2f\xdf\x3e\x98\xf6\xd3\x5e\x6a\x3d\xd9\xf7\xed\xd9\x0b\xba\xe4\xc6\x58\x1c\xd0\x2a\xd0\x13\x36\xc0\x08\x6d\x42\x48\xeb\x13\x73\x48\x07\x89\xf7\xd8\x33\x3b\x83\x1d\xb3\xba\xe0\xbd\xb4\x97\x89\xaa\xb9\x3c\xde\x1f\xaf\x1c\xe8\x8d\xcd\xc7\xa1\xa4\xf8\x61\x43\xce\x44\xf8\x51\xac\xe4\x59\xa5\x52\x8c\x96\x19\x5f\x44\x38\xee\x7c\x18\x56\xac\x61\xfd\x50\x35\xd8\x39\xd6\x2e\x48\xa1\xab\x6b\xd2\x3a\xd5\x2f\x1f\x6f\xfe\xd1\x98\x26\xb6\xd7\xf6\x49\x1c\xfb\x05\x00\x31\x76\xf2\x90\x79\x45\x54\x43\xf0\xab\x48\x21\x50\xfa\xc8\xe3\x2a\x39\x02\xa4\x09\x67\x75\xf3\x42\xed\xee\x2d\xaf\x4c\x4f\x33\x8d\x45\x5b\x4e\xa3\x5d\x39\x75\xf7\x2b\xe8\x5e\x98\xe8\x71\x58\x48\x6b\x4c\x3d\x6e\xc3\x7a\x37\x03\xf6\x3a\x3e\x19\x27\x2b\xa5\x25\x50\x89\xaa\xcd\x30\xfa\x39\x79\xb4\x58\xdf\x61\x6f\x57\xb7\x50\x2b\x42\x91\x38\x45\x62\x04\x1f\x61\x88\xdb\x50\x3f\x3d\xf7\xf5\x98\x1d\xa5\x70\x5e\xb0\xf1\xd2\x42",
        b"\x64\x33\xbd\x33\xdb\x0a\xc8\x26\x1c\x69\x1a\xf3\xa2\x7f\x52\xcd\xd4\xa6\x5d\x79\x99\x39\xfa\xf2\x79\xac\x41\x78\x8e\x75\x28\xa6",
        b"\x04\xcf\xdc\xb9\x93\x38\x2e\x8f\xd2\xdb\x8d\x90\xdc\xa8\x0e\x94\xb1\x7b\x43\x20\x09\x85\x2c\xd3\xf8\x66\x25\x15\x9e\x83\x7c\x19",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x2b\x43\x65\xa4\xac\x68\x54\xc9\x72\xda\x73\x47\xaf\x1c\xec\xc6\xed\xcb\xae\x9d\x53\x3b\x74\xfb\xe6\xdb\x57\x12\x16\x3a\x6c\xe9\x84\xf9\xd7\xa4\xc5\x4b\x44\xdd\x75\x55\xe5\xc2\xd2\xf3\xd0\x98\xf3\x1d\x51\x7f\x8e\xbd\x33\x01\x99\xa5\x4b\x15\x29\x7e\x5a\xde\xe1\xbd\xf3\x91\x58\x1f\x10\x19\xb1\xad\x72\xdc\xcc\xd5\x48\x4b\x51\xd2\x75\xa3\x68\xc6\x9a\x76\x62\xe7\x9f\x9b\x29\xc9\xa3\x08\x4c\x94\xae\x76\xda\x04\xf9\x58\xc7\xd3\x6c\xec\xc5\xd4\x1d\x77\xf2\x30\x2f\xf2\x8f\x2e\xd9\xc6\x6a\x06\x62\xca\xbf\x51\xc8\x42",
        p,
        q,
        g,
        b"\x58\xe6\x35\xee\xc8\x0b\xde\x1e\xb7\xbf\x2d\xa2\x06\x00\x61\x7a\xf2\x9f\x0a\x19\x17\x05\x67\x6b\xc1\x0f\x75\x53\xf7\x61\x11\x26\xe4\xc4\xd4\x4b\xcf\x14\xf7\xa9\xf4\x8d\xa6\xe1\xb1\xe5\x4d\x0a\x71\x57\x24\xaf\x5b\xca\x93\x86\x70\x90\xf9\xbf\xc9\x27\x41\xdf\xe1\xdd\x4f\x06\x07\x5e\xc2\xa9\x26\x2d\xa8\x1e\x0d\xca\xbf\xca\xb9\xe6\x94\xdd\xca\x86\xd0\xe1\xcf\xaa\x32\x1e\x2b\x58\x18\x18\x2e\xb6\x20\xbd\x5d\x16\xbc\x27\xa2\xda\x03\x5d\x4b\xc1\x78\x07\xcf\xe8\xae\x30\x38\xc5\xbb\xb8\xa0\x23\xfb\x23\x28\x14\xb9\x1b\x99\x74\x9f\x51\x9d\xe3\x9a\xa0\xf4\x34\x31\x33\x23\xb1\xb5\x82\x02\xc5\x91\x19\xb0\xbe\x21\x76\x17\x04\x7c\x9e\x2e\xa4\x53\xd6\x08\x56\x2c\xb9\x6c\x4f\x08\x51\xa7\x96\x5b\x16\x4f\x9b\xbe\x15\x1f\x9c\x50\x8c\xa2\x09\xf1\xaf\x65\x9e\x36\x38\x04\xc8\xd8\xfa\x1a\xd7\x00\xe2\x08\x66\xec\x9a\x1e\x50\x5b\x74\xbb\xab\x70\xcb\x47\x23\x08\x43\x1a\x3e\x87\x27\x2f\xeb\xf7\xcc\xe2\xc2\x0e\xc3\x7f\x5d\x68\xb4\xe4\x7b\xf3\x74\x10\x13\x72\x39\x36\xdb\x7c\x9b\x0f\x3d\xed\x96\x4a\xcb\x7f\x8a\xc9\xc5\xa6\xb4\xf2\x8d\xe1\x98",
        b"\x00\xa7\xc6\x64\xc5\x44\xcd\x7b\x61\x74\x94\x10\xdd\xa3\x3b\xb3\xa4\x7c\x3e\xb5\xa9\xa7\xbe\x5f\xba\x20\x1a\x39\x0c\xec\xfa\xef",
        b"\x6f\xbb\xda\x96\x7b\x58\x4b\xd9\xec\x6a\x0a\xe7\x6e\x0c\x55\x2b\x3d\x42\xbf\x0e\x9c\xf2\x93\x9c\xaf\x61\x23\xf6\xe8\x60\x46\xf6",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xca\xb1\xd1\x76\x66\xb0\xc9\x65\x8c\xc7\x8c\xfc\xba\x17\xa0\x8e\x29\x89\xd3\xc2\x02\xc8\xb5\x08\x55\x31\x40\x4d\x92\x8c\x61\x8b\x6e\x23\x0b\x25\xc4\x6a\x5b\x58\x43\x7e\x43\x35\xfc\x04\x00\x20\xba\x00\xc8\x63\x18\x23\x25\x94\x0f\x00\xaa\xd3\x30\x14\x5e\x66\x6d\x07\xe9\xe9\xd8\x76\x13\x70\x10\x93\x2a\xe5\x20\xd9\x18\x8c\xa3\xd7\x99\x3c\x90\x53\x95\x21\x9c\x55\x84\x6d\x19\xb8\xfc\xdb\x1d\x0c\x15\x86\xb9\xb5\x10\x97\xaf\xd6\x97\x2a\xe1\x47\x2b\x0e\x20\x45\x3f\x8f\xbd\x5d\x6a\xa9\xe4\xa9\xa9\xb3\xdc\x37\xdd\x8f",
        p,
        q,
        g,
        b"\x50\x22\xc8\xa6\xfa\x79\xb7\xaa\x11\xa3\xd7\xaf\x5a\xce\xbb\x2e\xf8\xc5\x0b\x28\xd8\xf0\xe3\xa5\x56\x19\x65\x62\xd3\x41\x31\xfb\x44\xf2\x2c\x3b\xe3\xf9\x89\x5e\x35\xee\xe7\x0a\xa5\x3b\x6c\x67\x92\x0c\x54\x0b\xa6\xc1\x08\x5b\x0e\xa8\x18\xb1\x2a\xea\x81\x1f\x2d\xfa\xeb\x6d\xae\xd9\x76\xe3\x62\x43\x07\x98\xfd\xcc\xa3\x91\x2a\x08\x91\xe7\xd1\xc8\x3b\x74\x8a\xf1\xe7\x68\x9e\x03\x8b\x49\x0e\xb7\x3f\x7f\xe6\xe0\x61\x2e\x8f\x23\x85\x80\xe7\x88\x33\xb2\x07\x27\xa6\x02\x76\x8a\xb2\xd5\x9d\xda\x36\xe7\x51\x46\xfa\x4d\x36\x64\xf7\xb0\xce\xf7\xbe\x87\x7a\xfd\xcd\xba\x23\x00\x4e\xe3\x13\xa6\x9f\xd6\x1c\x32\x67\x59\xe7\xe7\x79\xad\x75\x0f\x7a\x5c\xad\x9f\xb2\xdd\x80\xa8\xee\xa6\xdc\xbd\xa0\x19\x5d\xcc\x17\xb3\x8a\xd6\xf0\xe2\xab\x68\xcf\xc6\x9b\x15\xc5\x72\xf8\x5f\x20\xc3\x67\x9c\x15\xa8\x30\x99\xcf\x08\xa3\x79\x05\x5f\x8f\xbd\xd8\xf5\x90\xd4\x3b\xd1\x2f\x75\xba\xf0\xec\xcd\x6c\x07\x7a\xc7\x58\x9a\xab\x81\x71\xe8\x87\x5d\xb0\x12\x2e\x6c\x78\x61\x7c\x13\x58\x61\x43\xa7\xeb\xe9\x04\xa7\x82\x2b\xac\xf4\x8a\x75\x27\xf7\xfa\x4e",
        b"\x7b\x8b\x75\xac\x85\x14\xc6\x8d\xe0\xca\xa9\x8e\x9d\xe0\xb9\x60\x72\x53\xd8\x08\x8d\x3f\xea\xdf\x92\xb8\x3f\xfc\x26\xe0\x88\xce",
        b"\x4b\x10\xe1\x7f\xf6\x4a\x0e\xb7\x2f\x70\xa8\x63\xd0\x0a\x9b\xf3\x31\xbb\xb5\x15\xba\x3a\x9f\xef\x72\x75\x3a\xd7\xf0\xdf\x0b\xe5",
    )?;

    // [mod = L=2048, N=256, SHA-512]
    let p = b"\xf6\x3d\xa3\xbe\x9a\x96\x16\x19\x6c\x65\x56\xf3\xce\x6f\xd8\xb9\x8b\xdd\xa9\x13\x74\x73\xda\x46\xfe\xd9\x70\xe2\xb8\xd1\x47\x38\x7a\x81\x92\x20\x65\xd5\x28\xa7\xd6\x43\x3e\xbc\x5e\x35\xb1\x5c\x67\xea\x35\xa5\xa5\xbf\xf5\xb9\xce\xf1\xcd\x1e\x6f\xe3\x1d\xda\x52\x83\x8d\xa3\xaa\x89\xb9\xb4\xe8\xd9\xd3\xc0\x73\x2c\xcc\x4f\x23\x8c\xe1\xb4\x16\xc4\xca\x93\xf2\xc6\x80\x0e\x5f\x4e\xd4\x1c\x4f\x76\x15\xce\xc5\x53\x1b\x98\x68\x0b\x20\xdc\x63\xf7\x3e\x70\xd8\x03\xaa\xcf\xae\xce\x33\xd4\x5f\xa0\xe3\x9d\x77\xc8\x50\x82\x09\x52\x8b\x90\x46\xb5\x91\x70\x10\x79\x12\x34\x39\x7e\x41\x2d\x22\xbc\x0b\x8d\x67\xcb\xd1\xcd\x28\xa3\x2c\x24\x60\xa0\xbd\x86\xaa\xba\x0e\xea\x80\xe1\x6e\x32\x45\x64\x31\x71\xe3\x42\x21\x76\x0c\x20\x3a\x56\xb8\x20\x7a\x10\x09\xe6\xc1\xa2\xf6\xcd\xa8\x5f\x85\xc4\xf9\xe4\x10\xb9\x49\x92\x33\xc0\xee\x07\x2e\x46\x5a\xf4\xfb\x4f\xb9\x28\x2c\x5c\x10\xe8\x23\x4f\xd6\x30\xea\x92\xf0\xaa\xe6\xb9\x7a\x52\x0d\xb3\x44\x75\x70\x7b\x79\xa4\xc1\x75\x26\x5c\x03\x56\xcc\xbc\xa8\x27\xe3\x83\x7d\xf3\xd6\xd0\x57\x6d\x90\x79";
    let q = b"\x9b\x74\x63\xf8\x26\x9f\x0b\x90\x9a\xbe\xd1\x09\x91\x68\x4f\x36\xa6\x4a\xc8\x64\xe0\xd6\xd7\x17\xc0\xef\x21\x57\x7a\x4c\x39\x07";
    let g = b"\x97\x2a\x75\xf6\x06\xe8\xaa\x3a\x91\xff\x08\xfd\x13\x1a\x20\xf5\x96\x32\x51\x30\x4e\x3d\x14\x31\xb7\x12\xfa\x08\x03\xd5\x27\xfd\x71\x0f\xb7\xeb\x27\xe5\x29\x04\x97\x1c\xd4\x3c\xa9\x77\x19\x9a\x24\xdb\xee\xb4\xb7\xbc\x2b\xa0\x75\xd3\xb7\x2e\xb6\xb2\xc5\xad\x8f\x0e\x8b\x8f\x48\xc5\x0b\x55\x4c\x7e\x07\x11\xf4\xc7\x41\x63\x30\x80\x66\x72\x49\x8f\x43\x02\x92\x72\x4b\xf9\x8a\x8e\xa4\x8c\x7f\x53\xd7\xb3\x1d\x8b\x75\x28\xb1\xa6\xf0\x87\xd2\xc2\x7c\x33\x52\x02\x83\x5b\x1e\x31\x42\x25\xb3\x7a\xef\x8b\xfc\xec\x7d\x80\x92\x0c\x4a\x46\x0a\x3d\x68\x34\x4d\xed\x75\xed\x9e\xe8\x67\xfa\x2a\x69\x45\x06\x38\x94\xf5\x63\xb6\x86\x33\xb8\xb3\x9f\x83\xa1\xaa\xaf\x5a\x96\xc7\xf4\x22\x68\x7e\x7c\x84\xcf\x8f\xb8\xcc\x5f\x45\x04\xdf\xf0\x87\xbc\xb2\x6a\x95\xbb\xf8\x58\x3f\x03\xb3\xa0\xe4\x3a\x35\x6b\x2b\xd7\xe2\x5c\xdd\xdf\x7a\x01\x53\x00\xfa\xec\xc6\x79\x3c\x5e\xe9\x9b\x63\x27\xcb\x84\x56\xe3\x2d\x91\x15\x33\x9d\x5a\x6b\x71\x2b\x7f\x9d\x03\x01\xac\xb0\x51\x33\xe3\x11\x5e\x45\x4d\x3a\x6d\xd2\x4a\x16\x93\xc9\x4a\xab\x54\x06\x50\x4b\xf7";
    test(
        HashAlgorithm::SHA512,
        b"\x8a\xb0\x15\x10\xcf\xa3\x3c\xfa\x5b\xcf\xf0\x03\xbb\xa3\x99\x96\xfa\x72\x76\x93\xab\xf6\xac\x01\x0b\xb9\x59\xb0\xb5\x9a\x15\x30\x6c\x0c\x3a\x19\x21\xaf\x2a\x76\x71\x7a\xa5\x5b\x39\xfa\x37\x23\xf4\xc3\x22\x9c\xa9\xac\xf6\xb7\x41\x61\x4b\xb5\x51\xcd\xe8\xa7\x22\x0a\xb9\x7d\x4b\x45\x3b\xec\x1e\x05\xa0\xea\xa4\x2e\x38\x2b\xbc\x7b\x9b\x84\xf8\x23\x7d\xc8\x96\x4e\xe5\xb6\x6e\x9b\x2a\x4c\xa6\x1c\xf6\x75\x14\x0e\xfe\xf5\x4f\xb3\x27\xa6\x65\xde\xf8\xd5\x7a\xb0\x97\xe8\xc5\x3c\x64\x3f\xcb\x58\x20\x9c\x42\x15\xb6\x08",
        p,
        q,
        g,
        b"\x41\x19\x7c\xe2\x23\x3d\x7e\x48\xc8\x03\xcd\x64\xc7\x8f\x65\x79\x23\xb9\xe3\x6b\x87\x14\x01\xf8\x66\x1c\x21\xd8\xba\x38\xc6\xb9\xb3\x23\x9d\xb7\x67\xb1\x1d\x1d\x40\x1e\x5f\xae\xcb\xf7\xa4\x58\x60\xcc\x5f\x1a\x54\xd6\x02\x86\xb7\xd6\xe1\xc9\x9f\xd5\xb8\xc8\x4e\xd8\x51\xc5\x35\x7d\x41\xad\x60\x16\x3f\x22\x4d\x78\xc9\x96\x14\x3f\xff\x89\xdd\x3a\x8f\xe1\x23\xda\xe1\xf6\x21\x42\x7f\xd8\xcc\xe7\x6e\xd1\x38\xd6\x8f\xa2\x48\xf3\x74\xae\x23\x32\x49\x62\x5b\x93\xf3\xdd\x59\x37\xd1\x5e\x54\x1b\x7e\xff\xa4\xdf\x4f\xea\x7d\x52\xfa\xce\xd6\x15\xbf\xe0\x34\x84\x18\xff\x93\xe6\x9a\x20\xa5\x2e\x55\xc7\x6c\xc3\x0f\x30\x7f\x84\xe7\x1e\x4a\xab\xc0\x82\x5e\xca\x3a\x95\xb4\xbd\x58\xeb\xfb\x00\x29\xd2\x3a\x16\x9e\x9d\x80\xba\x7d\x1c\x5f\xd3\x53\x95\xe6\x60\x2e\x08\x9a\xa9\x91\x8f\x08\xba\xe3\x5a\xe1\xca\xc7\xaf\x33\x69\x41\x29\xe9\x8f\x0d\xad\xad\xd9\x0e\xae\xb6\xee\xd2\x50\x24\x39\x0b\x1a\x60\xaf\x79\x47\x34\xc3\x97\xb0\xf5\x09\x86\x5b\x13\x4b\x28\x67\xc1\x15\xd6\xf4\x89\xb6\xdd\x7e\x3c\x82\x99\x4b\x45\xdc\xe2\xa2\x3c\x6b\xc9\x02",
        b"\x6a\x47\xea\x57\xce\xae\xcc\x11\x6d\x71\x90\xff\x6c\x6d\xd9\x83\x1a\xb7\x5b\x4b\xf6\xcb\x29\x10\x83\xe4\x26\x8b\x48\x6e\xd2\x45",
        b"\x01\x73\x55\xf6\x98\xa3\x2a\xbe\x9a\x4d\x4a\x7d\xda\x7c\x85\x95\x0c\xdd\xc3\x48\xab\x8a\x67\x51\xe7\x2f\xdd\xc0\x1a\xa5\xd1\xf0",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xb2\xf5\x69\x48\xa3\x36\x98\x2a\x5b\xcb\x4b\xb5\xd7\x9e\x3f\xe5\xc3\x60\x81\xbd\x28\x6e\x6e\x02\x1a\xb2\x9b\x52\x2f\x0b\xe5\xff\x5e\x81\xe6\x38\xf2\x3d\x07\x81\xc2\x68\xa8\x9b\x09\x33\x25\x75\xcb\x31\xc0\x80\x4b\xbd\x34\xc8\x05\x89\xfb\x11\x57\x0f\xc6\x5b\x3f\x67\x61\x26\x05\xa9\x41\x1c\xda\xb3\xac\x00\xff\x3f\xce\x33\xab\x22\xc4\x6d\x26\xbf\x9c\x3f\xc5\xad\x2d\x90\x18\xde\xb9\xb6\x69\xb5\x0f\xbf\xba\xf8\xbe\xd6\x23\x0c\x7b\xd6\x21\xd5\x64\xfb\x1a\xf9\x53\xf0\xe8\x2c\x5b\x55\x20\xab\x97\xba\xcc\xf5\x8d\x6e",
        p,
        q,
        g,
        b"\x72\xb8\x4e\xb6\xa6\x0c\x68\x6f\x74\xf3\x76\xe2\x6b\x2e\x47\xe4\x4a\x6d\x5d\xd9\x2c\x06\xfd\xe4\x9f\xaa\xd0\xaf\x9b\x11\xe4\x31\x47\xce\x93\x08\xef\x35\x01\xa7\x52\xe7\xbf\x18\xe9\xe6\xdf\x3c\x0a\x49\xc4\x4c\xd2\x51\x5a\x05\x50\x8f\x80\x60\xa6\x1e\x6e\x6f\x1b\x2e\xcf\x14\xb3\x38\xcf\x0f\xd8\xb7\xcc\xbe\x67\x8d\x52\xdb\xdf\x20\x35\x2c\x15\x5a\x2b\xd5\x17\xd8\x27\xd6\xce\xfb\xf4\x8c\x56\x79\xc9\x98\x29\x8e\x21\x86\xef\x10\x98\x16\x0d\xfb\x65\x91\x45\x06\xa1\x77\x94\x3a\x4a\x05\x82\x82\x38\x2d\x32\x7a\xd3\x6f\x88\x30\x1b\xe6\x93\xc0\x20\x00\xc7\x24\x63\xe6\x82\x42\x1a\x02\x37\x80\x4d\xbb\x27\x33\x5c\x78\xe8\x49\x5f\xac\x78\x42\xd2\xaa\xfe\xbf\x90\xf3\xc3\x60\x5f\x75\x86\x15\xdf\x98\x9f\xdb\xd0\x6e\x23\xe4\xad\x69\x74\xb6\x23\x84\xf0\xaa\x01\x02\x7d\xb8\x9a\xc3\xdc\xb0\x1c\xb5\x25\x8c\xdb\xd9\xc1\x93\x72\xa6\xc4\xaa\xdf\x27\x29\x80\x62\xac\x9a\x16\xde\x2e\xb0\x76\xe1\x67\xad\x7c\x65\xd0\x50\x5c\x8f\xce\xcf\x35\x9b\xb5\xd0\x5c\xd2\x2e\x7d\x48\x62\x9a\xf5\x39\xfe\x7f\x60\xe2\x3e\x95\x7c\x84\xc7\xa6\x1a\xc9\x2b\xf8",
        b"\x43\x70\x4e\x96\xcc\x8d\x63\xe6\xf5\xb7\xe1\x18\xcb\x7c\x03\x0d\x0b\xd5\x63\xb8\xf7\xa1\xa3\x04\xb3\x68\xa6\xc6\x6d\x7e\x7f\xa8",
        b"\x49\x0d\xa4\x3f\xd0\xf1\x9f\xec\x4e\xe0\x81\xcc\xe2\x5d\xf6\xb2\x72\x0b\x1a\x76\xb0\x23\xc1\x57\x04\xdd\x03\xef\x1c\x3e\x48\xa7",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x9a\xe8\x47\x93\x27\xb8\xb8\xa5\x7f\x57\x0f\x6e\xc7\x6a\x1a\xc6\xf0\x2b\x19\x8c\x60\x48\xa1\xf0\x96\xe6\xce\x56\x30\xb6\xca\xf3\x63\x17\x64\x13\xd8\x80\x33\xb1\xcd\x07\xf4\xd3\x96\x0a\x12\xdb\xae\x8a\x65\x91\x74\xbb\x87\xc3\x7a\xca\x6e\xc5\x6e\xd5\xa6\x61\x9b\x8b\xa6\x76\xb6\x50\xd9\x7c\x6a\x21\xaf\x02\x39\x85\xdc\x36\x1f\xa2\x34\xb2\xb3\xc1\x7e\x77\x70\x3b\xa9\x9a\xe3\x21\x12\x60\xda\x10\xa6\x0f\x24\x0e\xee\xf4\x78\xf2\x64\x11\x84\xa2\x81\x71\x6a\xe5\x78\x88\x11\x7d\xba\x99\x28\x53\xf4\x94\xac\x3c\xaa\x45",
        p,
        q,
        g,
        b"\xce\x34\x8b\x5c\xb3\xd3\x68\x08\x42\x2a\x50\x16\xdd\x58\x73\xdf\x79\xf3\xcb\xb5\xe1\xb4\x58\xe8\xc1\x11\x02\x26\x04\x75\x43\xd9\x65\x76\x9a\x11\x2a\xdb\x4f\xce\xd0\xd1\x46\x23\x09\x62\xa8\xd4\x13\x22\x5c\xc7\x0d\x81\x0d\x40\xe6\xa7\x2e\x6d\xc8\x0d\xb5\x09\x40\x0c\x09\xd2\x63\xd6\x62\x06\x96\x6e\xd5\x1a\xb6\x59\x30\xa2\xaa\xc9\x9f\xcc\xe3\xa3\x98\xb6\x4d\x59\x09\x76\x83\xd2\xba\xa5\x76\x82\x70\x5a\xbc\x32\xeb\x8c\x32\xd6\xf1\xe7\xd9\x4c\xa1\x7e\xd7\x06\x78\x22\xcd\x20\xfb\xa3\x79\x5e\xd1\x84\x3c\x01\xb0\xd7\x55\x1c\x7c\x4c\x75\x9d\x53\xa4\x19\x14\x83\xbd\xc6\xe3\x12\x1c\x2b\xc1\x26\x07\x70\x1f\x43\xe3\xba\x38\x2c\x67\x66\x81\x9d\xb0\x7e\xf9\xc5\x95\x86\x93\x75\x14\x77\x2c\x2e\xcc\xde\x4c\x54\xd9\x25\x75\x73\x4c\x45\xa8\xe8\x32\xc4\x41\x7b\x43\xa9\x2c\x9a\xbd\x15\x22\x59\xcc\x0a\x96\x9b\xac\x64\xb2\x37\xbb\x3a\x08\x26\xae\x72\x91\x9d\x7c\x2d\xd2\xef\xdf\x03\xe8\x37\x01\x98\x0c\x2a\x8f\x50\xce\x6e\x44\xd7\xcc\x88\x48\x64\x5b\xf4\x0a\xef\xdf\x24\xfa\x7a\x6d\xce\x5a\x3b\x9a\xca\x6f\x01\x76\x18\xa6\x4d\x91\xce\x4b",
        b"\x00\x91\xd7\x50\xad\x9a\x4f\x29\x57\x3f\xd4\x57\xa5\x89\x1b\x68\xd4\xb6\xc1\x57\x03\xa2\xbc\x19\x2c\x7c\x62\x0c\x4e\x4c\x45\x29",
        b"\x92\xc4\x09\xc8\x97\x79\x75\xa4\x17\xd9\xf5\xe0\xe2\xdc\x70\x68\x3a\x53\xa9\x56\x62\xad\x27\x0a\xe3\x5d\x49\x65\x67\xa9\xa2\xfc",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xe5\xa1\xa3\x44\xc2\x5b\xa0\xcb\xbc\xff\xe6\x80\x01\x35\xf2\xed\xe8\x10\x49\x18\x0f\xb2\x75\x9f\xd9\xe1\xaf\x3b\x81\x6a\xd5\x43\x6a\x24\xfa\xf2\x9c\xf3\xad\x91\xcf\x41\x33\x32\xf4\x54\xf7\x4a\x9d\x4f\x5e\xfe\x76\xcf\x02\x51\x2c\x27\x3c\xd5\x25\xf0\x4a\xfd\xb5\xc2\x4b\x05\x88\xd6\x11\xd7\x21\x53\x68\x0d\x1e\x39\x95\xe0\xaa\x75\x0e\x90\x77\xb0\x75\x2b\xd4\x44\x2b\xf7\xbf\xa8\xdb\xa3\x8e\x1c\x5e\x7d\xdd\x68\x7f\x55\xaa\x54\xc1\x38\xc7\xe6\xd5\xf0\x64\xf3\xec\x55\x94\x2d\xc1\x92\xdd\x99\x6e\x55\x36\x33\xaf\xd6",
        p,
        q,
        g,
        b"\x38\x59\xd4\x73\x5c\x14\xba\xee\xc1\x4b\x79\xcc\x26\x93\xff\xca\xc9\x00\xa2\xc2\x6e\xc6\x34\xa8\xe9\x77\xd2\x06\xad\x6e\xc7\xb1\x3f\x2d\x45\x0e\xf0\x47\x82\xec\x0a\xbb\x0d\xa4\x8f\x00\x06\x28\xce\xc1\xf6\xe9\xa7\x27\xbb\x59\xd7\xc0\xf0\xd7\x43\xf5\x13\xac\x09\x25\xbe\xb6\x1b\xf3\xad\x75\x82\x4f\xff\xae\x1e\xb7\x83\xeb\x1b\x68\xfc\x40\xd2\x87\x70\xe2\x80\xfd\xe2\x38\x44\xa1\x44\xd4\xb1\xa9\x54\x09\xb7\x55\xc7\xff\x2e\x5c\x67\x81\x1f\x3b\x1c\x2e\xb9\x6c\xb1\x59\xa6\x42\xd8\x4d\xd7\xb5\xdc\xcc\x2c\x0a\xef\x06\xd1\xcd\x54\xea\xc9\x4a\x11\x27\x3f\x94\x98\xf1\xe7\xa7\xcd\x79\xc1\x08\xe4\x96\xdc\xf5\x73\xef\x3a\x66\x10\xb7\x73\x1a\xb1\x4c\x16\x2c\xe8\x37\x7c\xb9\xb9\x07\x88\xe3\x56\xf5\x1f\x4b\x51\xa1\xec\x8b\xd8\x6b\xd8\x8f\xd4\xc3\x8e\x62\xca\xd6\x19\xab\x89\x41\xbc\xb9\x8a\x2f\x35\xee\x51\x2f\x4f\x8f\xfd\xd5\xee\x70\xca\xed\x84\x67\x15\x6b\x89\x3b\x35\x32\xa0\xa2\xaa\x51\x99\xce\xae\xcc\x5b\x19\x4b\xc0\x57\x96\x4c\xf4\x50\x66\x8c\x44\xf2\x7e\xc8\x0d\xe2\x1e\xa1\xa4\x15\xee\x6a\x65\x69\x83\x23\x94\xf6\xb4\x05\xd1",
        b"\x44\x36\x44\xe1\x27\xe3\x81\xb1\x7b\xb6\x6c\x53\x50\x97\x18\xa5\x8a\x30\xf9\x27\x42\x58\x06\xa6\x28\x40\x11\x9e\x78\xc2\x93\xb7",
        b"\x3f\x01\xe5\xd1\xe9\xfd\xb1\xcf\xda\x25\xef\xf3\xca\xcc\xf4\xed\xf5\x99\xfe\xa2\x77\x20\x1c\xf2\xb0\x1f\xfd\x7c\xb1\xa9\xa7\x27",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xb8\x8c\x21\x20\x70\xbe\x39\x8a\x1f\x81\xe8\x5d\xfd\x71\xdc\x24\x24\xa3\x8a\xe3\x8a\x9d\x61\x08\x51\x86\x50\x4f\x4c\x2c\xbf\xa4\x92\xb7\x6d\xbc\xc0\x51\xce\xfd\xe0\x61\x6a\x7e\x33\x10\xb4\xbf\x17\x24\x4d\xe7\xd1\x0f\x84\x7c\xe2\xa9\xf6\x65\x94\x8e\x76\x72\x4d\x8f\x1f\x4b\xb3\xa6\x19\x19\xb2\xec\x7d\xc4\x7a\xd8\xa7\x2c\xb5\x99\x8b\x79\xfe\x3a\x15\x63\x95\xe4\xae\x88\xe6\x82\xb1\xdd\x16\xc5\x2d\x64\xcb\x4b\x31\xc3\x9d\x4a\x42\xa2\x1e\x62\x42\xdc\x0c\xdb\xb0\xac\xf3\xd4\x71\x82\x63\x8c\x5f\x21\x6d\xc6\xe8\xb1",
        p,
        q,
        g,
        b"\x54\x1c\x69\x0f\x4c\xa0\xc4\x2e\x52\x67\x64\x6f\x78\xef\x42\xfd\x68\xc3\x63\x37\x5b\x2e\x98\x3b\xe4\x44\xe4\x81\x9e\x63\xcd\xc1\x29\x01\x8b\xd3\xb8\xc6\xda\x8b\x70\x7c\x19\x6c\x35\xc9\x3e\xab\xee\x10\xe8\x75\xc4\x1f\xd9\x25\xbb\x3c\xe8\x06\x96\x93\x5d\x16\x31\x3f\xd3\xa2\x68\x58\xec\xcf\x2d\x50\x7f\xc2\xa1\x09\x50\x52\x5c\x67\x0d\xad\xc8\x83\xdc\x67\x79\xac\x1c\xe8\x66\xd8\x82\x03\x95\xf3\x54\x1c\x86\x30\x18\x33\x7a\x6b\xe9\x44\xdd\xc6\x44\xaa\xa6\xc0\x07\x19\x7d\x7a\x5f\x9a\xa5\x3a\x5e\x11\x80\xad\x51\xc9\x8b\xe9\xd5\x61\xa8\x5f\xe9\x73\x41\x60\xca\x35\xe4\xfa\xdb\x02\x52\x7b\xa0\xfa\x58\x04\x1b\x4d\x96\x38\x5f\x7f\x8f\xf6\xae\x75\x6a\xdd\x49\x68\xc0\xc2\x79\x9c\x0d\x68\x0f\x66\xc8\xce\x96\xf4\x98\x22\x87\x38\xe3\xe8\x7b\x7c\x86\x63\x44\xdb\x7d\x5a\x4e\xc3\x28\x24\x31\xae\xe5\x95\x1d\x9b\x4c\x83\xec\x2a\x0c\xda\x36\xcb\x2e\x2c\x43\x73\x63\xce\xba\x4e\x8e\x9f\x61\x28\x43\x9d\x12\xc5\x18\x68\xd0\xcb\x1f\x61\xe5\x3a\x68\xd4\xe7\x1c\x5a\x9e\x7d\xe4\x3c\x6d\xfc\xa2\x6f\x17\x41\xac\xa9\x16\xe4\x28\x26\x53\xbf\xc1",
        b"\x07\x8a\x71\x46\xa2\xc5\x09\xb9\x7a\x6a\x8c\x96\x3b\xaf\x1f\xbf\xbd\x1a\x2a\x5a\xa2\x14\xa1\x5e\xa4\x57\x63\xf0\xe7\x93\x0b\xeb",
        b"\x29\x79\xcb\xf5\x9a\xdb\x70\xf2\x8a\xc4\xfc\xb6\x92\x97\x49\x8f\x81\x63\x76\x4c\x62\xb3\x19\x63\xda\x9c\x8f\x9c\x0c\x43\xe0\x75",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x4a\xdf\x1e\xd4\xfb\xb5\xb8\x2d\x7a\x2b\x1a\x29\x38\x43\x07\x53\xa6\x20\x7d\xa1\xcc\x04\x95\x74\xf0\xa1\x93\x14\x27\x2f\x9a\x80\xc6\xa5\x34\x98\xb7\x8e\x5c\x0b\x74\x01\xce\x48\x5f\xd4\xba\xeb\xc9\x66\xda\x6c\x1f\xcb\x02\x58\x16\xcf\xae\x32\xb5\x8a\xa8\x7f\x5e\x88\x85\x05\x47\x35\xf9\x3d\xf1\x9e\xd3\x2c\x81\x97\x86\xd4\x10\x9d\xbd\xa0\x47\xd6\x8c\x05\x89\x33\x07\x15\xe1\x05\x22\x64\x3b\xbe\x27\xe3\x2c\x0d\xc9\xc5\x83\x36\xbe\x30\x5b\x4c\x0c\x98\x1b\x40\xe0\xee\xda\x0d\xe4\x61\xd8\x44\x1c\x02\xc1\x8c\xea\xc5",
        p,
        q,
        g,
        b"\x8b\x69\x27\xfe\x29\x3a\xc9\x11\x1b\xa4\x06\x12\x5d\x6e\xbf\xbc\x30\xf9\x6c\xbf\xd6\x96\xfc\xac\x7d\xde\xd4\x23\x05\xc6\x10\x54\x53\xac\xcb\x1b\x0c\xa6\xf0\xf3\x16\x01\xf8\xc3\x4f\x96\xbb\x8e\xe4\xcc\xf1\x49\x92\x3a\x12\x82\x1d\xfa\xa2\xa3\x85\x9a\x39\xcf\x82\x56\x76\x09\xb2\x06\x0f\xf6\x09\x23\x2e\x90\x26\x1d\x66\xcf\x31\xfb\x92\x64\x67\x1f\x3f\x1b\xff\x6c\x8a\x95\x8e\x5c\xd0\x15\xdc\xc0\x2d\xfd\x2f\x02\xfb\x6a\x44\x3c\x2b\xf4\x5a\xbf\x13\x86\x20\x59\xdf\x98\x06\x6e\x00\x31\x1b\xb6\x43\x8b\x7f\xe2\xd9\x1e\x28\x75\x53\xd2\x54\x11\xf0\xfb\xa4\x74\x17\xc2\x90\x2f\x97\x8c\x57\x25\x7a\xe4\xea\xa3\xf9\x93\x17\xd5\xad\xee\x0f\x9a\xdf\x4d\x41\xe4\x10\x72\x55\x2b\x3f\x51\xeb\x99\x36\xa7\xf6\x3c\xc2\x8b\x46\x6f\xab\x64\x29\xd0\x68\x68\xd1\x8c\xa0\x9a\xba\x63\x40\x93\x76\x71\x92\x04\x9b\x02\xbc\xb7\x52\xeb\x67\x4c\x98\xa8\x68\x69\xd6\x72\x6f\x74\x2e\x57\xef\x8c\x3d\x45\x31\x17\x1c\x64\xf0\x3e\x10\xa4\xe4\x40\x39\xa4\x4d\x40\x7e\xbf\xc6\xb5\x6a\x7c\xdf\x6b\x17\x39\x4b\x53\xb5\x60\x43\x47\xc5\x1c\xf3\x75\x55\x1b\x73\x06",
        b"\x5b\x20\x11\x16\xd8\xbb\xc8\x7d\xb9\x90\x01\x70\x7b\x56\x7e\x7c\x34\x51\xd8\x02\xfa\x6c\x67\x9b\xf3\xdb\x34\x56\x71\x1a\x19\x13",
        b"\x5b\xe7\xe4\xc4\x93\xfd\x5d\x19\xb7\x71\x37\x31\x41\x29\x4d\xaa\xd9\x76\x56\xa3\xdb\xe3\xfd\x2a\xbb\xd3\xb6\xc6\x2c\x16\x61\x26",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xbd\x49\x1c\xf6\x8b\x34\xf7\xba\x9a\xfe\x0c\x6e\xf5\xf2\xb7\x95\x6e\xf9\x64\x46\x5f\x28\xb2\x79\x7b\xc1\xd6\xe6\x70\xa6\xd8\x17\x30\xee\x29\x93\xd0\xb4\xaa\x96\x90\x51\x57\x02\x5d\x77\x5b\xa1\x04\xe7\xc1\x9b\x3b\x37\x2e\x85\x20\x26\xb1\x28\x6c\xbc\x6a\x48\xa1\x0c\xb9\x37\x8e\x97\xad\x96\x6f\x9c\xf0\x39\x17\xee\x8d\xb7\x5b\x62\x64\xe9\xb0\xa4\x8a\x0a\xe1\x0c\x2f\x46\x44\x47\x10\xd4\x23\x41\x26\xce\x45\x6b\x9f\xd1\x1a\xb7\xa3\x50\x49\x48\xd0\x46\xd5\xf4\x38\xd8\x93\xd9\xb1\x05\x2b\x8f\xac\x95\x47\x41\x54\x72",
        p,
        q,
        g,
        b"\xa9\x2e\x44\x65\x10\x76\x4e\xe1\xcf\x81\xc6\xb5\x9b\x51\x60\xa7\x60\x8f\xf8\x95\x2d\x04\x5d\xd6\x9f\x03\x4f\xdf\xef\x93\xf6\x33\x60\x7e\xc2\x09\xb1\x06\xc6\xac\x8f\x0c\xc6\xff\xa6\x4b\xb9\xa4\x48\x45\x60\xb8\x38\xd6\xf2\x4c\x99\x3a\x95\x4e\xfc\x9d\x5e\xe1\x66\x56\xaa\xba\x2a\x0d\x5a\x94\xe7\xa3\x46\xc7\xe5\x01\xaf\x83\xf1\x31\xdb\x9e\x0c\xab\x87\x89\xfa\xb1\x9b\xd5\x91\xec\x22\x7f\x39\xb3\x49\xbe\x7f\x8d\x0d\xf5\x8c\xa0\x39\x6e\xfb\x1e\x76\x54\x93\x35\x90\x4b\x88\xec\x21\xcd\x32\x65\xc5\x43\xc4\xe8\x0e\x9d\xde\x7c\xb5\xc9\xea\x8c\xdd\xa2\x3d\x96\xef\x1c\x38\x39\xad\xe8\xed\x4a\x5c\xd5\xfd\x98\xb7\x9b\xce\xee\xd9\xc6\x41\xc5\xa7\x75\x8d\x05\x29\xac\xea\xf2\x7b\x50\x14\xf1\x3d\xfc\xaa\x26\x7a\x14\xa0\x84\x1b\x36\x89\x7b\x6e\x1e\x89\x17\xb7\xf7\xcb\xf7\xcf\xf1\xd1\x95\x3a\xc4\x3c\xc0\x4a\xb0\x6c\xf1\x11\xe0\x06\x49\x7e\xb4\x2f\x28\xcb\xc9\x05\xd6\xf1\xcd\x5d\x83\x94\x85\x79\x83\xe1\xc9\xe5\x52\x01\x5a\x45\x1d\x0c\x13\xa6\x84\x8a\x8f\xc5\x6b\x79\xde\xc1\x72\x3a\x80\x67\xff\x18\x93\x1c\x85\x2c\xeb\x81\xaf\xfe\xc1",
        b"\x0c\xf5\x26\xd8\xa0\xf9\xc9\x12\xd1\x43\xf3\xf8\xaf\xde\xd4\x59\x8b\x2a\x5a\xaf\x20\x0e\x07\x49\xea\x27\xde\xfe\xb7\xf2\x8f\x3a",
        b"\x87\x7a\x90\x66\xf6\xc5\xae\x78\x25\x1d\x9d\x14\x0b\xcf\x39\xae\x91\x2d\x18\xbf\x13\x1b\xdc\x7e\x9d\x61\x01\x2d\xaa\xa4\x29\x2c",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xc0\x0a\x8a\x2f\xff\xd1\x0b\xc2\xea\xb6\x3b\x8e\x37\x5d\x0c\x10\xf9\xdf\xae\x28\x48\xba\x42\xaf\xe6\x08\x5a\xee\xc2\x6e\x21\xaf\x3e\xaa\x49\x3c\xe4\xb3\xd9\x5a\x31\xfa\x50\x2a\x60\xab\x88\xe8\x05\xf4\xfd\xf8\x89\xed\x91\xc1\x54\x21\x71\x80\x84\xcd\x0d\x64\x47\x95\x74\x9b\x1a\x6b\x18\x3d\x74\x78\x2d\x52\xc7\xba\xbf\x74\x00\x39\x3c\xee\x69\x8a\xf5\xdc\x01\x0c\x0f\xf7\xf5\xac\xdf\x02\x08\xf9\x3e\xe7\xe4\xef\x58\xda\x12\x3d\xfd\xe7\xf0\xa3\x4e\x20\x9b\xba\xec\x61\x00\x72\x93\xfd\x11\xaf\xa6\x0b\x65\x22\xc4\x5d",
        p,
        q,
        g,
        b"\x75\x60\x10\x5b\x85\x86\xc4\x53\x2b\xf1\xb5\x1e\x0d\x2c\xf9\xa7\x13\xa5\xea\x5d\x40\xe2\x62\xce\x01\xeb\xda\xf1\xee\x53\xd8\x57\x12\x9e\x15\x29\xa0\xf8\xdf\xf6\x3e\x86\x20\x2c\x11\x1c\x6e\xb2\x89\x43\x9c\xb1\x5c\xd5\x9f\xc2\x18\xab\xe6\x19\xc9\x51\x62\x50\xf1\x27\xfa\xfe\x9a\x53\x07\x62\x74\xf3\x06\xf0\xb7\x87\x1c\xff\xbd\x15\x6b\x1a\x88\x19\x79\x5f\x0a\x99\x55\x86\x47\x56\x65\x02\x74\xb8\x3e\x67\xca\xa4\xe2\x15\xf8\x33\xaf\xd5\xa7\x7d\x05\x94\xb2\x1b\x4b\x54\x35\x6a\x98\xa5\x6a\x0b\xf6\x17\x7f\xaf\xfb\x9f\xdf\xd8\x88\xd6\x53\x8a\x1c\xe7\x60\x59\x85\x4b\xd1\xf0\xa2\x07\x61\x28\x1d\x7b\x75\x17\x57\xc6\xec\xc9\xb1\xe8\x13\x11\x96\xd0\x66\x95\x97\x21\x3a\xe7\x3e\xdb\x99\x65\xda\x9f\xf3\x72\x42\x08\x51\x15\x50\x11\xf6\x91\xa0\x3a\x7f\x1e\x20\x40\x29\x15\x75\xb8\x6f\x59\x59\x98\xa0\x6e\xf7\x9f\x4e\xad\xba\xe2\xbd\x9e\x2e\x47\x7d\xd7\x26\x84\xd8\xef\xdc\x1e\x83\x5f\x7f\x0f\x5c\x93\x63\x5c\x18\x1b\x96\xcc\x7c\x0e\xaa\x27\xee\x62\xc9\x22\x7e\xd9\x48\x5a\x8c\x82\x2b\x32\x24\xe9\xe2\xb7\xac\xc1\x09\x56\xf3\xd4\x9a\x6f",
        b"\x98\xfe\xe1\x0c\x85\xab\x46\xd3\x34\x75\x87\x34\x81\x9e\x68\xb5\x04\x64\x39\xcd\x0b\x66\xbe\x26\xd4\x37\x60\x61\x3a\xc7\x7b\x8c",
        b"\x66\x5f\xab\x98\xdd\x43\x7e\x06\xa4\xf8\x77\xee\x21\x89\x86\xe3\x7c\x2c\xb2\xd2\x37\xe5\x98\xd9\x8f\x1b\x7d\x4e\x82\x9a\x84\x6b",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x27\xf0\x1b\x47\xd1\x5f\x7d\x19\x6f\x26\x67\xb7\x5e\xd1\x5b\x89\xd7\x44\x3f\xb4\xfa\xb0\x68\xf4\xad\xb6\x71\x75\xca\x70\x07\x1d\x52\xe2\x70\xf6\x89\x64\xf9\xfb\x0e\x0e\x14\xed\x5d\x29\x54\xa3\x3d\x93\x80\x7a\xcf\x3c\x82\x50\x0e\x8b\x9f\x5f\xc5\x51\x0c\xc3\xbd\x6a\xaa\x1d\xaa\xc8\x30\x91\x28\xef\x4c\x0b\x4c\xac\x02\x64\x25\xae\xfd\xd7\xe6\x9c\x22\xc3\x2e\x5f\x8d\x2a\x6e\x8f\x2e\xa2\x91\xac\x33\xda\x6c\x71\xa1\x95\x3e\x44\x3c\x0e\xa2\x06\x56\x8a\xad\xef\x2b\x96\x46\x6c\xbf\x76\xbf\x14\x9d\x89\xd8\x6f\x52\x9f",
        p,
        q,
        g,
        b"\x38\xfa\x99\x4a\x1f\x61\xab\x79\xee\x7a\x7e\x6f\x68\x9c\x38\xf6\xc2\x82\x6f\x06\x64\x7b\x16\x63\xcd\x81\x2a\xdb\x36\xd7\xfd\x7c\xcc\x50\xe9\xa9\x0d\x02\xbf\x7c\x3f\x12\xa2\x28\xc6\x92\xc0\x56\xfb\x3b\xd6\x08\xf5\x1a\xa4\x01\x02\x2c\x83\x97\x91\xe6\xa6\x78\x18\x5c\xd3\x1d\x88\xcc\x66\x1a\xf2\x9e\x5d\x23\x81\x42\x18\x1d\xd3\xf6\xe7\xc8\xb0\x57\x85\x22\x1e\x62\xfd\xb3\x6c\x71\xe0\x7f\x51\xd7\x32\xe7\xe0\xca\xb5\x20\xa7\xf2\xfc\x5b\x18\x31\xb0\xa6\xba\x28\x0e\x00\x32\x1c\xb9\xa0\x25\xdb\x65\x38\xab\xd6\x72\x46\x3d\xbf\xf5\xca\x81\x99\x36\x76\xbc\xba\xf0\xf6\xe9\xc7\x54\xf2\x4d\x65\x4e\xe7\x87\x9b\xc0\x3d\x7d\x4b\xc8\xe8\xca\x58\xfb\x9b\x39\x29\xa3\xc3\x83\x65\xcd\x2e\x20\x57\x29\xe9\xde\xf0\xa0\x01\x08\xdf\xfe\x94\x07\x27\x1e\x17\xd3\x55\xec\x4b\x29\x00\x3e\x0c\xaf\x0c\x5b\x2a\xcb\x9b\xd8\xe5\x2d\x44\x10\xba\xa9\xb9\x7a\x49\x87\x4c\x14\xbe\xeb\xf0\x3a\xbf\x28\xa9\xec\x59\xbc\x17\x38\xb8\xdd\x42\x23\xd4\x7a\xa3\x36\xac\xbc\xa7\x66\x2f\xc6\x9a\x6f\xef\xee\xcf\xfd\x47\xf6\x73\x7e\xcd\xa3\x31\xd1\xba\x5c\xdf\x02\x3d",
        b"\x8d\xad\x02\xc0\x2a\xd3\x4f\xe4\xe7\x58\xff\x5c\x81\xd5\x38\x4c\x40\xd2\xc4\x9d\x0a\xc7\x77\xba\xd1\xcd\xeb\xc5\x8e\xc0\x1c\xfd",
        b"\x0f\xe4\xe1\xf6\x87\x5c\x11\x3f\x1c\x17\xa0\xf0\xed\x22\x8d\x44\x21\x3f\x8d\x7e\x2f\x15\x56\x7e\x57\xce\xb2\xe8\xb1\x09\x8f\x7d",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x73\xcc\x5e\x4a\x18\x8d\x28\x14\x46\x69\x41\x38\x90\x14\xea\x45\xa1\xa0\x65\x25\xd2\x06\x9c\xf4\x88\x3e\xbc\xb5\xf2\x2a\xb1\x28\xc0\x0f\x04\x1c\xf6\x9f\xd9\x4b\x33\xfd\xad\xe7\x85\x48\xf6\x52\x3c\x83\x8b\x87\xcc\xd8\x68\xf3\xd3\xd0\xa9\xa0\x00\xf2\x78\xba\x54\x04\x8b\x9c\xad\xac\x7a\x99\xd9\x8d\xef\x51\x71\x31\x91\xad\x83\xe5\x23\x2e\x3e\x86\x49\x72\x45\xc8\x0b\xc7\x10\xfd\xd7\xfa\xaa\xd8\x8c\xe9\x2c\x89\x4f\x8c\xad\x3d\xe0\x07\x5c\xab\xa3\x37\xa2\x22\xcb\x7a\x3d\x7c\x2d\x93\x7b\xcf\xe4\xb6\xe6\x9d\x38\x8d",
        p,
        q,
        g,
        b"\x52\x66\x42\x7a\xd4\xc1\xcf\x3e\xa2\x29\x37\x7a\xd3\x97\xc7\xd5\x61\x35\x12\xfc\x27\xf2\xce\x37\x40\x7d\x2c\xea\x8e\x19\x99\xae\xbb\x8f\x37\x67\xee\x96\xcb\x92\x7e\xbd\xd4\x3b\x8d\xbc\x10\xba\x2c\x47\x84\x3d\x3f\x43\x36\x8d\x9e\x44\x2b\xf5\x1e\xbc\xf2\x0b\x48\xb5\x43\xa4\xc3\x88\xbb\x3a\xe3\xe4\x02\x7a\xcb\x65\x7d\x1b\xf7\x4a\xbe\xb8\xb9\x98\x42\x13\x08\x77\x0f\x70\xb3\xf7\xb1\xd9\x10\x21\x9a\x12\x10\x26\x03\x40\x12\x3b\x95\xdb\xa1\x87\xe0\x0c\xb0\x67\xf7\xe3\x77\x92\x34\x12\x02\x55\x4b\xfc\x8a\x23\x5f\xc0\x1e\xcb\x09\x9e\xc3\x61\x5a\x67\xa3\x61\x0d\x4d\x8c\x2d\xad\x16\x08\x70\x24\xf5\x97\x3e\xb1\x84\x00\xc2\x9c\x05\xd6\x98\x4d\x1c\x15\xc1\x59\x42\x28\x27\xc0\xdb\xb2\xbf\x45\x09\xd7\x10\xc4\x97\x2e\xe9\x3b\xe7\x28\x3a\xad\xd9\x91\xae\x8e\xf0\xe9\x73\x12\x11\x8f\x19\x5d\x30\x4f\xbe\x96\xd5\xae\xbf\xb2\x12\x03\xea\xe6\x11\x78\x31\xf9\xbe\x90\x99\xd3\xd4\x76\xb8\x3f\x65\xab\x22\x5f\x8b\xe4\x93\xa8\xad\x21\x62\x0f\x25\x9d\x8a\x44\x20\x08\x10\xc8\xe5\x62\xae\xa8\xe7\xa6\xbc\x23\x8c\x12\x9b\x19\xf2\x53\x1a\x6a\xf0",
        b"\x77\x23\x6b\x33\xb0\x42\x85\x42\x57\x75\xee\x3f\x65\x8b\x37\x61\x29\x5c\xbf\xf8\xe4\xbc\x05\xab\xdd\x22\xe3\xd7\x8b\x1b\x6d\xa2",
        b"\x43\xfd\xbd\x93\x6a\xb4\x04\x59\xf6\x84\x30\x56\xca\x77\xe1\x25\xb6\xec\x5a\xd9\x45\x04\x1c\x1f\x6a\x27\x70\xbe\x9d\xfc\xc6\x82",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xc0\x74\x6b\xef\xd2\xaf\xc6\xca\x15\xcd\xb1\x45\xc1\x84\x62\xc5\x15\xbd\x42\x79\x4c\x4c\x7e\xe5\x13\xcd\x9a\xeb\x0f\xc6\xfc\x30\x48\xb6\xc7\x23\x16\x34\x98\x4a\x1b\xe8\x24\xc7\x75\xf9\xc9\xb0\x28\x25\x5f\x5b\x3c\x3d\x8f\xa0\x8d\x47\xab\xa0\x77\x55\xb5\xf1\xb5\xb0\x08\x93\x3e\xff\x35\x83\x8f\x15\xa0\x2b\xa9\x36\x6c\x10\x36\xd3\xff\x19\xe8\x81\x99\xef\x86\xa8\x82\x27\x27\x2c\xf4\xe4\xe0\x0f\xfa\xd9\xc3\x6b\xeb\xac\x30\x57\x8b\x00\x21\x4f\xb2\x9b\xae\x43\xcf\x55\x5e\xd4\x31\xa2\xf2\x49\x22\x43\x0b\x14\x96\xfb",
        p,
        q,
        g,
        b"\x43\x1e\xee\x49\x09\x0a\xd5\x8f\x4a\x87\x4c\x2e\xb5\x89\x79\x69\xfa\xfe\x32\x74\xbd\x74\x86\xb6\x5e\x35\x19\xe4\x30\x9d\x63\x6a\xce\x68\x64\xd5\xca\x4d\x84\x48\xa3\x57\xca\xfa\xc1\x5a\xc3\xcb\x3b\xd7\xb2\x75\x5b\x3c\xb6\xdb\x0a\xf1\xa4\xe9\x1b\x2d\x1f\xcb\x28\x56\x1b\x17\x0f\xaf\x2e\x06\x90\x07\x1b\xc0\xf6\xe4\x2b\x2d\x82\xab\xe5\x64\x6d\xdb\x8f\x9b\x99\xee\x1d\xaf\x59\x06\x03\x6f\x39\x5d\x82\x4d\x08\x0b\xfa\xea\x10\x30\x48\xb3\xf4\x4d\x06\x36\xbc\x7a\x6a\x88\xe9\xb0\x04\xa3\x63\xb9\x9d\x24\xa8\x9b\x6e\x97\x37\x9b\x20\xba\xcf\x48\xc7\xae\x2e\x9b\xf7\xe2\x81\xfe\x3b\x4d\x7e\xb9\x47\xa1\x02\x39\x6d\x52\x3a\x1e\x85\xce\x17\xfd\x25\xf2\x71\xf3\xc2\x21\xa5\x68\x1e\x9f\xb7\x7d\x64\xd6\x24\x10\x39\xac\x8a\x85\xda\x32\x74\x1b\xac\xf0\x06\x60\xe4\x21\xfe\x85\x0a\x0f\xe7\x3a\x08\xee\x3a\x9b\x06\x9c\x6d\x91\x14\xc1\x97\x52\x72\x12\x74\x68\xf9\x00\x85\x52\xea\x4c\xdf\x9d\x96\x56\x1e\xa6\x9a\x64\x66\x95\x24\x25\x00\xf2\x31\x8b\xda\x82\xda\x63\x3e\xf1\xae\x04\x97\x01\x4a\x63\x7b\x15\xa5\x72\xdd\xdd\xec\x07\x0d\x19\xd8\x84",
        b"\x79\x6d\x7d\xba\x32\x2d\x92\xa0\x83\xda\x7a\x58\x8f\xb6\x23\x8d\xc8\x6b\x1f\xc5\x10\x4e\xd6\x00\xc9\xb4\xc6\x88\xed\xf8\x05\xe9",
        b"\x01\x2c\x1f\xf4\xde\x8e\xe3\x86\xb9\x51\x27\x5e\x25\x05\x81\xd6\x61\xd0\x30\xa4\xd8\xfe\x11\x54\x32\x28\x8a\xb0\xa4\xbd\x46\xcb",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xb8\xb9\x15\xcf\x4e\xa3\xb0\xc4\xcd\xcd\x8b\x2a\x06\x47\x9e\x71\xbb\x47\x97\x29\x4b\x6c\x41\xca\x87\x0d\x3c\xb2\xec\x2c\xb5\xa4\x9f\x6b\xfe\x5b\xcd\x10\xbe\x60\x9e\xd3\xe1\x88\x2a\x31\x23\x95\xfc\x99\x13\x45\xab\xa5\xb5\x66\xe6\x79\x60\xb4\x29\x13\xdb\x66\x90\x41\xea\x30\xc2\x99\x47\xed\xde\x7b\xdc\xfc\x08\x96\xb9\x76\x60\x74\x0d\x6c\x79\xf0\x08\x86\x65\xf5\x1d\xad\xcf\xa0\x7f\x7b\xe4\x48\x21\xd6\x0a\x8f\xfd\xe4\xe5\xcb\x1f\x98\x13\x9f\xf9\x1c\x9c\x6f\x31\x26\x59\x63\x44\xc5\xf7\xef\xf4\x00\x49\xd3\xf9\xae",
        p,
        q,
        g,
        b"\x1b\x37\x22\x76\x42\x64\xe1\x79\x94\xf3\x34\x3b\xf2\x60\xc7\x35\x75\xd1\x06\xf6\x30\x7f\x2e\xaa\x3f\x7d\xcd\x5a\xf8\x04\x46\x3d\xdb\x6b\xbe\x38\xa3\x8f\x5a\xb5\xa8\xae\x67\x01\x31\x7c\xf6\xc2\x67\x04\x9f\xc9\xb8\x40\x78\x24\x1f\x82\xd3\xc6\xb7\xe5\xbe\xba\x5c\x14\x27\x03\x02\x97\xf1\xdf\x25\x81\x48\xe5\xf9\xeb\x41\xeb\x20\xa8\x68\x77\xfc\xc0\x6e\x53\x73\xcd\x50\x56\x26\x13\xd3\x07\x64\x95\x39\xd2\x8c\xb5\x24\x18\xd4\x2f\xd5\x97\x58\xb6\x11\x85\xe7\x92\x99\x2b\x5a\x58\x12\x29\xb4\x34\x03\xd7\x93\xb0\x4d\x87\x8e\xb9\xb9\xd1\x2e\xa1\x0d\x2e\x64\xd1\x53\xd3\xfa\x41\x88\x1f\xe7\x9a\x67\xac\x40\x8a\x53\x48\xd7\x92\x39\x56\x7d\xca\x96\xe1\xea\xd3\xc6\xac\x22\xdb\xcd\xbc\xb5\x18\x5b\xf8\xac\xe5\x76\x60\xa4\x25\x21\x04\xe5\x04\x7c\xac\x87\x85\x1d\x28\x15\xb1\x2a\xe8\xae\x96\xab\x2f\x33\x34\x5e\xa1\xcf\x5f\x2e\x58\xa4\xdd\xcb\xa2\x62\x65\xc0\x6d\xf6\x5a\xfc\xc6\xe8\x52\xb3\xf9\x10\xc8\x77\x8d\xe2\x8a\x9f\x09\x81\x58\xed\x0e\xca\x65\x2d\xda\x2f\x9f\x4a\xc8\xa1\x7a\x9b\x25\x24\x10\xec\x59\x73\xa6\x06\x3b\x64\x25\x68\xf1",
        b"\x6b\x4b\x0e\x1e\x7c\xbd\xef\xed\xb1\xdf\x1f\x52\x9e\xce\x47\x89\x1f\x7b\x9e\x95\x9a\x3f\x85\x56\xba\x4b\xef\x7b\xb9\x85\x65\x60",
        b"\x7e\x93\x3b\x44\xed\xe6\xb2\xe9\x41\xb6\x0c\x37\xdc\xd1\x56\x82\x84\xde\xf2\x29\xc0\xa2\xbb\x90\x93\xf4\x82\x90\x00\xc4\x40\x9a",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xdf\xfd\x45\x8a\x80\x8f\x18\x89\xd7\xf3\xd6\x19\x7f\x0e\x41\x92\x0a\xd7\x31\x12\x4c\xee\x30\x8c\xb9\x0d\x23\x61\xb2\x3f\xee\x96\x9c\x0e\x10\x58\x35\x54\x9e\x5d\x0a\x3f\x76\x90\xd5\x86\x2d\x4c\xd6\xcc\xb3\x3a\xd1\x80\x94\xc8\x5c\x96\x50\xd7\x5b\x24\x84\x96\x39\x0a\x0b\x89\xe7\xdc\x7d\xc0\xd3\xa6\x13\x0d\xd9\x77\x89\xeb\xf1\x05\xf8\xe5\x5d\x8f\x0a\x11\x62\xfb\x3c\x6b\x52\x9e\x2a\x80\xdd\x51\xe9\x04\x5e\xf8\xec\x42\xca\x4b\xc4\x6a\xbb\x65\x39\x58\x8b\x53\x1c\x97\x99\x56\x0c\xf4\xea\x80\x6c\x3d\x93\xd0\x43\xe5",
        p,
        q,
        g,
        b"\xea\x43\x7a\xd0\xee\x92\x64\xde\x87\x92\xb6\x77\x20\x7e\x54\x70\x90\xb3\x2d\x6a\xb4\x60\xb4\xd5\x89\xd8\x42\xed\x0a\x0b\x4f\xb4\xc6\x35\xe4\x44\x3b\xf6\x0e\x46\xcb\xa8\xd2\x26\xf6\x59\xc7\x6d\x2c\xa0\x1c\x69\x70\x7b\xa6\xd9\x77\x25\x5c\x45\x84\xb7\x47\x40\xa7\xcd\xec\x4c\x97\x3e\x3d\x16\xab\x6a\xf6\x0c\xd3\x12\x3c\xa1\x2e\xd5\x97\x1e\x69\xea\xff\xa3\xda\x07\x70\xd8\xe1\x22\x88\x89\xcd\x68\x25\xe1\xb8\x58\x46\xf4\xf7\xec\xdb\x33\xf1\xe5\xc7\xac\xd6\xb2\xad\xd1\x30\x8c\x5c\xec\x43\x97\x28\xd0\xcc\x62\x5e\xb8\x9d\xf3\x4f\xb9\xc0\xdd\x45\x68\xf9\x79\xde\xea\xd2\x86\xc5\x01\x45\x90\x3a\x0d\xcc\xca\x72\x39\x87\x4b\x46\x83\xd3\x67\xed\x31\x69\x6e\xec\xad\xa9\x0d\xce\xd8\xa9\xb1\xe0\x13\x64\xb8\x79\x46\x60\xc6\x0f\x40\x59\x07\x94\xc9\x5a\x61\x4c\x04\x56\x3c\x92\xd4\x44\xb5\xec\xf0\x12\x86\xb1\xbf\xfe\x9e\xd9\xef\x91\x5b\x4d\xb8\x20\xea\x5c\x9a\x5b\x3d\xed\xcf\x89\xa3\xe2\xc3\x78\x71\xd2\x1b\x76\x39\x90\xc7\xbb\xf4\x44\x18\xf9\x1c\xdb\xce\x43\x61\xee\xb2\x27\x51\x6c\xb3\x44\x40\x9d\x2c\x65\x1f\x0d\xc2\x9e\xc8\x26\x23",
        b"\x31\x52\xfc\x28\x6f\xed\x44\xf2\x8b\x1a\xf2\xd5\x37\x59\x2c\x56\x91\xd6\x79\x8c\xae\xd9\x05\x91\xb5\x88\x8b\x0d\x6f\xe6\xbb\x07",
        b"\x7b\xff\x61\xa8\x67\x6f\x0d\xf1\x89\x65\x4f\x25\xc5\x81\x2b\x34\x1d\xd1\x7f\x4f\x44\x66\x77\x89\xcc\x88\x7c\x19\x1b\xf4\x72\x02",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xa6\x51\x60\x19\x72\x7d\x95\x63\x9d\xb0\x38\xf9\x03\x06\xa8\xd9\x4f\xac\x52\x43\xdc\x7b\x67\xc3\x56\x8d\x63\xd8\x5d\xea\xd1\xcf\xdd\xbb\x2b\x33\x0b\x61\x95\x89\xbd\x58\x2a\xf1\x5f\x08\x11\x17\x75\x04\xfd\x5b\x7a\xad\x7b\x29\x86\x47\xa3\xf6\x47\x97\xe3\xda\x5f\xe5\xbf\x87\xb6\x5c\x2d\xde\xc5\x76\xa8\xf4\x06\x60\x68\x6b\x80\x8b\xa4\x2e\x54\xbf\xd0\xe9\xe4\x80\x82\xd6\x90\x4f\x8e\x19\x05\x0e\x54\xea\x47\x97\xa2\xf4\x01\xff\x7c\x9f\x3d\x21\x7b\x52\x6c\x03\xbe\x92\x01\xc0\xdc\x1b\x0e\x8e\x05\x4b\xbb\x32\xc3\x82",
        p,
        q,
        g,
        b"\x97\x79\xeb\x53\x38\xdc\xae\x73\x77\xb1\x84\x70\x18\xce\x72\xc1\xed\x4c\x55\x29\x2a\x96\x3f\x81\x60\x8e\xf3\x32\x05\x0f\x0a\x48\x45\x19\xaa\x96\xb1\x8b\xcc\xe8\xe1\xb4\x9c\x11\xa2\x00\xc1\xab\x4a\x75\x72\x6b\xcc\x84\x24\x85\xdf\x63\x14\xe5\xc3\x9f\xec\x62\x2d\x81\x94\x34\x29\x4d\xbe\x1e\xb6\x47\x88\x5c\xe8\x41\x52\x7c\x03\x48\x1b\x7f\x22\xee\x58\x6d\x8c\x2b\x1a\x84\x71\xa2\x75\x7b\xff\xbd\xd9\xc2\x6f\x12\x50\x65\x68\x55\x09\xff\x0e\x4c\x8b\x82\x6d\x73\xc6\xe1\x2f\x6d\x4b\x93\x19\xcd\xfa\x72\xc0\x69\xe0\x7b\x2d\x2c\x25\x4b\x33\x0c\x06\xf4\x88\xd6\x59\x8c\x74\x76\xce\x0f\x33\x30\xc9\x7e\xc3\x6b\x7c\x10\x87\x13\x88\x47\x24\x51\xa3\x4a\xfb\x7b\x4d\x4e\x25\x1f\x9f\x72\xa4\xa3\x8a\x68\x51\xaa\xb8\x65\x07\xb2\x83\xe8\x90\xc3\x1b\xa9\x6d\x0a\x1e\x55\x72\x63\x7b\x2d\x84\x67\x06\x0c\x07\x36\xd1\x1d\x07\x44\xe3\x32\xa1\x9f\x59\xae\x29\x20\x89\x4e\x9c\xff\xac\xfe\xda\x64\xae\x1f\xf4\x86\x98\x82\xdf\x3b\x69\x0c\x7c\xe8\xfe\x0e\xb8\x81\x71\xe4\xf2\xab\x86\x24\xe6\xac\x77\xdc\x89\x07\x61\x32\x35\x16\x3e\x0a\x2c\x7d\x9f\xd6",
        b"\x72\x22\xd5\xeb\x39\x24\x60\xde\xfe\x8f\xe3\xdf\x18\xfa\x53\x4f\x30\x60\x23\x5f\x1e\x8d\xce\x53\x70\x76\x2e\xc6\xfc\x11\xe6\x90",
        b"\x43\x51\xc4\x28\x03\x1c\xd9\xaf\x56\x7b\x11\x63\x03\x7a\x4e\x37\x69\x62\x62\x0c\x4e\xc2\x3c\x43\xb7\x10\x58\x79\xf9\x5b\xf6\x14",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x1f\xfa\x7c\xf5\x5f\x92\xf2\x34\xa2\x4b\xd3\x29\x67\x44\xd5\x43\xa4\x33\xc9\x07\xc1\xf7\x7d\x8b\x70\x6f\x4b\x62\x62\xd0\x96\xe2\xdf\xe7\x13\xfa\x9c\xa8\x0e\x68\x57\x93\x96\xfc\x11\xa1\x2c\x03\x31\xcf\xb7\x74\x5d\x96\xb0\x05\x20\x4e\x48\x3f\xbf\x8f\x9f\xdc\x45\x8e\x2c\xa8\x61\x34\x06\x06\x9d\xf5\xf4\x49\x18\xef\xf8\xc5\xf5\x4b\x8b\x4d\x97\x2e\x07\xa4\xb8\xe0\x6d\x84\x26\xa7\x08\x74\xce\xfe\x6e\x93\x40\x4c\x1e\xb3\x81\xc2\xd0\x70\x1c\x37\xf8\x5a\xfb\x16\x01\xa0\x9f\xff\x8e\xcf\xda\xf6\xcb\x64\xad\x9b\xd8\xb7",
        p,
        q,
        g,
        b"\x18\xe2\x98\xe6\x30\x13\x89\xd4\x86\x44\x67\x4f\x83\x39\x48\x7a\x86\x51\xb0\x76\x8d\xee\x42\x59\x05\xe8\x03\xab\x35\x7c\x7f\x9f\xa0\x5d\xd5\xe2\xee\x84\xbf\xe1\x05\xa0\x92\x71\x62\x74\x55\x7e\x06\x3d\x08\x6e\x78\xb7\x81\xa4\x3c\x56\xa4\xe0\xea\x11\x5c\x5c\xfe\xac\x57\xa4\xc9\xb7\xe1\xef\xfb\x89\x41\x36\x89\x92\x8f\x15\x46\xfe\xb3\x07\x38\x58\x6d\x36\xff\xe3\x38\x08\x3e\xe2\xbf\x5c\x5b\xd3\x44\xbc\x3d\xb2\xa7\x97\x7d\xe2\xb1\xab\x5b\xa0\x06\xd9\xee\x93\xef\x86\x88\xa7\xd1\x0c\xaf\xe2\x7a\xf3\xe6\x71\x01\x3a\x81\x69\x84\x19\x6b\xfa\xcf\x00\x23\x35\xfe\x74\x14\x42\x3e\xd8\xbd\xc8\x03\x27\x37\x2b\x0d\x46\x08\x66\x48\x0b\xdf\x07\x3c\x9d\xef\x79\x77\x13\x1b\x06\xe2\x8d\x14\xae\x1a\x81\x6d\x32\x22\xeb\xaa\xdc\xc8\xd7\xc3\x00\xaa\x82\x0e\x03\x28\xaf\x66\xf7\x42\x06\x1a\xff\x5d\x4b\x71\x76\xa9\x94\xad\x69\xb3\x90\xbb\xdd\x61\x9f\xce\x04\x7d\xc7\xd1\x5a\x48\xea\x71\xaf\xa7\x20\x40\xbb\x14\xee\xaf\x4a\x2b\x23\xd9\x9b\x4d\x97\x7b\xeb\x6d\x80\x61\x01\x02\x1e\xb0\xc3\xa0\xe3\x1e\x54\x57\x9e\x58\xc9\x53\xb5\x5b\x6e\x32\x45",
        b"\x21\xd7\x0e\xd9\x55\xb0\x9e\xa3\x02\xfb\x79\x29\x78\xd1\x25\x01\x07\x1a\x2e\x8e\x2c\xc8\xf6\x59\xde\xcd\x3d\xf2\x4e\x37\xc4\x66",
        b"\x2c\xda\xae\xe2\xa5\xa3\xdd\x74\xa6\x77\x95\xf9\x3a\xc1\xd8\x41\x62\x23\x83\x6c\x76\xf7\xfe\x31\xc7\x2e\xc6\x17\x09\x25\xfd\x73",
    )?;

    // [mod = L=3072, N=256, SHA-1]
    let p = b"\xfd\x5a\x6c\x56\xdd\x29\x0f\x7d\xd8\x4a\x29\xde\x17\x12\x6e\xb4\xe4\x48\x7b\x3e\xff\x0a\x44\xab\xe5\xc5\x97\x92\xd2\xe1\x20\x0b\x9c\x3d\xb4\x4d\x52\x8b\x9f\x7d\x22\x48\x03\x2e\x4b\xa0\xf7\xbf\xc4\xfa\xfc\x70\x6b\xe5\x11\xdb\x22\x76\xc0\xb7\xec\xff\xd3\x8d\xa2\xe1\xc2\xf2\x37\xa7\x53\x90\xc1\xe4\xd3\x23\x9c\xba\x8e\x20\xe5\x58\x40\xec\xb0\x5d\xf5\xf0\x1a\x1b\x69\x77\xad\x19\x06\xf2\xcb\x54\x4c\xcf\xb9\x3b\x90\x1a\xd0\x96\x6b\x18\x32\xad\x2d\xab\x52\x62\x44\xa3\x15\x6c\x90\x5c\x01\xac\x51\xcb\x73\xb9\xdc\xd9\x86\x0d\x56\x17\x5a\x42\x5d\x84\x64\x85\xd9\xb1\xf4\x4a\x8a\x0c\x25\x78\xe6\xcf\x61\x94\x7b\xc1\xa1\x39\x2f\xdd\x32\x0b\x16\xa9\xd7\x04\x55\xfe\x43\x6f\x2d\x47\xde\xd8\xe8\xe6\x05\xf7\x48\x6e\xb5\x78\xea\x7f\xc4\xff\xd1\x3c\x07\xf9\x99\x6a\xf1\x59\xfd\x41\x1e\x94\x51\x40\x32\x78\xdd\x11\x41\xa8\xc9\x26\xb3\x5c\x96\x38\x4b\xbd\x6b\xee\x09\xc4\x6f\x44\xc3\x6b\x1f\xfc\x71\x97\xf5\xe9\x25\xdb\xe0\x54\x4a\x68\xe6\xab\x8c\x18\xe4\x26\xa4\x66\xb3\x92\xf9\xc2\x7d\xd7\x9f\xef\xa9\xca\x16\x3c\xc5\xa3\x75\x53\x9a\x85\x59\xf2\x77\xf6\x57\xa5\x35\xd1\x96\x4c\x6a\x5e\x91\x68\x3e\xf5\x69\x8e\xba\xa0\x1e\xf8\x18\xdb\xf7\x2c\xb0\x4c\x3f\xf0\x92\xd1\x88\x86\x6f\x25\xcd\x40\x51\x08\xf5\x66\xb0\x87\xf7\x3d\x2d\x5b\xeb\x51\xfa\xc6\xde\x84\xae\x51\x61\xa6\x6a\xf9\x60\x2c\x7e\x4b\xfc\x14\x6f\x48\x20\xbd\xfc\x09\x2f\xae\xac\x69\x13\x3e\x4a\x08\xa5\xb2\x02\xa1\x24\x98\xa2\x2e\x57\xba\xd5\x46\x74\xed\x4b\x51\x01\x09\xd5\x2b\x5f\x74\xe7\x0e\x1f\x6f\x82\x16\x17\x18\xcd\x4c\xf0\x0c\xc9\xf1\x95\x8a\xcc\x8b\xdd\xcd\xfb\xd1\xfb\xe4\x6c\xd1";
    let q = b"\x80\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x33\x4a\x26\xdd\x8f\x49\xc6\x81\x1c\xe8\x1b\xb1\x34\x2b\x06\xe9\x80\xf6\x4b\x75";
    let g = b"\x99\xab\x03\x0a\x21\xa5\xc9\x81\x81\x74\x87\x21\x67\x64\x1c\x81\xc1\xe0\x3c\x9b\x27\x4c\xfb\xc2\x7b\xc4\x72\x54\x29\x27\x76\x6d\xe5\xfa\x05\x39\xb3\xb7\x3f\x3f\x16\xac\x86\x6a\x9a\xec\x8b\x44\x5d\xed\x97\xfb\xff\x08\x83\x4e\xd9\x8c\x77\xe7\xfc\x89\xe5\xdc\x65\x7b\xef\x76\x6f\xf7\xfb\xf8\xe7\x68\x73\xe1\x7b\xee\x41\x27\x62\xd5\x6f\xe1\x14\x17\x60\xab\x4d\x25\xba\xfd\x4b\x6e\xf2\x5b\x49\xa3\x50\x66\x32\xd1\xf8\xe1\x07\x70\x93\x07\x60\xec\x13\x25\x93\x2c\x5a\x4b\xaf\x9e\x90\x15\x42\x64\xdd\xf4\x42\xec\x5c\x41\xfe\xd9\x5d\x11\x52\x51\x51\xdb\xcf\xb3\x75\x81\x49\xba\xd8\x1c\x62\xb9\xcf\xf7\x81\x6b\x8f\x95\x3b\x8b\x7c\x02\x25\x90\xd1\x58\x4e\x92\x1d\xc9\x55\xf5\x32\x8a\xc7\x29\x83\xed\x5c\xf0\xd0\x40\x56\xfe\x0d\x53\x1e\x62\xf8\xf6\xc9\xab\x3c\x0f\xcd\x44\xe1\x48\x60\xb7\x31\x1d\x25\x61\xc7\x7c\x1d\x32\xf6\xc6\x9d\xc8\xf7\x79\x68\xc9\xd8\x81\xad\x9d\xb5\xe0\xc1\x14\xfd\xa8\x62\x8b\xca\x03\x35\xeb\x7f\xb9\xe1\x5e\x62\x5a\xab\xab\x58\xfc\x01\x19\x4c\x81\xbf\x6f\xb2\xce\x54\x07\x7b\x82\x25\x0e\x57\xc6\xa7\xb2\x5d\xeb\x6e\xe3\x9d\x4b\x68\x6a\x5c\x30\x7a\x76\x12\xb2\xd8\x5e\xe9\x25\x12\x41\x3d\xea\x29\x7e\x44\xf3\x17\xbe\x7c\xeb\x70\xa3\x32\x8a\xf0\xb4\x01\x00\x1a\x41\x85\x62\xb8\xff\xe4\xe9\x77\x1b\x4b\x4a\x8e\x0b\x40\xc7\x91\x34\x9d\x5d\x4e\x45\x9f\xe6\x20\xa1\xa2\xfc\x72\xe2\xf6\xca\x28\x56\x7d\x4c\x26\x32\xbb\xde\x1b\x49\x86\x4c\x06\xbb\x12\x61\x9f\x13\x2c\x1d\xa8\xf5\x71\xef\x61\x3e\xac\x73\x9f\x66\xab\x39\x14\xcb\x3f\xa1\xab\x86\xe0\x5e\x50\x82\xeb\xaa\x24\xeb\xee\xa4\xcf\x51\xbe\xef\xc2\x7d\xf5\x12\xfe\x3f\xee\x7d";
    test(
        HashAlgorithm::SHA1,
        b"\xca\x84\xaf\x5c\x9a\xdb\xc0\x04\x4d\xb0\x0d\x7a\xcf\xb1\xb4\x93\xaa\xb0\x38\x8f\xfb\xad\x47\xb3\x8c\xd3\xe9\xe3\x11\x1c\xfe\x2c\xda\x2a\x45\xf7\x51\xc4\x68\x62\xf0\x5b\xdc\xec\x4b\x69\x8a\xdf\xd2\xe1\x60\x6e\x48\x4c\x3b\xe4\xac\x0c\x37\x9d\x4f\xbc\x7c\x2c\xda\x43\xe9\x22\x81\x1d\x7f\x6c\x33\x04\x0e\x8e\x65\xd5\xf3\x17\x68\x4b\x90\xe2\x63\x87\xcf\x93\x1f\xe7\xc2\xf5\x15\x05\x8d\x75\x3b\x08\x13\x7f\xf2\xc6\xb7\x9c\x91\x0d\xe8\x28\x31\x49\xe6\x87\x2c\xb6\x6f\x7e\x02\xe6\x6f\x23\x71\x78\x51\x29\x56\x93\x62\xf1",
        p,
        q,
        g,
        b"\xe7\xc2\xee\x18\xc3\xaa\x36\x2c\x01\x82\xc6\xa5\x6c\x25\x84\x62\x80\x83\xc7\x3e\x04\x5b\xed\xa8\xd6\x53\x69\x0c\x9c\x2f\x65\x44\xed\xf9\x70\x2c\x57\xc4\x55\x27\x39\x05\x33\x6a\x5f\x51\x71\x10\x7a\x31\x3c\xd7\xd0\xb0\xf5\x0f\x8d\x33\x42\xc6\x02\x19\xf2\x2a\x90\x23\x39\x40\x59\xd0\x5f\x46\x4c\x44\x96\xd5\x5d\xab\x6e\xb0\x89\x85\x27\xff\x4c\xf5\x67\x8e\x7b\x5b\xfb\x5e\x18\xd9\x2c\x4a\x9d\x73\x28\x8c\xce\x14\x53\x0f\xc4\x70\x2f\x6d\x03\x97\xec\x39\xa8\x80\xc4\xa7\x2d\x35\x87\x30\xc5\x66\x33\x38\x6e\xde\x02\x80\x23\xc1\x79\x1f\x31\x64\xd1\x57\x4e\x78\x23\xc7\x9b\x8a\x3c\xa1\x34\x3e\xa1\x66\xba\x6f\x02\xb7\xff\x7e\x9e\xf2\x19\x8d\xb1\x07\xf7\xcc\x15\x9f\x3b\x6a\x1c\x00\xa7\x8c\x35\x5c\x56\x6d\xeb\x0a\xc6\xfd\xe3\xf6\x33\xcb\x91\x77\xa1\xfb\xc6\xc1\x76\x6c\xa0\x21\xd5\xfe\xc4\x70\x10\x1a\xbb\x44\x0d\x2f\x06\x98\x21\x81\xa8\xc9\x2b\x7c\xdd\x76\x53\x36\xb9\xa1\xe1\xab\x70\x28\x3d\x6d\xb0\xa9\x63\xfb\x64\x8c\x37\xc4\xe2\x9a\x74\xc3\x75\x77\x29\x10\x49\xab\x47\xcd\xbc\x10\x4c\x04\xdb\x96\x66\x81\xea\x8e\xbb\x9f\x00\xcf\x4c\x4a\x54\x62\x11\x73\x79\x57\x5f\xbd\xa4\xb8\x01\x97\x94\x51\xfa\x94\xb1\x9b\x4e\x93\x65\x67\x05\xc0\xf7\x34\xf3\xe0\x91\x4b\xb9\x6c\x1e\x2b\x8a\x0f\xb6\x8f\xaf\x14\x29\x6e\xfd\xf3\x30\x0a\xd9\x5b\xcd\xe8\xb6\x7c\xc4\xb2\x6e\x64\x88\xee\xf9\x25\xcf\xae\xac\x6f\x0d\x65\x67\xe8\xb4\x13\x55\xf8\x9d\x1c\x2b\x8f\xe6\x87\xbf\xa2\xdf\x5e\x28\x7e\x13\x05\xb8\x9b\x8c\x38\x8c\x26\x19\x60\x90\xac\x03\x51\xab\xc5\x61\xaa\xdc\x79\x7d\xa8\xcc\xea\x41\x46\xc3\xe9\x60\x95\xeb\xce\x35\x3e\x0d\xa4\xc5\x50\x19\x05\x2c\xaa",
        b"\x21\xca\x14\x8c\xdf\x44\xbe\x4a\xe9\x3b\x2f\x35\x3b\x8e\x51\x2d\x03\xad\x96\xda\xfa\x80\x62\x3f\xde\x49\x22\xa9\x5f\x03\x27\x32",
        b"\x73\xe4\x8b\x77\xa3\xaa\x44\x30\x74\x83\xc2\xdd\x89\x5c\xb5\x1d\xb2\x11\x21\x77\xc1\x85\xc5\x9c\xb1\xdc\xff\x32\xfd\xa0\x2a\x4f",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x3c\xca\xd0\x01\x85\x19\xa8\x98\xf8\x7d\x8c\xe5\xf2\x8c\x0d\x93\xab\x16\xc5\x1a\xdd\xf4\x17\x33\x22\xcb\xc4\x9d\x48\xca\x9e\xa3\x7e\xbe\x8b\xc9\xd8\xc1\xb3\xf7\x83\xf8\xcf\x59\xcf\x3f\xcb\xa1\x0a\x39\x3e\xb2\xdd\xd9\x89\xce\x25\x8e\x73\x78\x8c\xe7\x4b\x0c\xe8\x22\x3d\x24\xe9\x93\xcf\xea\xfa\x49\xcc\x8e\xc1\xb8\xec\xee\x01\x7d\x83\xa1\x1b\xb7\x03\x4c\x77\x92\x06\xc3\x64\xac\x46\x3c\xfe\xd3\x04\x7e\x1a\x2b\xf5\xc5\x91\x77\x3b\x1d\x88\x2b\x31\x0b\xfb\xa2\xdb\x87\x89\x3c\x89\xa5\x44\x2c\x08\x45\xbf\x64\x4e\x21",
        p,
        q,
        g,
        b"\x37\x50\xd3\x63\x53\xbf\xd2\xe9\x97\x3e\x26\xa5\x55\xbc\xf0\xd8\x34\xd3\xd6\x62\x0c\xb6\x65\x79\x19\x9e\x04\x0c\xe8\xec\xcf\xae\xe6\x60\x04\x6e\x78\xdf\x66\xe8\xff\x64\x15\x23\x04\x6a\xdc\xf4\x25\xb8\x31\x9d\xb2\x44\x76\x80\x19\x4c\x3a\x38\x6b\x52\x01\xdd\x1a\xc6\xbf\x3e\x66\x39\x4e\x93\x9e\xaa\xac\xa4\xfd\x3f\x38\x6f\xcf\xe1\xd5\xef\x45\x24\xb0\x6c\x5e\xd9\xa1\x57\x46\xf2\x4b\xae\xf1\xee\xc4\x1e\x68\x3b\xf3\x53\x71\x08\x44\x95\xd4\xda\x8e\x72\x7a\xeb\xa3\x07\xfb\xa0\x00\xa7\x69\xa2\x34\xe3\xc4\x60\x97\x04\xb3\xba\x4d\xfd\x6a\x86\x44\xfb\xa5\x60\x83\xda\xc8\x48\x75\x1b\x52\xa8\xc2\xcd\xc4\x79\x46\xcd\x21\xea\x24\x38\x3c\xc6\x24\x4f\x00\x09\x18\xe9\xa2\x32\x76\xb6\x06\xc5\x68\x85\x65\xc4\x4d\xdf\x77\x88\x18\x1b\x78\x95\x65\xa6\xbe\xcd\x25\x71\x23\xbb\x81\xa2\xcb\xf9\xdb\x7f\xa3\x84\xe0\xca\x41\x80\x4e\xd7\xcd\x3c\x9c\xa0\xe1\xf8\xbb\x39\x0b\xff\x50\x21\x3b\x06\x29\x68\x24\x09\x93\x37\x70\xf6\xe0\x3a\x5c\x4e\x7e\x89\xad\xe9\x02\x55\x60\x97\x86\xf6\xb2\xfc\x5a\x7a\xa7\x56\x6b\xcf\x7f\x72\x5a\xea\xd4\xcf\x45\x6c\x5f\x5e\xd7\xdc\x3e\x91\xe2\x0d\x94\xd1\xaa\x2f\x65\x68\xc9\x7a\xbd\xf2\x1e\x0b\xa8\xcb\xfb\x65\x61\x30\x5c\xb4\x51\x75\xb1\xab\xd7\xf3\x9b\x9a\x11\xc7\x97\x92\x6b\x94\x4f\x5d\x13\xc3\xd7\x0e\x0b\x2a\x8c\xa1\x8e\x1f\x5c\xda\x8c\xe6\xac\x43\xec\xbc\x1f\xef\x88\x1f\x5e\xef\x5a\x84\x2f\xd5\x98\x4a\xd1\xe3\x21\xa3\x17\x00\x5a\xd4\x78\xcb\x47\xc9\xcf\xf6\x12\x67\xf1\xd4\x96\xfd\xed\x0a\x48\x32\x8d\x62\x9b\x7b\x20\x0c\x44\x16\x34\xee\x90\x88\x79\x01\x17\x45\xbc\xab\x66\x60\xe1\x55\x83\x74\x80\x14\xd6\xde\x2f\xe2",
        b"\x1e\xf7\x72\x33\x45\xb2\x01\x3b\x71\x10\x4c\xee\xdb\xe7\xa9\xca\xd4\x30\x01\x89\x68\xbb\x29\x5b\x67\x2c\x2b\x57\xb9\xa1\x08\xb9",
        b"\x72\x85\x2d\xa4\x85\xc0\x83\x6a\x8e\xbd\xbc\x4c\x99\x6f\x7f\x6c\xb6\x5e\x99\x39\x1c\xe0\x6b\x19\xa7\x18\x76\x18\xe9\xa9\x55\x84",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x1f\xc9\x82\x88\x85\x7f\xb3\xa8\x3a\xb5\x07\x46\x5a\x53\xc0\x79\xed\x66\x67\x9c\xaf\xdf\xb8\x65\x3b\xfd\xeb\xb0\x30\x20\xfe\x86\xa9\x43\x18\x2d\x4f\x13\x77\xd5\x8e\xca\x3c\x77\x10\xd3\x2e\x21\x0d\x8d\x03\x72\x8b\xc6\x9e\x1b\x80\x03\x94\x4f\xfe\xda\xa1\xb6\x9a\xe6\xcc\x50\x63\x02\xbd\x69\x17\x01\x9f\x58\x8c\xc2\x95\x01\xcc\x82\x63\x57\x2e\xbc\x0f\xeb\x15\x38\x77\x17\x4b\xcf\xdb\xad\x4a\x58\x65\x91\x75\xd2\xde\x71\xd5\xf5\x01\x9c\x46\xd1\x12\xb6\x63\x1c\xf0\xc3\xf9\x12\xaa\xc8\x31\x40\xcd\x56\xcd\xf9\x03\xee",
        p,
        q,
        g,
        b"\x33\x53\x72\x77\x0c\x0e\x8e\x59\x1a\x36\x7d\xe9\x98\x33\xbd\xe6\xf0\x12\x40\xbc\x6e\x23\x6a\x5b\x4e\x36\x23\x3e\x12\x0b\x8e\xe6\xd1\xc1\x9c\x77\xf4\xcd\xbc\x29\x4d\x32\x78\xc3\xd4\xcf\x73\xed\x9e\x8e\xa5\x03\x2b\x05\x24\xa3\x91\xcf\x29\x3b\x35\xee\x7e\x02\x34\x30\x22\x22\x16\xd9\xf1\x8b\x45\x02\x2f\x4d\x5f\x93\x85\xf6\x38\x4d\x9f\xaf\x1a\x0f\xfa\x4a\x80\x0d\xa2\x3b\x93\x76\x51\xa0\x9e\x82\xc2\x22\x85\xb9\xde\x6a\x40\x8e\x23\x38\x6f\xfa\x67\xab\xb9\xd1\xc7\x1c\xda\x7b\xc0\xc9\x35\x25\xfc\xd7\x9e\x83\x15\x3e\x74\x60\x70\x78\x24\x67\x85\x8b\x69\x7a\xd1\x49\x14\x67\x30\x33\xfe\xdb\x2d\x7a\x10\x5a\xd2\xd4\x38\xda\xaa\x35\xb5\x03\xb5\x18\x31\x4a\xc3\x70\xfc\x5b\x11\x12\xd4\xfe\x51\x4e\x58\x35\xd9\xa8\x6d\xe2\x5e\x6b\x35\x69\x13\x92\xd1\xcd\x04\x83\x6d\x41\x26\xb2\x95\xb8\xa8\x9f\x21\x7d\x58\x12\x58\xaf\x95\x27\x7b\x8b\x91\xc3\x1e\x6b\x0d\x23\xa7\xc5\x2b\x0c\xe2\x64\x1c\xf1\xa2\x52\x83\x8b\x6e\x28\xe2\x26\xcf\xc4\xfa\x9d\xc9\x14\xc5\xf6\x75\xfc\x90\x0e\xd6\x80\xdc\x1a\xa9\xe1\xd1\x71\x93\xc4\x32\xaf\x40\x32\xeb\xab\x95\x41\x91\x32\x70\x83\xc5\x9a\x5f\x64\xc1\xea\x18\x10\x7c\xe4\xd7\x21\x1d\x1c\x22\xf0\x48\x05\xed\x54\x8f\xc2\x2d\xf4\xb1\x62\xf3\x0b\x6f\xf3\xa7\xf7\xc3\x8a\x5a\x95\xfe\x82\x4d\x29\x61\x18\x0e\x98\xb3\x02\x08\xdc\x7e\xa7\x07\x1f\x79\x22\x61\xd4\x5c\x7b\xb7\xb9\x11\xf3\xb1\x9c\x3e\xe0\x17\x1a\x32\x6c\x03\x3c\xf5\xfc\x2b\xf7\x9d\xe7\xd5\x11\x5a\xc5\x68\xe0\x47\x89\xcb\x44\xe0\x8f\x3a\x86\x27\xa1\xb1\xf3\x76\x23\x42\xb4\x9b\x76\x79\xbd\x7e\xdb\xe4\x7b\xc3\xee\x9c\x3f\x02\xdb\x15\xd5\x32\x56\xa5\xea\x28\x47",
        b"\x5d\xd0\xc7\xe8\xa3\x99\x3b\x9d\xe0\x67\x6a\x57\x9c\x89\x7e\xa3\x99\x43\xa4\x3d\xbe\xc5\x99\x6e\x58\xc1\x98\x5b\x54\x1d\x7c\x1a",
        b"\x67\x97\x10\x01\x82\x2a\x08\xa2\x14\x8a\x6b\x1a\xdb\x50\x27\x4a\x57\xda\xfe\x89\x6f\xb0\x4a\x12\xa6\xf9\x97\x07\x55\x53\x06\xac",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xfd\xa9\x76\x5c\xc9\x1a\x9d\xb9\x22\xae\xc7\xb1\x3f\xc3\x2a\xc4\xec\x4e\x3b\x85\x34\xf9\xe9\x5a\xf9\x6e\x8e\xbe\xab\x89\xd8\x47\xdc\xd1\x50\x44\x48\x68\xcf\xaf\x42\x13\xf8\xd8\xba\xa6\xb1\xd0\x88\x62\x24\xe2\xaf\xd0\xae\xb9\x3d\x59\xb8\x86\x57\x20\x88\xd0\x5b\xf7\x21\xc7\xad\xfb\x54\xda\x47\xc6\xc4\x85\x12\x04\xa7\xa9\x2a\x11\xde\xb3\x9b\xa1\x7c\xf6\xc0\x7f\xb7\xce\x8b\xa3\x50\xa9\x9d\x01\x8d\x4e\xa6\x4b\xd5\x6d\x1d\x9f\x8f\x7d\x88\x15\x7f\x19\x0f\xcb\x37\x2a\xcf\x6f\x8d\x31\xcf\x7b\x79\x5b\x36\xc1\x0f\x5e",
        p,
        q,
        g,
        b"\x05\x39\xcc\x99\x2c\xa7\x0f\x91\x35\x37\xb1\x21\x1d\xd3\x26\xd8\x5f\x75\x31\xba\xa6\xbe\x05\x83\xba\x45\xb9\x57\x1b\xaa\x81\xcd\x58\x28\x05\x0d\xcd\x9a\xb7\xa2\x03\xbc\x4f\xe1\xd8\x74\xf7\x6e\xc1\xf3\x4d\x93\x55\x79\xed\x21\x32\x25\x57\x89\xd7\xe6\x01\x0c\xf5\x04\xb4\xc7\xf5\x86\xd4\x4a\x71\x66\x00\xac\xf8\xa0\x4a\xd3\x0c\xb7\xca\x05\x5d\x72\x23\xf9\x76\x1c\xda\xeb\xfd\xf7\xef\x72\xbd\xea\x3d\xfc\xd0\x20\x06\x9a\x96\x9c\x56\x01\x60\xf0\x53\x46\x76\xbe\xff\x5e\xa6\x11\xfc\xbc\x0f\xd4\x7c\x86\x7f\x31\x63\xe1\x37\x1e\x1d\xe6\x7a\x1a\x3c\x3e\x37\x16\x8b\xf0\xbe\x79\xc0\x9f\x45\xf2\xbc\x43\x51\x7a\xee\xa0\x10\x0a\x2a\x25\xd1\x48\xff\x19\x90\xc0\x61\x43\xfa\x25\x3d\x83\x06\xf4\x8d\x77\x36\x22\x24\xbc\x3e\xfe\x93\x38\x9e\x92\x2d\xef\x0f\xd1\x1d\x19\x92\xf5\x50\xed\x82\x94\xb6\x13\x65\x47\xff\xd6\x12\xb0\xbc\x8e\x4e\xe9\x0b\x31\x00\xbb\x89\x92\x21\x77\x14\x7b\xe0\x08\x32\x81\xbf\x66\x3f\x83\x70\x41\x7f\xa7\x90\xd4\x10\x5e\xb9\x8c\xc1\x26\xf5\x00\x5b\x7c\x08\xbc\x21\x1d\xea\x28\x98\xaa\x65\x3c\x3d\x2b\x51\xfc\x67\x73\x2b\xff\x56\x44\xe8\x04\xaa\xe6\x92\x00\xc4\x16\x03\x5a\xa0\xba\x5a\x14\xcc\x43\x9b\x56\x9f\x46\x21\x17\xb7\xdf\xcf\x3f\x2c\xc1\x3e\x72\x3a\x93\xff\x95\x33\x20\x8f\x20\x24\x1d\xaf\x36\xcd\x16\x06\x6b\xe3\xdb\xa2\x01\x17\xcb\x14\x5d\x75\x6f\x5a\x6f\x79\xce\x23\x56\xa0\x51\x64\x7a\xed\xd6\x45\xbf\xa6\xfa\xf8\xf8\x0a\x6f\xdf\x3e\xec\x42\xdd\xd4\x2b\xb2\xe7\xb7\x73\x82\x96\xe2\x39\x78\xc8\xbd\x63\xb8\x04\x59\x53\xe0\x6c\xef\x12\x63\xbf\xe0\x3b\xe2\xf6\x1b\x16\x00\x7d\xf1\xeb\x19\x85\x67\xa7\xbc\x6b\xff\x27\x4e",
        b"\x55\xc2\xb2\x7e\x76\x9f\xac\x99\xb4\x7b\xc0\xa5\x4f\xf1\x82\x1c\x7a\x46\xbe\x60\x01\xab\x66\x4f\xb6\x8f\xb1\xba\xfc\x04\x44\x6f",
        b"\x30\x59\xdb\x42\xa3\x99\xc4\x28\xf3\xcf\xbb\x10\x2d\x6c\x04\x09\xb0\x6f\x20\x06\x8d\x1c\xa8\xcb\xea\x48\x58\xac\x6e\x5d\xe1\xd3",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xe4\x9a\x12\xb8\xd7\x61\xef\x7a\xfb\xcb\x1c\x37\x7e\xed\xf6\x29\xd0\x8c\xc5\x09\xa8\x75\x3a\x5b\x92\xe2\x6a\x23\x97\x36\x51\x56\xe7\xc0\x81\xbc\xb4\x68\x66\x95\x57\x5c\x6a\x64\xf5\xd7\x7d\xfd\x55\x0b\x04\xdf\x39\x0a\xa5\x5e\x0d\x05\x1c\x75\x9f\x19\x7a\x75\x1a\x60\x41\xe2\xdd\x09\x59\xf9\x02\xf2\xe3\x59\xa1\x67\xd8\x80\xc4\x9c\xfa\x81\xe7\x19\x6f\xa1\x60\x4a\xd3\x2a\x80\x17\x07\x1f\x09\x8d\x4c\xb3\x46\xb3\x92\x66\xfb\xe7\x56\x59\xdf\xc6\x60\x7b\xf0\xd8\x29\x64\x07\x82\xcf\x3e\x12\xe3\x83\x76\xc5\xa9\x92\x82",
        p,
        q,
        g,
        b"\xee\x7f\xff\x18\x82\x2f\xf4\x54\xa2\x07\xf9\xdb\x54\x2d\x24\x29\x8b\xb5\xed\xb1\x1d\x80\xdd\xc6\xdd\xb9\xbf\xae\x0c\x95\x2d\x4f\xe8\xd9\xdb\x0f\x1a\x86\xe8\xa0\xf2\x19\x3a\xf7\xca\xae\xe7\x26\x4d\x74\x10\x6d\xe5\xaf\x0a\x6c\x14\xf7\x10\xbb\x86\x3e\xb7\xdc\x16\x7a\x1e\x43\x78\xb6\xcd\xb7\xab\x68\x41\xc6\x64\xe9\x82\x45\x29\x11\x97\x73\x57\x8e\xf5\x5b\x7c\x35\xed\x22\x1e\xf0\x70\xdd\x46\x90\xb4\xc1\x2f\x27\x67\x3e\x5d\x1f\xe9\x64\xff\xe2\x9d\xa5\x7e\x2d\x1a\xcd\x21\xef\x13\xe0\x66\x9f\xa9\x76\x68\xbb\x19\x9b\x56\xa3\xa5\x3e\x10\x46\x91\x33\x02\x20\x81\xcd\xf6\x26\x48\x10\x0d\xca\x26\x7c\x4f\x6a\x3c\xa3\xa7\x5b\x57\x3b\xb1\xb3\x9c\x8a\x4e\x1f\xcf\x81\x26\x9e\x9e\x1b\x10\xc6\x3f\x5b\xa4\xfe\x75\xcf\x71\x39\xd0\x38\xd0\x2f\x5f\x53\x4a\xa0\x81\xfc\xe7\x32\xcd\x50\x51\x60\x9b\xc0\x6f\x18\x87\x4d\xd0\x11\x21\xd3\xc1\x79\xf0\xc3\xf0\x39\x9c\x18\x5e\xeb\xdc\x34\x63\x5b\x31\x39\xf1\xca\x50\xfb\xff\xb3\xb0\xad\x12\xe4\x81\xc1\xa6\x46\x82\x14\x37\x93\xf0\x72\xc7\xdb\x8b\x5b\x9e\xef\x41\xcc\xdd\x66\xb9\x04\x13\x9d\x64\x44\x42\xa9\x2f\x62\x55\xed\xb9\xbc\x12\x34\xe2\x7d\x07\xa6\xba\x32\xb1\xf1\x4c\xdf\x98\xa2\x2c\x6a\x12\x30\x0d\xff\x50\xac\x1b\x65\x56\x8b\x6e\x91\x55\x41\xbb\x38\x6e\xc7\x25\xda\x44\x44\x67\xca\x25\xe8\x14\x48\xcb\x78\x37\x51\x46\xad\x20\x78\xa8\x30\xe7\xd9\x05\xde\x9a\xd7\xd8\x95\x59\xc9\xd4\x30\xcf\x5f\x41\x9c\xe9\x45\x70\x4a\x42\x6a\xb2\x64\x01\x6e\xd8\x7c\x90\xd9\x7f\x51\xa7\xd6\xe1\xee\x2f\x51\xbb\xb3\xa8\xde\x81\x39\x16\x97\xb0\xe4\x22\xdf\x9e\x5d\x35\x51\xe9\x33\x74\xe5\xf3\x80\x16\xb2\x96\xd5\x3b\xc2",
        b"\x21\xd3\x4d\xf6\x05\x23\x79\x75\xdb\x31\xb8\x64\xf9\x8c\x9a\xb6\xe4\x65\xdb\xf0\xb3\xfc\x58\x68\xd6\x7c\xd6\xcb\x3a\x13\x96\x3b",
        b"\x70\xc4\x88\x07\xd6\x2d\x1f\xe7\x4d\x58\x95\x93\x47\xab\x12\xc9\x7b\x50\x0d\x20\x60\x7e\xd2\xa9\x5d\x8a\x38\x8f\xee\x26\x58\x12",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x28\xf7\xa0\x67\xa0\xea\x7f\x0a\x4d\x79\x7c\xea\x39\x39\xf6\x6b\x28\x1e\xd1\x9c\xc9\x8b\x85\x63\xef\x37\x57\x98\xb4\x06\x14\xf4\xdd\x85\xac\x2f\xcf\xcc\xbc\x5e\xbf\x0a\xc9\x32\x28\xc0\xb7\x29\x37\xa4\x81\xca\x4f\x9d\xf7\xa7\xe5\xd2\xe5\xda\x9a\xf0\x48\x74\xdc\xec\x35\x03\x5f\x6a\x7d\xb4\x93\x79\x3a\xa2\x36\x1f\xb6\x6e\xf2\xee\xdb\x75\x74\xd0\x4e\x21\x47\xc3\x57\x29\x8a\x2a\xdf\x99\xac\xa1\xee\xbe\x00\xce\xfa\x44\xb3\x91\x57\xeb\x1e\x94\xaa\x8a\xa9\x8d\x54\x51\x51\xfb\xb4\xde\x67\x07\x0b\x39\x04\xcc\xe9\x30",
        p,
        q,
        g,
        b"\xcd\xb9\x92\x2d\x69\xe9\x9c\x7f\x34\xa9\x21\x0e\x2a\xfc\x5b\xe0\x11\x5d\xa4\xaa\xf6\x82\xd9\xea\x37\x78\x8e\x0b\x6c\xaa\x6f\xde\x13\xc8\x8e\x51\xf5\x58\x82\x06\x68\xb5\x9d\x14\xc0\x6d\x2c\xbe\x65\x49\xd3\xf0\x6d\x10\xdb\xee\xe4\x6f\x59\x15\x4c\xd4\x67\xae\x19\xe1\x6b\xe2\x5e\x6f\x6c\xd2\x38\xcc\xd1\x94\x7f\xc5\x81\x56\x2d\x30\xca\x32\x9b\xb3\x27\x25\x8c\xa4\xae\xb9\x01\xf8\x14\x41\x40\x58\xb6\xf1\x69\xa4\x5f\xf5\x5e\x40\x23\x2d\x78\x70\x49\x9a\xe7\x8c\x05\x13\x77\x71\x40\x75\x2d\x55\xf0\xa4\x70\x76\x1b\xdc\xff\x5a\x66\x09\xcc\xa2\xd1\x80\x9f\x18\x4b\x29\x87\x18\x07\x1d\x21\x6a\x14\xad\x01\xf5\x6c\xcc\xce\xd2\x39\x69\x60\x7b\x62\xd4\xd1\x40\xc9\xef\x28\x50\x76\x74\xf5\x9f\xec\xc7\xe7\xce\x8a\xd2\x63\x6a\x5c\x53\xf0\x70\xad\x31\x7c\x8c\xd0\x23\x1f\x50\x0a\x79\x0e\xf6\x9a\xc7\x86\x00\x0f\xaf\x68\xe7\xb7\x85\x4d\x6e\xb2\x64\x99\xa9\xd5\x24\xcb\xf8\xf3\x73\xca\x41\xdd\x6a\x2f\xa5\x19\x8e\xba\x2a\x8e\x22\x8f\x5a\xb2\x9b\xe9\xf6\xd4\x50\xf7\xf5\xa1\x49\xae\xb2\x0d\x8a\x27\x79\x71\xfa\x6e\x64\xa0\xde\x36\xc8\x75\x0a\xfc\x38\x19\x61\x75\x69\x75\x62\x1f\x28\x7a\x39\x50\xf8\x84\x02\xc5\x08\x1f\xe0\xc5\x4f\x44\xf9\xfa\x7c\x50\xdf\x90\x6b\x26\x40\x98\x85\x36\x46\xb3\xd0\x5a\x4f\x04\xc6\xf1\xbb\xc6\xc4\x40\xf7\xe7\x35\x8d\x3a\x72\xb2\x9f\x76\x43\xf4\x40\x6b\x7d\xb1\x73\x69\x0d\x40\xaa\x29\x38\xea\xf0\x18\x74\xd2\xba\x80\x94\xcc\x5b\xe1\x14\x5b\x2b\x2e\xe9\xe7\xcf\x15\xbf\x39\x8e\x50\x83\x2d\x95\x01\x74\x30\xb1\x86\x99\x38\x73\x2c\xdd\x1d\xf5\x93\xf5\xdb\x2b\x2b\xd7\x13\x08\xd8\xc2\x53\xd2\x54\xef\x39\xb4\x75\xe2\x49\xd8\x90",
        b"\x12\xde\x25\x2d\xa2\x59\x3c\x59\x69\xa6\x49\x6a\xe8\x08\xd8\x51\xca\xd1\xde\xd2\x95\x9e\xa8\x90\x57\xa9\x2e\x5e\xc9\x1c\x5f\x95",
        b"\x16\x53\x38\x07\x5e\x6a\x4f\xea\x0b\x23\x8f\x9f\xac\x90\x4b\x7b\x33\xdb\xee\x5a\x55\x26\x46\xdf\xbe\xd8\x27\xf6\xd2\x8d\x64\x92",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x0e\x15\x6b\x0b\xd8\x45\x95\x15\x5e\xf4\xfc\x21\x3d\xfc\x7e\x46\xbf\x27\xa8\x9c\x27\x57\x23\xe0\x98\x40\x76\xb0\x27\xc4\x9c\xb2\xee\xe6\xac\x86\x6d\x75\x33\x35\x81\xcc\xa6\xf8\x97\xe1\x14\x18\xfb\x37\xba\x5c\xab\x13\x91\xcd\x23\x7e\x2c\x6a\xb3\xf1\x1a\x05\x5d\x3b\xd0\x3f\x42\x5b\xaa\xab\xe5\xa6\xa3\x4e\xba\x4b\x11\x8a\xf7\x3e\xdd\x61\x07\x87\xcb\x8e\xaf\x47\x6b\xd2\x17\x04\x82\x08\xea\x4c\x1d\x05\x91\x37\x29\x47\xa1\xc0\xef\x94\x69\x65\x68\x98\x34\x24\xfd\x1d\x80\x2f\xc9\x11\xe7\xbf\x71\x22\x4a\xfd\xbd\xd9",
        p,
        q,
        g,
        b"\xd0\x97\x36\x41\xd5\x6d\x8b\xaa\xa2\xc2\xd4\x30\x50\x1d\xff\x44\xea\xf9\xa3\x65\x74\x78\x79\x91\x34\xb0\xf3\x35\xae\x94\xff\x27\x91\xdf\xd4\x94\x40\x13\x32\x48\x6b\xa6\x37\x68\x3e\x70\x4b\xd9\x85\xf5\x26\x91\x9e\x66\x1a\x22\x80\xd9\x9b\xd4\x82\x62\xb6\xc9\x30\x5e\x0c\x8f\xd8\x79\xcd\x0a\x83\x61\x28\xd8\x8e\xdd\xae\x51\xfc\xfb\x51\xf7\x44\xb2\x3d\x2d\x2d\x27\xa2\xcc\x1e\xa5\xa9\xd5\xe0\xa7\xfa\xf4\x22\x7a\x2a\xdb\xfb\x7e\xd4\x5d\x6a\xa9\xc3\x37\x98\xab\xf0\x7b\xc6\x9e\xfc\x5f\xdd\xe5\xdc\x5c\x78\x01\x96\x25\x70\x93\xec\xa7\x54\x68\xb1\x61\xcb\xa4\x4b\xcd\x14\x2b\x21\xfa\xe9\xed\xc6\xab\x32\x78\x30\xc2\x8e\x1b\x3d\x2d\x7c\x81\x2d\x8a\xec\x3a\x19\x52\x62\x7a\x04\x01\x10\x87\x2e\x14\x8e\x15\xde\x5c\x7b\x4c\xa2\x4f\x08\x63\x36\xda\xec\xbb\xf9\x81\x6c\xdb\x9d\xc7\x30\xdb\x8a\x66\xa1\x92\x9a\xbe\xcd\x4b\x09\xa0\x39\xa1\x9b\xff\xa4\x5f\xfc\x85\xdd\xf0\xbe\x32\x77\xbf\x07\x5b\xbb\x46\xf0\x7b\xf0\xda\xea\x24\x89\x7e\x07\x04\x4b\x5e\xe3\x7f\x9f\x44\xfe\xe7\x57\x18\x81\x70\xda\x22\x92\x4f\xa1\x5e\xd9\xc0\x7f\x11\x3c\xdf\x37\xa8\xc4\x86\x48\xe5\x86\xfb\x55\xa0\xc3\x5f\x3b\x63\xa6\x96\x67\x24\x41\x93\xc7\x0d\x94\xbb\xe3\x6d\x04\x3b\x25\xa0\x41\xfb\xa9\x2a\x20\x42\xe2\xee\xf7\x67\xe7\xcd\x18\xdd\x1c\x1b\x5c\xa4\x87\x8f\xe7\x74\xc8\x33\xcb\x5c\x5a\xff\x9f\x67\xbf\xd6\xcf\xbf\x2d\xfc\x63\xb8\x84\x2a\xd2\xd4\x9c\xeb\xca\xff\x4c\x39\x27\xf3\x19\x9c\x10\x6d\x0c\x14\x9a\x9b\x1b\x49\xbe\xf1\xd6\xf8\x14\x3d\x93\xd2\x5d\xf9\xdb\x1b\x5b\x37\xd5\x22\xe7\x23\xff\x64\xd9\xee\x52\xe4\x76\x20\x67\x12\xa3\x82\x46\xdd\x92\x62\x71\xf5\x59\x0e",
        b"\x5e\xf5\xd7\x8c\x42\x1a\xe5\xa6\x39\x78\xbc\xbf\x7d\x20\x37\xb5\x02\x2b\xc4\x7b\xe7\xb2\x93\x80\x65\x80\xad\x5b\x4d\xe2\x7a\x4e",
        b"\x67\xcc\xb2\x83\x3c\x1d\x32\xc6\x8e\x91\xae\x38\x90\xb4\xc9\xa6\xe5\x22\x9b\x22\xa5\x79\x91\x68\xc0\x04\x6e\xad\x92\x57\x3c\x85",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x84\x9c\x53\x37\xd8\x8b\x3b\x24\x7d\xf5\x73\xeb\x0d\x66\x55\x48\xb6\x42\x37\x63\xd5\x57\x1f\x8a\xcb\x5e\x61\xe3\x16\xd7\xcd\xc2\x08\xcd\xa5\xb3\x9a\x19\x44\xa7\x17\x58\x7e\x58\xe2\x1b\x86\xed\x22\x2b\x8e\xe2\x65\x10\x5a\x32\xba\xff\x36\x92\xdc\xf7\xb8\x71\x3d\x0b\x53\x92\x62\xa5\xbd\x9a\x95\x4c\xb7\x14\x3e\xe6\x6f\x87\x64\xdb\x62\x36\x13\x6c\xb1\xcb\x3b\x34\xa8\x7c\xbd\x3f\xee\x3b\x11\x28\x8b\xc9\x4a\xc9\x91\x79\xc6\x81\xa4\x69\xd6\x2d\x9b\xcd\x91\xd4\x03\x32\xa6\x50\xa5\xbc\xe3\x3b\x60\x26\x88\x4e\xf9\x4a",
        p,
        q,
        g,
        b"\x1e\x8d\x4d\x6f\xef\x99\x05\xd6\x39\xe2\x56\x4d\x87\xdc\xbe\x0d\x8f\x99\xbd\xe3\x80\x82\xff\x09\x1a\x97\x7f\x2a\xff\xca\xb8\x65\x05\xae\xff\xe6\xef\x1d\xdb\xac\xf1\x5d\x91\x65\xb0\x06\xac\x05\x17\x43\x4a\xaa\x65\xdb\x21\x04\x52\xfb\x2f\xf4\xc9\x90\xb8\x7f\x25\xfe\xe7\xad\x5b\x26\xad\x87\x74\x95\x75\x19\x00\x89\xa5\x6c\xdb\xce\xee\x67\x82\xce\xaa\xf5\x69\x81\x4b\xb9\xe6\x58\xff\x50\xae\xbf\x6f\x3c\x97\x91\x89\x3e\x5d\x6a\xda\x5f\xdf\x8c\x47\x20\xfa\xfa\x18\x4c\xc8\x4a\x84\xf5\xfc\xa7\x9d\x89\x96\x36\xe0\x07\xbd\x0e\x1a\x89\xda\x09\x4a\x37\x8e\xdb\x6d\x72\x24\x0c\xc2\xd1\xd7\x09\x8b\x53\xba\x48\x37\xa5\xd0\xd7\xd0\x20\x19\xb9\x52\x71\x2e\x4f\x14\x20\xe5\x8a\xf2\x3d\x13\x77\xcd\x6d\x5f\x39\x89\xb3\xd6\x0b\x5f\xc5\x72\x04\x3b\x96\xc4\xf7\xbe\xb7\x13\x7c\x08\x94\xfa\x99\xd7\x27\xa5\xa8\x8a\x5d\x5d\xcb\xf2\xda\x7b\x0b\x2d\x83\xdb\x88\x74\x7f\xb0\xcc\xaa\x89\x91\xd2\x4f\xcc\xde\xf4\x21\x11\xff\x40\x2e\xd0\xd9\xbd\xb8\xa4\xad\x13\xf8\xfc\xff\x6a\x1d\xf5\x6c\x82\xa5\xf8\x8f\x57\x5f\x49\xa0\x62\x75\xa9\xe6\x60\x67\xf1\x5d\xae\xc4\x02\xed\x87\x70\x48\x49\x99\x09\xb9\xe7\x6e\x5f\xde\x52\xfe\xac\x94\x4e\x1d\xe7\x89\x4c\xf1\x3c\x51\x52\x99\xac\xc6\x44\x2d\x90\xf0\x27\x31\x7b\x07\x13\x80\x5a\x95\x12\x25\x6b\xca\xa7\x96\x3b\x94\x29\xa5\x10\xc5\x86\x97\x92\xc1\xe2\x90\x82\x92\x1d\x0e\x7d\x0c\xef\xff\xc3\x4d\x30\x76\x2f\xb8\x3e\x2a\xbb\x78\x21\xfa\xb4\xca\x89\xd0\x8b\x49\x7f\x75\xe3\x14\x9a\x5c\xd3\xd2\x3b\x29\xbc\x52\x13\x7d\x8b\xe9\xc4\xa9\x5c\x63\x76\xf6\x2e\xd6\x4f\xdc\x15\x9b\x1b\xb6\xc8\x42\xbd\x07\xf8\xcf\x03\xf7\xf2\xeb",
        b"\x11\xb1\x63\x51\xf8\xf7\x20\x31\xba\x2a\x77\x20\x00\xac\x87\x26\xa4\x79\xe1\xbe\x45\x23\xa9\xee\xfa\xbe\x23\x94\x7a\x1d\xf0\xd9",
        b"\x26\x60\xfb\xb4\x4e\x29\xe7\x68\x7c\x10\xe2\x9d\xe9\x6f\xa1\xab\x03\xc0\x87\xcc\xce\x08\x6c\xdd\xab\x48\xec\x63\x77\x41\x41\xc1",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x4c\x37\xa4\xc8\xb4\x11\x09\x24\x0c\x4f\x53\xd8\x72\x77\xd3\xc7\x90\xb2\xf0\x71\x10\x5d\x15\xaa\x10\xbd\x0f\x77\x09\xda\x27\x4c\xce\xa1\x96\x1e\x0b\x99\x63\x5b\x31\xac\xd2\xc8\x05\x30\xd2\xb4\x03\xd7\x11\x0a\xd7\xcd\x0e\x35\x72\x51\x89\x09\xc1\x36\xe7\x3e\x57\xd3\x8c\x1c\x74\x43\xe5\x8a\x25\x7f\x07\x36\xb9\xf6\xf5\x1d\xa8\xfd\x1a\xe9\x21\x3e\x81\x93\x00\x3d\x69\x58\x33\x81\xf0\x20\xcc\xe7\xfc\x59\xba\x1b\x1e\xd5\x54\x1d\xbe\xf6\xb5\x99\x25\x75\x0d\x50\xb6\x51\x5a\x97\x7a\xa4\x32\x5d\x5f\xad\xe4\x2f\x82\x87",
        p,
        q,
        g,
        b"\x88\xa4\xdd\x59\x3b\x64\xa4\xeb\xcb\x27\xff\xea\x3d\xe9\xa7\xed\x78\x01\xf9\x67\x2b\x5c\x8d\xc2\x7b\x38\x3d\x6c\xba\x58\xb4\xf0\x01\x81\x63\x4d\x05\xeb\x49\x02\x82\xce\x4e\x57\xf0\x94\x03\x73\xd3\xa7\xbd\x7e\x9c\xca\xa9\xbb\x29\x65\x32\x2a\xb5\xfb\x21\xb4\x32\x7b\x47\xef\x4e\x2b\x42\x42\x4c\x13\x83\xbb\xd8\x55\x8b\x50\x6a\x7b\xf5\x53\x7b\x04\x9f\xff\x35\xc5\x58\xbc\xc7\x39\xb7\x60\x44\x37\x28\xc0\x90\xc3\x4d\x6d\x4e\xba\x81\xe2\x4e\x42\x39\x4f\x8f\xb8\x26\xf7\xc9\x2c\xa7\x1a\x9d\xab\x16\xe9\x99\x27\x47\x26\xb0\xc5\xd8\xf7\x2f\xb9\x14\x18\x70\xda\xc0\xbb\x9e\xc0\x42\x98\x02\xb6\x29\xad\x71\xae\x05\x60\xe5\x86\x2e\xcf\x3e\xab\xa9\xc2\xa5\x84\x88\x5b\x32\xc6\x84\xf6\xd5\x5f\xd1\xb0\x90\xd9\x3d\x03\x6a\x4e\x98\x58\xa4\xd8\x9b\x9b\x57\x50\x84\x9d\x92\x6c\x51\x91\x20\x13\x1d\x45\x6f\xce\x9d\x24\x73\x41\xeb\x17\x33\x6c\xa9\x72\x9a\x90\x80\xac\x5b\x12\x72\xfb\xf7\x07\x52\x6a\xfc\x8a\xe6\xa8\xc6\x61\xef\x3c\x15\x18\x45\xf6\xee\x09\x02\xde\x9a\xbb\x43\x22\xaf\xe5\x85\xe5\x9d\x6d\x41\x8e\x87\xd7\xcd\xce\x48\x97\xcc\xac\x81\xd0\x13\xfd\x72\xda\xe1\xa5\x55\x77\x62\x52\x73\x12\x58\x7c\xa6\x76\xf0\xe0\x67\x60\x00\xfc\x0c\x76\xb8\x26\x58\x42\xf2\xdb\x7e\x18\xe6\x21\xc0\xe3\xc2\xca\x92\x95\xe9\xe3\x6e\xc8\xce\x1c\x85\x09\x7c\xa5\xff\xfa\x62\xe7\xb8\x96\xbb\x16\x83\x6d\x06\x33\x86\xb1\xe6\x63\xef\x29\xec\x17\x02\x96\x5a\x7e\x05\x62\xd2\xd2\x82\xf8\x09\x52\xd7\x47\x6b\x32\x2f\xfa\x79\x29\xa4\x53\xa6\x38\xea\x3b\xed\xe8\x02\xff\x5f\x8f\x56\x60\x85\xa6\xe2\xa2\x41\x4e\xf7\xa6\xf1\x17\xac\x86\x28\x48\x6b\x23\x60\x3b\x14\x08\xfa\xae",
        b"\x23\xe1\x3a\x35\x77\x7c\x18\x9a\xe5\x65\x09\xc7\xaf\xb4\x11\xb3\x13\x07\x73\x7e\x2f\xfc\x8d\xb3\xf2\x08\x94\x0c\x5e\x76\xed\xb3",
        b"\x05\x44\x75\x83\x62\xcb\xb6\x1d\x66\xb6\x68\x26\x95\x8a\xca\x63\xaf\x1b\x8a\xd6\x15\xa4\x9b\xa5\x57\x92\x39\x59\xb6\x8f\x82\x28",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x44\x34\x73\xd6\x15\xbe\xdc\xba\x2c\x8d\x9a\x9a\x45\xa2\x8c\x42\x8d\x7f\x1a\x26\xab\x14\x70\x56\x27\xd9\xad\x13\xf5\x3b\x76\x7c\xbb\x60\xbe\x52\x3f\xc2\x1a\x99\xc3\x73\xbd\x77\x61\x81\x7b\x31\x42\x90\xf2\xf6\xa8\x0e\x06\xe1\x2c\xce\x23\x89\x54\xc6\x48\xac\xe5\x0f\x3b\x0d\xfd\xf7\x1d\xc3\x08\xe1\xa8\xee\x11\x59\xfc\x1f\x19\xb7\x3a\xb6\x01\x5d\x18\x6d\x9b\x6b\xad\x96\x5a\x9a\xd6\x2e\x44\x0a\x9c\xed\x13\x55\x0a\x44\x4b\x5f\x04\x00\xb9\x6e\x2d\x23\x8e\x9e\x3d\xc6\xe6\xde\x12\xf4\x42\x05\xd4\xfd\x57\xf6\x0e\x9d",
        p,
        q,
        g,
        b"\x0f\x4e\xc6\xe2\xba\xae\xa9\xc8\x1e\x90\x70\x05\x19\xf2\xf0\x5f\x54\x5d\xdc\x0a\xe9\xbd\x3a\x09\x1e\x8b\x6b\xa5\x25\x5c\x15\xfc\xe5\xef\x3c\x04\x67\x71\xc5\xf3\x1b\xb0\x1d\xe4\x37\x7e\x14\x28\x31\xac\x17\x49\x90\x3f\x93\x17\xc7\xb0\x1a\x99\x07\x14\x98\x5f\x92\x51\x19\x8c\x82\x90\x73\x20\x59\x24\xc5\x68\x05\x0a\xcd\x6d\xcc\xa7\x57\x61\x8c\xd2\x80\x9b\xb7\xaa\xb6\x4d\xb1\xe8\x6c\xa9\x2e\xeb\x85\x41\x20\xc9\xd8\x9f\xb9\x36\x35\x96\xbe\x9c\xbb\xaf\x8e\xac\xae\x2f\x18\xf3\xed\x48\x35\x89\xeb\x46\x6a\x51\x44\x82\x4f\xeb\x1f\x88\xc3\x0c\xfc\xbb\x76\x28\xf7\xcb\x41\x59\xce\x32\xe7\xc2\xed\x04\xd0\xff\x04\x81\xc9\x58\xe5\xff\x74\x45\x22\x94\x4c\xf3\x20\x20\x38\x9b\x32\x95\x9b\x5e\x12\xf8\x0f\x08\x06\x49\x08\xa2\x70\xf8\x69\x5a\x3f\x99\xe7\x5e\x7e\x85\xba\x3b\x3c\x77\x3f\x04\xef\x9e\x09\xe7\x6b\x6c\x47\x30\x2e\x41\xd5\x0e\xad\x04\x54\x1e\x0f\xca\x4a\x42\x50\x27\x22\x26\x5f\x82\xff\x60\xef\x46\xaa\x75\x47\xf9\xde\x24\x91\x35\xdd\x07\x7f\x24\xa4\xe7\xe0\x3b\xe2\xe3\x09\x47\x72\x76\x7a\x97\x60\x88\x3c\x52\x08\x16\xfa\xe6\x37\xc0\x30\x95\x6e\xa2\x5f\x0a\x86\x9e\x4a\x00\xa4\xa8\x01\x7b\xcb\x72\xb2\xf2\xfd\x83\x64\x3b\xdc\x01\xd8\xff\x28\x68\xd3\xca\xf1\x00\xae\x8b\x81\x8b\x92\x6c\x96\xa8\x50\xbd\x69\xd8\x93\x1d\xbf\xdc\xff\x31\xc6\x7c\x53\x7c\x4f\x59\x59\xd0\x4b\x74\x4a\x34\x66\x47\x06\x6d\xcc\x61\xf6\x3b\xe6\x25\x1b\x59\x0d\x68\x8a\xe3\xc9\xb5\x3f\x39\x20\x07\xd8\x58\x4e\x46\x24\xff\xd2\x94\x16\x50\xa3\x1d\xcd\x5a\xbf\xae\x7c\xa1\x20\xb1\x1c\x8d\x01\x94\xbe\x96\xe8\xdd\x09\xb6\x43\xd5\x68\x5d\x10\x65\xd9\x8f\x39\xb6\xed\x7c",
        b"\x76\xbb\x0e\xcb\x9f\xae\xc7\xc9\x71\x13\x7e\xa6\xfe\xac\xf1\x79\x20\x73\xae\x80\xbe\x1c\xa8\xed\x9c\xec\x2a\x5c\xa6\xcd\x51\x0f",
        b"\x34\x92\x02\x46\x73\x0e\x09\x74\xfb\x0f\xaa\x57\xe7\x7f\xc5\x0a\xb7\x87\x26\xc8\xe5\x15\x79\xa0\xef\x5e\xbe\x3f\xce\x3b\xa7\xcb",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xce\xe0\x6f\x79\x23\x32\x08\x0d\x6e\x73\xb3\xf0\x2f\x5e\xc1\x69\x96\xb6\x69\x95\xbe\xab\x4a\x2b\xa0\x92\xf4\x0d\x85\xc8\xac\x1a\xcc\xf5\x4f\xba\x06\x81\x28\xc8\xcd\xba\xda\x20\x93\x60\x77\x6a\x77\x06\x45\x50\x15\xe7\x3e\x92\xc6\x24\xad\xa1\xdf\xa6\x2e\xc7\x94\xcf\x2a\x1a\x92\x94\xf3\xfb\x55\x99\x4b\xc5\x21\x1a\xdd\x1c\x68\x5d\x9a\x54\xac\xd5\xbc\xd8\x30\xd9\xa4\xfc\xff\x29\xae\xc5\x00\x1c\x3b\x2b\x2a\x97\x06\x04\x6f\x38\xbf\xe4\x8e\x85\x22\x76\x8f\x1c\x6f\x08\xa8\xe2\x40\xe1\x23\xed\x30\xe2\x0f\xc4\x6c\x19",
        p,
        q,
        g,
        b"\x5c\x92\x05\xfb\x64\x9d\x3b\x4b\xa2\xd4\x4c\x80\xa9\x25\xe3\x0d\x27\xb0\x5b\xd3\x39\xf1\xce\x35\xe0\xd0\x41\x9a\x91\xed\x31\xfd\x10\x8c\x51\xa2\xa6\x2c\xf9\xd0\xad\xfd\x87\x7d\x27\xcf\x55\x75\xe4\x3a\xc7\xbf\xcf\xce\xec\x56\x73\x73\x6c\xae\x08\x95\x16\xdf\x8e\xb1\xea\x6b\x56\x31\x98\xb2\x4a\x6e\x25\x22\xf3\x20\xb1\x23\xbf\xb2\x50\xd4\x3b\x60\x0d\xf9\x29\x8e\x12\x1b\x6c\x5d\x2e\x63\x7a\x98\x92\x15\xe0\x95\xe6\x03\xee\x6d\x4e\x8a\x2d\xcd\x17\xb9\x08\x91\x8a\xa5\x14\xc8\x6a\x33\xd8\xc7\x17\x57\x8d\x86\x12\x61\xda\x43\xf7\x32\x50\xff\x2b\xe7\x46\xc6\x91\x6f\xc7\x28\x71\xfb\x42\xa2\x79\xd2\x25\x95\x05\x1b\x8a\xc0\x4a\xfb\xf2\x01\x30\x63\xe3\x16\x61\xb1\x17\xc5\xd0\x94\xb4\xc2\x32\xb2\x2f\x21\xd2\xc6\x5d\x63\x61\x29\x0c\x08\xf1\x2b\xef\xd1\xf5\xa2\xb9\xb5\x25\x9a\xf0\x43\x5b\x97\xb4\x32\x82\x97\xc2\x52\xd8\x13\x49\x9f\x52\x09\xdf\xa3\x5e\x91\x98\xde\x68\x50\x1a\xf4\xca\x86\x58\x94\x2d\x05\x9b\xb6\x2b\x8e\x55\xa3\xce\x61\x20\xa7\x8e\xe0\x98\x13\x2e\x8d\x2d\xc3\x75\x7f\x7e\x60\xf8\xc0\x8c\x4e\x43\xfe\xac\x67\xab\xcd\xdd\x1e\xa2\xf0\x16\x83\x9f\xb1\xa0\xf7\x97\xb8\xb1\x37\xab\x43\xb6\x45\x08\xef\x69\xf6\xae\x0f\x3a\xbc\x4e\xd6\x82\xaa\x7e\x38\xfa\x51\x46\xfe\xc6\x2e\x01\xe0\x95\x1a\x6e\x81\x15\x2d\xe4\x31\x71\xca\x88\x69\xfa\x1a\x42\xa4\xfb\x2d\x8a\xe5\x12\xc0\x05\xfd\x97\xd1\x2b\xb1\x3f\x29\x9a\xb9\xf5\x32\x1e\xe2\xfc\x39\xb2\x8e\x61\xc9\xeb\xcb\x91\xec\xd2\xb6\x10\xfd\x82\x91\xf5\x38\xa0\x0d\x06\xd0\x57\xc3\xe7\x94\x22\xa9\x31\x27\x9f\xed\x9d\x93\xb0\xb6\x53\x3f\xae\x44\x1e\x98\x41\x30\x25\xfb\x4f\xa7\x3c\xde\xfa\x80",
        b"\x6d\x02\x53\x6d\xb5\x46\xf2\xbb\x1f\x65\xff\x0b\x91\xb9\x64\x80\x2b\x38\xd1\x71\xe6\x78\x05\x4e\xe4\x1f\x2b\x85\x63\x80\x9c\xfa",
        b"\x6b\xc5\x11\x20\xe3\x5c\x95\x5a\xb8\xf7\x17\xf8\x93\x0d\x8c\xc8\xde\xf8\x50\x54\x15\xcf\x15\x9d\x25\x16\xf9\x65\x78\x84\x2f\x31",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x58\xab\xa2\x4e\x94\x81\xd1\x15\x1b\x57\x4b\x14\x6a\xc2\x1b\x17\x11\x0e\xd0\xb9\xbf\xaa\x55\xa4\xe2\xe0\x6d\xcd\xc1\x8b\xd1\x0c\xdf\xaf\xac\x04\x71\x89\xf5\xba\x9f\x10\x37\x7a\xff\xb4\x0a\x51\x4d\x52\x8a\x34\x83\xfe\x8e\x64\xb8\x31\xea\x0c\xd0\x76\xce\x58\x39\x42\xb9\x38\xa4\xb2\x57\xd0\xb5\xa9\x24\x12\xe0\x1d\xfd\xa8\x21\x7d\x5f\x80\x54\x59\x6a\x61\xd5\x73\x7d\x8a\xd8\x11\x2a\xe2\x28\x22\x0e\x3b\xff\x60\xe2\xe8\x91\xd0\x3d\x53\xfb\x14\xf1\x4d\xd9\x19\x75\xdc\x15\xd6\xb7\xbd\x62\xe9\x9d\x74\xef\x38\x39\xfd",
        p,
        q,
        g,
        b"\x2a\xdb\xc0\x7d\x8a\xee\x28\x4e\xc9\x82\xc4\xb9\x5e\x1e\xc3\xec\x3f\x5f\xd5\x17\x23\x68\xdd\xf8\x3f\x9a\x3c\x69\x65\x52\x91\xde\xe6\xb9\x9e\xd7\x13\xe5\xa1\xfe\xc3\x38\x23\x9b\x81\x99\xc5\xa3\xbb\x2b\x5e\x2e\x7f\x23\xfc\x79\x50\x58\xa9\xac\x70\xeb\xdf\xf2\xb3\xda\xaf\xfa\x38\x9e\x97\xfe\xe3\x5f\x17\x49\x61\xf1\x2d\x63\x4e\x8b\x82\x50\xb8\xb7\x70\xb8\xd7\x11\x3d\x0f\xbc\x02\x0b\x7b\x10\x8f\x8d\x6b\x2d\x7c\xb6\xc5\x9e\x2e\x15\x10\x15\x14\x5a\x8e\x37\x4f\x9b\x73\x96\xe9\x70\xd9\x1e\x3c\x1f\x85\xce\x23\xdc\xae\x12\xb2\xf5\x37\x41\xcf\xc2\x35\x0b\x58\x2c\xa8\x7f\x0f\xf9\xab\x50\xad\x0c\xa2\x87\x9e\x21\x6e\x61\xa5\xc3\x58\x97\x0a\x3c\x35\x28\xdc\xd9\xec\xe6\xb8\x3d\x52\x5b\x31\xfe\x68\x76\x96\xa2\xa2\xc6\x5e\x34\xf2\x85\x4f\xea\x6f\xf9\x22\x44\xd2\x75\x00\xf7\xda\x94\x6c\x37\x16\x97\x56\xf4\xa4\x66\x4b\x29\x09\x61\x15\x49\xad\x2b\x93\xeb\xac\xeb\xfc\x27\x0e\xcf\x42\x04\xe6\x64\x1d\xbc\xe0\x5d\xa2\xc0\x00\xa4\xca\x5a\xc8\x85\x40\x6b\xa1\x55\x80\x74\x94\x70\x61\x80\xd5\x4c\xc0\x12\xce\x06\xe7\x34\x02\x4f\x4c\xcd\x88\x2b\xdd\xd2\x25\x7a\xfb\x5c\x28\x7b\xc3\xa8\x57\x0e\xdf\x21\xa2\x0a\xfe\xda\x0c\x76\x2a\xd6\x96\xfb\xa1\x77\xa5\xf2\xf9\xd6\x09\x35\x5c\xb9\x1d\x72\xcc\xac\x8b\xb9\xe7\xc3\xcf\xf1\x83\x4d\x86\xb0\x77\x2a\xec\x74\x1d\x7b\x4b\x3c\x3e\x43\xbb\x26\xec\x9f\x5e\x86\xb8\x68\x5e\xa5\xc6\x25\xb6\xae\xa4\x50\xa4\x6e\x85\xe3\x80\xb1\x58\xde\x6a\xaa\x27\x01\xff\xad\x0c\x7d\x1e\xd0\xdf\x35\x5d\x09\xd0\x6f\xe1\x75\x8b\x2f\x27\xa5\xd0\x2a\xa2\x83\xae\xc9\xfd\x12\xd3\xb6\x2d\x50\x4d\xca\x0b\x66\x32\xe8\x9f\xc5\x5f\xb0\x83",
        b"\x2c\x46\x2d\x49\x34\x4f\x3a\xd0\x3b\x67\x98\xf9\x64\x52\xf7\xd6\x63\x51\xce\xad\x91\x9e\x82\x01\xb7\x66\x5c\x87\x7f\x82\x55\xbb",
        b"\x50\xe8\x90\x8a\x1c\x66\x84\xa2\xca\xa8\xaa\xfb\x43\x2c\xda\x4b\x76\x99\x00\x8c\x72\xd8\xd6\x22\xc3\xda\x41\x71\xe5\x1c\xfd\xbf",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xe1\x06\x04\xca\x00\x72\x8e\x53\x36\x21\xdb\xb6\x61\x8b\x0c\x87\x7c\x49\x02\xa2\xed\x79\xaa\xf4\x0a\x4d\xaa\x34\xd6\xcc\x21\x6a\xd4\x64\x8d\xaa\xb6\xcc\x1e\x18\x45\x1b\xb9\x4e\x6a\x1c\x0c\x6f\x9d\x0d\x88\x39\x62\xee\xbd\x50\x7d\xa0\x99\x78\x80\x08\xda\x23\x20\x5e\x3b\x4e\x90\xfa\xd9\xae\x85\x70\x74\xff\xea\xc6\x34\x30\xc0\xfa\xcb\xae\x48\x9c\x54\xc9\x57\xdb\x09\xd5\x3e\x12\xb6\x56\xcc\x27\x86\x15\xa3\xa5\x61\x2a\xf4\xc2\xf1\x68\xbd\xeb\x11\x8a\x42\xa2\xa6\x71\x03\xfa\xc3\x21\xad\xf5\x68\x8b\x05\x84\x8f\x7c",
        p,
        q,
        g,
        b"\xb0\x44\x8d\x43\xc5\x20\x37\x7b\x7d\xf2\x14\x96\x9f\x59\xff\xd4\xe0\x01\x0c\x12\xd7\xe5\xfa\x8f\x24\x1e\x9c\xe1\xc6\x34\x43\x9c\x94\x70\x0e\xd5\x74\x2a\x83\x22\xd4\x05\xdd\x05\xde\x99\x53\x44\x78\x31\xc7\x67\x4e\x5a\xe1\xb8\x90\x41\xfb\x8f\x2e\xc1\x05\x4b\x92\x8c\x64\xab\x86\x2f\x02\x1a\x55\xeb\xce\x83\x8d\x2a\x3d\x2c\x76\x45\xec\x7c\x0a\x1a\x46\x03\x61\x7e\x4f\x50\x89\x29\x14\x4c\x1e\xf2\xb0\x39\xbc\x78\xb5\x93\x62\xd5\xba\x95\x37\x90\x6e\x66\xc8\xe9\xc9\xa3\xc6\x8e\x71\xb3\x5d\x88\xb8\xba\xc8\x6c\xac\xbe\xbd\x96\x2c\x66\xe1\x81\x29\x63\x7f\xad\x2d\x98\xd2\x1e\x45\xa3\x26\x72\x64\x94\x92\xf1\x31\xba\xe8\x8c\x99\x89\xbd\x63\x72\xe1\x74\x92\xbe\xdf\xf4\xd9\xb0\x91\xb3\xdd\x00\xeb\xca\x6b\xcc\x49\x14\x84\x80\x58\x9f\x95\x93\xe3\x27\x95\x29\x9f\x3d\xe7\xe0\x9d\x88\xbc\x0e\xd2\x7b\x7e\xf2\x2e\xf7\xd2\x02\x20\x7f\xb5\xce\x8c\x91\x71\x2c\x3b\xd5\xe7\x58\xd2\x82\x28\x09\xea\x5d\x2c\xb2\x88\x33\x2a\xa0\x76\x03\x68\x25\x92\x81\xa3\x44\x47\xff\x5a\x98\xc9\xc9\x7c\x1d\x58\x38\x3c\xd1\x4f\x6d\x59\xbb\x5e\x57\x63\x21\x7b\x23\x37\xec\x23\x21\x26\x81\x97\xf0\x2c\xec\xd0\xd9\xfd\x93\xdb\x39\xf8\x05\x9a\x38\xbb\xb3\x57\x92\xba\x0d\x4e\xd1\xba\xd9\x5a\x05\xb4\x81\xc3\x9f\x6a\xdc\x90\x17\xde\xc1\xd6\x62\xb0\x80\x3f\x2e\xcf\x08\x45\x93\x57\x65\xf9\x35\x6d\xb5\x36\xc8\xc1\x18\x87\xd9\xe4\x4b\x73\xb6\x99\x6a\xe7\xac\x24\xfc\xad\x9c\x23\x01\x7e\x5c\x2a\xca\x88\xb5\xa1\x36\xb6\x30\x72\x98\xb8\x5f\xf0\x10\xf9\x64\xb7\x47\x7a\x4f\x98\x08\x00\xe6\x9d\x3c\xc0\xf4\x38\xaf\xf7\xf2\xdf\x8a\xc6\x1d\x64\x43\x5f\xfa\xf5\xe4\x66\x33\x60\x9e\x87",
        b"\x56\xab\x99\x47\xac\x94\xfe\x3d\xf7\xe3\x58\x01\x66\x0f\x68\x75\x3b\x0b\x62\x0a\x26\x59\x4c\xb8\xfd\x37\x5b\xe3\xea\x4d\xbf\x05",
        b"\x60\x8e\xd1\x83\x51\x39\xaf\x29\xa2\xe3\xd8\x74\xdf\x46\x5e\xdd\x8d\x64\x28\xf4\x03\x57\xd9\xae\x49\x04\xef\xe8\xbc\xcb\xd0\x35",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\x8a\xf3\x1f\x66\x77\x2f\xb0\xc3\x1a\x8c\x5b\x28\xe5\x68\xe6\x36\x8c\xb6\x6b\x59\x1e\xdf\xb0\xdb\x86\x7f\xd9\x9e\x83\xfe\xb3\x63\x8b\xc8\x0f\x0b\x14\x48\x3d\x06\x9e\x8f\x2e\x16\x7c\x8b\x0f\x10\xcd\x6b\x45\xd0\x39\xb7\xd6\xf8\x33\xbd\x58\xd9\x9b\x00\x59\x7a\xee\xf8\x2f\xa3\xaa\xe2\xe5\x5d\xed\x62\xab\x66\x08\x10\xde\x0f\xe1\xc9\x2d\x53\xad\xf9\x8c\x83\x8c\x18\xfd\x76\xa2\x73\xea\x12\x11\x9d\x67\x5a\xf7\x27\x01\x18\x69\x94\x3d\x76\x5b\x96\xef\x26\x62\x70\xb4\xf8\x9a\xc7\x2e\xda\xdc\xf7\x07\xa4\xa2\x1b\x75\x33",
        p,
        q,
        g,
        b"\x22\xf3\xdb\x9e\xa3\x69\x93\x8e\xd7\x50\xd5\xed\x37\x81\x36\x8d\x59\x4e\x62\x63\x5c\x6b\x6e\x10\x3d\x6d\xb4\x89\xa9\x97\x2f\x39\x82\x03\xab\xb9\x73\xd5\xad\x9c\x0d\xc1\x10\x58\x69\x78\xd2\x06\x14\x83\xc0\x20\x27\x38\xce\xb0\x1a\x66\x5d\xd2\x2f\xc5\x68\xcb\xdf\xf2\x14\x8a\xe6\x64\xdf\xfb\xf8\x88\xe4\xdd\xa5\xa0\x4f\xd3\xe8\x93\x98\xb4\xf1\xff\xc3\xa3\x81\x3a\xe9\x4d\xa1\xf8\x96\x5e\xfb\xe7\xf3\x00\x94\x87\x49\xe9\x75\x7c\xc7\xc0\x5f\x6e\x53\xfd\xbf\xf9\x94\xc2\x23\xab\xa2\xc1\x37\x15\x1b\x6a\x32\x0f\x5b\x7f\x8c\xdd\x60\x03\xba\xa6\x60\x20\x16\x29\x90\x62\x40\x99\xf3\xcf\x56\xd6\x8b\x74\xe9\x6e\xe0\x92\x40\xf2\xcf\x11\xe3\x95\x4e\x75\xb2\x61\xef\x9e\x8e\x35\x51\xc6\xc0\x0f\x41\xe9\xeb\x17\x42\x12\x03\xa4\x56\x53\x88\xc3\x21\xc1\x32\x5f\x72\xeb\x10\xc2\x8a\x9d\xee\xdd\xcb\x48\x06\xf6\x25\x38\x2b\x37\xf0\xbe\xcf\x77\x93\x6b\x7f\x83\xd2\x6b\xf1\xee\x1f\xe0\x5e\x8a\x00\x05\xa4\x05\x8c\x67\x8e\xb5\x69\xe3\x39\x42\x3e\x7c\x84\x43\x05\xf4\xa1\x8b\x11\x60\xa0\xc4\x30\x51\x3f\xad\x71\x58\x96\xb6\x2b\x9d\x6e\x24\x68\x23\x2a\xe3\x75\xf5\xf3\xc0\x05\x62\x45\xeb\x46\x16\xba\x11\xa6\x02\x94\x10\xa9\x55\xaf\x09\xf0\x75\x95\xfe\xfa\x03\xe5\x51\x6c\x95\xa4\xcf\xcd\x66\x04\x6b\xe2\xa4\xf7\xb3\xab\x27\x4b\x21\xc0\xa4\xf1\x26\xc4\x82\xc9\x34\xc7\x9d\xcb\xbd\x69\x16\xf3\xb8\x87\xb2\x60\x04\x72\x49\x5c\x83\x35\xde\x12\x1c\x77\x20\xf2\x9a\xe5\x6f\x5c\xcf\x9b\x99\xc9\xce\x56\x55\xc5\xe1\xd1\x5d\x67\x89\x5a\xf0\xde\xe5\x86\xbc\x49\x1a\x97\x24\x1f\x7e\xff\x43\x4b\xb7\x9a\xad\x83\x1d\xb0\x69\x57\x81\xe6\xb5\x12\xe8\x70\x24\x07\xa7\xd7\x48",
        b"\x0f\xda\x7a\x8a\x3e\x5d\x32\x4f\xc0\xa1\xc2\x84\x1c\xd2\x2f\x98\x75\x7a\x0c\x6a\x2a\x46\x5b\x0d\x9d\x65\xbd\xa9\xb2\x3b\x3c\x1a",
        b"\x40\x86\x02\x65\x22\x90\x85\x45\x3f\xe5\x84\x87\xa9\x33\xed\xf3\xc2\x84\x33\x69\x4c\x7b\x85\xf6\x37\x0d\x9a\x47\x83\x16\x82\x37",
    )?;
    test(
        HashAlgorithm::SHA1,
        b"\xe2\x45\x6e\xf5\xd4\x65\x73\x1b\x97\x6f\x2a\xd1\xfc\x94\x63\x4c\x05\x69\xa0\xff\x75\x66\xa4\x9d\x47\xd6\x9e\x60\xb3\xb6\xd7\xeb\x2a\xb2\x5c\xd4\x9c\x93\x12\x99\x79\x6b\xff\x7e\x97\x74\x07\x5e\xa2\x0a\x97\x2e\x39\x49\xa2\x9d\xfb\x50\xb2\xb5\x61\x3b\x45\xc5\x96\xca\x5d\xab\x28\x2f\xf1\x83\xf5\x64\xa0\x63\x11\xa4\x96\x01\xa1\xe8\x56\x0d\x43\xc6\xa4\x81\xce\x71\x3f\x46\xc6\xea\x85\xbf\x4c\x16\x48\x9f\xbd\x72\xcf\x55\x2b\x26\x51\x62\x98\xbc\x66\x94\x2a\x05\xd5\xa8\xe6\xd0\xf6\xa8\x8f\x3e\x67\x8d\x31\x0e\x29\x7b",
        p,
        q,
        g,
        b"\xdc\x9d\x68\xb5\x3f\x35\xc2\x9f\x7c\xa0\x03\xa2\x58\x3e\xc8\xf8\xef\x5d\x78\xa0\xe4\x5d\xb3\xc8\x84\xd3\x5d\xf4\xfb\x53\x1a\x08\x0e\xe3\x83\x1b\xff\xd3\xc7\x56\xea\x50\x42\xc7\x61\x45\x70\xfb\xa2\xf6\xca\x48\x70\xdb\x4a\x45\x3d\x0f\x79\x3f\xb4\xd0\x22\x5d\x94\xf2\x74\x12\xdb\xdf\x43\x43\x2f\x52\xcb\x8f\x86\x7f\xe5\xf4\x92\xa8\x87\x6d\x7b\xd8\x50\xd8\x99\xba\x2f\x0a\x53\x82\x0c\x44\x08\x41\xfe\x0c\xb7\x6f\xe0\x44\x4b\xd6\xc3\x23\x57\x85\xa3\xda\x30\x81\xfe\xf9\x9f\x53\xa1\x95\x31\x4a\xef\xe9\x55\xf2\x96\x4c\x56\x50\x6f\xcc\x96\x9b\x67\xb3\x23\x76\x6d\x29\x9c\x0b\x02\x98\x1c\x72\xa2\xce\x3d\x75\x24\xae\x6f\x08\x45\x87\x95\xfd\x32\xe3\x1b\x47\xaa\x1f\x97\x4e\x35\x60\x81\x16\x3c\xb2\x3e\xfd\x73\xa9\xe6\x55\xde\xef\xe5\xe7\x34\xce\xb5\x8e\x88\xa9\xdb\xb5\x24\xef\xf7\xe1\x1c\x3e\x30\x68\x07\x02\xd8\x56\x0d\xd8\xb6\xad\x9f\x61\xe7\x24\x6c\x6d\xde\x16\x4e\x91\x49\x51\xd6\xa0\x57\x31\x52\xec\x8b\xde\xa6\x79\xdc\xa1\x98\x5b\xcf\x26\x73\x04\xd5\xf1\xbc\xe2\xf3\x2b\xb9\x94\x6a\x05\x68\x57\x35\x9a\xfb\xaf\xfa\x59\xbe\xe6\x1a\xd9\x60\xc5\x67\xef\xe3\xf1\x14\x5a\x8a\x87\xc2\x49\x1f\xa6\xb3\x3f\x7e\x71\xfc\xdd\x8f\x1f\xfb\xcd\x2b\x89\x92\x09\x07\xd1\x14\x4a\x8c\xf0\x57\x3f\x5b\x89\x21\x7b\xc0\x59\x8c\x6e\x17\x54\xf1\xae\x7d\x9d\x42\xa6\x08\xa0\x51\x62\x14\x19\xda\x91\xd1\x1b\xda\x9b\xb9\xdf\xa7\x11\x8e\x4b\x66\x3e\x7b\xff\xe6\xe9\x94\x6c\x77\xce\x9f\x80\x86\xdf\xc8\x22\xa7\xef\x72\x88\x88\xb3\x16\x54\xa1\x9b\x6d\xeb\xd2\xca\x62\xf5\xe3\xb4\xe2\x89\x81\x04\x35\xb3\x63\xec\xab\x51\x1f\x47\xe9\xe1\x57\xf0\xf4\x19\x88\x62\xca\x13",
        b"\x77\x86\x40\xce\x75\xda\x58\x4a\x6a\x83\xf9\x79\x4c\x4f\xfd\xbe\x30\x41\x1b\xe4\x30\x27\x75\x8c\x74\xf8\x9f\x7c\xcc\x7f\x39\x83",
        b"\x61\x25\x48\x1e\x10\x3f\x78\x03\xb2\xf1\x6d\x9a\x4d\x00\xf8\x81\xe0\xb3\x67\x02\x4d\xf5\x82\x2f\x7c\xbe\xb5\x71\x1e\x0e\x44\x01",
    )?;

    // [mod = L=3072, N=256, SHA-224]
    let p = b"\xf6\x3b\x3c\xdd\x64\x6d\x8e\x7d\xdb\x57\x21\x6a\xa6\xee\xc2\x13\x4d\x70\x74\x88\xa1\xf2\x9c\xfa\x99\x70\x64\x5f\x12\x27\xea\x5d\xb2\xe3\x18\xee\xa5\xda\x16\x87\xc7\xed\x90\x50\x96\x69\x34\x5e\xd6\x13\x4c\xff\x32\x20\x3a\xb7\x2a\xec\xbf\xa6\x93\xd2\x16\xae\xb5\x5d\x8d\x28\xa9\x81\xf4\xab\xff\x07\xd1\x31\x9a\x79\x9b\xe5\xdd\x74\x6f\x84\x84\x28\x17\x92\x9c\x30\x5b\x40\x85\x98\xaf\x12\x04\x5d\xaa\x2f\x1c\xcc\x8b\xe4\xd8\x1b\x51\x3c\x63\x0f\x01\x7f\xec\x16\x58\xac\xa1\x08\xa1\xaf\x61\x20\xec\x05\xe3\x01\x8c\x42\x53\xc9\xdd\x35\xbc\xe0\x62\xb7\x3d\x0f\x2a\x93\xd4\x1c\x48\x1a\x5c\x43\xbb\x97\x90\x96\x82\xd3\x9a\x9a\x60\xdc\x3c\x35\xe3\x63\x75\xde\xc6\xce\xd0\xd2\xdb\x3b\xa0\xd1\x11\xbe\xde\xa7\x01\xa0\xe4\x75\x36\x24\x97\x7a\x9e\x75\xb7\x0a\x74\xe2\xb8\x1e\x38\xa5\x2a\xb2\x2d\xa1\x31\xb3\x54\x16\xd3\xce\xc9\x66\x30\x79\x74\x6a\x76\x34\x76\xe5\x75\x98\x14\x2e\x39\x86\x15\x45\xda\xaf\x8d\x38\xa1\x76\xf2\x6c\x71\xf5\xaf\xeb\xd9\xc5\x62\x0d\xa8\x0c\xf3\x45\x2b\x55\xc3\x7c\x66\x1b\x4a\x1e\xc0\x35\x17\x10\xb9\xde\x4a\x3c\xbe\x0b\x98\xb4\xd9\xec\x89\x12\x8d\x97\xaa\x7e\xfb\x19\xdb\x8b\xa4\x3c\xc0\xbe\x25\xc2\x00\xf9\x0e\x15\x06\xcb\x78\xec\x0c\x33\x6d\x7a\x95\x61\x3d\x42\x04\xe8\xed\x68\xd0\xf0\xa6\xc7\x84\x20\x10\x5a\x8d\x2d\x43\x8f\xbd\x25\x51\xa6\x4a\x1a\x0b\x03\xff\xb8\x78\x74\x2f\x8c\x99\x79\xcf\xa8\x73\x94\x15\x02\x81\x99\x8d\x51\x70\x1d\x5f\xcf\xa9\x69\x6a\x49\x89\xfd\x25\xf4\x00\x95\x5e\x62\x6b\x1a\xbe\x92\x6c\x0a\xfa\x69\xaa\x69\x81\x90\x0e\xff\xcd\xd0\x30\x59\x2f\x82\xb2\x04\x2a\x47\xa9\xa5\xa8\xcb\x02\x83\xdc\x4d";
    let q = b"\x80\x00\x00\x00\xba\x46\x34\xb5\xfa\x4d\xa0\x54\xbd\x0c\xa4\x8a\xe4\x90\xe5\x77\x11\xf3\x81\x19\x38\x42\x42\x91\x59\xba\x7c\xa1";
    let g = b"\x8a\xd4\x55\x3c\x4e\x49\xaa\x24\x72\x8a\xb5\x02\x44\x17\xb1\x32\xd2\xca\x53\xa5\x5d\x95\x94\x58\xf2\xf7\x59\xad\xb0\x43\x5b\xee\xef\xa3\xa2\xcf\xcd\x00\x38\xe2\x42\x06\x43\xfc\x4a\x4d\xee\xb5\xd9\xfe\xaa\x1e\xdf\x21\x19\x3b\x40\xe1\x4b\x42\x98\x2a\x94\xf3\x5c\x58\xb8\x11\x47\xd7\x18\x9d\x26\x3c\x9b\x12\xfe\x63\xab\x9f\xa5\xf6\xf0\x3a\x28\x60\xc1\x86\x43\x2e\x3a\xb0\x4f\x2a\xb0\xf2\xfb\x61\x47\xbd\x9b\xf7\xed\x5d\x20\x71\x3b\x9d\xa2\x13\x83\xe2\xc3\xa1\x68\xe7\xd0\x9d\x3d\x8a\x5a\x05\x8f\xd2\x30\x95\xb5\xac\xfe\xb8\x64\xa3\x30\x6b\xe2\x42\x5f\xa1\xad\x32\xad\x6d\x93\x82\xe6\x03\xb0\x3c\x68\xaf\x4a\xf0\x24\x63\x97\x10\x2c\x41\x55\xcb\xa8\x11\xab\xf9\x9d\xa7\x83\x9e\x77\xb2\xea\xc9\x97\x05\x88\xca\x1d\x0a\x23\x61\x72\x3a\x16\x4a\xc9\x22\x9c\x2e\x80\xdc\xfa\x8d\xb4\xf9\xe2\x98\x03\xef\xfb\x31\x68\xc7\xfe\xd7\xa3\xa6\xde\x40\xdd\xa1\x9a\x05\x36\xaf\x9b\x5b\x7a\xfa\xef\xb9\xc7\x0d\x6a\xe8\xdf\x12\xda\x65\x8f\x62\x36\x04\x3a\xea\x87\x3d\xb2\x9c\xeb\x6f\x07\xd1\x08\xf5\x22\x56\x87\xbd\x0c\x30\xe3\x08\x4e\x20\x90\xb4\x5a\xe2\xf9\x2a\x97\xb8\xec\xb7\xa9\x70\x5c\x49\x56\xb8\xb3\x1c\x4a\x3d\x61\x10\x7c\x84\xe4\x7a\xdd\xa6\xc8\x0d\x5d\x22\xda\xb3\xd8\x59\x22\x0f\x9d\x5a\xab\x13\x67\x7a\xe3\xdf\x16\x8f\x0c\x17\x6d\x17\x6b\x54\x50\x6c\x63\x98\x53\xf0\x4d\xde\xf2\x72\x2f\x39\xc1\x8e\x5c\xe4\x26\xe1\x45\x62\xad\x8f\xf2\x62\x47\xaf\x88\x87\x0e\xfb\x72\xc0\xcc\xe8\x36\xde\x8f\xee\x67\xa6\x62\x37\x82\x45\xb5\x02\xbf\x1f\x83\x09\x99\x88\xa0\x93\xce\x7c\xdc\x81\x36\x4c\x78\xb1\xf4\xa5\x1b\x80\x0d\xf6\x13\x7c\x71\xd6\x5e\x6b\x08\x9a";
    test(
        HashAlgorithm::SHA224,
        b"\x95\x79\x73\xfc\x3f\x3f\xe3\xf5\x59\x06\x5b\xe5\xd4\xa0\xc2\x81\xcf\x17\x95\x90\x18\xb9\xa6\x70\xd2\xb3\x70\x6d\x41\xd5\x81\x2e\x37\x30\x10\x05\xf8\xb7\x0e\xbd\x2f\xba\x3c\x40\xa3\xf3\x77\xa7\x51\xb6\xcb\x96\x93\xe3\xcb\x00\xd9\x28\x88\x24\x7d\x07\x92\x1d\x3c\x1e\x92\x57\xce\x08\x73\x3b\x89\x26\xe0\xdf\x7b\xdb\x6e\x85\x5f\x1f\x85\x10\x75\xd4\xe6\x28\xd1\x10\xd4\x2b\x64\x3b\x54\x87\x6e\x5f\xaa\x36\x11\x47\x7e\xe6\x83\x71\x56\x25\x55\x26\x9e\xd6\x2a\x92\x71\xba\xd5\x0c\xc4\xd4\x60\x38\xde\x2d\xd4\x19\x20\xc2",
        p,
        q,
        g,
        b"\x42\x24\x35\x39\xe4\x9d\xb9\xea\x19\xd9\x8d\x97\xf6\xf2\xa9\x4b\x23\x52\x98\x12\xdf\x88\x9e\xaa\xbc\xfe\xda\x01\xce\x4c\x75\x94\x87\xfb\x89\xbc\x82\xda\x75\xfe\x1c\x91\x34\x36\x1f\x86\xde\x47\xd1\x6d\x8e\xee\x80\xe5\x6a\xc5\x02\x17\x8e\x8e\xd8\x12\x94\x77\xaf\x8b\xfb\xd8\x26\x2c\x5e\xdd\x93\x7e\x1a\x86\xc0\xf0\xe7\xb2\xaf\xe7\xbc\xbd\xdf\xcb\x58\x14\xce\xd0\xb7\x56\xa7\x6c\xa1\x78\x42\x3b\xb4\xd5\x78\xc5\xda\x18\x37\x12\xd9\x68\x58\x26\x40\xaa\x0e\xc7\xe9\xfb\x56\xbf\xd9\x60\xd7\xa5\x75\x49\x74\x7d\x8f\xb7\xad\xe4\x7c\xfe\x81\x6c\x1e\x57\xda\x66\x33\xda\xcc\x53\x7d\xe0\x60\x81\x39\x64\xbb\x5b\x27\x57\xa3\x12\xf9\xda\x3d\x84\xe6\x0a\xff\x98\x17\x00\x51\xd3\xd9\x0e\x38\x0b\x8b\xcc\x19\x86\xc5\x8f\xf9\xdc\x91\xe8\x82\x7d\x4f\x9f\x5f\xc4\xb2\xb2\xe7\x43\xcf\x93\x89\xff\x02\xde\xc0\x1f\x5d\x43\x4b\x43\x0d\x16\x2e\x89\x1c\x33\x55\xf9\x18\x55\x33\x9f\x8d\xf5\x83\x00\xe4\xc9\x93\xae\x4d\xf8\xc4\x31\x8b\x5c\x4b\xd0\x52\x83\xca\x4b\x46\xb7\xd2\xfb\x0f\x64\x76\xbf\x15\x90\x7f\x50\xdd\x41\x41\xaa\x7a\xca\xc9\xda\xa6\x2e\xcc\xd3\xa6\x73\x57\x12\x20\x60\xb6\xce\xce\x04\x46\xa9\x3e\xb2\x30\xad\x93\xbc\x9a\x4d\x1b\x1e\xfe\xec\xa1\xe3\xfc\x83\xc1\x19\x78\x50\x35\xb4\x39\x50\x9f\xfb\x79\x68\xb1\xa4\x48\xb7\xbd\x83\x15\x75\x3f\xdf\x04\xa2\x56\xec\xa1\x56\x2a\x11\xb0\x96\xc9\x0a\x36\xb3\x53\x65\x9c\xbd\xe4\x42\x0e\x17\xe9\x0b\x94\xc4\x3c\x75\x19\xc6\x06\x41\xce\xec\x05\x6f\x89\x7b\x97\xd6\xbb\x18\x61\x26\x8e\x0d\xc7\x9b\x7c\x3b\x6b\x76\x39\xc2\x55\xbf\x06\x86\x57\x37\x45\x91\x26\xcb\x46\x5b\xc1\xda\x4a\x04\x3a\x19\x63\xda\x7d\x63",
        b"\x2e\x59\xd5\xf3\x0f\x73\x78\x1d\x38\x25\x5b\x70\xde\xde\xeb\x38\xae\x78\xdf\x4f\x00\x2c\x1f\x74\x7c\x08\xde\xad\xc6\x53\x01\x55",
        b"\x61\x5c\x55\xb2\xdf\x0c\xa2\x8c\x60\xa6\xb3\x85\xc5\x8f\xa0\x36\xdf\x8c\x4b\x2f\x4f\x19\x35\x73\x0b\xf8\xf4\xf0\xbe\xd1\x36\x10",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x54\x07\x1a\xca\x28\x96\x97\x49\xce\x2e\x2d\xc8\x55\x05\x20\x19\xbe\xc2\x7d\x0d\xd6\xa3\x10\x21\x93\x11\xb4\xb6\xd8\x22\x46\x7b\x22\xb3\xf0\x2f\xb8\x31\x39\x93\xfc\x77\xc4\xaf\x1d\x76\xab\x9d\xb9\x9b\x0b\x2b\x78\x20\x4a\xa4\x5f\x40\x32\xa7\xd9\x45\xf9\x3d\x55\xbc\xb8\xa6\xbb\xd4\x7f\x98\x29\x9a\x09\x29\x71\x04\x61\x41\x9e\xdb\xe1\x13\x2d\xc2\x25\x75\xf5\xaf\xbe\x70\x78\xcf\x5f\x05\xb2\x31\x00\x0f\x4a\x0f\x9f\x36\x7d\x90\x25\xed\x3a\xe1\x78\x6e\x01\x83\xea\xc9\x3e\xa9\x6b\x55\x30\x4a\x8c\x2d\xbf\x69\x08\x21",
        p,
        q,
        g,
        b"\xef\x78\x15\x2e\xfd\x88\x13\x0a\x4f\xec\xfe\x23\x50\x37\xde\x23\x09\xb1\xe2\xf3\x22\xd4\xf4\x15\x47\x56\xca\xa8\xf0\xb3\xe4\x1b\xe4\x5c\x80\xd8\x95\xde\x56\x38\x92\x57\xc3\x91\x30\x72\x86\xbe\x8e\x87\x09\xb8\x01\x86\xe2\x72\x41\x72\xb0\xf2\x97\x4b\xe5\x91\x58\x49\x16\xfc\x0e\x75\x0c\x0c\xaf\x83\xd8\x39\xb5\xc2\x48\xf5\xde\x65\x86\x68\x66\x5f\x00\x4b\xab\x8a\xd3\x10\x11\x88\x35\x95\x7c\x02\xda\x6a\xe9\xa2\xa7\x9d\xa0\x39\xad\xc8\x84\xf9\xeb\x8b\x62\xe3\x79\xe2\x7f\x54\x9e\x7f\x8a\xff\x8a\xd2\xfc\x27\x6e\xce\x15\xf0\x42\x35\x28\xa0\x9e\x31\xb2\x64\x21\xdf\x93\x57\x3b\xec\x7a\x4d\x6c\x2c\xbf\xbe\x5c\xe0\xfc\xe0\x70\x20\x88\xfb\x38\x4a\xd1\xdc\x35\xbb\x2c\x1c\x74\x2d\x43\xd7\x9a\xd1\x36\xe7\x10\x57\xcb\x9f\x22\xca\x04\x2e\x61\xd2\xc5\xcc\x4c\xcf\x5b\x75\xa7\x37\x99\x22\xbc\x4f\xd8\x83\x72\xd2\xa8\xf6\xa2\x75\x08\x65\xf9\x1c\x14\x34\x12\xa3\xfc\x61\xe4\xad\x4a\xbd\x03\xdc\x1c\xa0\xfc\x42\x97\xab\x10\x7a\x19\x63\x53\x3a\x3d\x80\xa2\x4a\xe2\xec\x41\x46\xe8\x26\x5a\xcf\xd4\x44\x6f\xc2\x81\x03\xc5\x04\x7c\x17\x79\x6c\x41\x48\xb8\xe6\x58\xe4\x4e\x9b\x1c\x25\x9d\x63\xc9\x7f\x0e\x76\x6f\xba\x8d\x9a\x73\x94\xcd\xb7\x34\x50\x8b\xfa\x09\xae\x42\xd2\xda\x30\x68\xe2\xc8\x5a\xf2\x06\x5f\x61\x8e\xc3\xf3\xc7\x3d\x73\xa7\x50\xc1\x36\x44\xc9\x6e\x3d\xbb\xb7\x47\x43\x25\xaf\x48\xd1\xd1\x45\xc2\x8d\x69\xf2\x2c\xbb\x4a\x90\x73\x05\x9a\x9c\x40\x89\x18\x04\xc7\x3a\x22\x9f\x01\xce\xf0\x67\x8c\xf4\x85\x5d\x18\xf9\x00\xf0\x25\x3a\xcd\x6b\x3e\xe5\x3d\xd9\x6c\x4c\x92\xaf\xff\x1f\x30\x87\xee\xb4\xfb\xa8\x6d\x2e\x94\x95\xc5\xf7\x34\xa4\x6c\xa2",
        b"\x0d\xeb\xcf\x6c\x88\x50\x4a\x88\x2a\x01\x91\xe6\xfa\x4c\x77\x4c\x10\x85\x83\x62\x62\x94\x28\xaf\xf2\x4c\x22\xe3\x36\x4b\xaa\x15",
        b"\x53\xd8\xc1\xdb\xb3\xa2\xc1\x02\x35\x21\xb7\x05\x00\x5c\xe6\x35\x0b\xcf\x66\xc0\x93\x58\x8c\x35\xd7\x68\xfc\xa2\x95\xa4\xa9\xce",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x49\xd5\xf2\x0a\xcf\x1e\x9d\x59\xa6\x56\xbd\x16\x3f\xe4\x6f\xc8\x68\x47\x6c\xcd\x92\x63\x77\xa4\x0e\xd3\xd7\x47\x6e\x9e\xb7\xa8\xa7\x0c\x4b\x88\xb1\x6e\x79\x91\x48\xd2\x5f\xa2\x3b\xd0\xc9\x16\x11\xb7\x6c\x96\x65\xf5\x72\x2f\x40\x4f\xd9\x0e\xfd\xb8\xad\x14\xb7\x59\xc3\x49\xff\x6c\x83\x06\x42\xd5\x10\x76\xcc\xbd\xc5\x7f\x15\x2f\xba\x41\xc6\xa7\xf3\xcd\x39\x05\xfa\x7c\x85\x72\x65\xff\xc7\x59\x6a\x64\xdc\x69\x49\x0a\x93\x2b\x95\xad\xbc\x79\xa3\xb4\xf2\x1b\x2c\x6f\xb5\xd5\x83\x5d\x8b\xca\xe5\xd4\x4d\x91\x2a\x0a",
        p,
        q,
        g,
        b"\x8f\xf1\x30\x22\x08\x03\x16\xbe\xa4\x9b\x89\xa0\x6d\xd5\xa9\x71\xd8\x6e\x0c\x9a\x3a\xf4\x14\x25\x8a\x8f\x48\x50\x88\xb6\x6c\xc3\x8c\xde\xa0\x2c\xdd\x62\x09\x6c\x00\xeb\x0d\x1c\x2e\xe6\x62\xcf\xf1\x6f\x6d\x2d\x30\x44\x0b\x2a\xd9\xe8\x97\xb9\xeb\x93\x9b\x12\x99\xff\x87\x95\x57\xf1\x63\xf1\x7c\x8a\xc6\x0d\x0c\x6e\x99\x8b\x3a\x04\x4b\x43\xfb\xfa\xc7\xb0\xcc\x30\xa5\x79\xa6\xbd\xa1\xb4\xff\x59\x8a\x53\x1f\x9e\x37\xcc\x19\x01\xa7\xb0\x8e\x79\x4a\x74\x01\xd0\xf8\xca\x4b\xe5\x5b\xff\x7b\x17\x63\x21\x82\x85\x75\xa4\x77\x68\x6a\x98\xb4\xb1\x72\x66\xe1\x01\x60\x1f\x43\x6e\x55\x4b\x9e\x42\x88\x05\x79\x70\xfa\x34\x63\x34\x3e\x7e\x52\xa5\x8c\xa1\x45\xec\x9b\xef\xd7\xbe\x31\xea\x76\x6e\xd7\x4a\xc1\x78\xbc\xcd\xfe\xe9\xd2\x95\x65\xe7\x93\x5e\x8d\x70\xc3\xeb\x09\x1e\x3e\x3b\x3e\x6e\x77\x71\x69\x31\xed\x72\x9c\x49\xb9\x64\x43\x60\x60\x98\xbd\x08\x10\x98\x9e\x0e\x6f\x25\x3c\xf3\xec\x38\x29\x42\x31\xb7\x11\xb0\x9a\x94\x16\x09\xac\xc8\x97\x68\x19\x07\x65\x43\x92\x6e\xc4\xe0\x6f\x3e\x4d\x7f\x12\x3c\x2b\x87\x71\xe5\x45\x89\xe0\x45\x24\xe3\xb4\xf9\x50\xda\x56\x0a\x25\xd1\x21\x72\xd4\xeb\xda\xdc\x17\x19\x40\x0d\x91\xcf\x02\x64\x70\x87\x14\x47\x92\x00\xc5\x0e\xf0\x0e\xc0\xe6\x04\x90\x9a\x54\x6c\x95\xeb\x2f\xa5\x3c\x65\xee\x72\xad\x53\xf1\x49\xc9\x38\xdc\x21\x93\x49\x6d\xb0\x7a\xf3\xb3\x0a\x1f\x43\x97\x08\xaa\x11\x5c\x8d\xd4\x7c\x81\xc1\xbc\x68\xea\x3a\xbd\x90\x26\x11\x3c\x01\xeb\x05\x55\x8b\x8a\x2b\xe9\x09\x34\x76\xf0\x12\x47\xbf\xbe\xb3\xf2\x85\x8b\x13\xe6\x22\x8b\x98\x20\x5f\xa7\x10\xb6\xaf\x1c\x5f\x71\x48\x0d\xee\x40\x1d\x74\x72\xd7",
        b"\x19\xa7\x3b\x04\x9b\x16\x4d\xbf\x7f\xb2\x82\x6f\x42\x53\x61\x7c\xf1\xc5\xbb\x46\xff\xc5\x20\x4e\xfa\x00\x00\x2a\x79\xe2\x3c\x0b",
        b"\x7b\xe1\x37\xc1\x09\xe6\x8f\x33\x7b\x5a\x21\xcb\x59\x1a\x87\xaf\x1c\xb8\x68\x14\x19\xf8\x75\xff\x8f\x04\x1e\x82\x99\x91\xfe\x28",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x11\x90\x85\x3e\xfb\x7e\x04\xcd\x49\x47\xc1\xea\x5b\x1b\x5d\x9e\x0a\xc5\xe6\xdf\x1d\xd0\x50\x87\x73\x08\xf1\xb2\xc7\xe0\xa4\x91\x7e\x58\x81\x03\xd2\x8c\x0f\x6e\x8b\x72\xd9\x67\xaa\x06\xac\xa6\x8a\x98\x6d\x80\x77\x40\xf2\xdd\xdd\xe7\x28\x1e\x55\x0a\xf4\xf6\x37\xea\xdf\x61\xf8\x80\xc7\x35\x1b\x48\x66\x15\x09\x6f\x6b\xa5\x0d\x87\x54\xbb\xf9\xba\x1c\x49\xa3\x48\x58\x15\xef\x06\xb3\xcd\x76\x1b\x55\x86\xc3\xfc\x2b\x46\x4c\x6f\xe1\x2c\x16\x0a\xb0\xf6\xf4\x46\xfa\xbf\x74\x21\x24\x30\xce\xc1\x5e\x75\xa5\x7b\x10\x2e",
        p,
        q,
        g,
        b"\x9b\xb8\x1c\x80\xd2\xb8\xa6\x01\xa0\x9e\x22\x47\x5d\x70\xd1\xdc\x55\x13\x40\x9f\xb4\x66\x8b\x17\x6c\x76\xb3\xaa\x1a\xf8\x63\x0a\xc7\x79\x0a\x44\x44\xab\x82\x37\x87\xf6\xf5\x69\xbd\xf0\x2b\x9e\xef\x5e\x7b\xb2\x1a\x88\xe3\xd3\x29\x68\x57\xe9\x19\x19\xf3\xc4\x73\xad\xd1\x6b\xcd\x76\x3f\x31\xa2\xf9\x84\x4d\x7c\xbd\x8d\x48\x06\x72\xa0\x36\xc4\xb1\x04\xbe\x66\xac\xd6\x6e\x6e\xf0\xe8\xa7\x44\xb3\xd8\x78\x09\x0d\x1d\xe9\xf1\x05\x56\x02\x47\xc6\x21\x53\xe1\x17\xef\xa5\x5e\xc6\x1c\x17\x7c\xd8\x2f\x8d\x72\xc5\x1d\x25\x3f\x4d\xc7\x33\x6f\x79\x82\x60\x25\x61\x9f\xb2\x10\x3f\x91\x14\x4f\x90\xf6\xa6\x89\xab\xcc\x51\xc6\x8a\xff\xd2\x84\x62\x57\x8b\x18\x3e\xec\x94\x20\x58\xf4\x8a\xbf\x54\x6f\x73\x89\x40\xa6\xc2\x6d\x30\x1c\x4b\x90\xca\x40\xea\x49\xc1\x17\xd6\x11\x47\xe8\x68\x39\x89\xba\xed\x7a\x22\x1c\x4f\x22\x09\x2f\x72\xb1\xed\x60\x4b\x6a\xa9\x4f\xf6\xa5\x74\xb4\x21\x5b\xd6\xf8\xe9\xd7\xb6\x38\xaf\xa4\x35\xa3\x34\x65\x89\xa6\x1b\x1d\x1d\xb2\x98\x9d\x7b\x45\xf3\x23\x45\x45\xe8\xa2\x2d\x60\x5a\xd6\xcb\x03\x6e\xf7\x91\xf6\x25\xd2\xc6\xa9\x95\xed\xa3\xe0\xca\xfc\xe7\x04\xa2\xbf\x15\xab\x5d\xfa\xd0\x16\x21\x04\x59\x2d\x23\xf5\x2a\xa0\xfe\xa1\xf4\x32\xf0\xa3\x08\xd1\x6a\x45\xe1\xf4\x1f\x82\x32\x62\x07\x4e\x91\x73\x75\x4c\xeb\xa7\x0c\xd8\xa3\x70\xdb\xab\x1a\x14\xf8\x41\x59\x11\x6d\xa7\x3d\x3a\x9c\xf8\x25\x94\xcb\x3a\xf9\x57\x97\xcf\x44\x42\x72\x85\x05\x89\xac\xc6\xbc\xa4\x71\xd0\x76\x33\x5d\x67\xc4\x61\xdb\x60\x23\x95\xbf\xb1\x7c\x39\xbf\xa2\x4d\xf1\x40\xc0\xac\x43\x88\xdb\x05\x34\xa5\x0d\xfd\x26\x13\x74\xf8\x1b\x31\x0f\x75\x1d\x16",
        b"\x58\x7d\x7f\x44\x54\xd5\x94\x18\xa7\x52\x75\x70\xf2\x8f\x1b\x07\x45\x1f\x3b\xaf\x28\xf5\xca\xbe\x03\x10\xc4\xd7\x9e\x42\x53\xa5",
        b"\x18\x83\x94\x04\xaa\xad\x59\xff\x24\xd6\xac\xce\xc3\xb7\xcc\x6a\xc7\x00\x3d\xd4\xad\xf9\x6b\x77\xba\xb0\x68\xae\x72\xf2\x5f\x61",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xb1\xcb\x43\x0c\x5a\x1d\x72\x78\x8c\x79\x5a\xb5\x67\xa8\x4c\x7f\x59\x77\x96\x59\x33\xa5\xbf\x23\x80\x58\xf2\xfc\x81\x88\x80\xd2\x5b\x4d\xde\xf9\x63\x54\x81\xfd\x9f\xdd\x45\x98\xae\xce\xc3\x76\x4f\xa7\x30\x93\xa2\x25\xd4\xe4\xeb\xcf\x01\xe4\xb7\x5b\xdc\x18\x41\xdc\x01\x65\x2c\x4d\x99\x16\xaf\xa2\x4b\x89\xc2\xd6\x85\x4b\x72\xea\xa7\xb1\xf3\x08\x9d\x1a\x91\x92\x10\x83\x1a\xc8\x0f\x99\x83\x57\x90\xce\x64\xab\xc3\x42\x70\xcd\x45\x51\xd3\x1b\x8f\x53\x48\xce\x8a\x70\xdf\x60\xb8\x8e\x08\x5a\x98\x4a\xca\xc6\x65\xa7",
        p,
        q,
        g,
        b"\xa8\x1a\x54\xbe\x06\x85\xf3\x35\x05\xae\xd9\x59\x1f\x33\x3a\x74\xa8\x42\x99\x5d\xa5\x13\x5f\xa4\x8f\x50\x53\xfa\xc2\x9f\xff\x08\xaf\xd9\xb9\x01\xc3\xdf\x13\x47\x20\x4a\x3f\x13\x3a\x7d\xff\x6b\x1a\xdb\xab\x07\x75\x26\xb6\x38\xa6\x38\x37\xd7\x84\x43\x39\xd4\x8f\xe1\x07\xaf\x08\xed\x62\xe8\x7d\xe5\x47\xce\xd8\x4d\xf9\xa2\xcc\xc4\x58\x76\xb2\x9b\xc5\x36\x1c\xe8\xa9\xa2\x1b\x81\xd4\xf8\x5d\x3b\x67\x1c\x9b\x44\xb5\x48\x3f\x26\x10\xef\xa0\x17\x51\xd3\xa0\x7f\xd6\x94\xe4\x66\x53\xac\x47\xac\x64\xa9\x10\xb7\xfc\x42\x1f\x07\xe5\xde\x54\xe8\x98\x78\x99\x89\x09\x1e\x9e\xd5\x8b\x7c\x04\xe9\xe1\xdc\xed\x60\x47\x5d\xc6\x93\xa0\xeb\x40\x15\xed\x65\x81\x10\xb8\x2f\x8e\x72\x0d\xc7\xaf\xff\x69\xce\xa7\xb8\xe5\x6b\x8a\x97\x55\xbf\x1e\x29\x33\xd0\x83\x60\x83\x77\x50\x4c\xab\x52\xd3\x8c\xce\x1b\xa8\x2f\x84\xc2\x62\x65\xe6\x93\xf1\x8c\xf5\x2e\x93\x0d\xc0\xd8\xbc\x9d\x41\xf4\xd2\x8b\x32\xb7\x40\x5c\xb1\xfc\xe8\x8a\x55\xbe\x40\xdc\xa1\xb1\xa3\x51\xaa\x7d\x77\xfa\x6e\xf8\x4c\x77\x6f\xa3\x01\xdb\xa2\xe2\x36\x93\x3d\x89\xc8\xb9\x44\xf5\x34\x03\x41\x4d\xf0\xd4\x34\xdb\x72\xca\xa7\x49\xfb\xcd\x56\x6d\x76\xf4\xf6\xf0\xbc\x40\xe4\x2a\x29\xae\xbe\x62\x10\xe8\x9f\xa0\xca\x8b\x6a\xc0\x8a\x4c\xac\x65\xc5\x90\x50\x35\x33\xc3\xe4\xf1\xb3\xc5\xbd\xe8\x68\xe7\x9d\x9d\xa9\x18\xb7\x2d\x1b\x09\x8a\x72\x78\x76\x95\x46\xb7\x84\x50\xe0\x0e\x46\xdd\x40\x0e\xfe\x97\xc8\x84\xdb\x96\x12\xba\xaa\xee\xe2\x48\x6f\x64\xcd\x83\x02\xa4\xc3\x2d\x8f\xdb\x87\x3f\xe0\xaf\xff\xd7\xbb\x74\x81\x12\x20\xb0\x13\x39\xdf\xc5\xe5\x67\xc7\x66\xaf\x28\x05\xec\x1c\x30\x12\x63\x99",
        b"\x60\xd2\x76\x3f\x01\x38\x07\x6e\x9e\x0e\x20\xf8\x3e\x4a\xa2\xe9\xaa\x35\x2c\x19\xca\x79\xe3\x72\x63\x03\xfe\x89\xb1\x2e\x27\xf2",
        b"\x07\xe0\x8d\x91\x6c\x8a\x10\xba\x26\x9d\xc4\x60\xee\x9d\x83\xf8\x6a\x7b\x3d\x98\x62\x1b\xb7\x32\x4a\x6a\x7e\x60\x72\x38\xba\xa3",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x3b\xb9\x43\x0e\xea\x69\x79\x12\x9b\xe7\x45\xd5\xae\x6b\xab\xd4\x96\x6e\x3a\xbf\x7d\x9e\xe5\x85\x6f\x2c\xaa\xe6\x01\x4c\xb3\x40\xee\xbd\x28\xbd\x9f\x39\x1e\xb4\x6b\x3a\x2b\x8a\x4c\xdc\x22\x4e\x55\x08\x53\x2c\xa0\x8c\xb1\x04\xaf\xf6\x77\x13\x3c\xf4\x39\x3a\x20\xfe\x44\x99\x96\x7d\xfa\x64\x51\x54\x55\x93\x0c\x65\x9d\x43\xbb\xee\x23\x40\xb1\x4a\x3b\x33\x42\xd4\xb9\xa4\x66\xb8\x89\xe8\x50\xdf\xf4\xb2\xa5\x1d\x38\x9c\xa3\x2f\xb6\xa5\xf4\x33\xed\x93\x03\x2b\xe4\xe5\x63\x69\x57\x97\xb8\xc1\xe1\xe0\x19\x18\x41\x72",
        p,
        q,
        g,
        b"\x75\xb7\x65\xec\xa4\xeb\xde\x0b\x65\x64\xc3\x13\x7f\x16\xcd\xae\x00\xee\xad\xd2\xd0\xb2\xcb\x83\xcd\x15\x00\xcd\x05\xed\x0d\xd1\x67\x30\xc9\x50\x1c\x8a\x35\x3a\x64\x63\x4d\x06\x5f\x61\x37\xff\xcf\x95\x63\xd9\x61\x27\x90\x6f\xb1\x7d\x5a\x79\xad\x29\x10\x24\xa4\xa6\xfb\x7e\x7d\x08\x02\x19\xa6\x23\x1c\xa1\x58\xb6\x5f\x52\x02\x91\x2d\xdc\xb8\xdd\x1f\x01\x8c\x9b\x0e\x76\xb3\xa4\x76\x33\x6c\x50\x41\xbc\x50\x2f\x8a\xcb\x74\x8f\x13\x6c\x3d\x78\xcb\x2c\x42\x9c\x8f\x1a\xc1\x7b\x63\xdd\x7e\x9e\x57\xb6\x07\xf9\xde\xbe\x57\x14\x59\xdf\x36\x88\xcf\x4c\x11\xfa\x1e\x84\x53\x3a\xec\xda\x2d\xfe\xce\x05\xf4\xbd\xb2\x68\xcc\x7b\x0c\x8f\xe7\xaf\x5a\x63\x3a\x83\x51\x5a\xda\x95\xf3\x18\x24\xd6\xa3\xc7\x12\x2f\xdc\xd1\x2f\x54\x99\x2c\xbe\x64\xd1\xd6\xbd\xbd\x0a\xb5\xae\x4d\x19\xaa\x52\x60\x97\x50\xa1\xde\x18\x6a\xfa\xb5\xa1\x63\x98\xda\x47\x3d\x12\x88\x82\xb0\x65\xe8\x73\x80\x9f\xae\x0b\xbd\xc0\x1a\x9c\x73\xb5\xc6\xee\x65\x85\x7f\xa7\x94\xa1\x50\x58\xdd\xfb\x24\xa9\xa1\x7a\x04\x08\x64\x6f\x20\x09\xdd\xa6\x10\xc8\x29\x1a\xe1\x48\xa1\x8c\x17\x3f\x83\x6b\x19\x7c\x78\xed\xe5\x65\x48\x95\xb4\x5a\x34\x19\xe9\xc3\x17\x7f\x25\x03\xa9\x3c\xe5\x26\xbe\x14\xad\x91\x99\x39\xeb\xe3\xf2\xd0\x7f\x00\x6a\x0b\x02\x2d\x6a\x62\x3c\x60\x17\xf0\xc7\x66\x19\xf0\x78\x05\x31\xd5\x39\x0d\x42\x39\xb2\xf9\x00\xef\xb4\x4c\x95\x30\xc7\xd9\xb3\xe8\x4a\x70\xc9\x04\xb1\x79\xad\x0c\x4f\x90\x92\x50\xf7\xcc\xf8\x3c\x5f\x42\xd6\x43\x7c\xbc\x9f\x03\xfb\xae\x81\x31\xa1\x2d\x33\xe0\x17\x21\xe6\x50\xae\xe9\x1e\x1c\x89\x3f\x5e\x7e\x03\x9e\x0d\x58\x5c\xd7\xcd\x74\x95\xc4\x0d",
        b"\x74\x16\x72\x9a\x1f\x60\x20\x8b\x7f\x83\x74\x80\xfb\xa8\x18\x40\xe4\x5b\x33\x8a\xb9\x84\x6e\x9b\xbb\x91\x68\x22\x9f\x64\xbc\xea",
        b"\x58\xeb\x90\x40\x76\xa3\xac\x69\x07\xd7\x50\xff\x6c\xdf\xaa\x46\x54\x35\xe9\x98\x2e\xcb\xdf\x72\x19\x7b\x09\xbb\x6d\xf1\x37\x3a",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x55\xa6\x9f\xc1\x6f\x6b\x75\x3d\x0b\xf6\x5e\x84\x4d\x06\x78\x59\xf5\x1d\xd3\x29\x27\x99\x80\x19\x60\x63\xfb\x59\xf8\x9b\xd7\x78\xa9\x24\x4f\x93\x2c\x2a\xdb\x68\x11\x18\x36\x12\x10\x5d\x1c\x52\x7e\x83\x02\xdf\xee\x50\x42\xcf\xce\x5d\xbe\xab\x16\x5a\x39\x6f\x5a\x4c\x21\x33\x9b\xe1\x02\x1b\x7e\xce\xc6\x6f\x21\x77\xf9\x42\x43\xef\x62\x61\x60\x8c\x56\x91\x96\x79\xd4\x48\x63\xcf\x9d\x2a\xfc\x60\x10\xfc\x2b\xf8\x21\xb9\x31\xca\x39\x70\xd6\x9b\x1e\x62\x2a\x90\x83\x89\xdb\x50\x49\xd7\x18\xe3\x57\x07\x10\x63\xae\xf8",
        p,
        q,
        g,
        b"\x61\x46\xa5\x1d\xeb\x79\x95\x7a\x83\xb2\xc7\xa3\x20\x4b\x5c\x34\xae\x4f\x8e\x0d\xb6\x0f\x0c\x07\xe7\x08\x03\xf2\x2b\xf9\x9a\x39\x64\x72\x63\xdb\x9e\x28\x5d\x72\xf6\x27\x0e\xe1\x0f\x18\x58\x4c\x39\x08\x1d\x25\x44\xd4\x05\x02\xc5\x0d\xf1\xe3\x5a\x45\x76\x00\xb5\x56\x9d\x61\xe8\x12\x6c\x05\x5f\x7b\x96\x45\x72\xe9\xf3\x28\x2e\x4d\x97\x45\x00\x69\x55\xc2\x42\x61\xc6\x8d\x7c\x0c\xb3\xf0\x8b\x0b\x0d\x8e\xaa\x97\x1e\x1a\x63\x1c\x68\xa3\xa9\x14\xd3\x5e\xfe\x89\xf7\x6b\x9c\x21\x16\xaf\xb7\xbd\x19\x89\xe2\x02\xe0\x92\xb5\xb5\x70\xea\xef\xcc\x93\x35\x42\xe6\x50\xd9\x2c\x03\x3b\x59\x73\x82\x1d\x6d\x77\xcf\xc2\x43\xf7\x44\xda\x80\xb5\x6e\xae\xa7\x65\x0b\xf5\x08\x02\x51\x62\x28\xad\x6d\x5b\x0d\x4e\x88\x9c\x57\x5e\x36\x78\xff\xdb\x1c\x28\x9e\x59\xd9\xff\x7f\x84\xa3\xd6\x3d\x39\xd6\x88\x8d\xbe\x21\x3e\x2c\x3b\x31\x14\x08\x5e\x00\x6a\xd7\x45\x05\x73\x9f\xce\x82\x6f\x96\x32\x84\xdc\x4e\x2b\x01\xec\x2f\x92\x33\xd3\x47\x0e\x82\xd8\x72\xed\x94\x4e\x62\x96\x1f\x64\x13\x4e\x80\x80\xda\xf2\xdf\x49\x4a\x76\x24\x0a\xc0\xcd\x22\xf9\xaf\xae\x7e\x80\xd3\xcf\x3e\xfb\xe0\x55\x14\x7f\x62\xff\x8c\x61\x92\xe3\x88\xb4\x9e\x47\xd9\xfe\xaf\x19\xec\xcd\x65\xdc\xa9\x99\x16\x38\xeb\xd7\xb0\x48\x07\x77\x07\xad\xab\x1c\xb2\xa4\x35\x8e\xef\xc4\xaa\xb8\x25\x1f\xb0\xf9\xd5\xf0\xb0\x9f\x29\x9c\x72\x0d\x3a\x8c\x00\xa5\xa4\xd8\x4f\xee\xc0\x40\x05\x70\x40\xb7\x09\xcc\x0e\xd1\x85\xa8\x32\x53\x7b\xc4\xb2\xdf\x0e\xc1\xf7\x71\x69\xac\x96\xe9\x12\x82\xde\x21\xf3\x42\xd5\x42\x9e\xc3\xd6\x6a\xd9\xd3\x36\xc4\x40\x94\x9a\x12\x11\x21\x7b\xf5\x4a\xad\x93\xbb\x4b\x0a\x43",
        b"\x13\x6f\x93\xdc\xc7\xd3\x3e\x55\x9b\x8d\xb0\xaf\x13\xe0\x0c\x71\x90\x92\x8b\xff\x50\x86\xee\xdf\xd1\x17\x06\xe6\xf2\x34\x9a\xd0",
        b"\x32\xb9\x5b\x9b\x14\x7c\x7d\x1a\xc2\xa2\xf0\x05\x7f\xc0\x53\x8a\x4b\x7c\x9c\xd4\x65\x2e\x67\x83\xe5\xd7\xe3\x53\x46\x55\x63\x1a",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x15\x67\x89\x0c\x69\xe5\x78\xa2\x7d\x62\x08\x91\x3d\xfb\xc2\x0e\xdd\xc6\x1f\x5f\xee\xd4\x57\x40\x06\x93\xdd\x17\x0f\x80\x67\xbf\x29\x0b\x11\x15\x07\x80\x68\x4c\x20\xd5\xcf\xd2\xbf\x1d\x53\x6d\xd3\xb7\x00\x25\x88\x3f\xb4\x17\x03\x43\x6f\xd0\x9c\x0a\x14\x11\x25\x78\x4f\x90\x91\x15\x13\x03\xef\x80\xcd\x34\x5e\x5a\x7d\x28\x54\x33\x5c\x29\x84\x53\x8c\x5c\xd7\x39\xb0\x07\x24\x8c\xd9\x9f\x1d\xbc\xd3\x14\x8c\xb0\xff\x0d\xb6\x33\xf8\xca\xfc\x7a\x0b\x99\xc6\x1e\x78\x4d\x03\x03\xa5\x12\x03\x07\xd3\xfb\x3c\x4c\x21\x9e",
        p,
        q,
        g,
        b"\x5c\x53\xd1\x3a\x1b\xee\x17\xa2\x87\x20\xb7\x08\x96\x46\xd0\x7a\x3f\xd5\x8b\x9b\x2b\x23\xec\x94\xaf\x31\x44\x83\x07\x46\x17\x7b\x0d\x20\x73\x70\x7b\x6b\x84\x90\x1f\xfa\xa7\xa4\x16\x5c\xef\xf2\x42\x56\x40\xfc\xfe\x5d\x17\x65\x0a\x44\xa1\x68\xeb\xd7\x69\xc8\x33\x44\x5f\x1b\x2d\x26\x43\x4c\x22\x8c\x1e\x2e\xdf\x17\x04\xd7\x11\xa8\x62\x57\xbe\x25\x23\x5a\x7c\xea\x1e\x5c\xba\xc4\x12\x23\x5b\x75\x96\xd1\xdf\xa0\x39\x80\x81\xa4\xf1\x81\x51\xcb\xb5\x1d\xc6\x2c\x22\x6a\x2a\xbc\xaf\x33\x35\xe8\x6a\xb5\x46\x08\x04\x0e\xe8\x14\xe4\x43\xb6\x43\x98\x21\x3b\xa6\x0d\x7b\x5a\x3c\x8e\xa7\x8e\xc6\xb9\x89\x34\xc8\x9a\xca\x05\xb9\x7d\xf5\xf6\x5b\xc5\x74\xa3\x0a\xcd\xdd\x09\xf7\x3c\xec\x14\x52\x8b\xe4\x9a\x2f\xbe\xca\x70\x29\x1b\x1b\x29\xf7\x04\x2c\x59\x49\x94\xda\x12\x8f\xda\x22\xb3\xed\x3a\x93\x5a\x1a\x00\x57\x5f\xf1\xff\xd1\x93\xc4\xca\xc5\x3a\x2a\x2d\x4b\x0c\x51\x02\x28\xa7\x6a\x74\x33\x36\x07\xd1\x5b\x56\x86\x14\x42\x71\x44\xb4\x17\x4d\xa3\x58\xe3\x83\xf6\x58\xc6\x0b\x45\x71\x00\x36\xf5\x4f\x93\xf1\x7b\xc8\x08\xb3\x02\x67\x4e\x83\x8c\x1d\xfd\x7f\x81\x6f\x7e\xa4\x4b\x0d\x97\x38\x6e\x4e\x16\x34\xc9\x53\x95\x68\xdd\x6a\xe1\xc2\x8f\x25\xb2\x7a\xa9\x44\x99\xae\x38\x9a\x09\x26\xc8\xfa\x62\x95\x6c\x6e\x24\xdc\xed\x0a\xfb\x04\x91\xdd\x9f\xac\x05\x16\xd2\x7f\xd4\xd2\xdd\x01\x50\xee\x6b\x4c\xff\x7b\xfd\x57\x50\x43\xd7\x01\xda\xad\x0f\x1b\x94\x2a\x0e\x4c\x61\x95\x6b\x32\xa6\x8c\x90\x78\xf6\x07\x7f\xa9\x94\x51\x98\xd4\x47\xa5\xbf\x3c\x47\xb7\x28\x84\x27\xed\xc6\xf9\x96\x55\xae\xad\xf8\xde\x18\x51\x57\x14\xc6\xb9\xc0\xd4\xce\x5a\xb0\x92\xc2",
        b"\x49\x47\xd3\x6e\x74\x26\xf1\x44\x1b\xe5\xa7\x5d\xc9\xcd\x84\x54\x50\xc6\x11\x04\xf1\x9e\xd4\x0c\xe3\x3e\x25\x2f\xa2\xc2\x62\x68",
        b"\x35\x68\x79\xde\xb1\xda\xef\x01\xda\x04\x75\x0d\x58\xe5\x98\xdb\x47\xaa\xaf\xf5\x0b\x1c\xf4\x2d\x87\x33\x4a\x61\x57\x80\xff\x8c",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x4f\x7d\x89\x4d\xfb\x7d\x82\x04\x0a\x9f\xed\x6c\x26\xa7\xd2\x7a\x9a\x15\x11\x38\x8c\x11\x3c\x64\x71\x5a\x06\xdc\x46\xfc\xf4\xf9\x04\x07\x0a\x6e\xd9\x5b\xdd\x8d\xc1\x73\x0a\x27\x64\x5d\x37\xeb\x3b\x02\x84\x7c\xb1\xc6\x31\xec\x0c\x67\xb2\xee\x07\xb8\x80\x5b\x34\xdd\x9b\x84\xe6\xab\x3f\x9a\xfb\x92\x46\x99\x4e\xa5\x79\x56\x7a\x8f\x4a\xf7\xfe\xb8\x68\x98\xcc\x9c\xb5\x34\xc3\x87\x99\x3c\x6e\xc1\x65\x84\xac\x85\xbe\xd3\x6b\xbc\x2c\x30\x57\x70\xf2\x11\x63\x68\x61\x67\xdd\x53\xfe\x56\x23\x62\xff\x54\x9d\x90\x35\x39",
        p,
        q,
        g,
        b"\x00\x96\x74\x78\x35\x8d\x7c\x16\x96\xce\xb9\x2b\xe8\x50\xf5\x53\x8a\xd8\x54\x3e\x15\x1a\xad\xd8\x4c\xab\xa1\xb7\x2f\x36\x36\xa2\x09\x2a\x86\xb6\x46\x28\x73\x90\x3d\x5b\xf1\x7f\x61\x2b\x45\xb5\x13\x3e\xac\x16\x30\xbf\x07\xc0\x37\x14\x23\xd2\xe5\xd7\x14\x7c\xea\xcc\x9b\xaa\x8c\xb3\xb0\x4c\xbc\x3c\xbd\xa4\x29\xab\x40\xd7\xe5\x92\x73\x0d\xc4\x77\xb0\xa9\x5f\x1f\xb5\xed\x5d\x91\xe1\x4b\x9d\x5a\x1a\xc8\xd4\x03\xa5\x5a\x65\x8d\x1c\x38\x3b\xb5\x98\x05\x3b\xe2\x38\xcd\x82\x38\x69\x68\xae\xdb\x81\x15\x86\xfa\x2a\x14\x11\x93\x24\x89\x6f\x21\x11\xb9\xbc\x7c\xff\x66\x6d\x37\xaf\xfe\x76\x04\x1d\x98\xf3\x62\xda\xa0\x9f\xf6\x5e\x82\xe8\x65\xeb\x29\xc5\xd4\x71\x0c\xa7\x80\x08\x86\x88\x7d\x38\x3d\xa0\xcb\x59\x9b\x22\x5f\xdd\x21\x0a\x3d\x70\x92\x9d\x35\xfb\x9c\xa8\x07\xe5\x6c\x91\xc0\x85\x12\x52\xb9\x5c\x07\xb6\xb1\x20\xb3\xb6\x50\x41\x8e\x0f\x54\xf4\x57\x36\xf8\x20\x18\xd0\x92\x94\x46\x2d\xde\x6e\xea\xfc\xb1\x5a\x2a\x72\x85\x77\xfa\xf3\xef\x3e\xb1\x3d\xb0\x44\x96\x5e\xa3\x89\x2f\x7e\xb0\x88\x4e\x47\x76\x60\x89\xd2\xa4\x3a\xbc\x62\xa3\xc3\x75\x83\x1c\x20\x84\x8d\xfd\xe8\xf8\x3c\x24\x9a\x8e\x27\xf2\x89\x7c\xaf\xcf\x5a\x06\xb7\xc3\x59\x1e\x09\xb4\x2f\x82\x84\x9d\x49\x86\x64\xf4\x85\xde\x26\xc7\x88\xe5\x59\xad\x5b\x15\xf9\x99\xdb\x92\x7f\x81\xf5\x4b\x96\xe9\x97\xb9\x09\x6b\x2a\x7e\x3e\x75\x6f\x5a\x9a\xab\x54\xc1\x60\xcf\xc2\xe6\x44\x92\x17\x94\x87\xc9\x8d\x0a\xa3\x83\x08\xd6\x74\x28\xf3\xa1\x13\x22\x8b\xc6\xdc\xdf\x7a\xb9\x3c\xbb\x1d\xa2\x25\xc7\x2c\x63\x6f\x49\xd2\x74\x42\xcf\x3c\xf2\xf9\xc4\x9b\x90\xac\x8b\xaf\xe7\x40\xdb\xbf\xd5",
        b"\x09\x40\x72\x48\x55\xa0\x67\x1d\x60\x14\x7d\xc6\x1f\xd2\x83\x19\x01\x34\xa6\x8c\x17\x81\x14\xd5\x9a\xb5\x8d\xa7\x3a\x1c\x81\x82",
        b"\x43\xf1\x94\xb9\x70\x78\xdc\x9b\x84\xc8\xe8\xe8\x67\xa7\x4b\xaf\xdc\x22\x11\x70\x6a\xe1\x10\xb5\xae\xc0\xb9\x9e\xde\x1f\xfe\xd8",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x9b\x62\xa7\x4b\xc4\x9e\xf4\xff\x5c\x62\x16\x5e\x7d\x25\x52\x1f\x13\x5c\x83\x6b\xc4\xef\x02\x3f\xb4\xbb\x1d\x6b\x42\xc6\x29\x10\x71\xea\xe0\xb4\x65\xc5\x92\x31\xcb\x29\x7c\xac\x6d\x14\x58\x75\xfd\x84\xf5\x72\x9f\x79\xf9\x22\x18\x52\x2b\x9e\x55\xcb\x70\xd4\x71\x03\x0d\x36\x29\x1a\x24\x92\x5a\xb7\x31\xa2\xd4\x45\x8c\xff\x67\x70\x79\xd2\x07\xce\x86\x5b\x3d\x55\x26\x00\x92\x38\x86\x1d\x64\x50\x6a\x92\xb7\x6b\xaf\xf5\x9b\x37\xb8\x63\x08\x75\x58\xd5\x96\x5d\x76\x68\x5f\x0f\xbd\x1f\xab\x1b\x1f\x95\x61\xf8\xf6\x9c",
        p,
        q,
        g,
        b"\x75\xd7\xd9\xa5\xdb\xdd\x47\xce\xcd\x12\xf6\x9a\xb2\x12\xdf\xe0\x8a\x96\x56\xe2\xbc\xa9\x2c\x81\xdb\x2d\x26\x8a\x29\x3a\x32\x5e\x51\x1c\xd5\xaa\x1b\xa5\x9d\xee\xf2\xab\x63\x11\x66\x5d\xda\x58\x23\x0d\x48\xf1\x41\x63\x71\xde\x1a\x83\x64\xb3\x8f\x5a\xd5\x99\xc4\x72\xd3\x63\xa1\x8a\x2c\x13\xd5\x72\xcf\x84\x9b\xe2\xfe\xf9\xa1\x66\xe8\x38\xaa\x58\xb7\x21\xec\xfc\x4b\x36\x1f\xda\xb1\xd0\x87\x6b\x78\xe2\xe8\xf2\x3e\xf1\xc8\x2c\xc0\xe1\x70\x0f\xa0\x15\xa4\x00\x7b\x1d\x7b\x53\x5c\x82\xd2\x3c\x12\x9d\x1d\x1c\x9c\x4a\xfe\x87\x5a\x06\xc0\x5f\x71\xf0\x78\xcb\x8d\x90\x60\xf4\xd9\x36\x67\x1f\xae\xe2\x17\xd4\x04\x55\x25\xd5\x70\xb0\xc8\xca\x0c\x4e\x8b\x55\xdf\xe9\xb7\x80\xba\x69\xc9\xd8\xcd\xa1\x0c\x50\xfd\x61\xc4\xe7\x21\x4b\x94\x3c\x1c\x29\x79\x7b\x09\x9f\x57\xa4\xc6\x48\x59\x7c\xed\xd9\xd9\x09\xbc\x58\x4a\x9b\x75\x4b\x20\x95\x15\xdb\xfa\x0f\xec\xce\x2a\xd0\x5c\x84\x8e\x99\xdc\xa2\x1a\x6d\x0d\x5f\x2d\xac\x23\x61\xe4\xc0\xea\xf9\x6d\xf1\x99\xad\x28\x88\xd6\x71\x97\x4e\xf0\x5d\x65\xc9\x27\x88\x43\x4a\xb4\x2f\x1f\x1f\x79\xed\xc4\x9e\xc1\xfa\x92\x13\x95\xbd\x0f\xeb\x6a\x9e\x6a\x06\x22\xe8\x25\x5b\x0e\xf6\x93\x7b\x89\xd0\xcc\xcd\x58\x52\x87\x2d\x2b\x0a\xb5\xd7\x9c\x2f\x19\x8b\xff\x6b\x8a\xa3\x8a\xce\xe2\x1d\x6c\x3a\xdd\x55\x62\xd8\x4d\x96\x87\x58\xd9\x3e\x8c\x1d\x61\x1f\x7d\x61\x82\xb6\x2e\x44\xf5\x7d\xf3\x42\x89\x9b\xb5\x64\xa7\x94\xd1\x39\x15\x88\x21\x43\xd9\xdf\x45\xf8\xf2\x1c\xc0\x30\xaf\x33\x97\xe9\xe9\x49\x68\x3d\xdd\x8d\x8d\xa9\x90\x9c\xc1\x13\x96\x19\xe4\xb7\xb2\x52\xaa\xdd\x02\xc6\x6a\x5e\x20\x10\x5a\xdf\x26\xf2\xf0\x21",
        b"\x01\xe3\xde\x39\x8b\x01\x8a\x69\x47\x80\xdd\xc6\xca\x12\xb7\x8d\xc5\x5e\x7a\xd9\xfd\xdd\xb5\xa3\xf5\xb2\xca\xd0\x10\x32\x53\xdd",
        b"\x03\xc9\x82\x80\xab\xe3\x05\x0a\x67\xf8\x8e\xf2\x9f\xb2\x14\xa8\x01\x24\xf4\x73\x21\xc6\x2e\x41\xe3\x90\x5b\x85\x32\xf4\x93\x6c",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x6c\x66\x05\x1e\x04\xc2\xe6\xaa\xa4\x3d\xe9\xaa\x42\xcd\x9f\x61\xe8\x32\x9c\x12\x4e\xd3\x03\x1b\x67\x45\x2d\xb4\xc4\x35\xdb\x29\x1d\x75\x6b\xa6\xef\x90\xab\x06\x30\x7c\xb8\xd7\x0f\x34\x96\x79\x2e\x63\x3b\xf5\xac\x98\x5c\x37\xc4\x3b\xdb\x4e\x45\x5c\x7f\x76\x1a\x5e\xe4\x50\x56\x7f\x85\xcc\x97\x7e\x96\x8e\x7f\xa4\x2a\x42\x8c\x1a\x7e\x91\x5c\x82\x87\x48\x65\x63\x1d\x80\x78\x89\x93\x77\x25\x59\x47\xc3\x44\x61\x82\x97\xb8\x3c\x96\x11\x4d\x11\xd7\x4d\x8c\xd5\x79\xb5\x53\x66\x7c\xac\x1d\x97\xae\xa4\xd1\x68\x49\x87",
        p,
        q,
        g,
        b"\xed\x2e\x10\xa4\x43\x16\xd6\x77\x46\x7d\x79\x94\x7b\xec\x9e\x40\x5d\x30\xf3\x2d\x86\x0a\x1c\xe4\x6b\x36\x68\x45\xdf\x9a\xd2\x22\xb0\xf9\x92\xf5\x84\x45\x71\xb1\x96\xa3\x10\xd5\x87\xff\xfa\x74\xbd\x51\x02\x15\xf3\xbd\xaf\xa1\xc9\x3d\x1b\x13\x15\x24\x6f\xd2\xf7\x94\xc4\xda\x07\xbd\x72\x2a\x98\xdd\xa9\xa0\x2a\xd4\x25\x5b\x6d\x52\x67\x73\x82\x56\xcb\x86\x39\xa1\x45\xc2\x84\x04\x56\x2a\xdd\x2b\xc7\x69\x1d\xac\x12\x60\x0b\xa9\xf8\xeb\xe0\x06\x14\xee\x3f\xc6\xe6\xb2\x48\x4d\x9c\x5c\x70\x90\xb3\xf3\xb1\x34\xba\x19\x90\x98\x64\x56\x30\x40\xfe\x87\x52\xd6\xc6\xab\x95\x11\x1f\xe1\x01\x4b\xf7\xbb\xe4\xe6\x74\xc9\xd0\x3b\xb8\xd2\x29\xe4\xb5\xf6\xa6\xe4\x71\xc6\x78\xb0\x26\x5e\x88\xcc\xad\x79\x60\xff\xfa\xe7\x00\xf3\xa7\x5e\x61\xa2\x4e\xa8\x82\xb9\x70\x53\x5e\xb7\x01\x7e\x16\xc4\x8c\xe9\xe2\xbc\x83\x57\xf7\xf0\x88\x9c\x87\x1d\x0b\x4c\xe2\x9d\x27\x9a\xfd\x1d\x11\x49\x98\xd1\xeb\x6f\xe4\xa5\x66\x1e\x42\x9b\x13\x27\xf0\xa3\x9e\x9e\xf0\x0a\x41\xa7\x4f\xe4\x79\xb9\x0f\xdd\xa2\x1d\x93\x15\x55\x5a\xfe\x22\x72\x74\xc1\x1a\x71\xc0\xd1\x0c\x9e\x5d\xfc\x89\x75\x0e\xda\x53\xc6\xa8\xb5\x2a\x52\x72\xc7\x55\x26\x37\x5e\x5f\xb9\x1f\xf7\x5d\x02\x8d\xf7\xaa\x2b\xce\xb5\xfd\xf6\xf8\xe3\xbc\x1e\xc3\xf1\xe2\x26\xd0\x4d\xf1\xd8\x42\xe4\xc8\xf4\x58\x98\x8c\xb7\x41\x5f\x0d\x2c\xa4\x49\x8b\x0c\xd6\x7e\x8b\x08\x5b\x00\x8f\xc4\xca\x06\x43\x93\xa0\xdf\x51\x7f\x0b\x48\x33\xea\x40\x51\xac\x3f\x1d\xe5\x68\x6d\xcc\xb7\xbb\xa8\xbd\x93\x90\x92\xd6\xd7\x8f\xa0\x8f\x5b\xf9\xbf\x6f\x13\xd7\xae\xf7\x2f\x04\x7f\xcc\x47\xa8\x82\x23\xdf\x6e\x1a\x62\xd2\x18\x16\x9f",
        b"\x31\xf2\xc8\x62\x87\xe5\x72\xff\x4d\x07\x42\x1a\x58\xdc\x7b\x3d\x72\x7d\xe1\x13\x76\x99\x52\xb6\xd8\xd7\x36\x08\x8b\x36\xa8\x25",
        b"\x30\xac\xbd\x1c\x4c\xd6\xaa\x66\x6e\xe5\x2b\x0b\xdc\x41\xfc\x3b\x23\x9b\x60\xd5\x7e\x27\x9b\x3f\x54\x83\xc4\xd5\x4b\xdd\x97\xa6",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x5f\x8d\x7f\x28\x3a\xf0\x03\x84\xa5\x19\x76\x90\x29\xd2\x08\xb6\x1e\xee\x0e\x1c\xb2\x1c\xe9\xfb\x80\xe9\xd8\x59\x6b\x89\x45\x80\xda\x7a\xb3\x45\x74\x29\xe7\x2d\xfa\x64\xe7\xcb\x83\x94\x14\xde\x34\x4d\xa2\x1c\xff\x55\xb1\xb3\xa8\x31\x89\xd2\x08\xad\x20\x89\xb3\x5a\xbd\x78\xe2\x41\x6b\xce\xb6\x64\x66\x76\x2f\xd7\xab\x9c\x23\x4c\x4a\xec\x38\x72\xcb\xc8\x44\x3c\x92\xb8\xce\x4e\xe4\x59\x54\x25\xe7\x46\xe4\xb6\xf7\x97\x2e\xbd\x5d\x06\x5f\xb3\xfd\xc5\xe3\x29\xe8\xa8\x7e\xd3\xcd\xdb\xe2\x79\xd5\x72\x27\xae\x4b\x13",
        p,
        q,
        g,
        b"\xaa\x4d\x06\x52\x70\xc3\x8b\xdf\x99\x6b\x1f\x5f\x1e\xe4\xb6\x7a\x76\xef\x1e\x7b\x13\x4e\xa2\x1f\xd0\xa6\x13\x75\x21\x24\x50\x52\xe7\x49\x54\xb9\x65\x44\xc7\x00\xd4\x0f\x36\x24\x8f\xf2\x9a\x71\x2a\x09\x8d\x80\xca\x12\xe2\x8f\xdd\x79\x01\xa6\x22\xdd\x09\x88\xe1\xc4\xd6\x7d\xe4\xc4\x97\xa9\x57\x88\x2c\xe9\x92\xfc\xb0\x8c\x5b\x85\xc6\x85\x84\x47\xed\x6f\xcb\xad\x26\xd8\xc4\x04\x85\xf0\xa8\x9d\x9d\x02\x0f\xe2\x33\xe8\x93\x19\x03\x84\x55\x64\x4c\x82\x8d\x60\x8d\xf9\x70\x7c\x63\x17\x0d\xd0\x61\x8c\x0b\xae\xf3\xec\xa8\xd1\x45\x54\x60\xa2\xeb\x25\xfa\xff\x44\x4f\x80\x3b\xca\x29\x7b\xb6\x80\xe5\xf0\xfd\x06\xe8\x87\xed\x50\xc8\x06\x0f\x55\xd0\x16\x0e\xc6\x45\x17\x08\x6f\x4e\x1d\x62\x4a\xb7\xd1\x2d\xf1\xb5\x94\x70\x17\xe6\x22\xeb\xbc\xd6\xf4\xed\xdb\x0a\x41\xdc\xba\x82\x74\x3e\xfd\xc5\x80\x42\x88\xd2\x86\x3f\x54\x00\x3e\xea\x12\x75\x32\x46\xe6\xe0\x35\x7d\xf0\x55\x01\xb1\x95\xfd\xf3\xa7\x76\x1c\x4c\x3a\xcf\x26\x53\x7b\xf9\x8b\x32\xf2\xe7\x2f\xf1\xe0\x15\x9d\x04\x6b\xbc\x05\x31\x71\xe3\xd5\x18\x34\x4f\x05\x37\xf2\xe7\x20\x0b\xcd\xd9\x57\xec\x96\x36\x5c\xaf\x55\xfc\xd2\x46\xaf\xe7\x71\x70\x9e\xce\xc2\x83\x48\xa3\x56\xa1\xd4\xeb\x13\x6a\x17\x6a\xdb\x5f\xa1\x02\xf5\xfa\x5c\x96\x9f\x90\x89\x64\x62\xe0\x67\x7a\xfc\x60\x6a\x94\x8b\x25\x58\x7c\x10\x31\x6d\x22\xe1\x26\x9f\xc6\x4f\x91\x5a\x79\x6c\x96\x5b\x8b\xe9\x7e\x5b\xea\xb0\x47\xca\x51\x98\xbf\x2f\xf8\x56\xdf\x74\x0a\xfb\xbc\x1a\xef\xaf\xef\xb1\xed\x47\x27\x8b\x15\x0e\x6a\x72\x22\x41\x7d\x3a\x86\x49\x4b\xdb\x51\xed\xd0\x61\x68\x99\x52\x6c\x27\xac\xc2\xa8\x18\xe8\x3b\xaf\x57\x9b",
        b"\x71\x87\xca\xe8\x36\x82\x36\x18\xf9\xa6\xe8\x47\x05\x5c\xa2\xbc\x38\xc8\x6e\x72\x6d\x02\xd3\x8f\x49\x50\xeb\x6b\x71\xb3\x6b\xcb",
        b"\x21\xf6\xff\x41\x75\x76\x54\x30\xe2\xdb\xed\x34\x2a\x85\xd3\x00\x56\xb2\x89\x05\x74\x4e\xce\x5d\xad\x79\x75\x5e\xe3\xd7\xbb\xbd",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xb2\x16\xa0\x35\xb0\xff\x29\xfe\xaf\x7d\x4c\x34\xee\xb1\x60\x41\x55\xc9\x03\x38\x00\x67\x53\xee\x2b\x36\x06\x2d\x72\xf6\x2b\x52\x45\x04\x65\x9f\x70\xb9\x76\xc6\x89\x52\xa6\x2c\x2b\x9a\x2a\x00\xcf\x00\x66\xa5\xe5\x09\x8a\x63\x2d\xf2\xee\x56\xdd\x1a\x14\x0a\x98\xf7\xb3\xac\x12\xdb\x35\x76\xb6\x10\xd7\x65\x63\xe4\x62\x16\x37\xda\x10\x98\xaa\x20\xf3\xc8\x32\x47\xb7\x27\x88\x60\x41\x7c\xec\xf7\xe1\x37\x19\x4c\xf1\xba\xe1\x2b\xbc\x63\xa7\xba\xe0\x2c\x90\x6d\x50\x3f\x69\x4d\xea\x3b\xd5\x34\x71\x8e\x37\x70\x49\x62",
        p,
        q,
        g,
        b"\x7d\x6b\x3b\x71\xb1\x41\x58\x07\xd1\x59\x01\x42\x7e\x6a\xb0\x02\xee\x98\x5c\xe7\xc8\xd8\x44\x96\x9c\x6e\x72\x94\xa2\x16\x7b\x4c\x26\x17\x1b\xcd\x64\x6f\x0d\x1b\xce\x14\xdf\x05\xe4\xce\x58\xa3\xae\x50\xb2\xab\xa5\xfb\x74\x45\x52\x33\xfa\x6d\x17\x9a\x07\x94\xcb\x26\xe9\x2c\xa9\x10\xcd\x1c\x16\xe5\x46\x4e\x8f\xa7\xba\x93\x63\x41\xd3\xac\x21\x1a\xc1\xf8\xa2\xf2\xa1\x9c\x14\x8a\x1c\x3d\x6b\x00\xac\x44\xc3\x5e\xa3\x45\xa3\xff\x73\xae\x9d\x5a\xbc\xc6\xab\x65\x16\x2a\x53\xda\xab\xdf\x6d\xa2\x5f\x96\x95\x8e\xaf\x89\xf5\x59\x89\x5c\xbe\xc5\x23\x51\x39\x4f\x91\x32\xc9\x56\x4d\x61\xaa\xc7\x92\x64\x0f\x11\xe0\x9a\xa6\xf6\xcd\xe9\xee\x9c\xa5\xe0\x5f\xd9\x02\x91\x11\x63\x81\x71\x77\xbf\x05\x4c\xf2\xea\xbf\x7c\xe8\xf3\x4b\xb1\xc4\xad\xed\x8d\xad\x93\x41\x1f\xb2\x76\xd2\xd0\xa2\x96\x79\x96\x61\x30\x7d\xe5\x79\x64\x1e\x60\x7f\xda\xd0\x58\xd9\xa3\xf1\x94\x57\x4e\xa7\x6f\x4b\xec\x46\xbe\xf8\xad\xc5\xd6\x2c\x73\x90\xda\x1c\x45\xf6\xfc\x5d\x9a\x78\x4f\x69\x6f\x24\xae\x7e\x6b\x27\xa8\x09\x02\x94\x18\xdd\x18\xa4\x20\x45\x5c\x2c\xc9\x69\x5e\x7c\x0f\xe0\x02\x19\xa1\x71\x14\x68\xe2\x86\x6b\x71\xf3\xf9\xc5\x38\x78\x9e\xd2\x84\x3f\x44\xf2\xa8\x21\x77\x3c\x52\xd2\x11\xdd\x13\x33\xb5\xf1\x64\xec\xdf\x6c\x3f\xfd\x71\xde\x66\x78\xb0\xc2\x72\xf9\x23\x55\xd5\x97\x4e\xb2\x1c\x3c\x8f\xbd\x0b\xca\x75\x38\xbb\xd9\x89\x47\x50\xb1\xdd\x01\x42\xbe\xa8\x51\x04\x35\x6f\x9a\x51\x5e\xf1\xab\x69\xda\xed\x98\xd9\x48\x03\xac\x91\x2c\x77\x0e\x26\xef\xa2\xfa\x0b\x04\xe1\x10\x51\xce\xd2\xf7\x0f\x06\xf2\xf0\x5e\xac\x80\x29\xd6\x8e\x12\x26\x16\x57\xcf\x4d\xbc\xc1",
        b"\x67\xdf\x1d\x51\x0d\x06\x3c\x90\x67\xe9\x75\x91\x80\xbe\x47\x0c\x71\xfe\x09\xc4\xf1\x33\xac\xa1\x81\xbd\xb4\x7b\xb8\x7b\x20\x97",
        b"\x73\x28\xb8\x87\xbf\x0d\x52\x0a\xbe\x6f\x24\xaf\xf2\x15\x3f\x40\xde\x00\x9e\x27\x06\xae\x04\x3d\xd3\xaa\x55\x52\x1d\x95\x72\xd6",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\x6c\x67\x11\x6f\xbd\x21\xa0\xe3\xed\x16\xb3\xc4\xca\x58\xac\x49\x66\x19\x18\xbf\xc6\xa7\xc3\xa6\xac\xdb\xcd\x53\xdd\x40\x87\x03\x4f\xca\x16\x4d\xf8\xd3\x8f\x7e\xf7\xdb\x03\x36\x37\x01\x40\x92\x46\x38\x2e\xe0\x53\xc6\x9c\x84\xfa\xfa\x3c\x77\xad\x2c\xe0\x8d\xc7\xf4\x1c\x34\xa3\x1d\xa4\x96\xd0\x70\xa9\x94\x35\x79\x9f\x26\x9d\xc8\xef\xfd\x06\xd3\x1f\x85\x87\x9c\x29\x9c\xf7\x24\x1b\x37\xb9\xa4\xcf\xd5\x45\x08\x63\x93\x15\x67\x37\xcd\x9d\xa2\xd2\x82\xe7\xd5\x69\xfc\xfa\x5c\xbd\xe4\xbb\xa5\x1b\xd8\x9f\xdc\xc9\x13",
        p,
        q,
        g,
        b"\x6a\x50\xd1\x12\x5f\x9f\x3f\xc2\xf7\xe0\x23\xc0\x93\xb3\x60\x8e\x69\x72\xac\xef\xe2\x9c\x0c\x6b\xa0\x7a\x2f\x61\xed\x74\x71\x53\xad\xa4\xa9\xb6\x80\x62\x2a\x84\x2b\x9a\x82\x01\x19\x67\x56\x20\xc1\x16\x88\x70\x0b\x85\x5d\x4b\x8d\x13\xbf\x72\x6c\x36\xac\xf9\x23\x25\x6f\xef\x1b\x53\x09\x36\x22\xd1\xbc\xbc\xf0\x23\x84\x8b\x8b\x8f\x4a\xbf\x43\xbb\x6e\x87\xb8\x4d\x06\x1d\xeb\x75\x23\x62\x24\xce\xda\x91\x4b\x18\xf7\xce\xb7\x27\x08\x78\x9d\xfb\x94\x07\x04\x13\xb0\xe6\x5c\x12\x31\xad\x02\xdb\x42\xde\xcb\xe0\xe5\x58\xae\xa0\x6c\x31\x0a\xa1\xa8\xd1\x13\xbe\x1f\x07\x14\x82\xfc\x61\x91\x32\x25\xf0\x07\xb5\x69\xb6\xe8\x67\xcf\xb3\x92\x72\x57\x76\xad\x71\xf5\x0d\xc9\x7b\x83\x4a\x71\x37\x5b\xac\x18\xfa\xbf\x78\x11\x26\xd0\x6d\xf6\x21\x24\x06\x4e\x6a\x72\x3b\x48\x63\x5e\x67\x54\xfc\x76\x7a\x50\x94\xd0\x64\x59\x74\x04\x15\x91\xd0\xad\x48\x28\xf6\x37\x83\x35\x66\x96\xaf\x7f\xf7\x7c\xd0\x01\x07\x94\x9f\xbf\xf4\x70\x9d\xff\x8a\x66\x0a\x41\x3f\x5b\x6c\x0d\xf3\x7a\xde\x84\xfc\xbc\x1d\x32\x53\xba\x61\x72\x65\xa1\x0c\xc0\x87\x60\x61\x30\x29\x09\x09\xa4\xf8\x13\x34\x1e\xfd\xb6\x11\x69\x6f\xeb\x5b\xea\x3d\x7d\x00\xa5\x3a\x81\xf3\xa2\x04\x3b\x88\x7a\x77\x60\x75\xd2\x50\xc1\xa0\x10\xec\x47\x66\x00\x87\xf3\xef\x05\x78\x2d\xd2\x1d\x29\x8d\x6d\x37\x55\x9c\xd4\x73\x00\x8f\x47\x4d\x8d\xec\xa6\x81\x7c\x13\x90\x18\x02\x76\x09\x7a\x81\xf4\x62\xc0\x52\x79\x28\xf9\x3a\x46\x1f\x4a\xc2\xd6\xed\x8c\x9d\x6d\x10\x1a\x2a\x9a\x29\x20\x1a\x83\xd0\x58\x9f\x57\xbe\x28\xa7\x27\x48\x45\x18\xc7\x42\x5c\xf5\x74\x4d\xf3\x96\xa0\xe1\x4a\x4d\x26\x0a\x5c\x8d\x29\xbf",
        b"\x7d\x48\x9a\xb0\xd4\x4b\xc7\x32\x71\xef\x42\xe2\x8a\x60\xe1\xb7\xef\x7d\xd2\x7a\xf4\x04\x55\x46\x04\x70\x85\xda\x40\x8b\xcc\xc7",
        b"\x31\x01\x51\xd9\x43\xf0\x88\xbb\x7d\xfd\xcd\x52\xd8\x28\x84\xa7\xf1\xee\x64\xd4\x6f\x9d\x60\x0d\x23\xf5\x2f\x4c\xea\x4d\x28\x62",
    )?;
    test(
        HashAlgorithm::SHA224,
        b"\xc8\xd4\x16\xc1\xef\xe6\x86\x63\x70\x78\x12\x2f\x79\x8d\x88\x04\xf6\x4a\x6e\x85\xe0\x5f\x7e\x8e\x07\x63\x4a\x30\x9a\x98\xe9\x2a\xbd\x54\x06\x1c\xcc\xc3\x19\xf1\xac\xd4\xa0\x87\xb1\xd7\xdb\xf0\xb6\xbf\x2a\x09\xc5\xdc\x50\x8e\xd1\x4d\xcd\x54\x42\x05\x6e\xad\xe7\x69\x1b\x7f\xb6\x5b\x67\x8e\xc2\xe1\x37\xb5\xfb\xe8\x75\x20\x8a\x42\x7c\x2a\x7a\xd9\x06\x65\x42\x6f\xbc\xbc\x76\x55\xe4\x8a\x89\x65\xd2\x3f\xde\xf1\x1c\xa8\x09\x2f\x51\x12\x07\xa6\x07\x35\x9f\x94\xe9\x1b\x19\x7f\xcc\x99\x3e\xe6\xce\x3c\x37\xad\x3b\x71",
        p,
        q,
        g,
        b"\xcc\x9b\x9d\x02\x92\x91\x5d\x63\x1a\xa0\xd9\xeb\x61\x61\xf9\x24\x70\x5c\x56\x6e\xe0\x9e\x74\xe4\x18\xd8\x8e\x6b\x67\xb7\xf5\x7a\xff\x51\x70\xf6\xc4\x2a\x83\x9b\xa8\x39\x40\x2b\xfe\x51\x7c\x28\x77\x81\xdc\x97\xdf\x2e\x05\x50\xb3\x86\x24\x84\xd2\x53\x15\x2f\x6c\xff\x89\x5f\x09\x23\x58\xb5\xc4\x45\x90\x48\x58\x13\x09\xef\xf2\xf6\x89\x23\x0b\x4c\x49\x51\xdb\x84\x13\x57\x3b\x6e\xae\x85\xc2\xdc\x50\xfd\x61\x34\x46\x13\x28\xe5\xb6\x43\x9f\x41\x44\x2b\x91\xe3\xa3\x42\x04\x42\x8d\x1e\x2c\x22\x41\x2b\x01\x22\x42\xb1\x4f\x92\xe2\xd1\xba\xd6\x26\xaf\x95\x05\x1b\xf0\x6c\x74\xda\x40\x81\xb0\xd6\x19\xe1\x36\xa9\x9c\x8d\xa3\xa9\x1a\xdb\x3b\x8c\xf8\xbc\x59\x64\xff\x65\x5d\x45\xc7\x5a\xda\x25\x3a\xba\x91\xc6\x40\x95\x39\x4c\x70\x1c\x53\xdd\xc1\x1f\x38\x8d\x61\x98\x4c\x32\xd4\x32\x6a\x8c\x62\x7d\xf8\x45\xb4\x10\x0f\x17\x1b\xbd\xb2\x52\xd3\xe2\x84\x94\xac\x17\x34\x32\xdd\x55\x31\xe0\x30\x40\x30\x2a\xac\x8c\x07\xc9\xea\x92\xa9\xab\x67\xfa\xf0\xc7\x8b\x3a\xd8\xd4\x54\xdc\xd4\x28\xf9\x42\xd8\xce\x6e\x29\x87\x30\x49\xfd\xbf\xa1\xdf\x0e\x6e\xc2\x24\xc9\xdd\x06\x6b\x98\x1a\x40\x0b\x1f\x51\x94\xfe\xe1\x3c\xc5\xca\x7f\xfb\xec\xa9\x8e\xd0\xa0\x22\x13\x77\xa1\xae\x61\x27\x40\xfc\xe7\x74\xee\xed\x68\x38\x2b\x32\xb6\x86\xa2\x5f\xfc\x01\x66\x82\x18\x64\x48\x20\x7c\x4d\x97\x83\xe8\x3d\xa2\x0a\x5e\x8b\x22\x8a\x13\x4d\xc3\xf4\x4e\xcc\x56\x5a\xb9\xae\x16\x2b\x85\x5e\xcd\x37\xe6\x40\x7e\x71\x40\x45\xf4\xe8\x3b\x97\x1a\x5f\x4e\x30\x4c\xd7\x78\xf3\xd3\x41\x37\x74\x5f\xc6\xea\x15\xb4\xb7\x4d\x60\x17\x6e\xf8\x07\x41\x0b\x1b\x26\xf6\x8e\xa1\x4f\x8f\x91",
        b"\x7f\xa5\x12\x31\xbc\x84\x5f\xa8\xb6\x68\x39\x3b\x78\xa7\xb0\x40\x81\x13\xfb\x77\xc1\xe3\x6f\x3c\x78\xc6\x7d\x65\x71\x5a\x8b\x58",
        b"\x73\x0c\x9e\x34\x83\x81\x1c\x52\xcf\x29\x5b\xad\x04\x2a\xcb\x5d\xd6\xee\x90\x08\x38\x57\xbe\xe9\x5b\x63\x92\xb0\x80\xb5\x04\x1d",
    )?;

    // [mod = L=3072, N=256, SHA-256]
    let p = b"\xc7\xb8\x6d\x70\x44\x21\x8e\x36\x74\x53\xd2\x10\xe7\x64\x33\xe4\xe2\x7a\x98\x3d\xb1\xc5\x60\xbb\x97\x55\xa8\xfb\x7d\x81\x99\x12\xc5\x6c\xfe\x00\x2a\xb1\xff\x3f\x72\x16\x5b\x94\x3c\x0b\x28\xed\x46\x03\x9a\x07\xde\x50\x7d\x7a\x29\xf7\x38\x60\x3d\xec\xd1\x27\x03\x80\xa4\x1f\x97\x1f\x25\x92\x66\x1a\x64\xba\x2f\x35\x1d\x9a\x69\xe5\x1a\x88\x8a\x05\x15\x6b\x7f\xe1\x56\x3c\x4b\x77\xee\x93\xa4\x49\x49\x13\x84\x38\xa2\xab\x8b\xdc\xfc\x49\xb4\xe7\x8d\x1c\xde\x76\x6e\x54\x98\x47\x60\x05\x7d\x76\xcd\x74\x0c\x94\xa4\xdd\x25\xa4\x6a\xa7\x7b\x18\xe9\xd7\x07\xd6\x73\x84\x97\xd4\xea\xc3\x64\xf4\x79\x2d\x97\x66\xa1\x6a\x0e\x23\x48\x07\xe9\x6b\x8c\x64\xd4\x04\xbb\xdb\x87\x6e\x39\xb5\x79\x9e\xf5\x3f\xe6\xcb\x9b\xab\x62\xef\x19\xfd\xcc\x2b\xdd\x90\x5b\xed\xa1\x3b\x9e\xf7\xac\x35\xf1\xf5\x57\xcb\x0d\xc4\x58\xc0\x19\xe2\xbc\x19\xa9\xf5\xdf\xc1\xe4\xec\xa9\xe6\xd4\x66\x56\x41\x24\x30\x4a\x31\xf0\x38\x60\x5a\x3e\x34\x2d\xa0\x1b\xe1\xc2\xb5\x45\x61\x0e\xdd\x2c\x13\x97\xa3\xc8\x39\x65\x88\xc6\x32\x9e\xfe\xb4\xe1\x65\xaf\x5b\x36\x8a\x39\xa8\x8e\x48\x88\xe3\x9f\x40\xbb\x3d\xe4\xeb\x14\x16\x67\x2f\x99\x9f\xea\xd3\x7a\xef\x1c\xa9\x64\x3f\xf3\x2c\xdb\xc0\xfc\xeb\xe6\x28\xd7\xe4\x6d\x28\x1a\x98\x9d\x43\xdd\x21\x43\x21\x51\xaf\x68\xbe\x3f\x6d\x56\xac\xfb\xdb\x6c\x97\xd8\x7f\xcb\x5e\x62\x91\xbf\x8b\x4e\xe1\x27\x5a\xe0\xeb\x43\x83\xcc\x75\x39\x03\xc8\xd2\x9f\x4a\xdb\x6a\x54\x7e\x40\x5d\xec\xdf\xf2\x88\xc5\xf6\xc7\xaa\x30\xdc\xb1\x2f\x84\xd3\x92\x49\x3a\x70\x93\x33\x17\xc0\xf5\xe6\x55\x26\x01\xfa\xe1\x8f\x17\xe6\xe5\xbb\x6b\xf3\x96\xd3\x2d\x8a\xb9";
    let q = b"\x87\x6f\xa0\x9e\x1d\xc6\x2b\x23\x6c\xe1\xc3\x15\x5b\xa4\x8b\x0c\xcf\xda\x29\xf3\xac\x5a\x97\xf7\xff\xa1\xbd\x87\xb6\x8d\x2a\x4b";
    let g = b"\x11\x0a\xfe\xbb\x12\xc7\xf8\x62\xb6\xde\x03\xd4\x7f\xdb\xc3\x32\x6e\x0d\x4d\x31\xb1\x2a\x8c\xa9\x5b\x2d\xee\x21\x23\xbc\xc6\x67\xd4\xf7\x2c\x1e\x72\x09\x76\x7d\x27\x21\xf9\x5f\xbd\x9a\x4d\x03\x23\x6d\x54\x17\x4f\xbf\xaf\xf2\xc4\xff\x7d\xea\xe4\x73\x8b\x20\xd9\xf3\x7b\xf0\xa1\x13\x4c\x28\x8b\x42\x0a\xf0\xb5\x79\x2e\x47\xa9\x25\x13\xc0\x41\x3f\x34\x6a\x4e\xdb\xab\x2c\x45\xbd\xca\x13\xf5\x34\x1c\x2b\x55\xb8\xba\x54\x93\x2b\x92\x17\xb5\xa8\x59\xe5\x53\xf1\x4b\xb8\xc1\x20\xfb\xb9\xd9\x99\x09\xdf\xf5\xea\x68\xe1\x4b\x37\x99\x64\xfd\x3f\x38\x61\xe5\xba\x5c\xc9\x70\xc4\xa1\x80\xee\xf5\x44\x28\x70\x39\x61\x02\x1e\x7b\xd6\x8c\xb6\x37\x92\x7b\x8c\xbe\xe6\x80\x5f\xa2\x72\x85\xbf\xee\x4d\x1e\xf7\x0e\x02\xc1\xa1\x8a\x7c\xd7\x8b\xef\x1d\xd9\xcd\xad\x45\xdd\xe9\xcd\x69\x07\x55\x05\x0f\xc4\x66\x29\x37\xee\x1d\x6f\x4d\xb1\x28\x07\xcc\xc9\x5b\xc4\x35\xf1\x1b\x71\xe7\x08\x60\x48\xb1\xda\xb5\x91\x3c\x60\x55\x01\x2d\xe8\x2e\x43\xa4\xe5\x0c\xf9\x3f\xef\xf5\xdc\xab\x81\x4a\xbc\x22\x4c\x5e\x00\x25\xbd\x86\x8c\x3f\xc5\x92\x04\x1b\xba\x04\x74\x7c\x10\xaf\x51\x3f\xc3\x6e\x4d\x91\xc6\x3e\xe5\x25\x34\x22\xcf\x40\x63\x39\x8d\x77\xc5\x2f\xcb\x01\x14\x27\xcb\xfc\xfa\x67\xb1\xb2\xc2\xd1\xaa\x4a\x3d\xa7\x26\x45\xcb\x1c\x76\x70\x36\x05\x4e\x2f\x31\xf8\x86\x65\xa5\x44\x61\xc8\x85\xfb\x32\x19\xd5\xad\x87\x48\xa0\x11\x58\xf6\xc7\xc0\xdf\x5a\x8c\x90\x8b\xa8\xc3\xe5\x36\x82\x24\x28\x88\x6c\x7b\x50\x0b\xbc\x15\xb4\x9d\xf7\x46\xb9\xde\x5a\x78\xfe\x3b\x4f\x69\x91\xd0\x11\x0c\x3c\xbf\xf4\x58\x03\x9d\xc3\x62\x61\xcf\x46\xaf\x4b\xc2\x51\x53\x68\xf4\xab\xb7";
    test(
        HashAlgorithm::SHA256,
        b"\xcb\x06\xe0\x22\x34\x26\x3c\x22\xb8\x0e\x83\x2d\x6d\xc5\xa1\xbe\xe5\xea\x8a\xf3\xbc\x2d\xa7\x52\x44\x1c\x04\x02\x7f\x17\x61\x58\xbf\xe6\x83\x72\xbd\x67\xf8\x4d\x48\x9c\x0d\x49\xb0\x7d\x40\x25\x96\x29\x76\xbe\x60\x43\x7b\xe1\xa2\xd0\x1d\x3b\xe0\x99\x2a\xfa\x5a\xbe\x09\x80\xe2\x6a\x9d\xa4\xae\x72\xf8\x27\xb4\x23\x66\x51\x95\xcc\x4e\xed\x6f\xe8\x5c\x33\x5b\x32\xd9\xc0\x3c\x94\x5a\x86\xe7\xfa\x99\x37\x3f\x0a\x30\xc6\xec\xa9\x38\xb3\xaf\xb6\xdf\xf6\x7a\xdb\x8b\xec\xe6\xf8\xcf\xec\x4b\x6a\x12\xea\x28\x1e\x23\x23",
        p,
        q,
        g,
        b"\x45\x6a\x10\x5c\x71\x35\x66\x23\x48\x38\xbc\x07\x0b\x8a\x75\x1a\x0b\x57\x76\x7c\xb7\x5e\x99\x11\x4a\x1a\x46\x64\x1e\x11\xda\x1f\xa9\xf2\x29\x14\xd8\x08\xad\x71\x48\x61\x2c\x1e\xa5\x5d\x25\x30\x17\x81\xe9\xae\x0c\x9a\xe3\x6a\x69\xd8\x7b\xa0\x39\xec\x7c\xd8\x64\xc3\xad\x09\x48\x73\xe6\xe5\x67\x09\xfd\x10\xd9\x66\x85\x3d\x61\x1b\x1c\xff\x15\xd3\x7f\xde\xe4\x24\x50\x6c\x18\x4d\x62\xc7\x03\x33\x58\xbe\x78\xc2\x25\x09\x43\xb6\xf6\xd0\x43\xd6\x3b\x31\x7d\xe5\x6e\x5a\xd8\xd1\xfd\x97\xdd\x35\x5a\xbe\x96\x45\x2f\x8e\x43\x54\x85\xfb\x3b\x90\x7b\x51\x90\x0a\xa3\xf2\x44\x18\xdf\x50\xb4\xfc\xda\xfb\xf6\x13\x75\x48\xc3\x93\x73\xb8\xbc\x4b\xa3\xda\xbb\x47\x46\xeb\xd1\x7b\x87\xfc\xd6\xa2\xf1\x97\xc1\x07\xb1\x8e\xc5\xb4\x65\xe6\xe4\xcb\x43\x0d\x9c\x0c\xe7\x8d\xa5\x98\x84\x41\x05\x4a\x37\x07\x92\xb7\x30\xda\x9a\xba\x41\xa3\x16\x9a\xf2\x61\x76\xf7\x4e\x6f\x7c\x0c\x9c\x9b\x55\xb6\x2b\xbe\x7c\xe3\x8d\x46\x95\xd4\x81\x57\xe6\x60\xc2\xac\xb6\x3f\x48\x2f\x55\x41\x81\x50\xe5\xfe\xe4\x3a\xce\x84\xc5\x40\xc3\xba\x76\x62\xae\x80\x83\x5c\x1a\x2d\x51\x89\x0e\xa9\x6b\xa2\x06\x42\x7c\x41\xef\x8c\x38\xaa\x07\xd2\xa3\x65\xe7\xe5\x83\x80\xd8\xf4\x78\x2e\x22\xac\x21\x01\xaf\x73\x2e\xe2\x27\x58\x33\x7b\x25\x36\x37\x83\x8e\x16\xf5\x0f\x56\xd3\x13\xd0\x79\x81\x88\x0d\x68\x55\x57\xf7\xd7\x9a\x6d\xb8\x23\xc6\x1f\x1b\xb3\xdb\xc5\xd5\x04\x21\xa4\x84\x3a\x6f\x29\x69\x0e\x78\xaa\x0f\x0c\xff\x30\x42\x31\x81\x8b\x81\xfc\x4a\x24\x3f\xc0\x0f\x09\xa5\x4c\x46\x6d\x6a\x8c\x73\xd3\x2a\x55\xe1\xab\xd5\xec\x8b\x4e\x1a\xfa\x32\xa7\x9b\x01\xdf\x85\xa8\x1f\x3f\x5c\xfe",
        b"\x53\xba\xe6\xc6\xf3\x36\xe2\xeb\x31\x1c\x1e\x92\xd9\x5f\xc4\x49\xa9\x29\x44\x4e\xf8\x1e\xc4\x27\x96\x60\xb2\x00\xd5\x94\x33\xde",
        b"\x49\xf3\xa7\x4e\x95\x3e\x77\xa7\x94\x1a\xf3\xae\xfe\xef\x4e\xd4\x99\xbe\x20\x99\x76\xa0\xed\xb3\xfa\x5e\x7c\xb9\x61\xb0\xc1\x12",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x06\x61\xc1\xbf\x79\xee\xd7\x8a\xd4\x87\x9e\x24\x0a\x46\xb9\x5a\x0d\xb2\xb2\x9b\xf8\x12\x63\xb9\xb1\x67\x6d\xaa\x25\x54\xaa\xd7\x22\x2c\x9e\xb7\xa8\x93\x04\x8e\x46\xfb\xd2\x82\x6a\xb6\xe8\xcf\x42\xab\x0c\xd6\x31\xc4\xc4\xa1\xa8\x19\x56\x0f\x73\xcc\x86\x1a\x5b\x64\x65\xcf\x28\x80\xa7\x30\x63\x5e\xd7\xf4\x9e\x28\xf7\xb5\x65\x76\x8f\x02\x9d\xb2\xa4\x43\xba\x0a\x1b\xd1\x07\x73\xf2\x6f\x75\x2c\x83\xda\x40\xfc\xd3\x3f\x32\xf7\x8d\x24\xac\x98\x20\xd0\xbf\x70\xda\xe5\x68\xa1\x25\x38\xaf\xfa\x86\x71\x60\xc8\x1e\x39",
        p,
        q,
        g,
        b"\x54\xb6\x81\x80\x54\xcc\x00\x0c\x3a\xf6\x1b\x62\xef\x41\x89\xba\x35\xe0\x48\x45\xde\xe0\x01\x5b\xe6\x27\x33\x92\xc6\x73\x32\xe2\xe0\x45\x10\xcd\x5b\x2b\xbf\x47\x23\xcd\x81\x96\xe0\x25\x51\x1f\x66\x23\xf0\x36\x07\xe5\x66\x48\x4c\x33\x07\x51\xd0\x3c\x71\x30\x68\xa7\x7e\x08\xbd\xe9\x07\xfc\x57\xb3\xc0\x21\xe3\x73\x03\x37\x3d\x9d\x81\x1e\x38\xf1\x4b\x54\x7d\x2b\xd8\x7d\x98\x12\x69\xc6\x77\xda\xc6\xad\xe6\xac\xbb\xae\x30\x14\xeb\xd3\x81\xb4\x00\x86\x37\x03\x1c\x9b\x6d\x49\xca\x90\x87\x65\x47\x2b\x05\x96\x2f\x55\xaa\x36\x1f\x7d\xd5\xa4\x26\x07\x05\xff\x5e\xcf\x7b\x31\x7d\xb1\xfe\x5d\x33\xfd\xbf\x48\xe6\xa3\x3b\x3c\x78\xb1\x4e\x62\x0d\x93\x80\x6b\x52\xe8\x6e\x08\x2f\xe4\xf5\x4d\x52\x65\xe8\xdf\x62\x3b\x0c\x9a\x25\x9f\x61\xb7\xfa\x2c\x04\x55\xfa\xdf\x39\x69\x3e\xf3\x97\x74\x40\xf3\x02\x06\x7c\x3a\xff\xbc\x45\x74\x22\x4d\x5a\x22\x04\x4e\x9b\xfe\x11\xd0\xd6\xed\xe2\x73\x9c\x7f\xfe\x92\x77\xc8\x64\x4d\x46\xbe\xec\xb9\x46\xf8\x17\x75\xc1\x16\x38\x8f\xd6\xc2\x4a\xf0\x2e\xc5\x9f\x62\x12\x33\xef\xe8\x79\x2d\x6d\x0c\xd2\xc8\x43\x33\xb1\x1f\x07\x65\x73\x33\xda\x4e\x27\x4b\x8c\xd3\x91\x4d\x97\x77\x06\xe7\x86\xf3\x25\xe1\x8a\x33\x9b\x80\x5c\x51\xb4\x5e\xac\xb3\xce\x24\x18\x45\x97\x0a\xcb\x9f\xd1\xa4\x82\xa5\x64\xb2\xae\xec\xda\xeb\x0a\x0d\xb3\x9f\x33\xad\x29\x91\xf2\x5c\xf6\x22\xbf\x22\xf0\xc4\x43\x0c\xf9\x4d\xf1\xdb\x59\xaa\x2d\x7c\x20\x04\xb5\x17\x7b\x9e\xa6\x9f\xf5\x56\xdd\x4c\x07\xed\xec\x62\x59\xee\x13\x9b\x42\x15\x73\xa1\x1c\xf8\x5d\x11\xe2\x45\xe2\x51\x19\x0b\xa8\x69\xc9\xcb\x4d\xaf\x9f\x49\x45\x1a\x85\xf3\x8b\x9b\x90\x3e",
        b"\x51\x9f\xe4\xc5\xf9\xb7\x70\x7a\xe4\xb3\x62\x17\xea\x17\x07\xa1\x87\x1d\x8f\xce\x98\xee\xe9\xe6\x43\xc4\x5c\xd3\xeb\x50\xc5\xd3",
        b"\x1d\xf2\x24\xaf\x0b\x51\x51\x9e\x11\xd8\x42\x29\x99\xb1\xd3\xab\x09\x72\x06\x41\x80\xff\xc3\xf1\x11\x4c\x9f\x87\x6a\x1d\xe3\xb1",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x15\x97\x35\x3f\x24\xaa\xf5\x15\xfd\x7c\x0b\x0a\x74\x53\x44\x4d\x5f\x32\x9d\x6c\x3f\x09\x91\x13\xbb\x3a\x13\x30\x9b\x05\x3e\x6c\x12\x3a\x56\x22\x7a\x81\xe8\xb1\xa0\xc8\xab\x4b\x46\x16\x0c\xc5\x38\x0d\xf5\x91\xb1\x9d\x8a\x38\x6d\x29\xa8\xe4\x3c\xca\xb5\xd8\xc0\xe5\x47\xfb\xa2\x1b\xff\xcf\x5e\xf4\x2e\xfb\x9f\xb2\xe9\xbe\x62\x97\xc0\x3d\x57\xda\x0b\x58\x89\xb3\xb9\x74\x2d\xdc\x2c\x54\xb8\x37\x3f\xed\x1f\x21\x95\xf5\xbb\x23\x29\xa8\xf1\xf3\xf8\xaf\xce\xc2\x5e\xb1\x52\xe7\xfa\x81\x9e\x5d\x36\xcf\xd3\x62\x52\x39",
        p,
        q,
        g,
        b"\x50\x62\xaa\x1f\xdc\x67\x29\x4c\xd5\x76\x23\xce\xdd\x28\x08\x30\x3c\xeb\x43\x53\x7e\x3a\xbf\xa1\xbd\xbc\x49\x2b\x1a\xee\xce\xe6\x1b\x1f\xd9\x6c\xc0\x55\xd1\x45\x9a\xb5\x2d\xdc\x3f\x23\x44\x38\x9e\x5f\x21\x44\x8a\x90\xcb\x36\xe4\x48\xe6\x07\x87\xb1\xff\x5a\xb6\xe5\x54\x9a\x39\x21\x49\x6e\x83\x54\x64\x6b\xc1\xfd\x6c\xd5\xf2\x35\x9a\xe2\x99\xc0\xa0\x47\xfa\xc3\x92\x05\x12\xa1\xf4\x11\xc4\x38\xba\xfd\x03\xe9\x5e\x53\x8c\x6e\x21\xd1\xdd\x1f\x15\xa8\x9d\x38\xd4\x8f\x26\x30\x5c\x25\x34\xfa\x8e\x31\xd0\x54\xdc\xb0\x07\x74\x13\x8f\xb8\xfc\x61\xc6\xa8\xd4\xae\x1c\xa4\x64\x30\xd0\xe3\x1b\x4b\x92\xdf\xb1\x5b\xd6\xb8\x73\x9f\xd5\x37\x10\x1e\x77\x33\x4e\x6f\x3c\xe5\x46\x9e\x82\xa8\xdb\xc5\x8b\x3b\xe5\xca\x37\x03\x59\xf4\xa6\x13\x2f\xe0\x33\x60\xb8\xf6\xbe\x24\x8c\x34\x22\x0a\x80\x03\x77\x26\x48\x66\x40\x59\xf1\xf6\xa3\x22\xe0\xc1\x22\xf4\x27\xef\xdb\x7d\x64\x0e\xb5\xbb\x7f\x3d\xb2\xd9\x67\xa2\x15\x90\x92\xd8\xf8\xdf\x33\x3f\xf5\xba\x13\x56\x02\xb9\xee\x7e\x9d\xb6\xae\x0b\x95\x88\x6d\xf3\x8d\x4b\x4a\x26\xa4\xb2\xd7\x90\xc2\x4f\xa2\x14\xcd\x68\xd0\xa7\xed\xe6\x3e\x7d\xfa\xca\xea\xe1\x4d\x97\x85\xbe\x69\x3a\xd7\x8d\x88\x24\x2d\xfa\xd9\x88\xb7\x12\x2a\xdf\x5a\xfa\x9e\xfd\xd0\xc2\x04\x74\x70\xc6\x07\xd4\x7b\x30\x08\x9f\xf8\xbf\xc4\xcf\x5d\x7a\x8b\xa6\x9a\x7d\x0a\xb6\xc5\x4c\x05\x28\x0d\x66\xaa\x40\x19\xf6\x36\x2e\xa2\x4a\x1d\x3f\x8f\xcd\x80\xc3\xeb\x20\x83\x1b\x6e\x0d\xb0\x10\xfa\xf8\x26\x48\x8f\x01\x5f\x63\xf0\xb9\xac\x6d\xf7\x28\x83\xef\xd2\x86\xf0\x53\x2b\x5b\xef\xf1\xb9\xe8\x10\xff\x6a\x2b\x2d\x32\x8a\xf6\x75\xea\xfc\x2f\x56",
        b"\x05\x02\xa6\xe1\xd8\xc8\xdf\xdf\x56\xeb\x67\xf9\xa6\xf6\x60\x57\x35\xe4\xd1\xb0\x07\x6c\x8b\x08\xb6\x1d\xaf\x8e\x7c\x2b\xf2\xd6",
        b"\x7c\x67\xab\xdc\xf4\xe5\x80\x81\x2b\x13\xd0\xa4\xed\xba\xe8\xa2\x78\x6d\x66\x12\xbc\x86\x6e\x3c\x13\xbc\x09\xf3\xe9\x66\x16\xe0",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x71\x5f\x29\x69\x30\x31\x23\x68\xa2\xa9\x8d\x3f\x42\x81\x0d\xa5\x71\x15\xf0\x0f\xfc\x4a\x12\x02\x9c\x27\x6b\x10\x62\x9e\x6b\xdd\xd6\x0b\xca\x2c\x53\x5b\x79\xa5\xf4\xa0\x06\x81\x77\x91\xf7\xf3\xad\x2e\x01\xa0\x02\x16\x67\x2e\xe5\xad\xec\x57\x9d\xeb\x07\xe9\xd2\xb0\xdb\x22\x2c\x4e\x01\xe1\xf8\x19\xc1\xa5\x2d\x10\x1b\x1e\xf6\x78\xcf\xca\x85\x65\x5d\xd6\xb2\x42\x6f\x1a\xc3\x79\xa9\x2a\x9c\x69\xb0\xf8\x98\x74\x32\xd1\x09\xcd\x9a\x7b\xc0\x4e\xf2\x87\xc2\xaf\xb6\x63\x44\x46\x88\x60\x1c\xe3\xc5\x5f\xd9\x0d\x0f\xa3",
        p,
        q,
        g,
        b"\xb6\x33\x40\xd6\xa1\x95\x57\x31\x28\x30\x64\xf6\xf2\x2a\xd7\xf0\xe2\x81\x99\xf6\xa5\x8c\x57\xdd\xcb\x44\xa0\x26\xc6\x1e\x44\x13\x18\xc4\xf8\x75\x5d\xfd\x71\xb2\x95\xe9\xe7\xba\xbe\x00\x08\x49\xc9\x72\xf6\x8d\x4b\xe0\x09\x54\xa3\xc2\x9c\xd4\xb4\xe8\x3a\xd5\x18\x30\x08\x0e\x29\xe7\x61\x9e\x45\xd3\xab\xbf\x9d\x82\xfd\x87\xe9\x75\x81\xfe\x90\x9d\x3d\xa1\xe3\xe9\x6c\xb3\xf0\xc8\x93\xaf\x9d\x07\xf4\x18\xdf\x90\x2e\x76\xb0\xbb\xc1\xc9\x71\x39\xcb\xd5\x12\x26\xac\x44\x2b\x3d\x0b\x05\x25\xc7\x84\xba\x13\x81\x31\x42\x1c\x60\x54\x3e\x6e\x29\x60\x69\xf6\x11\xb9\xc3\x7c\xf6\x03\x06\x36\xee\xca\xf4\x1c\x3b\x48\x38\xf5\x06\xc0\x2c\xc8\x4c\xde\x6b\x99\xca\xbd\x2c\xa5\x78\x44\x9c\xc1\x71\x8a\xa4\x18\xca\x12\xa2\xb7\x6f\x78\x25\x9c\x16\x91\xe0\xb4\x9f\x09\xdb\xda\xf5\x85\xf6\x26\xcf\x74\xd7\x32\x12\xb3\x42\x78\x45\xc6\x6f\x22\x83\xb6\x07\x03\xad\xf1\xa2\x62\xbb\x8b\x10\xac\x7a\xc5\xd1\xec\x73\x61\x4f\xdd\x37\xee\x51\xb7\x1c\xd1\xfb\x4e\x6d\xb8\x93\x83\x82\x64\x3c\x72\x1f\xbc\x4c\xfc\x98\x7b\xc5\xef\xbc\x81\x29\x9b\x37\x5a\x56\x0c\xde\x5a\xda\xe6\x28\x31\xca\x41\x38\xc3\x99\xd8\x2f\x1f\x8b\xc6\x80\xf9\xc6\xb4\x7e\xb4\x64\xa1\xe0\xaa\xc4\x48\xfe\x3b\x5c\x25\xbd\x8c\x0b\x7a\xfb\x70\x1b\x06\x80\xdb\x87\xab\x51\x73\x8f\x19\xf5\xb9\x65\x37\x5d\xd4\x8d\xac\xa0\x7b\xff\x38\x85\x63\x21\x75\x70\x0c\x67\x86\x19\xf1\x94\xe4\xee\x5f\x55\xaa\x44\x8a\xec\xa7\xf7\xb3\x32\x2f\x64\xa5\x47\x31\x5c\x5c\xee\x04\x51\x22\x54\x9f\xb3\x8b\x8a\xcc\x95\xda\x5e\x83\x30\x22\xb3\xb8\x94\xf0\x3c\xcb\x7f\x73\xb9\x1c\x1f\xe8\x2c\xe4\x14\xe1\x21\x94\x11\x78\x0e",
        b"\x4c\x5e\x99\x0a\x6e\x24\xfe\xdd\xab\x48\xd0\xaf\x4a\x08\xb4\x5a\xe8\x09\x25\x94\xbf\xb3\xc0\x12\xfa\x1c\x32\x5c\x97\x7a\x3c\xc0",
        b"\x82\x0b\x6c\xaf\xa8\x9b\x41\xc4\xcc\xbe\xc8\x42\xd7\xc4\x08\xc6\x5d\x49\x98\xab\x1a\xc6\xb6\xbc\xe8\xd4\xd5\x69\xcd\xf0\x47\x26",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x1f\xe5\xad\x49\xe1\x1c\x20\x7d\x3d\x5e\x19\x23\x06\x08\x32\xaf\xbf\xc0\xaa\x0c\xb2\x9f\xc0\xb2\x2b\x3b\xe5\x9a\x59\x8f\x8c\x70\x3b\x9b\xf2\xc7\x34\x7f\x8a\xbd\xe2\x56\x77\xea\x9c\xc6\x0a\xf9\x30\x7d\x21\xd3\x01\xfd\xd2\x3c\x28\x27\x7f\xce\x11\x40\x03\x10\x03\x39\x62\xc0\x4e\xcd\x37\x7f\xd4\x46\x35\x8a\x34\x49\xef\xd6\xbc\x05\x72\x1b\x78\x4d\xdf\x0e\x23\x8f\x28\x60\x8e\x86\xbd\x4c\x3d\x7a\xc6\x31\xff\xf8\xbe\x06\x78\xd3\x7b\xfb\xac\x16\xb7\x5b\xc1\x5a\x50\xce\x13\x97\xdd\x4b\xa3\xbf\xfc\xf9\x4d\x34\x12\x74",
        p,
        q,
        g,
        b"\x53\xfc\xd0\x73\x99\xe4\xd3\x1b\x09\xab\xef\xf2\xf0\x96\xa7\xb2\xcc\x5c\xf4\x17\xde\xe1\x20\x7d\x8a\x5a\xab\xf9\xe8\xf9\xfb\x0f\x66\xbe\x48\x82\x6a\x3d\xc1\x1e\x39\xbe\xba\x2f\xf4\x7b\x76\x54\x4b\xcf\x55\x48\x5a\xcf\x1e\x3d\x49\xe1\x90\x57\x01\x5e\x49\xed\x01\x2a\x48\x77\xbe\x74\x16\x07\x74\x9b\x6f\x4b\xf9\x5c\x44\xec\x3c\x9e\x8b\x89\x3a\xae\x8d\x80\xe3\x69\x97\x8a\x35\x80\x37\x1c\xc1\x3d\xe8\xe7\x14\x09\x2b\xb8\x92\xe4\xa9\x56\xad\x36\x54\x03\x2f\x77\x58\xfb\x94\x54\xa1\xcb\x56\x40\x6e\x1b\xf4\x58\x55\x10\x8e\xe9\x60\x10\x7a\x65\xd4\x54\x53\xcb\x48\x2d\xc1\x90\x49\xb6\xc8\x3b\xac\x11\x17\x56\xca\xf6\x5b\xdb\xe5\xe6\xb2\x70\xd5\x87\x5b\x99\x7a\x17\x22\xee\x9d\x58\x38\x49\x41\xaa\x40\xe8\x10\xb6\x0b\x83\x41\x2e\xaf\xd0\xa7\x42\x8a\x0a\xbb\x55\xdf\x45\x68\x0c\xf2\x26\x56\x71\x1d\xb6\xbf\xce\x8b\xdc\xbb\x4c\x08\x3a\x40\x1c\xdb\x68\x28\x4e\x0c\x7e\xc0\x0f\x7d\xe7\x4e\x57\x14\x6a\xda\xe2\x21\xe5\x4c\xc4\xa5\x66\xb0\x5a\x11\x3d\xdb\x22\xcb\xc1\x9d\x88\x1a\x41\xcd\x75\xde\x8c\xf6\xc7\xb8\x9a\x5f\xae\x65\x0d\xf5\x85\xaa\x70\xc0\x45\xb8\x4b\x2c\xbb\xcc\xd0\xe7\xab\x72\x0c\x58\x96\xab\xfd\x35\x6a\x66\xf3\xdc\xbb\xb5\x38\x6b\xe6\xd0\x2e\xa9\xb3\x19\x1c\xa2\x75\xd2\x22\x48\xae\xdc\x36\x0e\xcd\x40\x57\xae\x06\xab\x2c\x2a\xaf\xb5\x06\x57\xa9\x1c\x62\xe0\x38\xea\xc9\xf5\xc4\xd8\x81\x06\xdb\x4c\x69\x26\xfb\x5d\xd2\xde\x1e\xc7\xe4\xe0\x05\xce\x18\x45\x70\xe7\xe9\x7d\x76\x42\x2f\xa0\x37\x62\x1a\x6f\x6d\x46\xcb\x83\xab\x6f\x4d\x43\x4b\x6a\x8f\x07\x39\x00\xcb\x03\xa7\x81\x04\x55\xd1\x9e\x77\xd4\xdf\x62\x4d\x08\xe7\x82\x09\x0f\xfa",
        b"\x41\xa2\xc9\x55\xf4\x14\x13\xa7\xab\x06\x7b\x4f\x50\xc6\x1e\x39\x6f\x9f\xeb\xff\x61\xc1\x50\x0b\x1a\x4b\xc6\x9e\x50\xa5\x19\x35",
        b"\x79\xed\xd7\x51\xa9\xdc\x23\x72\xb4\x05\x80\xfa\x4d\x53\x8f\xbe\x2c\xda\x41\x49\xf6\xb1\x19\x39\xdd\xad\x92\xc5\x74\x74\x08\x83",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xa3\x26\x97\x30\x93\xce\x50\x2c\x16\x47\x3d\x89\xba\x19\x65\x07\xd9\x22\x81\x50\x47\x59\xcb\x34\xc6\xcc\x35\x3d\x45\x19\x7f\x91\x5b\x5e\x73\x6b\x8f\xf8\x57\xa8\xb2\xec\x99\x64\x9a\x32\x24\xf8\x57\x40\x18\x98\xc9\xea\x60\x7e\x6a\x2c\x1d\x32\x0f\x27\x56\x4c\xcf\xf5\xdb\xda\xcf\xd8\x7a\x14\x5f\x1a\x02\x94\x25\xd7\x65\x02\xc0\x81\xac\x0f\x6a\x14\xde\x5b\x2c\xad\x1c\x23\xa6\x1d\x4e\x9e\xc6\xa0\x4e\x1a\x45\x5f\xd7\x10\xc3\xc7\x8c\x09\x67\x53\xc0\xb7\xf1\x51\x1e\x8b\xa5\xf5\xf1\xaf\x4f\x07\x41\xfe\xe8\x8b\x77\xeb",
        p,
        q,
        g,
        b"\x92\x91\x5d\xb2\x1c\x2c\x3e\x57\xfc\xcc\xb7\xdf\xdc\xe2\x8a\x12\xaa\xf6\xdd\x10\x58\x11\x93\xb9\x8b\x7d\x51\xa7\x28\xc3\x85\x16\xe3\x9e\xf5\xcf\xb1\xff\x9f\xa1\x65\x9c\x9b\xee\x56\xd4\xeb\xc1\xcd\x69\x64\x6c\x3c\xc3\xf7\xca\xae\x0c\x42\xd9\xcc\xa9\x21\x91\x48\xe4\x99\x8c\x2d\xdc\x89\xeb\x9a\x3e\xdc\xfa\x6f\x45\x71\x29\x00\x7a\x93\x44\x01\x3d\xd1\x23\xaf\xf1\x97\xbf\xcd\x3d\xb1\xd9\xe2\x19\x9b\xce\xa1\x61\x65\xa4\xc3\x4e\xd2\xac\x32\x16\x7a\xbd\x16\x77\x04\xea\xd3\x1d\x5f\xc2\x86\x0b\x83\x4d\x44\xf8\x6c\xb5\x30\xda\xd9\xe8\x87\x01\x3c\xa4\xd6\xe8\x83\x00\x8c\x28\x6d\x20\x6b\x6c\x7c\xb2\x52\xd1\x32\x8b\x50\x3a\xe0\x67\x9b\x50\x2e\xc1\x64\x6f\x69\xf2\x60\x2d\x5e\x3d\x63\x1d\x4a\x5a\x63\xfc\x7a\x5d\x06\xf2\x79\x26\xa4\xd6\xb1\xef\x2f\x77\xdd\xff\x3d\x85\x0d\x3d\x9f\x58\xa9\x58\xc3\xf4\xf1\x2c\xf0\x29\xf1\x48\x38\x6c\x5b\x8a\x71\xba\xe9\x09\x4d\xec\x85\x27\x9b\x1e\x38\x77\x99\xd2\x6b\x2a\x6a\x0e\x0d\xbf\x06\x49\x73\x66\xe4\x90\x3e\x55\x9e\x70\x97\x5d\xed\xc7\xd4\x93\x4d\x4e\x2d\x3d\x2c\xd3\x05\xab\x82\x64\x02\xea\x8f\x27\x78\xe2\x66\x25\x11\x9e\x7b\x0c\x24\xc4\x5d\xd9\xc0\x5a\x38\x90\xdd\x1d\x9d\x93\x0b\xd0\xbb\x40\x93\x66\xb0\x7a\x47\xce\x57\x2e\xd5\xbc\xd5\xf6\x3c\x46\x7d\x49\xc5\x68\x11\xfc\x3e\x40\x13\x41\xb9\xa4\x53\x1f\x77\x6d\xeb\xde\xa5\x40\xa3\x4c\x7c\xca\x3c\x3f\xb2\xea\x99\xc5\xfa\x9f\x9f\xdf\xde\x91\x8a\x94\xf7\x4e\x08\x0d\x19\x86\xb6\x8f\xc1\xe3\xfb\x97\x80\x54\x87\x2c\xed\x97\xba\xfd\x96\x73\x1e\x6d\x4f\x1c\x4a\x91\x27\x8c\x38\x3d\x47\x61\xc9\x74\x10\x09\x74\x52\x2f\x7b\x6e\x8a\x28\x84\xd5\xb3\xbb\xf6",
        b"\x73\xf1\x92\x2e\x26\xd9\xb8\x06\x8b\x68\xf8\x3c\x2b\xd5\xdb\xbb\x59\x60\x40\x3b\x49\x22\x3c\x02\xa4\x2c\xe6\xcf\x38\x10\xdb\x66",
        b"\x3a\xd3\x0b\xe9\xa6\x0f\x6d\x42\x27\x03\x94\x56\xc9\x82\x7d\x54\x24\x85\x8a\x02\xa8\xe6\xd3\x89\x17\x72\xcf\x80\xa5\xe4\xee\x21",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x75\x04\x38\x2f\xb7\xfb\xa1\xda\xb3\xc9\x3b\xd3\x1b\x16\xe7\x3d\x9a\xe1\xd0\x27\xdd\x23\x16\x6b\x3b\x94\xc7\x12\x41\x83\xfa\xf3\x96\x3c\x42\x0b\xe5\x20\x5a\x1f\x44\xa9\xa9\x02\x6c\x6e\xf7\x7e\x7c\x4e\xf1\xec\x48\x45\xfe\xf6\xe5\xea\x24\x87\xce\x01\x2f\xf5\x3f\x94\x50\xfc\xeb\x0d\x3a\xc6\x2f\x21\x02\xd7\x17\xe3\x28\x7d\xb3\x71\x47\x17\xa2\x8c\xd8\xb7\xfc\x64\x55\x6a\x86\x17\x3e\x6e\x7f\x47\x9f\x8a\x8d\xcd\x89\x54\x29\xcd\x7f\x0f\x53\x04\xef\x6a\xaf\x27\x5d\x94\xa7\xf4\xb3\x0a\xcc\x10\x71\x78\x7c\xa5\xf0\x62",
        p,
        q,
        g,
        b"\x20\x55\xbb\xe8\x9d\xa0\xa0\xc4\x88\xc3\xdb\xf2\x95\x31\xf1\xf7\xcd\x3f\xb5\x5a\x26\xef\xc5\x40\xc2\xed\xdc\xcc\xea\x16\x15\xdd\x92\x3f\xea\x4c\x8d\x0c\x95\xa5\xaf\x7e\x1e\x78\x16\x04\x8f\x2a\xe8\x53\x23\xa9\x64\x11\xe7\xd1\xad\x62\xc4\xca\x67\x5b\x63\xdf\x9d\xba\x31\xc1\xc7\x68\x03\xfb\x1c\x82\x92\x46\x5a\xd0\xa7\xe4\x9b\xa3\x75\x6a\x8a\xd4\xc6\xce\x86\xfd\x30\xb8\xb2\x8e\x08\xc4\xb4\x77\x7e\x07\x9f\xaf\xf1\x0f\xf8\x52\xf7\xd8\x91\xa9\x84\x19\x8d\xd0\x49\x77\x97\x21\x08\xc5\x2c\xe8\xbd\xb1\x15\x64\x62\x24\xa7\x93\x37\x74\x6e\x36\x47\x21\x31\x98\xf1\x12\x74\x30\xf5\x60\x87\x33\xd8\x82\x04\xa6\x2b\xe6\xea\xee\x84\x62\x9f\xc7\x28\x2a\xce\xf4\xc4\xf5\xd3\xad\xbe\x72\x41\x0b\x1e\xdf\xb7\x4b\xe1\x6b\x2d\x67\x5c\xca\x89\x1b\xd8\xce\xf2\x05\x17\x89\x02\xb9\x92\x71\xb4\x80\x41\xab\xe3\x3a\xc1\x19\xad\x6b\x75\x6a\x47\x7a\x63\x06\x3a\xae\x8a\x17\xcc\xfb\xe2\xac\xae\x3c\x0a\x3c\x63\x0c\x13\xad\xe1\x97\xcf\x3d\x05\xa9\xfa\x9d\x68\x99\xc0\xa3\xf9\x48\x7e\x61\x48\x73\x2d\xc6\x3e\x90\x7e\xf7\x94\x88\xdf\x33\x73\xb8\xa2\x13\x70\x5d\x69\xdc\xce\x6e\xd9\xa2\x20\x9f\x59\xeb\xc5\x8b\xbb\xeb\x08\x05\x45\x10\xb5\xa6\x51\x69\xd0\xfc\x1d\x4d\x10\xbd\xa6\x8a\xa7\xec\xea\xe2\xe7\x2f\x03\x39\xa2\xea\xae\xa0\x83\x03\x06\x4d\xd6\x58\x84\x14\xee\x77\x05\xdf\x3a\xb9\x74\xde\xbe\xf5\x88\xf4\xe3\x1f\xd6\xa8\xf2\x59\x79\xc9\xf5\x21\xd2\x34\x31\x20\xe4\x07\x94\xf4\x1a\x46\x01\xbe\x57\x91\x83\xb8\x77\xe6\xa8\xf6\xc0\xab\x7c\xe8\x48\x0e\x7f\xbf\xf4\x67\xa5\x81\xdf\x57\x0a\xf8\x99\x29\xbc\x4b\x56\x39\x7b\x78\x7d\xf4\xd7\x29\xe6\x5f\x9b\x98\xee\x7e",
        b"\x56\xe2\x1a\x7a\xb6\x1f\x9e\xab\xbf\xf4\x7c\x75\xe5\xf6\x8c\x31\x87\x3a\x9e\x1f\x2e\x1d\xb6\x62\x73\x11\x82\xf9\xa0\x29\xb8\xf6",
        b"\x2f\x24\xc5\x2f\x7b\xaa\xe2\x9c\x0b\x46\x33\xa3\x85\x52\x33\x18\x0e\xba\x80\x61\x1d\xbc\x7e\x88\xe2\x35\x48\xa5\x20\xb6\x0f\x66",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x0c\x0f\x7b\x0f\x99\x55\xbb\x54\xf1\x6e\x4e\x39\xad\x9b\xfd\x1d\xeb\x04\xb8\xe8\xb3\x8e\x67\x4d\xa4\x55\x69\x6b\xdf\x7c\xf2\x8e\x24\x11\x4a\xd0\x05\x13\xd8\xdd\x4e\x5c\x89\x5d\x35\x1e\xa9\x13\xfe\xe5\x16\xb6\x46\x82\x00\x87\x72\x1d\x9a\x0b\x5e\xcd\x76\x9b\x38\x25\x73\x91\x23\x54\x4e\x70\x58\xb6\x6d\x23\x42\xb0\x44\x62\xd5\xd1\x73\xcd\xb0\x0e\xf6\xac\xa6\x04\xaa\xa4\x38\xb8\x86\x8d\x15\xdd\x66\x24\xab\xb8\xd1\x93\x84\xdb\x48\xbd\xaa\x66\x47\x14\x13\xa8\x94\xd3\x61\x0b\xc9\x7d\x84\x8a\x59\xe2\xc6\x9c\x0c\x0a",
        p,
        q,
        g,
        b"\x45\xef\x38\x4e\xd8\x17\x38\x66\x68\xe1\xb9\x0b\x42\xf1\xd4\x23\xad\x9b\x17\xea\x87\x01\x19\xc0\x93\x2a\xc2\xf5\x15\xf5\x46\xa3\xb6\xb8\x0a\x61\x2e\xe6\x6d\xfc\x00\xcc\x4d\x9e\x3b\x5d\xd1\x53\x03\xd5\xeb\xc0\xaa\x40\xcb\xcd\x77\x46\xf5\x4a\x3f\xfe\xa2\x3a\xea\x07\x04\xae\x9c\xf5\xad\x61\x45\x62\x9c\x61\xd1\x58\xdb\x6e\xe3\x9a\xc8\x99\xbb\xda\x59\x79\x4b\x17\x69\xa9\x29\x82\x08\x2b\x77\xa1\xd4\x88\x56\x42\x7b\x78\xbb\x6e\x07\x7e\x27\x33\x5f\x11\x5b\xb8\x42\xe5\x32\x51\xf6\x99\xf0\x44\x88\xbe\xaf\x83\xa6\xc4\xaa\x6a\x4b\x76\x37\x0c\xef\xc9\x09\x9c\x0a\x45\xbc\xf9\x73\x24\x2d\xf2\xa0\x1e\xf6\x8e\x66\xc8\x7e\xff\xd7\xf9\x8f\x44\x1e\x94\xa0\x9a\x28\x30\x07\x6c\x28\x95\xf9\x97\xaf\xd0\xa9\x09\xb4\x5b\x3c\x05\x91\x77\x00\x02\x36\xc5\x01\xbf\xaa\x56\xda\x80\x0e\xcf\x08\x70\x1d\x21\x20\x16\xb5\x25\xf3\x0d\x63\xcc\xf3\xaf\xea\x09\xdf\x39\xe1\xcf\xab\x7b\xf4\x5d\xe1\xa3\x9a\xc7\xf2\x8d\xe0\x03\x7e\xc5\x52\xe2\xea\x10\xc6\xb5\x6a\x5d\xb8\xc1\x3f\xcb\xf7\x3d\x2e\x50\xd5\x8b\x4f\x3c\xf2\x78\x50\x6f\x1e\xaf\x08\x73\xe9\xee\x94\x65\xcb\xaf\xf4\xae\x62\x6f\x3a\xa1\x09\xfc\xe4\x9e\x55\xd5\x7f\xe8\x81\xc5\x0f\x72\x79\x26\x26\x21\x28\x2a\xdc\xf3\x79\x14\x1c\x9b\x2c\x39\x81\x3f\xaf\x82\x3a\x7e\xc0\x77\xc6\xe6\xbf\x95\x3f\x13\x0a\xca\x58\xf3\x6e\x7a\x87\xab\x1a\xae\xea\x5e\xeb\x44\x02\xfa\x9e\x26\xef\x89\x38\xc8\xf3\x8a\x6c\x04\x08\x09\xf4\xd0\x4c\x81\xe2\x94\x83\x87\xd7\xbe\x81\x3a\x97\x3a\x9c\x95\x17\x67\x00\x11\x7d\xe2\xf3\x3e\x61\x94\x03\x87\xf8\x51\xa7\x3d\xfa\x4a\xc5\xc9\x84\xec\x97\x91\x8c\x96\x7b\xfe\xdd\x88\x6d\x1b\xb7\x05",
        b"\x77\x56\x3b\x3b\x48\xfc\x9e\xe0\xdb\xea\x79\xfc\x74\xdd\x6c\x69\xb7\x2c\x42\x70\x91\x8e\x6a\x1b\xe2\xc9\x98\x17\x70\x23\xb4\x0f",
        b"\x09\x9c\xdd\x62\xdc\x04\x4a\x57\xea\x25\xd1\xb5\xc1\xf6\xed\x84\xd1\x1b\xac\xbb\x09\x75\x97\x6d\x58\x21\xc4\x14\xb5\x41\x6b\xde",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xc6\x77\x35\x69\x8a\xe7\xbb\xae\xb6\xf3\x21\xa1\x08\x86\x17\x38\x2a\x5c\x92\x09\x21\x51\xec\x36\x45\x82\x96\x2c\x9c\x0e\xd9\xed\x8f\xc7\x90\xcd\xe0\xd9\x74\x4d\x4e\x38\x97\x0a\x84\x82\x40\x1c\x0f\x61\xe9\x18\x05\xf4\x98\x4b\x8c\xfd\xf9\xdc\x80\x93\xa5\xc6\x68\x1d\xac\x13\x80\x9b\xc4\x1d\x16\x7d\x3e\x11\xbc\x99\x69\x8a\x4b\xc0\x7f\xd2\x48\xa6\x74\x91\xe8\x64\x10\x81\xff\x1e\x97\x87\x17\x45\x15\x7c\xf9\x30\x19\x5a\x35\xa1\x4d\x08\x83\xa2\x6d\xb4\x42\xe4\xed\xb9\x62\xaa\x61\x87\xb8\xd1\xc7\x79\x1d\x61\xbd\x25",
        p,
        q,
        g,
        b"\x0d\x3b\x3c\x3d\xf0\x72\xb5\xf5\x12\x91\x18\x13\x2b\xb7\xbc\xa3\xc5\x2f\x51\xdf\x36\x76\x7f\x11\x52\x38\x7e\xc0\x0d\xf6\x5c\x72\x8f\x0c\xff\xc1\xcb\x6f\x22\x42\x58\xcb\x6d\x3e\x90\xf7\x9d\xd9\x76\xb5\xa1\x80\xb8\x39\x03\xd2\x10\xf0\xc4\xda\xb8\x2e\xb7\x2a\x1f\x89\x97\xbf\x09\x30\x1d\x0f\x7c\x89\x07\x5d\x55\x2c\x81\xfd\x95\x85\xb0\xb1\xb1\x29\x17\x44\xd2\x1b\xd1\xed\xcb\x51\x12\x17\xc2\x96\x2e\x1a\x6d\xe9\xbb\x01\xc2\xb9\x69\x8f\xf5\x5e\xa7\x5d\xcf\xe4\x56\xbe\x48\x1c\xb6\xf0\x64\xfe\xd4\xbf\xf8\x74\xeb\x1c\x9b\x74\x51\x97\x9f\x7d\xe7\x01\x1b\xaf\x5a\x47\xc9\x76\xa1\x79\xae\xe9\x09\xd2\x5c\xa8\x7f\xd5\xe3\xc7\x5d\xf7\x78\xe2\x12\x72\x93\x7c\x5b\xa7\x80\x6a\xef\xa7\x06\x47\x22\x1e\x5f\x7c\xc3\x2a\xb8\x01\x59\x21\xa5\xa9\x5e\xcb\xb3\xca\x4b\x66\x72\x49\xd0\xf3\x4d\xd2\xd8\xba\x86\xdc\x15\x8f\x9e\x84\x25\x17\x6e\x98\x80\x48\xef\xd9\xf7\xb7\xcc\x53\xe9\xfc\xdb\x29\xad\x24\x12\xab\x4c\xa6\xeb\xbd\xe6\xf4\xef\xca\x59\x45\xb5\x3b\x27\x53\xbf\xc4\xea\xbe\x62\x80\x23\x56\x20\xc4\x46\x4f\x69\x40\xac\xca\x1a\x94\x65\x9a\x52\x7a\xa1\x4c\xc7\xc5\x46\x73\x82\xa5\x4f\xe4\x79\x65\x6d\xfb\xc1\x19\x23\x09\x4f\xe8\x01\x9a\x08\xc3\xce\x7e\x99\xa2\x8f\x08\x6b\xda\xaf\x0f\xaa\xc6\xee\x16\x19\x0d\xca\x8e\x94\xbf\x87\x65\x70\x58\x49\x5a\xd0\x79\x31\xc8\x90\x08\xca\x1e\x56\x50\x76\x25\x6a\x93\xcb\x24\x68\xaa\x71\x22\x75\x8b\x8e\x17\x4f\x6a\x80\xf4\x1a\x90\xfc\x92\xf0\x5b\xf1\xf1\xf4\x7d\xa1\x85\xb2\xf2\x5a\x1a\xbf\x5e\x0c\xcc\x66\x13\xe3\xae\xf8\x71\x93\x40\x0d\x75\x1b\x4c\x87\xb4\x4d\x9b\xdf\x5c\x0e\x20\x7f\x0f\x6a\x7d\xc2\x11\x37\x99",
        b"\x42\xc9\x02\xc5\x82\x68\x74\x77\x45\x50\x46\x4c\x4b\xb7\x36\xf2\xaf\x7f\xd2\xa3\x47\xf2\x7c\x65\xba\xe1\x18\x20\xee\xb7\x52\xaa",
        b"\x64\x11\xb4\x59\x47\xa4\x3c\x5b\x01\xc2\xf6\xce\xfc\xd4\x1c\xab\x73\xfc\xb6\xea\x0f\x2a\x35\xa2\x14\x75\x56\x30\x55\x31\x6e\x3e",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xeb\x6a\x03\x59\xc6\xe4\x6e\x09\xa4\x2c\x55\x47\x05\xbc\xfc\x5c\x0c\x02\x26\x70\xb2\xf6\xc1\xa5\xbf\xe1\x4e\xa8\x05\x75\x9c\xa2\x25\x61\x53\xfd\xf8\x15\x05\x7c\xa9\xbd\x5f\x4c\xf8\x37\xe1\x4f\xdb\xa3\xad\x17\x61\x2c\xcd\x19\xfd\xe0\x07\x64\xba\x2e\x8e\xcd\x8f\x5a\x18\x5c\xb2\x65\x12\xf7\x45\x72\x59\xc2\xf0\x67\x08\x52\x74\x1e\x73\x93\xb4\x0c\x8b\xab\x67\x3b\xe2\xfa\x51\x9b\x48\xa9\x5d\xee\x65\x52\x36\x5f\xdb\x7d\xdb\x63\x2b\x1b\x33\xf1\xa5\x29\x0b\x82\x8d\xa5\x96\x5e\x82\xd8\x74\xf7\x9c\xdb\x92\x88\x14\xfb",
        p,
        q,
        g,
        b"\x6d\xb8\x3b\x06\xc6\x98\xed\x80\x12\x2e\xc4\xa2\x18\x33\x70\xed\x7d\xbd\x6e\xa4\x4d\xbb\x45\x42\x14\x95\x68\x57\x0c\x53\x52\x1d\x33\x99\xab\x44\xfe\x2b\xab\xd4\x90\x68\xe1\x19\x53\xc5\xd3\x8f\x7f\xfe\x3b\xcb\xe4\xcb\xce\xb9\x1c\x15\x5a\xc8\x74\x1d\xcf\x22\x6a\x59\xed\xe1\x0b\x05\x0b\x9f\x37\x43\xf2\x96\x89\x26\x6c\xe6\xee\x02\x0c\xa1\x7f\x9f\xa0\xe7\x5b\x3f\x71\x58\xa6\x5c\xef\x9f\xac\x76\xc8\x87\x86\xb5\xe3\x77\xaf\xea\xcb\x9b\x3d\xda\x55\xbe\x92\x2d\xa0\xef\x95\x8a\xa5\x56\xab\xfb\x43\x06\x7a\x41\x4e\x91\x5e\x31\xaf\x5f\x53\x70\x88\x1e\xd9\x7b\x25\xb4\xbf\xec\xbe\x08\x2a\x14\x5d\x02\x71\x7a\xf8\x00\xe7\x7e\x28\x96\x3c\xc0\xa6\xa1\xc1\x1b\x02\x83\x5e\x14\xbd\xba\x1a\x8c\x9c\xe4\xbf\xeb\x06\xaa\xeb\xd7\x60\xd7\xc4\x3c\xf5\x6b\xa2\x12\xd0\xc7\x5d\xa0\x26\x17\x65\x35\xf9\x82\xe8\xd7\x49\xf2\x0c\x2a\x8d\x5f\x53\x87\x5d\x89\x33\x74\xd8\x59\xb7\xce\xe5\x8b\x0e\xb3\x19\xd3\x31\x3c\xb8\xd1\x76\x02\xf4\x7e\x12\x0d\x1a\x24\xa0\xf8\xa6\x3c\xfe\x45\xa5\x02\x8c\xc0\x93\x7b\xbe\x89\xf6\xb3\xb7\xcd\xca\xa7\xdc\xd5\xec\x5f\x3e\xd2\xaa\x9f\x3a\xa8\xe9\x1a\x49\x6a\x8b\xad\x78\x74\xdd\x34\xbd\x8f\x2a\x95\x91\x99\x7d\x54\xf9\x2d\x58\x64\x21\x6c\x95\x36\x46\x84\x0b\x37\x8c\x7a\x05\x21\x5e\xcd\x97\xb6\xba\x94\x4c\xa1\x85\x97\xb7\xa5\x48\x32\xec\x98\xc1\xca\xc0\x00\x3d\x50\xd5\xa0\x53\x12\xcb\xc8\x52\xd5\x07\xcc\x97\x3e\xcb\x56\xf4\x24\xe8\xa1\xc1\x98\xbc\xdb\xaf\xaa\x6f\x92\x8f\xd2\x7a\x7c\x91\xf8\x4b\xc2\x34\xf2\x53\x26\x39\xa8\xaa\x21\x96\xf8\xfc\x2b\x71\x11\xb3\xd0\xb1\x15\x31\x65\xa0\xe0\x52\x5d\x4e\xa5\x95\xf8\x9a\xec\x33\xb6",
        b"\x04\x93\xdb\x0c\x18\xa3\x88\x27\x09\xb3\xcc\x9f\x8d\xbe\x05\x45\x45\x06\xc0\x4c\x3a\x12\xa4\x1d\x59\x9d\x20\x1d\x76\x15\xb6\xd8",
        b"\x74\x94\xb4\xd1\xb2\xf3\xae\x22\x79\x72\x55\xa1\xd0\x66\x27\x46\x35\x2a\x3d\x05\x32\x29\x04\x02\x06\x85\x94\xcf\xe4\x8c\x23\xa3",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x5c\x59\xb2\x09\xbb\xc0\xa1\xe0\x10\xcb\x10\x8d\xb4\x10\x1b\x8e\x2d\x04\xce\xd9\x12\x99\xa8\x74\x23\x22\x10\x2e\x0d\x57\x8c\x36\x98\x42\x2b\x43\xd1\x9d\x33\x16\x08\x18\x8b\xed\x4c\x7e\xdc\x03\xa4\x42\xf8\x9a\xae\x60\xf4\xe7\xee\x9b\x63\x25\xde\x3a\x8b\xb7\x02\x91\x8c\x21\x34\x3b\xc9\xb2\x66\xf2\xeb\xcf\x5a\x62\x03\x36\xa7\xbc\x99\xae\x36\x85\xf1\x90\x80\xdb\x46\xf2\x4a\x50\x12\x28\xc5\xbb\xfd\x9c\x0b\x4b\x0a\xbe\xcb\xfb\xd6\x76\xc3\x59\x60\x7c\xe2\x92\xcf\xfd\x52\xd2\x6a\xf8\x0b\x22\xe3\xc4\xd5\x16\xba\x0f",
        p,
        q,
        g,
        b"\xbe\x31\xfd\x5d\x62\xdb\x69\x0b\xcd\xbc\x09\xe4\x53\xd4\x41\x7f\x82\xe8\x62\x1a\xd7\x17\xca\xb9\x46\x48\x20\x1a\x74\xf6\xff\xdf\xab\x96\x53\x11\xe8\xff\x35\xc4\xa0\xb5\xdd\xa3\x39\xb4\x35\xf1\x73\x17\x17\x5a\xc6\x42\xf7\x85\x12\x9e\x15\x16\x94\xea\x8b\x24\x46\x27\xe3\x00\xce\xb0\xf3\xbe\x08\xf9\x1c\x0f\x52\x7f\x2e\x0d\xf7\xc9\xf5\x54\x92\xd1\x32\x9b\x7d\x96\x89\x63\x4c\x8a\x4f\x52\x10\x15\x7e\x24\x19\xe6\x15\xd9\x43\x17\x36\xf8\x04\xb1\x64\x11\x03\x37\x1e\x7f\xfe\x72\x00\xe7\x42\x96\x12\x7d\x59\xa8\xf9\x7d\x41\xaf\x11\xd7\x0c\x3f\xd0\x25\x31\xf7\xb8\x11\xda\xa7\x51\x6a\xa2\xf2\xa9\xba\x70\xdc\xb7\x04\xf3\xfe\xe4\x7f\x2c\xbe\xd6\x5c\x1e\x3d\x06\xc8\x81\x4e\x1b\x28\xab\xe2\x9f\x3d\x05\x67\x92\xef\xdf\x9a\xc9\x30\x7e\xd0\x10\x6c\x5a\x32\x87\x21\xaf\x0e\x20\x2b\x6d\xf7\x37\xec\x4d\x82\x14\x3d\xd2\x50\x5e\x10\x3a\xd8\x45\x86\x3c\x45\x86\x9e\x69\xab\xd9\xe0\x2c\x7b\x6e\xaa\xff\x9e\x2e\x12\xbc\x18\x81\x38\x68\x8c\x0b\xe3\xe6\x94\x1c\x37\xc7\xdd\xc9\xb6\xd2\x89\xf7\xcc\x8f\xde\x42\xbc\x3c\x14\xe3\xee\x52\x16\x35\xf3\x2f\x54\x28\x0d\x11\x9c\xce\xdf\xc5\x10\x90\xa0\xad\x00\x6b\x24\x27\x60\x40\x14\xea\x4d\x0e\x0c\xd1\xef\xbc\xe0\x9c\x7f\x8e\x99\x81\xf9\x69\xae\xd6\xd4\x81\xca\xfb\x32\x9f\x99\x53\x43\x54\x1d\x36\x68\x6d\xe6\xcb\x8e\x4b\x1e\x7e\x37\x27\xab\xd5\xc1\xe3\xff\xa6\x93\x6a\xd4\x4b\x92\x60\x63\x56\x15\x12\xc0\xe9\xac\x78\x7f\x8e\xb7\x91\xf9\x63\xf7\x90\xba\x1b\x21\xdf\xe1\xb8\xd3\x1d\x4c\x16\xb1\x52\xa6\xde\x65\xbf\x54\xab\x0f\x0d\x1e\x3d\x45\x03\x17\xb1\xcf\x0c\x4e\x33\x1d\x18\x58\x7a\xcc\xb6\x96\x0c\xcd\x04\xdd",
        b"\x7f\xc9\xba\xb3\x50\x5a\xdc\xd1\xb1\xc8\x12\x7e\x2d\x1f\xbc\xd0\xe1\x5e\xaa\xc3\x14\x25\x0d\xc1\xc6\x84\xfc\xc4\x7f\xda\x29\x93",
        b"\x70\xf2\x00\x7e\xdd\x68\xfb\x9d\xfe\x19\xa6\x3e\xee\x4d\x5a\x97\x72\x91\xab\xd2\x35\xed\x26\xe4\x29\x14\x76\xca\x5d\x0c\x81\x71",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xc8\x05\xd1\x8c\x0b\xb5\x3d\x32\xb5\x7c\xb6\x52\xf5\xb0\xe5\x29\x3b\xe4\x92\xa1\xc8\x8d\xfb\xec\x5b\xaf\x47\xee\x09\x3e\x2d\xf0\x69\x18\x99\x4e\x5c\xac\xbc\x3d\xff\xf2\x29\xab\xd3\x1f\xab\x7a\x95\xad\xe2\xfb\x53\xad\xaa\x7d\xff\x51\xf6\xc8\x58\x1c\x69\xeb\x5b\x09\x0b\xae\xc3\x86\x07\xee\x94\x35\x44\x7a\xd8\x13\x74\x55\xb6\xba\x17\x9f\xc5\x3a\xc0\x94\xf9\x7e\x3e\x29\xd0\x72\x4c\xd1\x08\x11\xf1\x42\xd6\x7d\x1c\xfc\xd5\xc3\xd1\xe9\xb4\x11\xda\xc3\x8f\x6e\x1c\x0c\x14\xdc\x9a\x50\xd8\x4b\xcf\x00\xec\xe8\xa6\x03",
        p,
        q,
        g,
        b"\x2b\x6e\x1a\x8d\x44\x82\xb4\x16\x97\xbb\xbe\x50\xb5\x5b\x3d\xcd\xec\xea\x8d\x2e\x2e\xb5\xcf\x27\xb8\x92\xbc\xbc\xab\xfb\x25\x3c\x19\x48\x6f\xa7\x7c\x98\xc1\x5a\xdd\x41\x49\x92\x5b\x55\x01\xe5\xa5\xef\x45\xb3\x2a\xd0\x9a\x87\x24\x62\xa0\xf4\x1d\x04\x8a\xf4\xe5\x30\x66\x0a\x38\x64\x93\x7b\xa6\xa9\xeb\x07\x34\xe9\x0f\xda\x3c\x9b\x6f\xcd\x30\xc9\x07\x87\x71\x29\x5a\x93\x80\x2d\x9e\x19\x92\xa4\xee\xe9\xaf\x7a\x04\x13\x88\x0f\x33\xbc\x0b\x62\x03\x62\x03\x28\x68\x44\xbc\x38\x41\x87\xec\x51\xa3\x3d\x39\x0e\xaa\xc0\xcc\x33\x28\x09\x8a\x84\x75\x09\x12\x9b\xda\x73\x59\x09\xfc\x7a\x11\x89\x3a\xd0\xec\x61\x27\x6b\x7a\x5d\xcd\x4e\x62\x6d\x9b\xa6\x76\x10\xea\xf0\xaf\x87\x6a\xfc\x04\x19\xfa\x4f\x00\x9a\xa5\xf9\x13\xa1\xc7\x37\x98\xc2\x70\x7e\xeb\x8f\xa7\x7f\x4e\xe0\x58\x22\x9a\x0a\xd3\x7e\x84\x57\x39\x66\x8d\x95\xde\x22\x67\x60\x89\x8c\x02\xd0\x6f\x15\x5f\x82\xdc\x16\x36\x0c\x3a\xbc\xa3\x78\x0b\xcd\xb7\x94\x46\xc8\x34\x35\x83\xdc\x0f\x69\x25\x43\x4b\x0d\xae\x7b\x59\xcb\x26\xb1\x00\x08\xf8\x65\x70\xca\x03\x50\xde\x34\x0b\x27\x55\x24\xf0\x05\x51\x31\x0f\x1d\x09\x5d\xb8\x48\x0b\x4a\xcc\x48\x9c\xf5\xe2\x94\x7e\xb9\x29\x04\xeb\xfd\x0d\x97\x8b\xbf\xb5\xd0\xc6\xa1\xa9\xdb\x50\xcc\x69\x17\x94\x9c\x71\x85\x46\x32\xb4\x40\x8b\xad\xe5\x19\x5d\x40\xdc\xaf\x61\xfe\x95\x0e\xff\x0c\x89\x97\xc3\x74\xf1\xd4\x65\xc8\x0b\xc6\x5a\xdd\xa6\x36\x43\x3e\x94\xf2\x2c\x5f\xbc\xf0\x9e\x99\x66\x6a\x53\x59\x19\xee\x6f\x88\x15\x49\x34\xf1\x13\x77\xa9\xa9\xe0\x21\xf2\xd7\xec\xab\xa3\x25\x10\xe9\x2b\xf5\xad\x67\xfa\x8b\x3d\x70\xdd\x20\x92\xb1\x38\x9e\x31\x93",
        b"\x38\x20\x8c\x09\x85\x62\x4b\xb9\xd6\x27\x13\xbc\x71\x50\x94\x2c\xbc\x92\xb8\xe8\xa3\x6e\xf6\xd1\xec\x4d\x08\xd1\xd9\xa5\x71\x5f",
        b"\x65\xd2\xba\x78\x7e\xd4\xc0\x8b\xea\xbf\x24\x34\x3d\x06\xed\x61\x87\x2d\x6d\x68\x4a\x3b\xc7\x03\x07\xfc\xb7\xe2\x0d\xf9\x31\xda",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x9e\x0c\x66\xa4\xf1\x20\xe8\x5a\xea\x06\x4e\x7a\x8b\xa1\x32\xcf\x30\xa4\x5d\xe2\x88\x9f\x35\x47\x38\x4e\x4e\x84\xf4\x5b\x35\x72\xbb\x04\x23\xb8\x34\xde\x9f\x2c\x96\x36\xfa\xff\xdb\x63\x31\x92\x4f\x0d\x2f\x5b\x68\x76\x14\x5d\x9c\xae\x11\x0a\xb0\xcf\x6f\xc9\x0c\x2e\xef\xf9\x8c\x61\xfa\x18\x6c\xc3\x95\x2b\x57\x29\x9a\x73\x67\x8f\x45\x85\xbb\x18\xfb\xb8\x4e\xf4\x16\x67\x79\xff\x10\xee\xd1\x4d\x47\xae\x52\x8e\x03\x29\x8d\xbb\x97\xcf\x4f\x88\xb7\xe6\xd0\x95\x9b\x58\x94\x55\x0a\x3e\x2e\x35\x69\x47\xd2\x5f\xfe\x73",
        p,
        q,
        g,
        b"\xa6\x2a\xdb\xda\xa5\xa5\x5a\x2d\x1e\x43\x9b\x54\x89\xcd\x6c\x8f\xcb\x23\xe9\xc6\x4f\xbf\xae\x7c\x83\xe9\xd5\x59\x93\x19\xbf\x3f\x06\xc3\xc2\x90\xb9\x89\xa6\x38\x94\x0b\x1d\x0b\x7e\x8b\xf6\x74\x13\x19\xab\x4c\x38\xd4\x6e\x77\xeb\xd4\x94\x5e\x25\xcb\x89\xcb\xb6\x4e\x44\xb9\x47\x4b\xc7\xc9\xd9\xf6\x1a\x36\xe5\x7e\xb6\xaf\xab\x6c\x7a\x14\x9a\xfe\x02\xc1\xcd\x68\x54\x83\x20\x8c\x55\xfe\xec\xb0\xd0\xbd\x96\x69\x7b\x43\x79\x91\x05\x92\x67\xd7\x6a\x48\x84\x65\xfa\xab\x4a\x7e\x17\x59\x23\x29\x56\x70\x05\xfa\xa4\x21\xe0\x11\xd6\x7f\x4d\xa7\x5a\xcc\xb6\x27\x53\x7e\x93\x3e\x9e\xf0\xbe\x3c\x70\xf2\x1e\xd3\xf8\xc3\xb3\xd7\xd7\x69\xbb\x61\x1f\x82\xf2\xba\xa1\x0f\xbc\x73\x13\xad\x08\x19\x04\x8d\x35\x3d\x67\x97\x36\xc4\xd1\x4b\xca\x99\x85\xec\xd3\x70\x41\xaf\xff\xb2\x91\xa7\xd9\x09\xc7\x45\x81\x81\xd0\x15\x92\xe6\xc9\x0c\x0e\x34\xb4\x94\x61\xed\xe6\x6c\x5a\xc0\x02\x67\x1a\x49\x85\x54\x6a\x60\x75\xdf\x95\xb5\x23\xf1\x66\xd2\xe0\xd1\xf5\xda\x77\xba\xff\x5a\x24\xdf\x77\x5c\xc9\xd3\x67\xf2\xa0\x72\x8c\x48\x02\xd7\x97\x04\x17\x88\xc5\x6c\xb8\x71\x29\x03\x32\xc1\x36\x1f\x8d\xa8\x89\x7b\x5b\x8e\x25\xd4\xa9\x35\x94\xac\x64\x8b\xc5\x3c\x9d\x85\xb4\xfc\xdd\x7a\xb0\xf5\xa3\xee\x9c\x25\xcc\x14\xba\x65\x43\xb0\x78\x85\x95\x24\xec\x7f\x0b\x61\xcd\xb2\x09\xcc\x51\xc4\x0a\xa9\xaf\x08\x2e\xa9\xc1\xd4\xb9\x1b\x2c\x1f\x6d\xc1\x1c\xd8\x79\xfb\x38\x65\xd8\x79\xfe\x00\x0f\x0e\x0b\x4b\x23\x3d\xbd\x01\xc9\xc9\x8d\x01\xa6\x64\x74\x65\x77\xa6\x4b\xf2\x8d\x88\x25\x6b\x76\xde\x2b\xab\xf1\x49\x61\x11\x37\x33\xb1\xbb\x55\x53\x25\xc0\x9d\x8e\xc9\x18\x9f\xca",
        b"\x4e\x35\xf5\x86\xfa\xd4\xf5\x12\x86\x3c\x48\x5e\xc6\x1e\xd0\x16\x29\xaa\x13\x99\xb1\x6f\xef\x4d\x80\xcb\x33\x27\x52\xb1\xda\x92",
        b"\x26\x2d\xfe\x6a\xc7\x2a\x2f\x60\x44\xf6\x26\x98\xe4\x2d\xd2\xf9\x2b\x1f\x9a\x91\xbe\x42\xb5\xfd\xd2\x93\xb1\xbf\x9a\x14\x5f\x00",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\xed\x88\xd7\x07\x6c\x5f\x6a\x5e\x0f\x94\x75\x43\xd5\xfe\x74\x6a\xfc\xa9\xb2\xc4\xd0\x66\x55\xda\x46\x07\x68\x5c\x79\x9c\x21\x0b\xe4\xaa\xee\x0e\x6e\xd1\x97\x13\x81\x41\x82\xc7\xf7\xd5\x84\xdd\xbe\xd4\x88\xc8\xe3\x23\x9d\xdd\x81\x05\x55\xad\x63\x16\xd1\xdb\x37\xfd\x95\x53\xad\x74\xe3\xce\xef\x9e\xee\xfa\xf5\x45\x63\x60\x2f\x55\x47\xaa\xd4\x16\x1e\x93\x84\xed\xab\x65\x5a\x89\x84\x16\xdb\x53\xf7\x12\x37\xac\x5a\x14\x85\x71\x11\x82\xbc\x5b\xff\xf7\x24\x60\x25\x27\x84\xab\x1b\xba\x23\x63\x4a\x36\xbe\x77\x53\x3f",
        p,
        q,
        g,
        b"\x3e\x1c\xe8\x78\x0f\x39\x44\x4c\x21\x30\xdb\xf9\xd8\x0c\xa4\xb2\x58\x17\xdc\x16\xd0\x8e\x2c\xda\xca\x0b\x56\xcd\x2a\xbd\xb9\xef\x5a\xdb\x74\x1c\xcc\x1a\xbe\xcf\x62\x80\x6a\xd7\xe8\x76\x36\xf5\x28\x31\xc6\xde\xa4\x8e\x07\x29\xb9\x04\xe5\xa0\x61\x5d\x7a\xb4\x45\x01\x04\x20\x8a\x5d\xdf\xdb\x2f\x25\x69\x14\x6e\xe8\x3a\xc9\xaa\x27\xb4\xd0\x66\x35\x5f\xc5\x3d\xc1\xa3\x68\x32\x11\xad\x3e\xfa\xd1\xae\x69\xb8\xa7\x73\x7b\xbd\x89\xf5\xff\x48\x48\x2e\x2c\x56\xed\xaa\x77\x6e\x43\xb2\xa0\xba\x62\xe5\x13\x86\x2d\xa2\x90\x28\x8f\x07\xf8\x4c\xa5\xa0\x68\x37\xd1\x9e\x9b\x18\x6d\xc8\xd3\x69\x52\x96\x6e\x08\xf7\x21\x33\x40\x18\x6d\x31\xfd\x41\xa2\xd1\x45\x5a\x08\x3a\xee\x62\x12\x7a\x28\xdf\xe4\xda\x6c\x87\x6a\x5a\x6f\x36\xc4\x52\x45\xde\xe6\xf6\x56\x6b\x83\x18\xd3\xd0\x19\x43\xb2\xad\xf8\xce\x94\xea\x01\xa0\x1b\xa4\x1a\x6e\x28\x68\x20\xa9\x67\x07\xcb\xd4\x00\x28\x75\xb7\x9d\x9f\xe2\xdb\x6c\xc3\xf8\x08\xef\x0f\x71\x38\x0e\xa9\xa7\x3f\xc7\xe3\x68\x50\xd0\x22\xff\xac\x13\x16\x36\x36\x78\x86\xa6\xe9\x96\x57\x59\xd7\x3f\x03\xac\xe6\x97\x04\xb5\x21\x44\xf6\x7b\x67\x8e\x2f\xa2\x01\xc1\x9b\xb3\x7b\x00\x37\x7d\xaa\xbc\x93\x77\xad\xcb\xdd\xea\x28\x16\xcb\xb5\x0b\x26\xad\x2e\x42\x9e\xa0\x57\x6e\x77\x21\xb3\xb7\x5c\x4f\xed\xb3\x1f\xdf\x1f\x0c\x6c\x2e\xaa\x13\x5f\x52\xc9\xa9\x7f\x0d\xf5\xfb\x25\xef\x28\x84\x8b\xdd\x73\x90\xcd\x05\x40\x03\x72\x25\x82\xd9\x4e\x90\xa3\xbb\xe8\x5b\xeb\x34\x70\x12\x71\xb4\xbb\x48\xbd\xf9\xb3\xd0\xe1\xbb\x56\x23\x44\x5c\x78\x28\xc9\x37\xa4\x23\xbe\x51\x2c\x11\x77\xc9\xc0\xb5\xb0\xb6\xb0\xe1\xf6\x39\xd3\x30\xe0\x51",
        b"\x2e\x7c\xb4\x04\xa6\xda\xaa\x8e\x00\x76\x0d\xaf\xc9\x5b\x4e\xb5\x54\x56\x83\x22\x4a\x61\xa1\xbc\xd6\x12\x8b\xc4\xe7\xac\x53\x5e",
        b"\x3a\x70\xb3\xa9\x7e\x06\xe6\x3b\x89\xd5\x6e\xd5\x23\x23\x46\x46\x1c\x1a\x3b\x6b\x14\x5d\x89\x04\x3a\x48\xd6\x66\xde\x02\x56\xd5",
    )?;
    test(
        HashAlgorithm::SHA256,
        b"\x9e\x44\x00\x52\xed\x92\x73\x21\x94\x83\x88\x77\x6d\x37\x19\xbe\x06\x87\x39\xdc\x2d\x6c\x64\xc5\x93\x71\x76\xb2\x00\x5c\x2d\x70\xa9\x38\x9e\x6a\x65\x56\x63\x36\x6c\x09\x70\xa8\xe2\xe3\x11\x7e\xce\xf2\x57\xe9\x51\xac\x81\xc0\x73\x1d\xfc\xd4\xfb\xdb\x12\x41\xbc\x24\x9a\xdd\xe9\xcb\x39\x8c\x7d\x15\xe3\x81\x36\x8a\xd3\xd2\x4e\xde\xe2\x33\x97\xc1\x5a\x5a\x35\x6e\x78\x7d\x8f\x2f\xe9\xbe\x76\x26\x0b\xd3\x63\xe1\x70\x06\x28\x1c\x19\x9f\xe5\xb7\x10\xf9\xdf\xca\xc5\x28\x95\xe3\x92\xf7\x38\x4d\x71\xbb\x83\x05\x3f\xfc",
        p,
        q,
        g,
        b"\x89\xe8\x59\xfc\x63\xa2\x63\xbc\xc0\x51\xbc\x2e\xf5\x8c\xc9\x19\xee\x53\x73\x85\xcb\x36\x36\xd8\x3a\x62\x4a\x42\x30\xd4\xb0\x02\x4e\xc5\xe2\x8b\xcb\x88\x46\x67\xcd\x2b\xf8\xc2\x84\x51\xb6\x4d\xe0\x97\xf2\x19\x4c\xbb\x8c\x6e\x1c\xec\xbd\x6f\x9f\xbd\x57\x64\x81\x55\x5d\x0f\x0e\x8f\x13\x75\x2f\x24\x72\xf7\x61\x9d\x05\x23\x18\x42\x43\x10\xf6\x9d\x50\xde\x78\xad\x6c\x45\x7b\x98\xc6\x11\xf8\x48\x1d\x45\x43\x03\x1a\x73\xf8\x3d\x1e\x85\x2c\x1f\x20\x38\xa6\x43\x5e\x57\x1f\x77\x6b\xbb\x5c\xf9\x78\xa9\xb2\xc8\x8f\x05\xd1\x34\xfd\x5f\xf4\x65\x6a\x69\xd6\xfe\x6b\x66\x7d\xa6\xda\x54\xbe\x48\x38\x62\x50\x39\x4c\x75\xb4\x95\x68\x9f\xd4\x62\x8f\x66\x64\x24\xeb\x08\x00\x94\x44\x8d\x41\xb7\x06\x29\x2e\x51\xe7\x53\x86\x54\x3e\x5f\xcc\xe6\xa6\xf3\xaa\xc0\x3a\x7d\x6d\x5c\x25\x51\xca\x6b\x5b\x85\xfa\xdc\x86\xbf\xf1\x4c\x79\xa1\x60\x2f\xb0\xc1\xd4\x3d\x88\xd5\x67\x90\x21\xe8\x26\x06\x2e\xcf\x18\x6a\xaa\xae\xfc\x31\x2e\xab\x9f\x9e\x2d\xa1\x20\xa8\xd7\xd0\x8b\xa0\x9a\xa9\xab\xf4\xe3\x4f\x6d\x88\xc4\xc3\x14\xc5\x9c\x36\xba\x57\xf9\x28\xd8\x8d\x5d\x70\xfe\x48\xac\x67\x00\xf5\xcf\x60\x7a\x55\xe3\x64\x6d\xd0\x3d\x47\xe9\x6a\xd8\x69\xf7\xba\x2b\xcc\x7d\x65\xa9\x9c\x32\x21\xd4\x90\x9d\x1f\x22\xe4\xcc\xba\x81\x5f\xa5\xb7\x20\x57\x0e\x42\xf8\x62\x6c\x31\xd9\x9f\x60\xcd\x6a\x01\x53\x91\xfa\xb3\x53\x74\x46\xf7\x47\xc0\x11\x12\x93\xc5\xbd\x6b\x5d\xab\x2b\xc3\xd5\x13\x7d\x21\x24\x02\x9e\xed\x12\xdb\x71\xbd\xf7\x94\xde\x1a\x2e\xc5\x07\x0d\x83\xf8\x71\x95\x26\x4f\xf0\x9c\xb4\x8c\xdd\xb5\xe8\x52\xb2\x33\x57\x0f\x1b\x70\xcd\x45\x7c\xf8\x64\xe2\xef\x3b",
        b"\x37\xc3\x4f\x9c\xce\x91\x6d\xf3\xde\xff\x26\xbe\x08\xa4\xe6\xbb\xae\x06\x61\xfb\xbb\x5d\x81\xd6\x03\x9f\x00\xb1\xe5\x63\x2b\x67",
        b"\x3f\x4a\x29\x32\x91\x7e\x6b\xb0\x88\x59\x9a\x26\x9d\x7b\x59\x07\x69\xac\xf9\x80\x7d\xc5\xa9\x42\x0a\x95\xe1\x2c\x73\x64\xc5\xfa",
    )?;

    // [mod = L=3072, N=256, SHA-384]
    let p = b"\xa4\x10\xd2\x3e\xd9\xad\x99\x64\xd3\xe4\x01\xcb\x93\x17\xa2\x52\x13\xf7\x57\x12\xac\xbc\x5c\x12\x19\x1a\xbf\x3f\x1c\x0e\x72\x3e\x23\x33\xb4\x9e\xb1\xf9\x5b\x0f\x97\x48\xd9\x52\xf0\x4a\x5a\xe3\x58\x85\x9d\x38\x44\x03\xce\x36\x4a\xa3\xf5\x8d\xd9\x76\x99\x09\xb4\x50\x48\x54\x8c\x55\x87\x2a\x6a\xfb\xb3\xb1\x5c\x54\x88\x2f\x96\xc2\x0d\xf1\xb2\xdf\x16\x4f\x0b\xac\x84\x9c\xa1\x7a\xd2\xdf\x63\xab\xd7\x5c\x88\x19\x22\xe7\x9a\x50\x09\xf0\x0b\x7d\x63\x16\x22\xe9\x0e\x7f\xa4\xe9\x80\x61\x85\x75\xe1\xd6\xbd\x1a\x72\xd5\xb6\xa5\x0f\x4f\x6a\x68\xb7\x93\x93\x7c\x4a\xf9\x5f\xc1\x15\x41\x75\x9a\x17\x36\x57\x7d\x94\x48\xb8\x77\x92\xdf\xf0\x72\x32\x41\x55\x12\xe9\x33\x75\x5e\x12\x25\x0d\x46\x6e\x9c\xc8\xdf\x15\x07\x27\xd7\x47\xe5\x1f\xea\x79\x64\x15\x83\x26\xb1\x36\x5d\x58\x0c\xb1\x90\xf4\x51\x82\x91\x59\x82\x21\xfd\xf3\x6c\x63\x05\xc8\xb8\xa8\xed\x05\x66\x3d\xd7\xb0\x06\xe9\x45\xf5\x92\xab\xbe\xca\xe4\x60\xf7\x7c\x71\xb6\xec\x64\x9d\x3f\xd5\x39\x42\x02\xed\x7b\xbb\xd0\x40\xf7\xb8\xfd\x57\xcb\x06\xa9\x9b\xe2\x54\xfa\x25\xd7\x1a\x37\x60\x73\x40\x46\xc2\xa0\xdb\x38\x3e\x02\x39\x79\x13\xae\x67\xce\x65\x87\x0d\x9f\x6c\x6f\x67\xa9\xd0\x04\x97\xbe\x1d\x76\x3b\x21\x93\x7c\xf9\xcb\xf9\xa2\x4e\xf9\x7b\xbc\xaa\x07\x91\x6f\x88\x94\xe5\xb7\xfb\x03\x25\x88\x21\xac\x46\x14\x09\x65\xb2\x3c\x54\x09\xca\x49\x02\x6e\xfb\x2b\xf9\x5b\xce\x02\x5c\x41\x83\xa5\xf6\x59\xbf\x6a\xae\xef\x56\xd7\x93\x3b\xb2\x96\x97\xd7\xd5\x41\x34\x8c\x87\x1f\xa0\x1f\x86\x96\x78\xb2\xe3\x45\x06\xf6\xdc\x0a\x4c\x13\x2b\x68\x9a\x0e\xd2\x7d\xc3\xc8\xd5\x37\x02\xaa\x58\x48\x77";
    let q = b"\xab\xc6\x74\x17\x72\x5c\xf2\x8f\xc7\x64\x0d\x5d\xe4\x38\x25\xf4\x16\xeb\xfa\x80\xe1\x91\xc4\x2e\xe8\x86\x30\x33\x38\xf5\x60\x45";
    let g = b"\x86\x7d\x5f\xb7\x2f\x59\x36\xd1\xa1\x4e\xd3\xb6\x04\x99\x66\x2f\x31\x24\x68\x6e\xf1\x08\xc5\xb3\xda\x66\x63\xa0\xe8\x61\x97\xec\x2c\xc4\xc9\x46\x01\x93\xa7\x4f\xf1\x60\x28\xac\x94\x41\xb0\xc7\xd2\x7c\x22\x72\xd4\x83\xac\x7c\xd7\x94\xd5\x98\x41\x6c\x4f\xf9\x09\x9a\x61\x67\x9d\x41\x7d\x47\x8c\xe5\xdd\x97\x4b\xf3\x49\xa1\x45\x75\xaf\xe7\x4a\x88\xb1\x2d\xd5\xf6\xd1\xcb\xd3\xf9\x1d\xdd\x59\x7e\xd6\x8e\x79\xeb\xa4\x02\x61\x31\x30\xc2\x24\xb9\x4a\xc2\x87\x14\xa1\xf1\xc5\x52\x47\x5a\x5d\x29\xcf\xcd\xd8\xe0\x8a\x6b\x1d\x65\x66\x1e\x28\xef\x31\x35\x14\xd1\x40\x8f\x5a\xbd\x3e\x06\xeb\xe3\xa7\xd8\x14\xd1\xed\xe3\x16\xbf\x49\x52\x73\xca\x1d\x57\x4f\x42\xb4\x82\xee\xa3\x0d\xb5\x34\x66\xf4\x54\xb5\x1a\x17\x5a\x0b\x89\xb3\xc0\x5d\xda\x00\x6e\x71\x9a\x2e\x63\x71\x66\x90\x80\xd7\x68\xcc\x03\x8c\xdf\xb8\x09\x8e\x9a\xad\x9b\x8d\x83\xd4\xb7\x59\xf4\x3a\xc9\xd2\x2b\x35\x3e\xd8\x8a\x33\x72\x35\x50\x15\x0d\xe0\x36\x1b\x7a\x37\x6f\x37\xb4\x5d\x43\x7f\x71\xcb\x71\x1f\x28\x47\xde\x67\x1a\xd1\x05\x95\x16\xa1\xd4\x57\x55\x22\x4a\x15\xd3\x7b\x4a\xea\xda\x3f\x58\xc6\x9a\x13\x6d\xae\xf0\x63\x6f\xe3\x8e\x37\x52\x06\x4a\xfe\x59\x84\x33\xe8\x00\x89\xfd\xa2\x4b\x14\x4a\x46\x27\x34\xbe\xf8\xf7\x76\x38\x84\x5b\x00\xe5\x9c\xe7\xfa\x4f\x1d\xaf\x48\x7a\x2c\xad\xa1\x1e\xab\xa7\x2b\xb2\x3e\x1d\xf6\xb6\x6a\x18\x3e\xdd\x22\x6c\x44\x02\x72\xdd\x9b\x06\xbe\xc0\xe5\x7f\x1a\x08\x22\xd2\xe0\x02\x12\x06\x4b\x6d\xba\x64\x56\x20\x85\xf5\xa7\x59\x29\xaf\xa5\xfe\x50\x9e\x0b\x78\xe6\x30\xaa\xf1\x2f\x91\xe4\x98\x0c\x9b\x0d\x6f\x7e\x05\x9a\x2e\xa3\xe2\x34\x79\xd9\x30";
    test(
        HashAlgorithm::SHA384,
        b"\xed\x9a\x64\xd3\x10\x9e\xf8\xa9\x29\x29\x56\xb9\x46\x87\x3c\xa4\xbd\x88\x7c\xe6\x24\xb8\x1b\xe8\x1b\x82\xc6\x9c\x67\xaa\xdd\xf5\x65\x5f\x70\xfe\x47\x68\x11\x4d\xb2\x83\x4c\x71\x78\x7f\x85\x8e\x51\x65\xda\x1a\x7f\xa9\x61\xd8\x55\xad\x7e\x5b\xc4\xb7\xbe\x31\xb9\x7d\xbe\x77\x07\x98\xef\x79\x66\x15\x2b\x14\xb8\x6a\xe3\x56\x25\xa2\x8a\xee\x56\x63\xb9\xef\x30\x67\xcb\xdf\xba\xbd\x87\x19\x7e\x5c\x84\x2d\x30\x92\xeb\x88\xdc\xa5\x7c\x6c\x8a\xd4\xc0\x0a\x19\xdd\xf2\xe1\x96\x7b\x59\xbd\x06\xcc\xae\xf9\x33\xbc\x28\xe7",
        p,
        q,
        g,
        b"\x1f\x0a\x5c\x75\xe7\x98\x5d\x6e\x70\xe4\xfb\xfd\xa5\x1a\x10\xb9\x25\xf6\xac\xcb\x60\x0d\x7c\x65\x10\xdb\x90\xec\x36\x7b\x93\xbb\x06\x9b\xd2\x86\xe8\xf9\x79\xb2\x2e\xf0\x70\x2f\x71\x7a\x87\x55\xc1\x83\x09\xc8\x7d\xae\x3f\xe8\x2c\xc3\xdc\x8f\x4b\x7a\xa3\xd5\xf3\x87\x6f\x4d\x4b\x3e\xb6\x8b\xfe\x91\x0c\x43\x07\x6d\x6c\xd0\xd3\x9f\xc8\x8d\xde\x78\xf0\x94\x80\xdb\x55\x23\x4e\x6c\x8c\xa5\x9f\xe2\x70\x0e\xfe\xc0\x4f\xee\xe6\xb4\xe8\xee\x24\x13\x72\x18\x58\xbe\x71\x90\xdb\xe9\x05\xf4\x56\xed\xca\xb5\x5b\x2d\xc2\x91\x6d\xc1\xe8\x73\x19\x88\xd9\xef\x8b\x61\x9a\xbc\xf8\x95\x5a\xa9\x60\xef\x02\xb3\xf0\x2a\x8d\xc6\x49\x36\x92\x22\xaf\x50\xf1\x33\x8e\xd2\x8d\x66\x7f\x3f\x10\xca\xe2\xa3\xc2\x8a\x3c\x1d\x08\xdf\x63\x9c\x81\xad\xa1\x3c\x8f\xd1\x98\xc6\xda\xe3\xd6\x2a\x3f\xe9\xf0\x4c\x98\x5c\x65\xf6\x10\xc0\x6c\xb8\xfa\xea\x68\xed\xb8\x0d\xe6\xcf\x07\xa8\xe8\x9c\x00\x21\x81\x85\xa9\x52\xb2\x35\x72\xe3\x4d\xf0\x7c\xe5\xb4\x26\x1e\x5d\xe4\x27\xeb\x50\x3e\xe1\xba\xf5\x99\x2d\xb6\xd4\x38\xb4\x74\x34\xc4\x0c\x22\x65\x7b\xc1\x63\xe7\x95\x3f\xa3\x3e\xff\x39\xdc\x27\x34\x60\x70\x39\xaa\xdd\x6a\xc2\x7e\x43\x67\x13\x10\x41\xf8\x45\xff\xa1\xa1\x3f\x55\x6b\xfb\xa2\x30\x7a\x5c\x78\xf2\xcc\xf1\x12\x98\xc7\x62\xe0\x88\x71\x96\x8e\x48\xdc\x3d\x15\x69\xd0\x99\x65\xcd\x09\xda\x43\xcf\x03\x09\xa1\x6a\xf1\xe2\x0f\xee\x7d\xa3\xdc\x21\xb3\x64\xc4\x61\x5c\xd5\x12\x3f\xa5\xf9\xb2\x3c\xfc\x4f\xfd\x9c\xfd\xce\xa6\x70\x62\x38\x40\xb0\x62\xd4\x64\x8d\x2e\xba\x78\x6a\xd3\xf7\xae\x33\x7a\x42\x84\x32\x4a\xce\x23\x6f\x9f\x71\x74\xfb\xf4\x42\xb9\x90\x43\x00\x2f",
        b"\x76\x95\x69\x8a\x14\x75\x5d\xb4\x20\x6e\x85\x0b\x4f\x5f\x19\xc5\x40\xb0\x7d\x07\xe0\x8a\xac\x59\x1e\x20\x08\x16\x46\xe6\xee\xdc",
        b"\x3d\xae\x01\x15\x4e\xcf\xf7\xb1\x90\x07\xa9\x53\xf1\x85\xf0\x66\x3e\xf7\xf2\x53\x7f\x0b\x15\xe0\x4f\xb3\x43\xc9\x61\xf3\x6d\xe2",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x4b\xfd\x28\xa0\xa7\x9c\x94\xdb\xd6\x67\xc2\x75\xef\x77\xa2\x35\xd8\xea\xd7\xc6\x98\xd4\x2f\xb7\xf7\xc1\xfd\x3c\x8c\x2d\xc4\x8d\x0d\xda\x24\x08\xde\xa5\x63\x25\xd6\x92\x83\x69\x2a\x52\x3d\x28\x1f\xfe\xa8\x56\xff\xd9\xf8\x41\x7e\xaf\xbe\xa6\x06\xd8\x62\xdc\x58\x97\xbd\xf2\x41\xf3\xe8\xe4\x9a\xde\xd5\xea\xdc\x72\x95\xe5\xaf\xbf\x96\xb3\x97\x5d\x0e\x25\xda\xa2\x43\x36\x12\xe1\x20\xf6\x59\x03\x6b\x80\x7c\x18\x53\xc0\x3c\x90\xfa\xde\x2c\x19\xdc\xd9\x23\x49\x2e\xcc\x90\x6c\xaf\xc5\x7a\x95\xda\x6f\x20\xdd\x59\xd6",
        p,
        q,
        g,
        b"\x6c\x77\x8b\xcb\x14\x65\x82\x27\x76\x33\x93\x1b\xfd\x02\x9e\x69\xc9\xe8\xc0\xae\x9e\x24\x91\x3f\xa7\x34\x55\x4f\x24\xf6\x4a\xa6\x4f\xd9\xbc\x60\x8e\xf6\x77\xa1\xd4\x82\x9a\xa8\xa8\x56\x4c\x2f\xf0\xff\xa2\xfa\x6a\x0c\x1a\x2c\xcb\x60\x6d\xda\x01\x8b\xf0\x95\xf8\xc8\x97\xd7\xa4\x33\x49\xbe\xb9\x80\x7b\x7b\x11\x8f\x8d\xe8\x85\x6b\x16\x4b\x8d\x8b\xab\xdc\x17\xb4\x8f\x3a\x2b\x97\x2c\xe5\x37\xab\x4e\x7a\x7d\x9b\xa5\xd7\xe6\xfa\x36\x98\xac\xa9\x19\x73\xcd\x17\x87\xef\x7b\x6b\x4d\x04\x10\xde\x59\xcd\x31\x43\xe0\xf3\xac\xfd\xaa\xbe\x56\xb3\x71\xb4\x35\x4d\x0d\x32\xdb\xd1\xb5\xca\x6a\x87\x20\x54\xf3\xe6\x56\x63\x19\xd5\xd5\x0b\x2c\xf5\x4c\x12\x3f\xfc\x92\x90\x07\xad\x18\x57\xba\x13\xb7\xc4\x03\xf5\x51\xc2\xfa\x41\x09\xc4\x4e\x19\xef\x97\xaf\xb6\x2a\x61\x03\x35\x6f\xcc\x2e\xf4\x51\xe7\x36\x26\x10\x10\xb0\xef\x58\xae\x07\xa0\xc8\x01\xff\x75\xeb\xaf\x6c\xdd\x76\x3f\x8d\xf2\xf8\x3f\x0e\xbb\xda\x40\x84\x5b\x2f\x42\xd3\xfe\xea\xc0\x71\xfc\x62\x6e\xe5\xb5\x1f\x9b\xc1\xa1\x30\x51\x4f\x22\x04\x97\x1b\x4b\x72\x61\xb4\xbd\x78\x3f\xf7\x57\x75\xaa\x73\xa6\x3d\x7e\xbe\x99\x0b\x93\x9b\x0f\x44\xa9\x09\xec\x39\x00\x36\xf2\x97\xc3\x56\x3f\x64\xd1\x42\xc1\x4e\xa4\x3c\x5d\x3c\x6d\xef\x4a\x3a\x9c\xcf\x62\x74\x18\x2b\x93\x9b\x88\x65\x01\xae\xb4\xef\xb2\x3d\x00\x73\x43\x4c\xec\x6a\x91\x5a\x67\xe2\x4c\xbb\x23\x54\xc9\xbb\x10\x89\xaf\x48\x7e\xab\x5d\x8e\x49\x9a\x63\x2e\x6c\x61\x49\x2e\xa1\x5d\x2c\x44\x4c\x26\x9d\xe3\x32\x71\xa9\x00\x42\x46\x8d\xe2\x76\x7f\x0d\xcf\x7a\x66\x42\x4a\x3a\x40\xa6\x3e\xeb\xd1\x9c\xb8\x9c\x8d\x74\xc5\x85\x04\xc4\xe1\x03",
        b"\x37\xc3\xf7\x55\x6d\x6e\x5a\xcf\x79\x89\xf0\xba\xa7\x70\xc2\x45\x0d\xee\xbd\x4d\x5f\x58\xb6\x1e\x17\xb4\xb2\xb9\x26\xb5\x80\x31",
        b"\xa6\x1d\x86\x36\x5f\x10\xca\x5e\x1e\xe2\xc4\xbf\x27\x6f\x23\x74\xe8\x8b\x5a\x2d\x1a\xcd\x8e\xcc\x11\xe9\x77\x85\xb4\xfd\x99\x31",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xe3\xfc\x75\x1b\x69\x78\xfc\xf4\x0f\x09\x60\x6e\xe4\x26\x3e\x16\x60\xff\x20\xe9\xc6\x3a\x71\x38\xf0\x78\xae\x3e\x3e\x60\x3d\xfc\xad\x17\x2f\x3c\x7c\xb3\xf3\x54\x5f\xc2\x3b\xc3\x0c\x37\xc8\x43\x9c\x7b\x23\x83\x41\xf2\x91\x48\x27\x6e\xa2\x12\x2e\xa8\xed\x0f\xea\xcb\x14\x9d\xe1\x7c\xfd\x33\xb8\xc9\x40\x8a\xee\x8a\xb0\xea\x8b\xa4\xa2\xb2\xea\x23\x74\x18\xbc\x31\x65\x36\x9c\x8c\xd4\x20\x24\x2f\x8d\x32\xbc\xab\xe0\xc3\x52\xe2\x1f\x65\xde\x80\xd5\x87\xba\x27\x13\xce\xa6\xe5\x3c\xa5\x24\xae\xc3\x65\xbd\xf2\x1a\xdc",
        p,
        q,
        g,
        b"\x13\x49\xbb\xf1\x6d\x37\x5c\x39\x2a\x9a\xcd\x5b\xdc\xe6\x55\xf1\x4d\x61\x62\x74\x38\x8a\x45\xcd\x37\x29\x25\xc5\x07\xac\x12\x9f\xe6\x1b\x99\x8e\x25\x12\x7f\x21\x09\x26\xad\x11\x91\x58\x3e\xee\x8c\x41\x90\x02\x6b\xa0\xa9\x58\x94\xbe\x3f\x0a\xd5\xd0\x58\x86\xc5\x9a\x3c\x7a\x00\x44\xf7\xe2\xbd\x9b\xbe\x28\xbf\x93\x66\xd0\x34\xdb\x42\x4f\x34\x96\x0e\x30\xa8\xe7\x88\x8f\x92\x7d\x0b\xf9\x84\xb0\xff\x99\xea\x27\x18\x71\x12\x4a\xa1\x2e\x0c\x0e\x19\x62\x4e\x53\x3c\xb4\x14\x9c\xed\xb3\xe1\x1d\x32\x16\x00\xdc\x07\xb3\x2e\x53\x1a\x61\x5c\x8f\x7f\xd7\xf3\x3a\x07\x1c\xaa\xa7\x64\x33\xd1\xaa\xb0\xb7\x10\xfa\x7b\xa3\xdd\xb0\x17\x5c\xed\x4e\x55\x8d\x51\x17\xaf\xc7\x54\x2b\x9b\x07\xa8\xfe\x8e\x4b\x08\xa1\xde\x45\x64\x43\x55\x3f\xe8\x7a\x4c\x24\x55\xde\xd7\x2f\x98\x54\x4d\x6c\x41\xd6\xef\x66\xb7\x14\x2a\x4a\xa9\xaa\x1d\x3d\x20\xf7\x00\x01\x03\x89\xe4\x17\x84\x07\x82\xfa\xd6\x82\x15\x3d\x56\x9f\x94\x4d\x3d\x3a\xd1\xd8\x8d\xb5\xbf\xba\x34\x99\xe4\xc3\x66\x0b\x76\xb4\x4d\xa4\xb0\xe6\x72\x7e\xbc\x3f\x22\xb2\xa0\xaa\xf6\x2d\xc2\xa2\x9d\xb8\xba\xbc\xac\xc2\x16\x9c\x2b\x86\x74\x05\x4c\x89\xfd\x77\x0d\xb9\x8b\x12\xaf\x2d\x93\x3b\xec\xbe\xca\x9f\x22\x44\x4b\x52\x7a\xa8\x94\xb3\x76\x52\x92\xdc\xff\xaf\x34\x08\xe6\x99\x49\x5d\xf7\x9b\x98\xd9\x57\xfd\xba\x7e\x4c\x8e\x7a\xce\x3f\x98\x7a\x95\xdc\xb2\xe7\x77\xfa\x2d\x13\x04\x47\x9a\x6d\x13\x7e\xfc\xb0\xc4\x04\xe6\xd8\xed\x39\xd6\xaf\xba\x25\x49\xf3\xee\x2b\x9a\x45\xf3\x24\x56\x7c\x02\x27\x31\x9d\xc5\x9b\xca\xdf\xcf\xdf\x15\x66\xf3\x56\xf7\xc2\xba\x6d\xb2\x1c\xca\x2a\x8f\xb2\xfb\xea\xf3\x1c\xb7",
        b"\x2d\x3f\x3c\x60\x5e\xca\x8f\xec\x37\xa7\x6d\x60\x6d\x20\xfd\xe8\x9c\xb6\xf9\x71\xa4\x47\x96\x09\x5a\x01\xdc\xf8\xe9\x00\xf5\xb2",
        b"\x6a\x43\x16\x83\x34\xe5\xb0\xea\x07\xcf\xa5\x97\x86\x09\xe8\x6f\x96\x9d\x10\x05\x52\x8e\xbb\x3e\xe9\x07\x3d\x56\x55\xd5\x4b\x44",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x45\xf6\x56\xa1\xef\x0e\x61\xde\x46\xdf\x2c\xa2\xd8\xea\x26\x64\x0a\x99\x4c\x30\x38\x0c\x0c\xfd\x66\xbe\x39\x98\xd8\x98\x49\x16\x1b\xbc\xf3\xbe\xe7\x7a\xd3\x0e\x76\x9f\x10\xe2\x3a\xad\x5b\x4d\xf4\xed\xc1\x9a\x86\xfb\xb5\xab\xde\xec\x87\x79\xb7\x6b\xe2\x79\x53\x2d\x76\x92\xbc\x58\x6c\x62\x69\x2f\xa1\xe3\xdb\xcc\xe3\x3f\xfd\xdc\x9f\x97\x58\x91\x72\xf6\x4a\x48\x53\x56\x93\xde\xd6\xbc\x73\xb2\xca\x32\x46\x9d\x0e\xaf\x67\x06\xd2\xa5\xf5\x8f\x8d\x28\xa7\x45\xdc\x32\x8b\xcc\x75\xb3\x41\x5c\xa9\x3e\x29\xea\xbb\x1e",
        p,
        q,
        g,
        b"\x31\xa9\x89\x60\x1f\x32\xb2\x05\x94\x3a\x84\x18\x87\xdf\x3c\x68\x14\xcf\xb2\x25\x8e\x52\x04\xd0\x4d\x39\x28\xdd\xfa\xba\x0d\xff\xad\x43\x15\x1e\x27\xd6\x66\xd2\x92\x8b\xed\xc6\x72\x75\x44\x0f\xb5\x02\xed\x3e\xaf\xc3\xad\xc1\x10\x09\xee\x70\x3f\x01\xea\xa0\x34\xaa\x72\x4f\xcc\x63\xc5\x9a\x8a\x59\x63\xf3\x35\x2f\x72\x93\xea\x24\x25\xea\x89\xbb\xf1\xe4\x17\x24\xb6\x9f\x38\x3b\xf1\x0a\x97\x31\x46\xed\x02\xf5\x52\x08\xb0\x48\x33\xd1\xbb\x53\x99\xa6\x7f\x04\x08\x15\x90\xac\xfc\xfb\xb1\x21\x05\x42\x3e\x26\x09\x1d\x09\x07\x8c\x45\x00\x7d\x43\x6e\xb1\x9f\x95\x2f\x87\x98\xb0\x01\xa3\xc6\x4a\x3b\xaa\x54\x96\xc9\xdb\xe6\x58\x07\x81\xd4\x02\x0b\xb7\xe4\xe7\xae\x23\x80\xce\x79\x65\x8c\x10\xa2\xe5\x7b\xbb\x8c\xac\x12\x08\x77\x28\xce\x43\xba\x2b\x9f\x38\x0e\x3a\xbc\x2d\xd1\x2a\x68\x24\x88\xc6\xb4\xfb\x2f\x8d\xd7\xf3\x84\x6b\x6a\x26\xf9\x13\xac\x15\x68\x79\xee\x6a\x1a\xe0\xad\xa9\x56\x85\x21\xa4\x42\x8e\xd9\xf7\x41\xe0\xe7\x9a\x84\x28\x80\x01\x9c\x01\xb3\x4e\x98\x8a\x7c\xf7\xe6\x35\x24\xe8\xcd\x02\x54\x53\x22\x3a\x26\x60\x27\x3e\x49\x19\x68\xaf\x7f\x4b\x1d\xc2\x12\x39\x61\xde\x37\x53\xab\x16\xec\xa5\xb1\x85\x9a\x4f\x71\x17\x25\x38\xf0\x5a\x2a\x82\xa3\x4f\x98\xba\x07\xc1\xe5\x31\xd8\x2e\xf5\x92\xe5\x49\x35\x33\x41\x6b\xd6\xc6\xa4\xc7\xca\x3b\x0d\x2a\x2f\xff\x88\xa8\xf0\x73\xa7\x6c\x69\x18\x02\xaa\xae\xce\x4e\x85\x2d\x66\x50\x87\x1a\x17\xcc\xa0\xf5\x25\x1e\xf2\x2d\xfc\x8e\x3b\x26\x1b\xfc\xbd\x5a\x22\xb2\x73\x2a\xa1\x7d\x7d\xf1\xf7\xb8\x2f\x6b\x22\x2e\x5f\x60\x65\xbf\x80\xd0\x4c\x2e\x57\x74\x09\x40\x84\xe4\xd5\xce\x0d\x3e\x89\x17",
        b"\x3c\xed\x0e\xa5\xf7\xfd\x58\x86\x68\xa4\x1e\xfe\x0e\x90\x95\x4c\x09\x30\xaf\xb6\xbe\x18\xd9\x07\x52\x83\x1f\x68\x3c\xd9\x2a\x9c",
        b"\x9e\x46\xca\x12\x94\x17\x45\xea\x1a\x12\xc5\xa2\xd6\x09\x88\x4c\xb5\x79\x2f\x46\xaf\xaa\xcf\xf0\x72\x37\x13\x74\x00\x36\x68\x68",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xc7\x37\xd5\xae\x24\x8a\x96\x06\x2d\x6a\xfa\x8d\xca\xcc\x03\x84\xc5\xfb\xfb\x9d\x8b\x60\x52\xb5\x24\x93\xc6\x0d\x3e\xdf\xc5\x24\xb5\x67\xb1\xf8\x96\xe7\x44\x7d\x0e\x24\x01\x94\x03\xed\x83\xe4\x88\x9c\x0c\x4d\xe5\x7c\x70\xfa\xda\x6c\x8b\x5a\x09\x90\x43\x50\xa4\x4d\xfa\xf7\x7d\x60\xaf\x62\xde\x3e\xdf\xd8\x76\x0d\x07\x74\x73\xf2\x6d\xf2\x83\x7c\xfc\x20\x15\xf2\x27\xdd\x7d\x35\x1a\x53\x50\xf1\x42\x8f\x26\x99\xfd\x3f\x51\x83\x26\xfe\xa8\xae\xf9\x8f\xc4\xea\x67\x31\x30\xc8\x07\x9f\xac\x38\x95\xfe\x85\x6c\x77\xf8",
        p,
        q,
        g,
        b"\x61\x12\xd3\xcd\x31\x91\xd1\x7d\xee\x77\x88\xf5\x68\x81\x5a\x0a\xab\x50\x00\x60\x02\xc9\xde\x2b\xd1\xa9\xbb\xa2\x45\xba\x02\x89\x4b\x02\xe9\x24\x75\x17\xac\xe6\x98\xae\x0a\x05\x17\x6b\x62\xb3\xa0\x25\xa5\x63\xdd\xa8\xde\xb7\xf2\xfc\x3e\x17\x7a\xe3\x47\x74\x48\xd3\x9a\xe4\xeb\xe7\xae\x8e\xc6\x5a\x44\x21\xf7\x54\x66\x7f\xd6\xd7\xc2\xeb\x93\xf1\xa1\x8d\x3d\x1a\x62\x35\x73\x6b\xcd\xb7\x47\x46\xf4\x6d\x88\xe6\x5d\xc0\x7c\x25\x91\xe1\xf9\x5d\xda\x5e\x5e\x20\xe1\x05\xee\x8b\x4d\xdc\xaa\xf3\x60\x21\x29\x0d\x6b\x64\x93\x67\x1d\x8a\xaf\xae\x14\x5d\x9b\x90\xbe\xc3\xcc\x60\x17\x9b\xb8\xfc\x30\xf1\x43\xc5\x75\xd5\xd8\x61\x62\x37\x21\xb6\x54\x7d\x3a\xaa\xad\xe4\x55\xf0\x5f\xef\x93\x18\xab\xcd\x29\xbd\x19\xb1\x2c\x35\xca\x75\x6d\xe5\x10\x8c\x18\x5e\xce\x4a\xa1\xbf\x1a\x8e\x38\x80\x97\x97\x06\x7b\xd1\xf5\x2b\x6c\xf2\xc4\x15\xe7\x3f\x92\x46\xbd\x5b\xfa\xdd\x7b\x9a\x9d\x2b\x53\x69\x70\x1e\x72\x14\x7e\x22\xda\x7e\x09\x2d\x9b\x57\x8f\xb0\xc0\x44\xa3\x6e\xff\xcb\xd7\x09\x25\x85\x00\xa0\x0c\xff\x23\x09\x62\xc4\x42\x25\x71\x2f\xc4\x3f\x9e\x80\x2b\xae\xad\x7f\x9c\xb4\x6a\xb4\x93\x1f\x66\x3c\x6e\x3e\xd4\x08\x2d\x59\x61\x0f\x01\x74\x1b\x5f\x24\x56\x6b\x01\xb3\xe3\x93\x3b\x29\xe0\x28\xc5\x4b\xd2\xfc\x75\xb5\x49\xfd\x05\xe6\x4c\x58\xc9\xae\x0b\xa4\x17\xa9\xe9\x85\x81\xdb\x77\xbe\x75\x23\x3a\x42\xf7\x71\xc9\x9f\x0a\x49\xb4\x94\xf0\x95\x52\x02\xb1\x9d\x6c\x74\x0e\x86\x60\x66\x10\x4e\x46\x3e\x65\xe4\xba\xd9\xa0\x81\x63\x6d\x05\x36\x74\x26\x15\x3f\x04\xbc\xb2\x71\x21\x86\xdc\xa6\x83\x43\x88\xe8\x25\x20\xd3\x4e\xfd\x8a\x89\x31\x3b\x2c\x7e\x60",
        b"\x00\x41\xb1\xc7\x56\xdd\x2e\x42\x71\x4f\x9e\xe7\xed\xce\x21\xea\x33\xef\x49\xdb\xf4\x52\xcc\xd9\x35\x7d\x5f\x45\xff\xab\x08\xf9",
        b"\x10\x2c\x6e\xaa\xd3\x8d\x39\xc0\xd0\x36\x33\x5a\xe1\x9d\xd0\xd7\x5e\x8d\xca\xba\xe5\x9b\x12\x0f\x69\xcb\xd2\xb5\xcf\x48\xab\xdb",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xa6\xfc\x89\xa2\x23\x02\x2e\xe9\xe5\x08\x72\x52\x78\x58\x2f\x56\xdb\x9c\xd2\x4c\x0d\x75\xd0\x72\xa5\x28\xd0\xc6\x0f\x27\x17\x1e\xa3\x76\xe2\xdc\x28\xa9\xdc\x0b\x12\xe6\x68\xaf\x77\xdc\xbb\x38\x17\x37\xe1\xba\x7d\x9e\x80\xb9\xbe\xc8\x0b\xf9\x06\x1b\x8f\xa1\x0e\x43\xa7\x40\x3a\x29\x16\x24\xa6\x00\xdd\x4f\x5c\x2b\x50\xc5\x2d\x5c\x61\x55\xd5\x2b\xe5\xa3\x25\xf6\xad\x81\x3f\xb3\xec\xaf\x6d\x1f\x92\xe9\x8c\xc8\x7c\x26\xc6\x8c\xbd\x15\xd5\x48\xa3\x78\x2b\xff\xdd\x11\x16\xc7\xc1\x1f\xca\xbd\xe4\x02\x5f\xec\x51\x54",
        p,
        q,
        g,
        b"\x6c\x1d\x4d\x6b\x52\xaa\x4b\xff\x35\xf4\x30\x23\x30\x05\x27\x77\xf5\x1f\x6a\x08\x49\x16\x1f\x90\x6e\xf2\x17\xb0\x4b\x18\x54\x5c\xe5\x2a\xe4\xae\x42\x3a\xd1\xb4\xf8\xb1\x73\x5a\xe0\x0a\xb0\xc0\x44\xa5\x6f\x94\x5d\xa8\x4d\x1c\xdc\x26\xe0\x82\xd7\xac\xd7\x72\xdf\xab\xcd\x18\xb5\xe1\x3c\x05\xc2\x79\x1a\x8d\xc1\x61\x46\xe1\x51\x32\x3e\x4e\xf2\xce\x5d\x64\x38\x9f\x69\xd9\x34\x7a\xa2\xa5\xbd\x01\x14\xde\x0e\xec\xdf\x99\x0a\x44\x0d\x1b\xf9\x89\x0d\xd9\x5f\xd6\x40\xd2\xfb\x17\x89\xca\x6a\x6d\xbe\xe1\x83\x6a\xd7\xcb\x47\x37\x0b\x74\x56\xe4\x9f\x3b\xac\x03\x31\x0f\x8c\xbe\x61\xdd\x1c\xc0\x6d\x78\xc7\x6f\xec\x63\x97\xe6\x08\xa4\xca\xc4\xe2\xc3\x89\x83\xce\x5a\xa9\xdc\xba\x07\x4a\x20\x6f\xa6\x08\xdb\x35\xf2\xad\x3d\x63\xd9\x5b\x2c\xb7\xa0\x1c\x33\xd4\x98\x76\x7e\x8e\x68\x57\x8e\x4e\x99\x53\x8b\xf3\xd7\x03\xe6\x38\x63\xa2\x50\x91\x45\x2e\x73\xb9\x6a\x37\x16\xe9\xcc\x10\x9b\x66\x00\x8f\xa5\xca\xfd\xbf\x96\xb7\xfc\x10\xc3\xbb\x89\xd7\x9d\x45\xff\xef\xc0\x19\x08\xd2\x47\xef\x1d\x4f\xcb\x90\x3b\xf5\xe7\x91\x7a\xf8\x86\x18\xa5\x2a\x12\x00\x47\x98\x89\x05\x40\xa5\xa7\x5c\x65\xfb\xc0\x57\xd8\x60\xf4\xb6\x5d\x8b\x08\xb8\xd2\x15\xf0\x56\xd8\xe5\xe3\x8b\xf0\xb3\x19\xe2\x94\xdb\x24\x2a\x4f\xc7\x9b\x2e\x10\x6f\xec\xa2\x55\x6d\x14\x6f\x52\x03\xfd\x72\xad\xc7\x3a\x48\xe3\xa5\xaa\xdb\xb2\x93\xa2\xef\x58\x62\x65\x4c\x31\x53\x9a\xd8\x56\xa1\x6e\x57\x16\xc4\x37\xb4\x74\xf3\x33\x9c\xd8\x4f\x0a\xc9\x2b\xc2\xca\x6f\xac\x10\xc7\x51\xd0\x99\xa9\x04\x08\xde\xf6\x10\x6c\xa8\x38\x93\xd8\x7e\x32\x81\x8d\x76\x34\x53\x7a\x4e\xf6\x67\xce\x7f\x26\xa5\xcb",
        b"\x48\xbd\x01\x0c\x1a\xf7\x7b\x3c\x40\xdb\x50\x34\x97\x06\xd6\x4d\x16\xcb\xb7\x2d\xb5\x19\x43\xd3\x45\x15\x1d\xea\xcd\x4a\x41\x33",
        b"\x0f\x1c\x4b\xdb\x47\x58\xab\x3b\x55\x18\xd4\x60\x5b\x98\x64\x80\x57\x23\xd3\x3a\x36\x11\x6e\xa6\x50\x54\x6f\xee\xf1\x1c\x4a\x5e",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x2a\xe4\xac\x7c\xe2\x9a\xe7\xd3\x24\x90\xd3\xa5\x4b\x71\x5d\xb3\xf4\x73\x06\xf8\x4b\x59\xb3\x3b\x21\x62\x2a\x18\xaa\x2c\x06\x0a\x44\x34\xad\xfa\x01\xff\x16\x86\xb5\xd1\xdd\x30\x35\x30\x8e\x92\xf7\xac\xc7\x6d\xea\x96\x9d\xee\xfb\x98\xc2\x97\x2b\x42\xa5\x96\xe1\x05\x5a\x5a\xa2\xc6\x61\xf0\xb7\x34\xba\x4f\x0b\x34\x1c\x77\x82\x7d\x88\x91\x5a\x5e\x89\xf9\x5a\x98\xd6\x3d\x77\x29\x87\x4f\xce\x4f\xf7\x5d\x7a\xdd\x74\xf4\x31\x3d\xff\x78\x4e\x41\x7b\x2e\xe1\xfc\xd2\x70\xc0\x38\xdb\xbb\xb9\x6a\x77\x68\x48\x4b\x88\x54",
        p,
        q,
        g,
        b"\x0a\x84\x29\x8f\x47\x68\xe9\xd7\xbf\x79\x6d\x06\x58\x5e\x8b\x75\xfb\xde\x65\x83\x98\xa2\x24\xa8\xac\x3a\x49\xfb\x91\x23\x5e\xaa\xa1\x83\xaa\x88\x27\xcc\x2a\xf7\x9e\xa3\x34\xdc\x8b\xe4\xcc\x72\x90\x29\xab\x5f\x81\x61\xf7\x18\xf7\xbf\xbe\x90\xad\x2a\x15\x98\x88\x52\x39\x82\xb6\xd4\x93\x2d\x81\x59\x49\x5b\xa8\x4d\x0a\xb3\x5d\x7e\x39\x5d\x14\xdb\xa9\x06\xa1\x67\x9a\xe3\xcb\xb7\x2c\x10\xed\x6f\xa1\x4d\xa4\xd6\x00\x77\xb0\xbf\xb5\x91\xa3\xde\xc6\x43\x99\x6c\x39\x63\x38\xa5\x1d\x44\x6b\xde\x62\x24\xae\xa1\x6a\xef\x41\xf3\x54\xe0\x9a\x9d\xce\x9f\x3a\x00\xcb\x44\x5a\x5c\x9c\xae\x4a\x6c\x3c\x19\x19\xc9\xe0\xc5\x30\x82\x17\x3d\x0e\xc0\x0a\xe5\xe1\x5a\xa7\x26\x07\x50\xb6\xa0\x3e\xf0\x5a\x51\x8a\x48\x61\x53\x40\xac\x20\x98\x40\x73\xce\xa5\xfc\x99\x0d\x48\x98\x58\x94\x9a\xaf\x6e\x9e\x34\x7b\x48\x02\xaf\xbe\x25\xa0\x66\x94\x72\xbd\x93\x16\xba\x2c\x23\xa6\x1c\xc3\xaa\xdf\x1b\x70\xd9\xfd\x97\x61\xbb\x03\x5f\x0c\xa5\x1e\xdb\x2b\x12\xfc\xfd\x65\x1c\xb9\x23\x63\xef\x48\x00\x5a\x26\x83\xfd\x2e\xd8\x66\x5d\x70\x58\x8f\xd9\xa1\xbe\x3a\xa5\x1c\x95\x8b\x81\xf1\x3e\x4a\xcf\xaf\x0d\x2a\x90\xaa\xae\xf2\x1b\x2c\xc9\xef\x2e\xd3\x7b\xce\x3c\x47\xc8\xbc\xbf\xc1\xfb\x9f\x94\xe4\x9b\xd2\xf1\xa3\x0a\x88\xdf\x22\x73\x5a\x0f\xdf\x0a\xc6\x02\x8a\x00\x8b\x06\x2c\x95\x60\xc4\x2a\x47\x69\x97\xdd\x21\x10\x06\x92\xef\x63\x96\xd5\xf3\xfb\x2c\x15\x53\x28\x25\x7e\x7b\x7d\x2b\xc0\x5f\xab\xd5\x4a\x81\xa2\x27\x29\x93\xd3\x42\xbe\xc8\x57\x7c\x64\xd5\x1b\x4c\xdb\xe3\x65\x4d\xae\x56\x8c\x4d\xa0\x18\x61\x8c\x30\x47\xae\xe0\x6b\xf2\x62\x1e\x05\x6b\x33\x5d\x04\x4b",
        b"\x6b\x7e\xd3\xa4\xc2\xa4\xf7\x85\x00\xc7\xe9\x47\xe6\x17\x5c\x5c\xa8\x57\xc9\xd6\x13\xe7\x79\x0b\x9b\xe0\xd1\x4e\xc8\x40\x3e\x5f",
        b"\xa1\x16\xf3\xde\x16\x62\x60\xd1\x10\xe2\x0e\x84\xeb\x8c\x97\xc3\xf0\x18\x17\x86\x08\xa2\xea\x3e\x3e\x2f\x5e\xd9\x1d\x43\xde\x11",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x3e\xad\xe9\xa1\x0f\xb5\x9a\xf3\x6a\x54\x01\x70\x73\x7f\xbc\x53\x6e\x4c\x52\x30\xb8\xf6\xc4\xb2\x16\xed\xdd\x3e\xa9\x23\x42\x12\x3a\x33\x74\xd0\xc7\x51\xb2\x4b\x62\x7f\x9e\xad\x4d\xe2\x6e\x9a\x78\x97\xd9\xbc\x5d\x58\xa6\xa3\xac\x74\xcd\x45\x75\xb3\x28\x6e\xc1\x5f\x84\x53\x22\x4f\x37\x17\x9e\x51\xd9\xc4\xad\x8a\x60\xbf\x37\xd7\x1c\x62\xad\x7f\xc5\x3e\x5c\x7b\x12\xf4\xaa\xa2\xd4\x28\xe5\xc8\x89\xfd\x7f\x06\x2c\x91\x3d\x9b\x57\x4f\x4b\x5d\xb5\x16\xc9\x76\xba\xd5\x88\x30\x2f\x21\x9f\xd8\x3e\x18\xbe\xe8\xe6\x8e",
        p,
        q,
        g,
        b"\x08\xa1\x5b\x23\x84\xdf\xf4\xf3\x03\x3c\x87\x16\x86\x73\xc5\x67\x05\x98\x70\xc8\xe7\x8d\x2f\xdd\xc7\x54\x0a\xfd\xa8\x05\x8d\xf3\x84\xd3\x18\x2a\x42\x61\x54\x32\xff\x93\x77\x7d\x3f\xce\x49\xc1\x17\xc7\xbb\xe8\x21\xe6\x78\x9b\x51\x37\xdd\xf0\x84\x65\x60\x98\xaa\x7b\x05\x16\xfd\x30\xa4\x2c\x8c\x86\xd9\x4e\x6b\x26\x8b\x6e\x13\x01\x1d\x25\xeb\xa0\x18\xca\x40\xcf\x8a\x35\xe1\x96\x31\x35\xd5\xcd\x65\xa5\x7a\xca\x8b\x00\x79\x88\xa5\xea\x75\xad\xb4\xd0\x1c\xc0\xf0\x83\x8a\xb4\x2d\x3d\xf6\x43\xa7\xd2\x56\x1c\xfd\x1f\xde\xbe\x3a\xd8\x6a\xd0\x3d\xe3\x17\x02\x75\x33\xd5\x23\x35\x1b\xe5\x32\xbc\x73\x1a\xaf\x43\xb8\x64\x2a\x7d\xa8\x08\x73\xb8\x0d\xc6\x1b\x7a\x24\x9e\x58\x60\xfd\x1a\x3e\xae\x0f\x8f\x0c\xf2\x1e\x20\x5d\x6f\x40\x3c\xb0\xa1\x03\x29\x0c\x9e\x69\xd3\x8c\xbe\xd9\xe0\x92\xb6\x9f\x71\xf9\x17\x2b\x36\x76\xf2\x9a\x97\x13\x3f\xc3\xe1\x87\x46\xfe\xdc\x65\x3f\xbf\xb6\x2c\x5e\x0a\xfe\x89\xa8\xe1\xb8\x72\x4b\x1a\x33\x14\xc4\xca\xcc\x4b\xb8\xf3\x90\x43\x97\x01\xa6\x14\xae\x9b\xcd\xaf\xd4\x72\xb0\xab\x13\x16\x67\xdb\xbf\x1c\x79\x0f\x73\xab\x90\x46\xa5\x89\x32\x69\x1a\x93\x0b\x3c\x42\xe9\x08\xb4\xd1\xf4\x7e\xd6\xe2\xff\x18\xd6\xb7\x0b\xb1\x6d\x1a\xf7\x99\x3b\xdb\x2c\xa3\xcb\x35\x9a\x0b\x43\xf8\xdc\x84\x4d\xea\x6a\xeb\xaa\x34\xb8\xd2\xb6\xfc\x28\x84\x19\x78\x0f\xf9\x80\x90\x89\x26\xc4\x6c\x3b\x0e\x59\x5f\xa3\x08\xf4\xe8\x94\xec\xb6\x83\xc8\x04\xc9\x31\x40\xd9\x17\x69\x13\x2d\x37\xe9\x37\x91\xb9\xf8\x9d\x59\x5e\x69\x8f\x04\x9b\x3a\x95\x02\xab\xc4\x88\xbd\xd9\x47\x2f\x11\x31\xa7\x57\xf3\xd5\x4b\x14\x90\x67\x50\x7d\x1b\x04\xa9\x76",
        b"\x9e\x83\x3e\xc3\xde\xd9\xd8\x1e\xa7\x42\x2b\xda\xc7\x84\x22\x27\x4f\xa3\x53\x48\xe3\xfc\xe3\xbb\xc9\x3b\x3c\x10\xd7\x0b\x4f\x1e",
        b"\x65\x37\x56\x59\x4e\xac\x68\x1d\x48\xa2\x35\x8a\x0f\x82\xa1\x0f\xaa\x79\x29\xb0\x0f\xd9\xcd\x43\x94\xc3\x26\x79\x06\x0f\x96\xe3",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x33\xde\xcf\xc1\xe0\x6b\x92\xed\x81\xcd\x30\xee\x37\x71\x47\x0b\x59\xe2\x2c\x15\x64\x64\x7f\x1a\xae\x85\x10\x72\x97\x15\xa8\xce\x94\x62\x4a\x11\x55\x4a\xc9\x09\xc9\x24\xae\xc8\x53\xdf\x64\x32\x75\x46\xdb\x85\xd3\xdf\x59\x79\x16\xa3\x93\x53\x38\x8a\x8b\x33\x63\x76\x52\x81\xa4\x35\x27\x01\xff\x1a\xf4\x3f\xba\x6d\x03\x66\x41\x27\xc1\x5d\xa7\xb8\x4c\x04\xd5\x40\x9c\x36\x40\x94\xdc\x62\xe3\x79\x83\xa8\xeb\x06\x68\x80\xde\x81\x36\x70\x14\x06\xe6\x72\x50\x67\x93\x00\xd2\xb9\x7d\x22\x83\x27\xc1\x51\x4c\x0b\xc1\xea",
        p,
        q,
        g,
        b"\x16\xea\x2e\x79\x5c\x63\x6c\x9d\x31\x21\x59\xa5\x79\xb8\xdf\x32\x9f\xfc\x28\xfe\xcc\x4a\x4c\x13\xb1\x6a\x29\x0b\xd1\x52\x5a\x53\xa9\x7d\x72\x31\x5b\xe2\x51\xd1\x1d\x23\xca\x78\xbb\xec\x45\xc0\xe2\x43\x27\x9b\x1e\xb6\xe2\x06\xa9\x27\x3c\x1e\x76\x6e\x21\x36\x48\xbd\xf9\x0c\x40\x47\x9d\xf4\x8a\xcf\xd9\xc2\x09\xa5\x23\xc8\xb4\xa9\x9a\x48\x1c\xa8\xdf\x47\x74\xb3\xbb\x29\xf8\x25\x26\x52\x0c\x2d\xc2\x8a\xb3\x14\xfe\x14\x14\x0f\x2b\xe1\x79\x2e\x1a\xc3\xc7\x59\xad\x44\xf7\x84\x5a\x20\x12\xf6\x4e\xca\xb0\xb1\xfe\xc0\xed\x16\x6b\xd1\x75\x95\x57\x04\xf6\x2d\x94\x01\x11\x1f\xfc\x04\xf8\x04\xe4\x8f\xe7\x74\xdf\xd3\x46\xbb\x41\xf4\xbe\xca\x2b\x34\xa8\x31\x34\xa3\x88\x4a\x01\x72\x9c\xce\x1a\xbc\x5b\x8d\x0d\xe3\xfe\x26\x54\xc3\x74\xde\xb2\x46\xd9\x6f\xfa\xff\xc7\xaa\x20\x55\xb7\x4e\x81\x9b\xbe\xec\x13\x7e\xb3\xca\xed\x1f\xc7\x1f\x12\x9c\x8e\xa8\xb7\x63\xf2\xf5\x7e\x88\xde\x08\x45\xf7\x6c\xeb\x18\x41\x55\x90\x19\x87\x2a\x5b\x5a\x96\x9c\x9c\xf3\x85\xd6\x57\x8b\x4f\x27\xb5\xb7\x6b\xe3\xef\x0a\x8f\xd3\xee\x47\xee\xd6\x95\xe1\x6f\x14\xe2\xa3\xb7\x91\xf2\xa0\x16\xd6\xb8\x6f\xf8\xec\x23\x43\xc6\xa5\xc8\x0a\xb6\x22\x4b\x65\x02\xeb\x37\x4c\x8f\xa6\x51\x0b\xce\x99\x0d\x70\xef\xdf\xa9\xa0\xb7\x02\x58\x55\x95\x18\x45\x14\xc7\x8f\x7e\x90\x5b\x6f\xd6\xc2\x37\x33\x3d\x56\x0f\xcc\x06\x30\x36\x37\xac\x0b\x2c\x7f\x7c\x4d\xa5\x59\xe3\x1f\x53\x1d\xf2\xe5\xd6\xc6\x51\x59\x17\x71\xd7\xea\x45\x75\x88\x8a\xfc\x40\x11\xfa\x11\x24\xfb\xd1\xa2\x82\xa4\x1d\x93\x39\x89\xef\xf9\x1a\x51\xcd\x39\xbc\xe7\xfb\x0d\x56\x9f\xed\xcc\x42\xde\x48\xbf\x18\xee\x75\x5f",
        b"\x6f\x77\xa5\x21\x69\xa2\xe8\x80\xa3\xb5\x5a\xa2\x78\xf6\x46\x30\x32\xdc\x5f\x81\xc3\x84\x68\x22\x4d\x55\x32\xf6\xa6\x01\xf2\xd9",
        b"\x96\xb7\x53\xef\xb4\xab\xbc\x8c\x17\x9d\x03\xcc\x2a\x1a\x0c\x12\x56\xe2\x3d\x1f\xa2\xe9\x7c\xfb\xf5\x5d\x2b\xb6\x98\x12\xd1\x00",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x6a\xe5\xa6\xda\x79\x4f\x92\x3f\x6d\x80\x32\x54\x9b\x81\xd0\x4a\xe7\xaa\x35\xc2\x09\x9d\xff\xbd\xd8\x3b\xb9\x4d\xb5\x74\xfa\xf8\xf9\x5c\x71\x26\xdb\x2d\xb6\x0f\xed\x50\xf7\x40\xe8\x7c\x35\x95\x44\xdc\x2e\xbf\xbc\xaf\xb0\x94\xdd\xca\x69\xc9\x14\xd2\x7e\x5f\x3d\x10\xfa\x0c\xe3\x2d\x2a\x13\x55\xbc\xf6\x1a\x25\x74\xc7\x55\xd7\xc3\x24\xa2\xe0\xed\x6f\x77\x19\xba\x2f\x2c\x9f\x11\x3d\xf8\xd0\x40\x25\xf4\xab\xd2\xe1\xc4\xb7\xbc\x18\xd8\xac\xec\x9f\x6d\x8d\x79\x7c\xd7\xb0\x42\xf5\x03\x48\xee\xb3\xf7\xa2\x92\x2d\xa7",
        p,
        q,
        g,
        b"\x93\x10\x6f\xb0\x00\xc6\x7f\x11\x11\xc6\xfd\x3d\xa0\xf4\x4b\x4a\xe4\xcb\x36\x95\xde\x2e\x35\xb2\x41\xdf\xe8\x8d\x32\x69\xb8\xfd\xa2\x5b\xf3\x48\x00\x87\x25\xfd\x61\x3c\xd6\x1a\xa8\x26\xbd\x8f\x1a\xaa\xee\x22\xb4\xdc\x0a\x02\x84\x22\x90\xbb\x7d\xad\x91\xaf\x0b\x28\x54\xff\xab\x16\x93\x22\x08\xd2\x72\xf2\xc0\x81\xc1\x38\x89\xdb\x3e\xd0\xb2\x46\x46\xc6\x65\xaf\x9f\x4b\x72\x38\x98\xeb\x1a\xc0\x05\x3f\x2a\x0f\x4c\xf2\x2f\xd4\xe1\x29\x40\xb5\xb5\x22\x69\x48\x4e\xbb\x8a\xbc\x48\x4c\x06\xed\xdb\xd9\xb1\xa4\x26\x13\x2f\x40\x2e\xfd\xcd\x88\xab\x29\xe7\xe5\x10\x96\x1a\xf8\xec\x83\xa6\x42\xe3\x40\x15\x85\x8a\xc3\xf3\x21\x97\x60\x1a\x88\x8e\x16\xc7\x59\xc9\x4e\xc5\xb8\xde\xc0\xda\x30\x64\x3b\x9d\x9d\xb2\x57\x4a\xf2\x9e\x78\xf9\xd3\xf6\xa7\xb4\xc7\x6f\x45\xcd\x0b\x2a\xb5\xe8\x52\x49\x35\xb8\x86\x91\x8b\x5d\x9e\x9c\xcb\x5a\x68\x53\xe6\x2e\xfa\xd2\xdf\xf8\x3a\x85\x20\x98\x5e\xe8\x44\x2f\x2b\xdd\x1c\x5f\x9d\x48\x06\x2a\xde\x6b\x28\x8c\x8a\xd8\x2a\x41\xdb\x6c\x34\xe2\xde\xba\x54\x1a\xaa\xc3\xcd\x31\x56\xc9\x75\xef\xbb\xc7\x18\xeb\xd4\x96\x19\x96\xb3\xed\x1c\xc5\xc2\x98\x7a\xb7\x79\x05\x2c\xdb\xec\xf5\x1d\x17\x66\x1b\x49\x8e\x84\x37\x1f\xf8\x59\xf8\x99\x06\xf4\x26\xf5\x63\x57\x2f\x66\xc2\x79\xef\x3d\x03\x6a\x42\x77\x78\x46\x3f\x67\xf8\xd4\xde\x62\x3f\xb4\xb2\x80\x30\x07\x87\x1d\x0a\x34\x9e\xc2\x02\xa9\xaa\x1c\xff\xef\x70\x13\x7e\x00\x93\x03\x49\x72\x14\xad\xa7\x86\x35\x7a\x4d\x80\x46\x25\x5e\x40\xf8\x9e\xa5\x88\x00\x06\x34\xe7\xf0\xaa\xf6\x4d\x92\xaa\x21\xff\xf8\xfb\xe0\x78\xba\xa9\x69\x61\x69\x97\x38\xb2\x68\x23\x7e\xab\x60\x6c",
        b"\x86\x36\xd4\xd3\x20\x3a\xa0\x91\x2f\xbf\xc9\x38\xbe\x43\x70\x07\x7e\xa9\xc7\x51\x95\xcd\x2f\x67\xe6\xee\x42\x7c\xde\x53\x1c\x40",
        b"\x93\x02\x3d\x97\xef\xb4\x32\x7e\x9e\x88\x6e\x7b\x78\x37\x41\xe9\xd2\xc3\x97\xaf\x9c\x67\xb9\x1c\xdb\x8a\xa2\x7f\x83\xbb\x02\x5d",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x86\xe0\x3b\xc3\xf4\xdd\xea\x6a\x93\x88\x8e\xe3\x89\xb1\x5e\xb6\x90\x82\x2c\x71\xf9\xb8\x5e\xfa\xaf\xfc\x52\xe4\x86\xb1\x14\x4a\xd7\xfc\xff\x3f\x53\xbf\x97\xda\x24\x81\xe8\x5e\x09\x83\xee\x1d\x52\x79\xe2\x7a\x36\x4d\x0e\x69\x0f\x58\x7a\x31\x53\x5f\xb9\x4e\xec\xe7\x47\xf8\xb6\x05\x72\x4a\xdf\xb2\x58\xc9\x98\x3c\x90\x02\xe0\xc1\x1b\x79\x76\x62\x76\x90\xd5\x82\x81\x30\x5e\xa9\x30\x8d\xb7\x4c\x49\x1a\x28\x19\x2e\x35\x4b\x60\x0e\x83\x76\x81\x1c\xce\xfb\x75\x1b\xb1\x0c\x7d\x97\xb4\x2f\xfe\x30\x4b\xee\x97\xec\xaf",
        p,
        q,
        g,
        b"\x23\xed\x54\x45\x39\x1a\x5b\xb9\x4e\x00\xc7\x6e\xc8\x0d\x83\x72\x8d\x5d\x46\x1b\xe4\x25\xda\x79\xf9\x21\xbc\xa2\x7d\x62\x5c\xb4\x2b\x32\x39\x71\x02\x2a\xd4\xc3\xf0\x5b\xca\x10\x99\x10\xfd\x06\xba\x39\xe9\x5b\xeb\xe7\x94\xed\x10\x8d\x2e\xad\x29\x7a\xd7\x94\xf9\x9c\x32\xc2\x19\xe6\x5f\xb7\x26\x53\x27\x15\xb1\xbc\x20\x75\xdd\x4b\x69\x49\x29\x77\x12\xf9\x1d\x5b\xa0\x61\x19\x6f\xb2\x57\x54\xc3\x43\x77\xbb\xbe\x6a\x37\xf6\x17\x87\xea\x84\x4d\x35\x92\x85\xc7\x8e\x73\x3e\xb6\x5f\x66\x5a\x6b\x15\x7f\x83\x2b\x56\x38\xd7\x4e\xbe\x1d\x5d\xce\x66\xd5\x28\x92\x5e\x44\xee\xf1\x3b\xf2\x3f\x80\x7d\xa3\x5f\x34\xd1\x69\xa6\x87\x75\x82\x29\xb9\x9a\x31\x3a\xce\xcf\xb2\x0b\x14\x2b\x53\x49\x26\xd5\x9a\xaa\x76\x43\xa7\x90\x30\xe9\x33\x5e\xf2\x8a\xbe\xdd\xac\x8a\xc9\x47\x1d\xa4\x99\x7e\x33\xf3\xe4\x91\xdb\x86\x68\xa2\xc3\x92\x0a\x3b\x3a\x37\x22\x51\x79\x36\x1d\x55\x39\xbe\xb3\x3f\x32\x52\x24\x42\x67\x46\x5e\x48\xfa\xf5\x75\xcd\xac\x93\x81\x33\xef\xfe\x9d\x1f\x69\xf1\x9f\x1b\x44\xb2\x45\xa4\x47\xb1\xfc\x2b\x85\x92\x44\xe2\xe3\x90\x53\x59\x5c\xf7\x97\x89\x33\xc3\xd4\x68\xc6\x5c\x23\x16\x63\x07\x0a\xea\xf2\xec\x23\x13\x8d\x16\x60\x08\x1a\x55\xbd\xc3\xdd\x3f\x24\x46\x17\x6b\x1d\x6d\x99\x77\xa1\x4e\xbd\x0e\xd4\xd8\xdf\xcd\xfc\x4a\x43\x31\x18\x40\x1f\x2c\x26\x32\x09\x5c\xe7\xae\x62\x00\xc7\x4b\xda\x5d\x2f\xd3\x85\x45\x24\xc3\x08\x17\x41\x97\x5a\x07\x6a\x1b\x4f\x93\x3e\xc3\x2a\x2b\xac\x91\x71\xbe\xbf\xdf\x3b\x35\x5e\xdd\xb1\xf4\x55\xec\xaf\x73\x39\x6e\x85\xfb\x04\x79\x75\x58\xba\x4f\x2b\xbc\x49\xd9\xf2\x32\x9a\x23\xb3\x93\x30\x1a\xe0\xdb\x92",
        b"\x68\xef\xaa\x05\xeb\x90\xc4\x8c\x6a\x7a\x45\x33\x7c\x29\x17\x5f\x8e\xe5\xb1\x9b\x53\xdb\x4e\xbd\x83\xa0\x2f\x53\xc5\xb2\x10\x4b",
        b"\x14\x5f\x13\xf1\xae\x36\x75\xc5\x21\xb3\x34\xce\x6a\x49\xfc\x6f\x50\x2e\x3a\xc6\xb2\xb5\x14\x3b\xe0\x64\x1d\x0d\x57\xb3\xc7\x22",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x1d\x09\x54\xee\x0d\xe1\xe9\xce\xee\x05\x32\x59\x7e\xe4\x34\xc7\x3f\xe4\xf6\x66\x35\xf7\xe7\x2d\x38\xb6\x77\x63\xc6\x68\x17\xf5\x3c\xf3\x6c\xa0\xf6\x13\xe0\x18\x96\xce\xbc\x9f\x77\xa7\x72\x60\x7f\x4a\xee\xdd\x38\x56\xc7\x3f\xc2\xf1\x91\x00\xaa\x7b\x54\x0c\xcd\x05\x7f\x26\xcd\x95\x64\xd6\x73\x22\x8c\x68\x08\x8e\x5f\x1a\xbf\x12\x54\xa9\x7e\xd1\x45\x3e\xe5\x58\xe0\x62\x71\x1c\xeb\x76\x43\xb3\x45\xad\x33\xb6\x49\xaf\xfb\xe8\xa6\x20\x67\xf9\xd8\x4e\xd4\xc8\x50\x6f\xcf\xf5\x78\xd2\xeb\xa5\x96\xa2\x05\x26\x73\x87",
        p,
        q,
        g,
        b"\x2f\x0d\x89\xac\x78\xa6\x1f\xb7\x4f\x81\x14\x2b\x17\x76\x66\x56\xd1\x78\x89\x40\x07\x78\x08\xe3\xd8\x80\xce\x10\xec\x60\xe2\xbb\xb1\x58\xd5\x4e\x02\x0d\xbc\x5f\x67\x86\xc0\xb4\x3c\xca\x2c\xb0\x02\xc8\xce\x13\xb2\x91\xb2\x50\xf3\x99\xe8\xe0\x2f\x19\x59\x26\x97\x8f\x6c\x5b\x00\x7d\x4f\x0a\x66\x04\x89\x96\xa9\x93\x2a\x91\x8b\x23\x63\xc4\x00\x8f\x54\x7a\xdc\xaa\x7d\x12\x69\x4b\xae\xe4\xfb\xca\x34\xbc\x6d\x7e\x29\xc5\x04\x9c\xda\x13\x69\x8f\xcc\xe6\x1b\xd3\xb3\xdb\x05\xd2\x15\x81\x32\xdd\x38\x0c\xf6\x53\xcc\xcd\xf2\x79\xaa\x16\x41\x34\xbf\xbd\xdd\x7e\xa3\x47\x76\x00\x41\xf9\x2c\x3a\x4c\xfd\xe0\x09\x2d\x5c\xb9\x6b\xb8\xc2\x4e\x98\x25\x94\x75\x59\x6f\x33\x77\xd5\x9f\x11\x66\x1b\xcc\x0d\x47\xe8\x3c\xb3\x1a\xae\x9d\xcb\x4a\x6f\x25\x61\x9a\x29\x05\x4b\x62\xaa\x8b\x42\x1e\x52\x9e\x61\xac\x95\xa0\xde\x01\xc5\x0b\x09\xe1\x19\x51\x6c\x2c\x5b\x35\x63\xd4\x7e\xed\x67\x9a\x1c\xf8\x0b\xa7\x0a\x50\x25\x4d\x85\x1a\x13\xa7\x78\xe1\xa0\x8d\xa8\x66\x7e\x46\xe3\x59\x79\xc1\x5d\xf4\x5c\xf7\x88\x6d\xde\x5a\xf9\xd7\x44\x62\x4b\x98\x1a\xcd\x25\x2e\xc5\xba\x46\x87\x0b\x8e\xe4\xb3\x2b\x1b\xe1\xb9\x44\x80\x2d\x91\xd8\x14\x8d\x38\xf5\x43\x15\xa7\xad\x4e\x38\x07\x9e\xa2\xbe\xd9\xdf\x8f\xa5\x94\x14\xdd\xde\xd3\xa1\xd2\x30\x8b\xa7\x69\xae\x2a\x65\x2f\x10\xc2\xd9\x69\x17\xed\xfe\x58\x74\x88\x5f\x3c\x99\xd6\x91\x2f\x69\xae\x3f\xc3\xb4\xde\x82\xde\xcc\x30\xed\xc9\x31\x4f\x7e\xc9\xe5\x67\xb7\xe0\x0d\xe2\x19\x59\x48\x6a\x88\x7d\x74\xa5\xb2\x18\x02\x93\xdf\x5d\xbe\xae\x1e\x35\xa6\xe9\x37\xb2\x50\x6d\x20\x50\x92\xcc\x4c\x35\x95\xdb\x92\xfc\x25\x5a\xf5",
        b"\xa6\x72\x10\x34\x1a\x04\xcd\x3a\x4b\x63\xeb\xc7\xe6\x20\x8f\x37\xe4\x87\xa8\xc6\xf1\x13\x4c\xd2\x60\x1b\x84\x4d\x69\x03\x20\x3f",
        b"\x6b\x97\x2c\x62\x2c\xab\x48\xd8\x5a\x2d\xde\x35\x5f\x94\x7a\x81\x51\xa1\x7a\x0a\xcf\x06\xb7\xf3\x65\x9f\x86\x8d\x5e\xce\x92\xd9",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x14\xf5\x66\xc5\xfe\x44\xaa\xad\x6e\x8b\x3c\x62\x75\x70\xaa\xbd\xd4\xef\xb7\xfc\xfa\x1a\xb1\xbb\x74\xf2\xc6\xd8\x79\x5e\x88\x23\x3d\xac\x4e\x7d\x24\x0a\xbd\x5e\x9b\xbd\x8e\x1f\xb0\x3a\x3b\xf5\x0c\x0c\xa9\x2c\x9a\xef\x18\x94\xf2\xae\xd6\x00\xfc\x58\x73\xd2\x34\x51\xd3\x20\x4d\x75\xab\x95\x81\xcb\xcf\x82\xae\x8c\x0d\xf0\xdf\xbd\x3a\x1f\x14\x9f\x70\x66\x08\x65\x72\x6c\xdc\x73\xc0\x15\xd5\xdd\xbf\x75\x13\xee\xdc\xd1\xef\x17\x57\x8d\x27\x19\xfe\xa1\xe5\xba\x39\xae\xf3\xfa\x6f\x00\x84\x6f\x0f\xb8\xd9\xa1\xa4\x36",
        p,
        q,
        g,
        b"\xa3\x6a\x33\x39\x00\x03\x5d\x34\x53\x13\x9b\x28\x35\x6b\xf0\x12\x4e\x57\x1f\x55\xa5\xe4\x25\x9b\x8b\x2e\xe1\x45\x7c\xc3\x58\x80\x56\xd6\xc6\xa6\x45\xd4\x22\xca\xc7\x24\x74\xc5\x90\x1d\x0a\x7f\x41\x0d\xf7\xf9\xb4\xe2\x2f\x86\x84\x86\x7d\x93\x32\xe2\xd4\x26\x6a\x6e\x59\x5e\x51\x5b\xec\xff\x7f\xb9\x4d\x21\xa8\xa9\xad\x72\x11\x57\x2e\x44\xce\x84\x48\x31\x7b\x34\xc3\xc0\xb8\x9b\x30\x97\xab\x2e\xc1\x34\xec\x7c\x17\x8c\x22\x78\x30\x9c\xf9\x15\x2b\x22\x3b\xb9\x37\xe6\x86\x82\xf1\xf6\x80\xc1\x7e\xe5\x9e\xcd\x06\x98\xa0\x5c\x24\xc1\x35\xd2\xb0\x23\x8e\x71\xf8\x07\xe0\x79\xf1\x75\xe1\x16\x71\x30\x8f\x5b\xd9\xe5\xa6\x97\x12\xa9\xc5\x08\xb3\xb5\x09\x25\xd1\x27\x6d\x55\x2b\xda\x51\xce\xf3\xbd\x0f\xbd\x00\xa9\xd2\xdd\xdf\x0e\x5e\xcb\x6b\x32\x83\x78\xea\x63\x7b\x49\x38\x46\x48\x0e\xd7\x5a\x31\x52\xd9\xe6\xa4\x88\x4e\xeb\xad\x12\xb0\x7c\xad\x8d\x10\x1b\x3d\x00\x1b\xc9\x9f\xb1\xee\xe4\xe9\x8f\xd6\xfc\x92\x0c\xb5\x76\x5e\xc2\x4e\x62\xab\xd3\x2f\x97\x5a\x47\xd5\x0f\x61\x55\x3e\x1c\x14\x77\x51\x93\xb5\x3b\x05\xb7\xd0\x20\x24\xaa\xce\x81\x8a\xb6\x59\xd7\x17\xd1\x1d\xea\xcc\x98\x77\xb8\x18\xa5\x16\x89\xd2\x39\xb6\x0f\x7f\x9e\xd4\xca\xf7\x32\x5a\xc0\xb3\x1b\x31\x6c\x03\x65\x99\xea\x66\x95\x9d\x52\x5f\xd1\x6f\x5c\x1a\x2a\x80\x9f\x28\x66\xee\x9e\x99\xf6\xd8\xa3\xc4\x2b\x58\xd3\x3d\x0e\x5d\x38\x05\x5c\x55\xc7\xbc\xcd\xef\x31\x0c\xcd\x34\x26\x20\x7d\xbb\xc6\x0f\xaf\x9f\x2a\x21\x9a\xb3\x67\xce\x84\x62\x3b\x81\x10\x48\x22\xe2\xc7\x7e\xc5\xb1\x33\xce\x70\x50\xca\xed\x09\x09\x46\xc1\xf1\x35\x5d\x87\x8a\x13\x17\xde\x69\x4e\x68\x6c\x62\xff\xdf",
        b"\x12\xb4\x0b\xd1\xc8\x66\xce\x38\xe7\xda\x07\x64\xd8\x07\xae\x82\x51\x2b\x33\xb5\x1d\xc9\x08\xe5\xa5\xb3\xd7\xc1\x6f\x0d\x08\xa5",
        b"\x5c\xac\xce\xe2\xbc\x85\xe2\x8d\x50\x6a\x9b\xc6\xd2\x60\xdb\xd0\x82\x05\xb7\x5d\x20\x69\x0e\x26\xaa\x6b\xed\x30\xd7\x32\x70\x99",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\x60\xc2\x9d\x99\x75\x3d\x08\x47\xbb\x52\xe9\x06\xc8\x62\xa1\xb0\x62\x84\x96\x41\x6c\x14\xdf\x5d\xcf\xbb\x5e\x28\x04\xf5\x02\xcb\x0a\x2d\x16\x3e\x9b\xc2\xd8\x41\x22\xc0\xb3\xf5\xd0\x60\x9b\x82\xac\x16\xaa\x15\xef\xd5\x5f\x55\xc8\xca\xa3\xd1\x11\x4a\xc0\xcb\x83\xe5\xff\x3d\xb1\x2a\x24\xb8\x9a\xca\x5f\x05\x14\xd2\xce\xb0\x9b\x14\xfa\x91\x60\x00\xc0\xf4\xde\xb0\x16\xdb\x75\x5e\x88\xb3\x26\x17\x21\x44\xe4\xf1\xa7\x05\xa8\x00\x55\x9b\x3d\xa3\xc2\x7a\xf5\x5c\xb3\x2b\x11\x47\x46\x0c\x31\x18\x6d\x99\xdc\x1c\xf2\xe5",
        p,
        q,
        g,
        b"\xa3\x73\x97\xe6\xea\xfb\xdc\xf1\xe0\x15\x8f\x1f\x4e\xa1\xcb\x3a\x1e\xbd\x73\x9c\x85\x59\xa5\x00\xde\xf3\xb7\x55\x17\x99\xd6\x52\xb3\x27\x10\x1c\xfe\xa0\xb8\x70\x16\xdb\x59\x15\x22\xb9\xb3\x4e\xd2\x67\x13\x2c\x52\x55\xe7\x76\x53\xc4\xeb\x93\x5c\xe0\xc8\x22\xb4\xb1\x0a\x5e\x8f\x3c\xce\x39\xad\x1b\x96\x06\xde\x5b\xe2\xb2\xd3\x6e\x1c\x54\x11\xf0\x6a\xba\x04\x61\xea\x8d\xc4\x8b\x64\x9f\x10\x8e\xba\x88\xde\xf4\x4d\xaa\x2a\x5c\x65\x3d\xcc\xf1\xd8\xae\x29\x20\x5d\xd5\xc3\x40\xe3\x4b\x7b\xd6\x98\xec\xcd\xcd\x34\x5b\xd4\xaa\x5e\xee\x3c\x08\xb9\x16\x2c\xa1\x80\x48\x72\xde\x3c\x57\x5d\x57\x2f\x34\xdd\x48\xb4\x1f\x82\x35\xd0\xf5\x11\xc8\xdc\x65\xda\xeb\x07\x09\x5c\x3b\x5d\xbd\x3a\x07\x6f\x8e\xb2\x44\x12\xf3\x62\x1f\x49\x21\x26\x73\x7a\x9d\x73\x01\x4d\xef\xa5\xf5\xd5\x7b\xdc\x6f\xaf\x53\x14\x2e\xb1\x91\x60\x6f\x2f\xd3\xdc\x03\x5f\x4b\x8a\xe8\x4d\x65\x5c\xb6\xda\xaa\xf8\x89\x00\x5c\x3c\x33\x4f\xfd\x7e\x3b\x04\x98\xfa\xe2\xa6\xf8\xdc\x1b\xc6\x2f\x37\x04\xc8\xf8\xc0\x05\xc8\x01\x9e\x0b\xf4\x5b\x7a\xa8\xe0\x80\x3b\x93\xa9\x92\x67\x5e\x38\x1f\x61\xa8\x98\x58\x29\x50\xb9\xce\x40\xe7\xcd\xb0\x30\x0f\x4b\x26\xf9\xb4\x44\x84\xe8\x9c\x92\x34\x17\x9b\x60\xa3\x72\xfe\x94\x76\xf8\x4d\xe0\xed\x4b\x93\x49\x72\x16\xfb\x96\xba\xe4\x32\x97\xdc\xdc\x84\x96\xc6\x34\x10\x0c\xf0\x66\x40\x2c\x7d\x29\x0a\x7c\xd2\x8c\xbc\xf8\xb0\x8a\xd4\xc1\x36\xdb\x2f\xe9\x92\xff\xa0\x45\xbf\x8c\xb2\x49\x23\x4f\x29\xa6\x74\x76\x2a\x56\xd2\x08\x97\xea\x55\x38\xc6\x74\xa1\x43\x53\xdb\x64\xba\x60\xfe\x40\x52\xa0\x52\x8e\xb0\xb2\x58\x87\xe3\xc5\xea\x69\xb4\x1f\x68\xb3",
        b"\x72\xcf\x0e\x18\xe4\xbc\x37\x49\x64\x7c\xdf\xa6\x2d\xcb\xd2\x51\x3c\x7c\x2b\x1d\x39\x7c\x1f\xcb\xc7\xf6\xa4\x25\xeb\xb8\x97\xce",
        b"\x7b\x7d\x0a\x9e\x93\x34\x09\x41\xbb\x55\xf6\xaf\xa6\xcd\x63\xf7\x36\x49\x63\x67\x10\x08\xed\xe4\x57\xd0\x5b\x65\x45\xfa\xb1\xf1",
    )?;
    test(
        HashAlgorithm::SHA384,
        b"\xb3\xde\xa6\x2a\x20\xa9\xed\x9d\xa9\x90\x46\x5b\xeb\xe1\x8a\xa7\x1f\x08\xf9\x3f\xba\xee\x4f\xe5\xd5\x81\xff\xaa\x6f\xd5\x5c\xbe\x27\x2a\x11\x5d\x7f\xa1\x8f\xb9\xcf\x56\x62\xf5\x95\xb7\xcb\x9b\xdb\x97\xa8\x1b\xdc\x07\x8e\xe3\xbd\xce\xb2\xc0\x37\x22\x61\x01\x34\xc3\xbb\xfd\x7a\x6f\x8b\x79\xec\xc6\xa9\xa7\x70\x92\x65\x68\x7f\x9c\x23\x6f\xc6\x8b\x02\x20\x3b\xa6\x66\xe9\xec\xed\x51\x61\xde\x90\xc1\x10\xee\x7a\xf9\xbf\x54\xd8\x4a\x22\x18\x1f\x17\xb4\x32\x93\x48\xbd\xee\xfb\xb3\x24\x96\x2e\x63\x56\x9f\x07\xc2\x85",
        p,
        q,
        g,
        b"\x45\x01\x33\x18\xb9\x41\xa7\x10\xb8\xab\x10\x10\xd8\x18\xc3\x10\x36\x34\x65\x8d\x2e\x3e\x2f\x41\x31\x65\x86\x08\x05\xe0\x8d\x5c\x1e\x80\xad\xd9\x96\x9a\x3d\x3a\x0d\x23\x43\x2c\x8a\x48\xcc\xe8\x36\xb2\x4a\x41\x08\x92\x09\x9b\xbf\x53\xcc\x5a\x84\xa9\x5e\x1e\xb3\xb6\x82\xd2\x75\x4e\x72\x1e\xfc\x86\xd3\xf4\x24\x8b\xaa\x33\x7d\x6f\x6e\x5d\xac\x47\x59\xb2\x96\x16\x59\x18\xa7\x1b\x31\xce\xd2\x5b\xf1\xb0\x5d\x67\x5b\xfa\x22\x29\x80\x60\x8f\xda\x8f\x9d\x0e\xba\x9a\xa0\x84\x75\x51\x2d\x04\xc6\x12\x13\x3c\x88\x25\x3b\xf3\xe2\x7e\x9f\xfe\x3a\x85\x70\xbe\x20\x4f\x54\xbf\x8f\xf1\xc7\xfe\x42\xae\xce\x83\x20\x50\xaa\xbd\xd9\x41\x57\x64\xb8\xc8\x72\x69\x7f\x9c\x8e\x78\xe2\xf5\x6b\xd2\x35\xeb\xbb\xb4\xb9\xcf\x8f\x05\x4b\x60\x29\x29\x63\x76\x45\x36\xd6\xfd\x4c\x6c\xfa\xa1\xba\xea\x53\x54\x6c\x6f\xfb\x56\xa0\x4f\xbf\xae\xe0\x01\x22\x82\x80\xae\xc4\x0e\x66\xd9\xdc\x19\x2f\x9b\xa7\x43\xbd\x3f\xfc\x0e\xaf\x27\x7b\x6b\xa3\xd3\x3c\x36\x97\x02\x48\x92\xb0\xb3\x54\x19\x53\x48\x73\xfb\x7a\x3d\x59\x4d\xd6\xae\x07\x51\xa2\xfa\x43\x0b\xa4\x62\x37\xf4\xa5\x5e\x4a\x67\x80\x72\xc6\x51\xfe\x6a\xd3\x14\xa0\x10\xfd\xfe\x8f\x8b\x53\x42\xbd\xab\xe9\xae\x59\x10\xc6\xf4\x4a\x51\xf4\x75\x24\xa6\xfe\x82\x16\x83\x0c\xca\xed\xed\x26\xce\x1f\x13\xf7\xf2\x16\xe0\xb7\x80\x9e\x92\x72\x56\x3c\xab\x33\x52\xb8\xed\x76\x66\x50\x22\x7b\xfe\x16\xe9\x81\xb5\x05\x60\x9c\x41\xf0\x3d\xca\x98\xe2\x19\xd0\x2a\xa7\xd9\x19\x21\xed\xb3\xa8\x92\x29\xe7\x8c\x30\x16\x1c\xc1\x39\x73\xb3\x5d\xe3\xc8\x77\x79\x37\x8b\x8d\x60\x7a\x19\x32\x04\x05\x66\x13\x12\x43\x2d\xd8\xd0\x7a\xf2",
        b"\x3e\xc6\x77\xe9\x1c\x63\xe6\x5a\xaa\x17\x4a\xee\x27\x91\xdc\x40\x92\x44\xcb\x80\xc0\x22\x09\x91\xdc\xb4\x97\x39\x7a\x3c\x5e\x9b",
        b"\x1d\xe0\xec\x46\x6b\x2a\xd4\xed\x1a\xdc\xe3\xbc\x38\xee\x52\x18\x03\xdc\x87\x08\x5e\x2f\xbf\xc5\x61\xd6\x38\x44\xc1\xa9\xa2\xe6",
    )?;

    // [mod = L=3072, N=256, SHA-512]
    let p = b"\xc1\xd0\xa6\xd0\xb5\xed\x61\x5d\xee\x76\xac\x5a\x60\xdd\x35\xec\xb0\x00\xa2\x02\x06\x30\x18\xb1\xba\x0a\x06\xfe\x7a\x00\xf7\x65\xdb\x1c\x59\xa6\x80\xce\xcf\xe3\xad\x41\x47\x5b\xad\xb5\xad\x50\xb6\x14\x7e\x25\x96\xb8\x8d\x34\x65\x60\x52\xac\xa7\x94\x86\xea\x6f\x6e\xc9\x0b\x23\xe3\x63\xf3\xab\x8c\xdc\x8b\x93\xb6\x2a\x07\x0e\x02\x68\x8e\xa8\x77\x84\x3a\x46\x85\xc2\xba\x6d\xb1\x11\xe9\xad\xdb\xd7\xca\x4b\xce\x65\xbb\x10\xc9\xce\xb6\x9b\xf8\x06\xe2\xeb\xd7\xe5\x4e\xde\xb7\xf9\x96\xa6\x5c\x90\x7b\x50\xef\xdf\x8e\x57\x5b\xae\x46\x2a\x21\x9c\x30\x2f\xef\x2a\xe8\x1d\x73\xce\xe7\x52\x74\x62\x5b\x5f\xc2\x9c\x6d\x60\xc0\x57\xed\x9e\x7b\x0d\x46\xad\x2f\x57\xfe\x01\xf8\x23\x23\x0f\x31\x42\x27\x22\x31\x9c\xe0\xab\xf1\xf1\x41\xf3\x26\xc0\x0f\xbc\x2b\xe4\xcd\xb8\x94\x4b\x6f\xd0\x50\xbd\x30\x0b\xdb\x1c\x5f\x4d\xa7\x25\x37\xe5\x53\xe0\x1d\x51\x23\x9c\x4d\x46\x18\x60\xf1\xfb\x4f\xd8\xfa\x79\xf5\xd5\x26\x3f\xf6\x2f\xed\x70\x08\xe2\xe0\xa2\xd3\x6b\xf7\xb9\x06\x2d\x0d\x75\xdb\x22\x6c\x34\x64\xb6\x7b\xa2\x41\x01\xb0\x85\xf2\xc6\x70\xc0\xf8\x7a\xe5\x30\xd9\x8e\xe6\x0c\x54\x72\xf4\xaa\x15\xfb\x25\x04\x1e\x19\x10\x63\x54\xda\x06\xbc\x2b\x1d\x32\x2d\x40\xed\x97\xb2\x1f\xd1\xcd\xad\x30\x25\xc6\x9d\xa6\xce\x9c\x7d\xdf\x3d\xcf\x1e\xa4\xd5\x65\x77\xbf\xde\xc2\x30\x71\xc1\xf0\x5e\xe4\x07\x7b\x53\x91\xe9\xa4\x04\xea\xff\xe1\x2d\x1e\xa6\x2d\x06\xac\xd6\xbf\x19\xe9\x1a\x15\x8d\x20\x66\xb4\xcd\x20\xe4\xc4\xe5\x2f\xfb\x1d\x52\x04\xcd\x02\x2b\xc7\x10\x8f\x2c\x79\x9f\xb4\x68\x86\x6e\xf1\xcb\x09\xbc\xe0\x9d\xfd\x49\xe4\x74\x0f\xf8\x14\x04\x97\xbe\x61";
    let q = b"\xbf\x65\x44\x1c\x98\x7b\x77\x37\x38\x5e\xad\xec\x15\x8d\xd0\x16\x14\xda\x6f\x15\x38\x62\x48\xe5\x9f\x3c\xdd\xbe\xfc\x8e\x9d\xd1";
    let g = b"\xc0\x2a\xc8\x53\x75\xfa\xb8\x0b\xa2\xa7\x84\xb9\x4e\x4d\x14\x5b\x3b\xe0\xf9\x20\x90\xeb\xa1\x7b\xd1\x23\x58\xcf\x3e\x03\xf4\x37\x95\x84\xf8\x74\x22\x52\xf7\x6b\x1e\xde\x3f\xc3\x72\x81\x42\x0e\x74\xa9\x63\xe4\xc0\x88\x79\x6f\xf2\xba\xb8\xdb\x6e\x9a\x45\x30\xfc\x67\xd5\x1f\x88\xb9\x05\xab\x43\x99\x5a\xab\x46\x36\x4c\xb4\x0c\x12\x56\xf0\x46\x6f\x3d\xbc\xe3\x62\x03\xef\x22\x8b\x35\xe9\x02\x47\xe9\x5e\x51\x15\xe8\x31\xb1\x26\xb6\x28\xee\x98\x4f\x34\x99\x11\xd3\x0f\xfb\x9d\x61\x3b\x50\xa8\x4d\xfa\x1f\x04\x2b\xa5\x36\xb8\x2d\x51\x01\xe7\x11\xc6\x29\xf9\xf2\x09\x6d\xc8\x34\xde\xec\x63\xb7\x0f\x2a\x23\x15\xa6\xd2\x73\x23\xb9\x95\xaa\x20\xd3\xd0\x73\x70\x75\x18\x6f\x50\x49\xaf\x6f\x51\x2a\x0c\x38\xa9\xda\x06\x81\x7f\x4b\x61\x9b\x94\x52\x0e\xdf\xac\x85\xc4\xa6\xe2\xe1\x86\x22\x5c\x95\xa0\x4e\xc3\xc3\x42\x2b\x8d\xeb\x28\x4e\x98\xd2\x4b\x31\x46\x58\x02\x00\x8a\x09\x7c\x25\x96\x9e\x82\x6c\x2b\xaa\x59\xd2\xcb\xa3\x3d\x6c\x1d\x9f\x39\x62\x33\x0c\x1f\xcd\xa7\xcf\xb1\x85\x08\xfe\xa7\xd0\x55\x5e\x3a\x16\x9d\xae\xd3\x53\xf3\xee\x6f\x4b\xb3\x02\x44\x31\x91\x61\xdf\xf6\x43\x8a\x37\xca\x79\x3b\x24\xbb\xb1\xb1\xbc\x21\x94\xfc\x6e\x6e\xf6\x02\x78\x15\x78\x99\xcb\x03\xc5\xdd\x6f\xc9\x1a\x83\x6e\xb2\x0a\x25\xc0\x99\x45\x64\x3d\x95\xf7\xbd\x50\xd2\x06\x68\x4d\x6f\xfc\x14\xd1\x6d\x82\xd5\xf7\x81\x22\x5b\xff\x90\x83\x92\xa5\x79\x3b\x80\x3f\x9b\x70\xb4\xdf\xcb\x39\x4f\x9e\xd8\x1c\x18\xe3\x91\xa0\x9e\xb3\xf9\x3a\x03\x2d\x81\xba\x67\x0c\xab\xfd\x6f\x64\xaa\x5e\x33\x74\xcb\x7c\x20\x29\xf4\x52\x00\xe4\xf0\xbf\xd8\x20\xc8\xbd\x58\xdc\x5e\xeb\x34";
    test(
        HashAlgorithm::SHA512,
        b"\x49\x41\x80\xee\xd0\x95\x13\x71\xbb\xaf\x0a\x85\x0e\xf1\x36\x79\xdf\x49\xc1\xf1\x3f\xe3\x77\x0b\x6c\x13\x28\x5b\xf3\xad\x93\xdc\x4a\xb0\x18\xaa\xb9\x13\x9d\x74\x20\x08\x08\xe9\xc5\x5b\xf8\x83\x00\x32\x4c\xc6\x97\xef\xea\xa6\x41\xd3\x7f\x3a\xcf\x72\xd8\xc9\x7b\xff\x01\x82\xa3\x5b\x94\x01\x50\xc9\x8a\x03\xef\x41\xa3\xe1\x48\x74\x40\xc9\x23\xa9\x88\xe5\x3c\xa3\xce\x88\x3a\x2f\xb5\x32\xbb\x74\x41\xc1\x22\xf1\xdc\x2f\x9d\x0b\x0b\xc0\x7f\x26\xba\x29\xa3\x5c\xdf\x0d\xa8\x46\xa9\xd8\xea\xb4\x05\xcb\xf8\xc8\xe7\x7f",
        p,
        q,
        g,
        b"\x6d\xa5\x4f\x2b\x0d\xdb\x4d\xcc\xe2\xda\x1e\xdf\xa1\x6b\xa8\x49\x53\xd8\x42\x9c\xe6\x0c\xd1\x11\xa5\xc6\x5e\xdc\xf7\xba\x5b\x8d\x93\x87\xab\x68\x81\xc2\x48\x80\xb2\xaf\xbd\xb4\x37\xe9\xed\x7f\xfb\x8e\x96\xbe\xca\x7e\xa8\x0d\x1d\x90\xf2\x4d\x54\x61\x12\x62\x9d\xf5\xc9\xe9\x66\x17\x42\xcc\x87\x2f\xdb\x3d\x40\x9b\xc7\x7b\x75\xb1\x7c\x7e\x6c\xff\xf8\x62\x61\x07\x1c\x4b\x5c\x9f\x98\x98\xbe\x1e\x9e\x27\x34\x9b\x93\x3c\x34\xfb\x34\x56\x85\xf8\xfc\x6c\x12\x47\x0d\x12\x4c\xec\xf5\x1b\x5d\x5a\xdb\xf5\xe7\xa2\x49\x0f\x8d\x67\xaa\xc5\x3a\x82\xed\x6a\x21\x10\x68\x6c\xf6\x31\xc3\x48\xbc\xbc\x4c\xf1\x56\xf3\xa6\x98\x01\x63\xe2\xfe\xca\x72\xa4\x5f\x6b\x3d\x68\xc1\x0e\x5a\x22\x83\xb4\x70\xb7\x29\x26\x74\x49\x03\x83\xf7\x5f\xa2\x6c\xcf\x93\xc0\xe1\xc8\xd0\x62\x8c\xa3\x5f\x2f\x3d\x9b\x68\x76\x50\x5d\x11\x89\x88\x95\x72\x37\xa2\xfc\x80\x51\xcb\x47\xb4\x10\xe8\xb7\xa6\x19\xe7\x3b\x13\x50\xa9\xf6\xa2\x60\xc5\xf1\x68\x41\xe7\xc4\xdb\x53\xd8\xea\xa0\xb4\x70\x8d\x62\xf9\x5b\x2a\x72\xe2\xf0\x4c\xa1\x46\x47\xbc\xa6\xb5\xe3\xee\x70\x7f\xcd\xf7\x58\xb9\x25\xeb\x8d\x4e\x6a\xce\x4f\xc7\x44\x3c\x9b\xc5\x81\x9f\xf9\xe5\x55\xbe\x09\x8a\xa0\x55\x06\x68\x28\xe2\x1b\x81\x8f\xed\xc3\xaa\xc5\x17\xa0\xee\x8f\x90\x60\xbd\x86\xe0\xd4\xcc\xe2\x12\xab\x6a\x3a\x24\x3c\x5e\xc0\x27\x45\x63\x35\x3c\xa7\x10\x3a\xf0\x85\xe8\xf4\x1b\xe5\x24\xfb\xb7\x5c\xda\x88\x90\x39\x07\xdf\x94\xbf\xd6\x93\x73\xe2\x88\x94\x9b\xd0\x62\x6d\x85\xc1\x39\x8b\x30\x73\xa1\x39\xd5\xc7\x47\xd2\x4a\xfd\xae\x7a\x3e\x74\x54\x37\x33\x5d\x0e\xe9\x93\xee\xf3\x6a\x30\x41\xc9\x12\xf7\xeb\x58",
        b"\xa4\x0a\x6c\x90\x56\x54\xc5\x5f\xc5\x8e\x99\xc7\xd1\xa3\xfe\xea\x2c\x5b\xe6\x48\x23\xd4\x08\x6c\xe8\x11\xf3\x34\xcf\xdc\x44\x8d",
        b"\x64\x78\x05\x09\x77\xec\x58\x59\x80\x45\x4e\x0a\x2f\x26\xa0\x30\x37\xb9\x21\xca\x58\x8a\x78\xa4\xda\xff\x7e\x84\xd4\x9a\x8a\x6c",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xc0\x1c\x47\xbf\xa2\x08\xe2\xf1\x9d\xdd\xa5\xcd\xe5\x83\x33\x25\xd1\x6a\x83\xfb\xda\x29\xe6\x66\xfe\x67\xff\x34\x89\x80\x3a\x64\x78\xa5\xac\x17\xff\x01\xed\xc7\x97\x3d\x15\xfe\x49\x98\xf6\x3b\xbc\x09\x5f\xc1\xac\x07\x53\x42\x41\xc6\x43\xa4\x44\x44\xdc\x9a\x35\x6f\xa8\x12\xd5\xca\x19\x1a\x2f\x6e\xd1\x62\xa2\xd5\xfd\x6d\x0a\xa8\x98\xa2\x05\x63\xd9\x93\x83\x02\x54\xdb\x8a\x4b\xf6\x5b\xa8\x60\x99\xcc\x6b\x58\xa1\xbf\x6e\xbb\x01\xa1\x9c\x79\x30\x43\x08\xac\xeb\xe1\xda\x09\xf1\x75\x3a\x19\x5e\x9e\xf5\x86\xc7\xe1",
        p,
        q,
        g,
        b"\x97\x0d\x38\xcd\x8b\x3f\x16\x65\x9e\xc4\x2a\x46\xa1\x9f\xf0\x6c\xe8\x49\x5b\x9f\x47\x7d\x9b\x7e\x35\xae\x10\x35\xb0\x8b\x0e\xe1\x7a\x0c\x3c\xee\xdf\x02\x98\x46\xe3\xae\xb9\x12\xf8\x50\x88\x1c\x22\x77\xf8\x22\x81\xe7\xc0\x74\x1d\x2f\x87\xe9\xfa\x5c\x30\x67\x7f\xe7\x26\x8c\xc5\xfd\x9a\xed\x29\xf3\x08\xd9\xbe\x8d\xe9\x2b\x96\x1e\x39\xc1\xdb\xc4\x67\x90\xc9\x9b\x7e\x29\x57\x9d\xaf\x88\x81\x76\xd5\xce\x16\xdb\x5c\xab\xfc\xbe\x42\x09\xac\x47\x53\xb0\xe9\x6b\x15\xd0\xb8\x2c\x7e\xef\xb4\x2a\x10\xde\x88\xf8\xa7\x72\x34\x92\xa2\xbe\x54\x51\xc1\xc6\xec\x68\xca\x75\x9d\x8b\x4e\xe4\x18\x82\x6e\x71\xf3\x9c\xd0\x76\x54\xd0\x0d\x0e\x0f\x88\xd0\x92\x4b\xdb\x97\xaa\xca\x5a\x63\x46\xad\x69\xfc\x22\x3c\xd5\x7f\x5b\xb0\x30\x04\x77\xb5\x94\xaa\x44\x5e\x5e\xa8\x89\x6c\xdf\x3b\xc8\x82\xe8\xfa\x55\x23\xb8\xa3\x32\xfd\x98\xe9\xd0\xa9\x24\x57\x89\x44\xd2\x4a\x41\xcb\xea\xe3\xed\x7b\x37\xdf\xfb\x2f\x60\xc0\x08\x4e\xaf\x00\x5c\x12\x51\x82\x3d\xa4\x1d\x2a\x5d\x97\x7d\x8e\x48\x3d\xdb\x33\xf7\x3f\xbc\x27\x25\x4a\x81\x4b\x61\x6d\x6a\x39\x05\x13\xf0\x56\x7a\x56\x3a\xc0\x53\xa7\x66\x67\x19\x7b\x45\x58\xf8\x71\xb6\x9c\xbf\x2c\x11\x6c\xe4\x57\x51\x3f\x60\xb4\xf5\x28\xe2\xdc\xda\xa7\x1a\x9a\x3a\x4c\xcc\xb3\x73\x8a\x22\x93\x7b\xca\x2a\x04\x2b\xef\x8a\x74\xa6\x00\xac\xd2\x69\x75\xc8\x91\x46\x6d\x7e\x57\xcc\x93\x09\x84\x21\x2e\xe0\xea\xf1\x74\xeb\xcb\xaf\xbe\xb8\xcc\x12\xbc\x43\xbf\xdb\x00\xfd\x11\x57\x6c\x43\x95\x13\xef\x5b\x59\xa8\x8f\xa5\xa9\xae\x96\x3d\x94\xda\xfd\x78\xf8\x1e\xe7\xb0\xd7\xfa\xb5\x3e\x41\xbb\xf6\x5f\x84\x49\xa4\xf5\x8b\x44\xf9\xe3",
        b"\x5b\xb5\x0e\x4f\x53\x8a\x6e\x46\x38\x20\x6b\xe1\x19\xdb\xf7\x12\x77\x61\x54\xac\xfb\x4c\x06\xd6\x5d\x66\xc8\x02\x12\x34\x17\x39",
        b"\x7b\x7e\x64\x0c\xd7\x60\x86\xd3\xf6\x40\xd1\x8c\xeb\x26\xbb\x53\xe3\x02\x82\xaf\xb1\x74\x01\xe7\xb4\x8a\xa6\x81\x89\x34\xdc\x5c",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x47\xe7\xaf\x22\xc9\x29\x8a\xd3\xbf\xef\x9b\xee\x50\x86\xbe\xdb\xdc\x51\x3d\x67\x41\x6d\x5f\x4e\x79\x81\xcd\xdb\x10\x02\xcb\xa2\x47\x00\xc4\x5d\xd6\xd4\xdc\xef\x4f\x81\xd0\x03\xf0\x51\x3d\xab\x4e\x04\xeb\x4c\x70\xd9\x44\x04\x2e\x1b\x72\x6d\x8a\x33\x05\x0d\x0e\x4f\x70\xc0\xa8\x34\x1b\x75\xfd\x4e\x27\xc7\x94\x87\x54\xe4\x41\x20\x8e\xb9\x3f\xc7\xb7\xc3\x73\x54\x25\x2f\x73\xb8\x38\xfd\x02\xd0\x78\xc6\xa1\xae\x07\x3e\xf1\x23\x3a\xa1\xc8\xaa\x27\x81\xe1\x93\xba\x28\x97\xcc\xdd\x8c\xf6\x17\xca\x23\x54\x1c\xe1\xc5",
        p,
        q,
        g,
        b"\x75\x16\x3a\xf1\x5c\xd6\xb2\x28\x25\x15\x04\xba\x02\x4d\xf5\x1d\xf3\x2f\x63\x8e\x37\xf0\xf2\xf9\xd0\x88\x37\xf8\xc6\xec\xfb\xa4\x3e\xb5\x15\xcc\xba\xbe\xa1\x1b\x01\xe1\xe1\xfd\x3c\xfe\x7e\x40\x5f\xc7\xf8\x14\x2b\x07\x31\x5e\x1d\xc3\x7b\x08\xc7\x86\x68\x42\x1e\x2a\x21\xfc\x5d\x81\x1d\x26\x55\x8c\x50\x4a\xbc\x4e\x6f\xdd\xf0\x37\x40\xb8\xa2\x7f\xa2\xeb\xcd\xa5\x46\x0a\xd7\x85\x70\x6c\x53\xcd\x2d\x14\x09\x3d\x92\x3d\xf9\x42\x05\x1c\xbb\xa2\x58\x6b\x4d\x54\x70\x9d\x24\xba\xbe\x2f\x7c\x61\xa5\x0d\xa8\x45\x18\x95\x99\x91\x66\xe8\x0c\x0f\xab\x89\x2a\x37\xeb\x67\x82\x74\x55\x96\xb4\x9f\x96\xe1\x1e\x9a\x95\x7c\x8e\xc6\x50\xd2\xd9\xa4\x0a\xa4\xb0\x14\xd2\xe9\xa4\xc0\x8b\x9d\x7b\xfe\xaf\x1e\xcd\x42\x78\x5b\x95\xc0\x17\x2a\xe2\x1c\xf2\x5c\x4d\x36\x8b\xb5\x10\x0b\x6e\x6d\x92\x31\x0b\x28\xb7\xb1\xaf\xe6\x4d\x49\x6b\x9c\x60\xb7\x63\xca\xc0\x8a\xc4\x6a\x6b\xce\x1b\xbd\x3a\xc8\xbb\x76\xbb\x55\xb6\x49\xb7\x59\x48\x20\xab\x6e\xf7\xdd\x1b\x09\xbb\x12\x85\x28\x16\xb6\x1e\x6d\xbe\xfa\xb7\x42\xe0\xea\x2c\xda\x47\xea\xc7\xd9\xd9\x13\xdd\xd4\xbf\xd8\xb2\xeb\x5f\x01\x95\x1c\xaa\x4f\x41\x3e\xb5\xe7\xa4\x1a\x06\x85\x69\x5f\x83\x31\xa3\x94\xe0\x6b\x14\x95\xc1\x70\xf3\x0a\xc2\x94\x66\x0e\x89\x09\x84\x3f\x9f\x11\xc4\xbf\xa6\x4e\x87\x92\xdf\x67\x7d\xa0\xa0\x8a\xae\x32\xa8\xa4\xe7\x06\x7f\xc3\x5e\xee\x03\x96\x4e\x8a\xfb\xdb\x6a\x42\x1b\x82\x48\xad\xd2\x84\x78\x9e\x4e\xd3\xca\xce\x71\x06\xc2\x3f\xe6\x66\x6c\x4b\x12\xb8\x36\xe7\x30\x7a\x55\xab\x24\xd9\x2d\x58\xac\x84\xe7\x1f\x81\xdc\x9b\x0b\x74\x36\xad\x07\xf7\x49\x94\xaf\x7d\x0b\x04\x9b\xd0\x9a",
        b"\x61\x75\x47\x3d\x7a\xa7\xd5\xce\x55\x59\x0c\x95\x2a\x19\x89\x72\x06\x08\x68\x87\xfd\x84\xbf\x2b\x56\x69\x26\xe4\x79\x81\xc2\xa3",
        b"\x71\xd7\x85\x7b\x6f\xf0\x6c\xa6\x78\x85\xfa\x9c\x9c\x71\xb8\xcc\x24\x6d\x03\x39\xb6\xc2\x72\x52\x47\x17\x2a\x29\x7e\x26\xa7\xb5",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x93\x11\xd8\xf9\x51\x14\x17\x13\xf4\x59\xeb\x65\xf0\x18\x80\xb9\x61\xc0\xa5\x90\xb3\x6f\x78\x5f\x1a\xeb\x88\x0e\xe7\x13\x00\xc0\xcb\xc6\x01\xb3\xa6\x07\x21\x93\xda\xd6\xdd\xf2\x02\x8e\xca\x4c\x8b\xd7\xb8\x57\x51\x87\x92\x8f\x84\xbd\x69\xc5\xdc\xfb\x0b\x9d\x32\x00\x03\xc3\xa8\x63\xc0\x9e\xe5\x03\xe3\x8a\xbe\x07\xce\x2e\x0d\x46\xb3\xce\xc9\x26\x23\x1a\x57\xde\xfa\x0a\xeb\xd1\xa6\xe0\x1e\xef\x4f\x9b\x53\x7a\xe1\xfc\xdf\x64\xe0\x14\x34\xd4\x0a\xb5\x01\x9f\x39\x65\xc7\x35\x41\x1a\x5c\x19\x94\x1f\x41\xfe\xbf\x4f",
        p,
        q,
        g,
        b"\x28\x7d\xdc\x19\x69\x15\x6c\x18\x42\x07\x43\xad\xe0\xfa\x12\x71\xea\x34\x6c\x33\x29\xf9\xca\x9b\x5d\x54\xeb\xfa\x21\xf6\x76\xf9\xe0\x13\x61\x62\x39\xf4\xbb\xe6\x0e\xaf\x8e\x19\x02\xed\x9a\xc7\x42\xd8\xdf\x91\x88\x76\x77\x08\x94\xb5\x12\xaa\xa2\x5c\x06\x8b\xde\x96\x1f\x56\xc9\xb5\xb8\x78\x06\xd7\xd0\xa9\xde\x78\x43\xd3\xcb\x07\x97\x90\x31\x26\xa4\x7b\xd9\x42\x23\x37\xe3\xb4\x6b\xb1\xf4\xf4\xa7\x9f\xdf\x9c\xf6\x76\x21\x57\x11\x8a\xee\xe1\xe7\x11\x16\xf3\x4d\xaf\xce\x00\x47\xf0\x5d\x43\xc7\xf2\xcb\xd4\xcd\x52\xd6\x14\xb7\xa9\x45\xd4\x8b\xe4\x4c\xfe\xbf\x78\x43\x32\xfe\x99\xc1\xee\x1a\xa8\x31\x08\x67\xdf\x20\xb2\x80\xda\x85\x5b\x19\x02\x9f\xa7\x9e\xcd\x6d\xd6\x91\x9a\x4d\x22\xb5\xa1\x40\x0c\x30\xe6\x2c\xe7\xac\xc4\xb2\x8e\xfb\xdb\x94\xea\x23\xaf\xbb\x64\xd6\xe5\xf7\xb3\x97\x5d\x2a\xc6\x3b\x1d\x04\x8f\xee\xa8\x35\xc7\xf5\x0b\x42\x5c\xe3\xcb\x41\x8a\xfd\xf4\xdc\x84\x00\x84\x73\x60\x65\x74\xe2\x0d\xb5\xeb\xf8\x6c\xb1\xad\x27\x73\x7d\x46\x49\x4b\x2e\x48\x5b\x26\xb8\xc9\x5d\x82\x9c\xf6\x56\xf8\x0f\x96\xb1\xa6\x2e\x7c\x03\xc8\xf2\x0f\x18\xdc\x58\xbf\x59\x91\x66\x82\xe6\xdc\xc6\x8d\x34\xc8\x9c\x1b\x1b\xd6\xe6\xb1\xe1\x5a\x7d\xc3\x25\xe2\x3f\xd7\xa3\x50\x99\x83\x1d\xbd\x75\x98\x9c\x73\x80\x20\xbf\x4d\xc4\x07\x9c\xcb\x0b\xf1\x2f\xaf\x3b\x9d\x64\x94\xa3\x79\xaa\xcb\x1b\x66\xd0\x7c\xbc\xeb\xbf\x77\xa6\xe2\x9a\xef\x22\xf4\xba\xa3\xdf\x40\xd2\x70\xb4\x57\xdd\xe6\x4f\x00\xb5\x37\x59\xae\x57\x81\x1b\x64\xe0\x40\xcb\xd4\x2e\xa9\x0f\x4e\x28\x08\xbc\x81\xdf\xd6\x63\xb2\x85\x84\xcd\xb8\x19\x9d\xa9\x6d\x3e\x03\xd0\x3f\xb4\x13\x3e\x2f",
        b"\x66\xf7\x29\x71\x64\x56\xa2\x78\x1b\xdb\x85\x78\xfa\x18\xd1\xe6\x4a\xf0\xed\xf8\xec\x1d\xee\x0a\x50\xd2\x59\x81\x91\x2f\xc4\x5a",
        b"\x8c\x3c\xcc\xfe\x6f\x0c\xfd\xc0\xac\x3a\x54\x2c\x8e\x8c\x85\x21\x0b\xbd\x7f\x95\x13\x4c\x8f\x03\x5d\x1c\xe1\x6f\x44\xab\x7a\x06",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x80\x86\x03\xf7\xf8\x43\x94\x41\x27\x79\x13\xb2\x1b\xef\x4e\x01\xc8\x9e\x41\x13\xe0\x7c\xac\xc3\x3f\x65\xac\x98\x49\xdb\x1a\xd1\xa1\xcb\x7d\xd2\xfe\xcd\x88\xee\x41\x39\xb1\x63\x83\x55\xc6\x23\x82\x13\x09\xf3\x26\xc1\x6b\xc6\x58\xbb\x48\x21\x51\x82\x38\x98\x2e\x52\x51\xf7\xcd\x37\x80\x72\x92\x15\x3d\x2b\x07\xdd\xdc\x06\x6e\x00\x3c\x60\x69\xc3\x71\x15\x5d\x2d\x19\x1f\x15\x11\x1f\x20\x89\xce\x42\x3f\x5c\x2a\x1f\x85\x34\xe3\x01\x31\x3c\x69\x62\x3f\x62\xba\x63\x5a\xdc\xe8\x55\x17\x33\xa8\x2a\x8f\xac\x1a\x66\xb1",
        p,
        q,
        g,
        b"\x38\x96\x72\xec\x6d\xe0\xb8\x66\x55\xcb\x10\xf1\x19\x9f\x85\x70\x13\xb6\x32\x0d\x52\xc8\x72\x8f\xbb\xb5\x36\x0a\x97\x01\xb1\xd6\xca\x4f\x9e\xec\xb8\x48\x7f\xb8\x79\x69\x0f\x85\x43\x0c\x58\x2d\x3d\x91\xef\x18\x4c\x82\x47\xd1\x62\xb9\x4d\x6d\xfd\xfe\x7c\x4a\xe8\x67\xac\x16\x72\x82\x79\x70\x41\x5a\xa6\x7a\x14\x06\xac\x1a\x6e\x2c\x6c\x13\x16\x77\x19\xe1\xd1\xa5\x36\xd1\x00\x78\x42\x7c\x21\x1c\xf6\x82\x05\x1a\x75\xee\x83\x22\xc1\x40\x8b\x89\xd9\x63\xbd\x8e\x85\xf9\xef\xf7\xbb\x8c\xe0\x5c\xa4\x22\x25\xb4\xbd\xfe\xad\x6b\x89\x7b\x0f\xea\xb7\x6c\x22\x72\xb4\x87\xd2\x7d\x4e\x8d\xcd\xe0\xf1\x9e\x46\x15\xf7\xe1\x11\x45\x41\xf6\x1d\x43\x53\x3c\xe7\x88\xcc\x45\x05\x60\x0b\x83\x26\x6b\x1b\xea\x66\x59\x12\x19\x6c\x2c\x84\xc3\x6a\xa9\x3b\xaf\x5b\x74\x64\xa6\xdd\xf5\x47\x18\x3e\x2c\xd0\x58\xbb\x50\xa1\x27\x65\x53\x6f\x0a\x4d\x35\x24\xaf\x4f\x31\xac\xc6\x09\xfc\x44\x7e\x17\x29\xaa\xb9\x7b\x5a\x36\xb0\x17\x64\xb8\x4b\xc5\xf7\x7f\x6c\xc5\x84\x86\x6d\x1a\x6c\xfb\x3a\xa8\x43\x78\x95\xf7\x77\xf2\xdc\x68\x97\x49\x9f\x6c\x5f\x02\xfa\x1e\x6c\x1e\xad\x68\xf3\x38\x5b\x73\x33\x87\xc6\xb5\x8f\x2d\x11\x28\x4a\x63\xae\x7c\x7c\xfe\xe4\x2c\x3f\x44\xa3\xc9\x26\xad\xad\x81\x07\xcc\xa1\xc3\xf9\x44\xf9\xb9\xe2\x37\xd9\xab\x35\xc8\x13\x91\xd7\xc5\xf5\x29\x2d\x1a\x32\x2f\x7a\x12\xce\x10\x8a\x86\x23\x7b\xa4\xde\x3c\x61\x2f\xa7\x38\xf5\x31\x94\xba\x67\xbe\xd8\x43\xcd\x2d\x43\x30\xa5\xd1\x94\xd6\x7c\xf4\x5f\xa0\x51\x83\xe0\xcb\x46\xc2\xd2\x3a\x1b\xae\x76\x75\x5c\x30\x9f\xa1\xc3\x16\x05\xc8\x8a\x92\x14\x22\x7c\xe0\x2f\xe9\x15\xbc\xf0\xd3\x4b\xce\x8c\x8e",
        b"\x98\xfe\x58\x7e\x43\xaa\x96\xf9\xa9\xbb\xe8\xaf\x40\x4a\x08\xb0\x23\x07\xb3\x60\x53\xdb\x87\xf6\xdb\x25\xa3\xaa\x36\xfc\xc3\xdb",
        b"\x5c\x94\xea\x70\xf9\x9f\x9f\xf1\x4b\x8e\x5d\xd4\xa6\x68\x83\x98\x26\x09\x07\x17\x6e\xa8\x0e\x19\xc3\x9b\x14\x62\x11\x49\xf0\xd6",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xce\x2a\xa3\xed\x12\xc1\xb8\x84\x3a\x3e\x11\xb0\x6b\x5f\x0e\x5e\x63\xfe\x8e\x19\xc1\xa3\x8a\xc4\x46\xa4\x8e\xec\xa8\xda\xc6\xd8\xb7\x69\xd7\x80\x94\x42\xc3\x2a\xc8\x2e\x93\xf6\x86\xec\x64\x34\x7e\x94\x44\xc3\xf4\x52\x82\x3c\x84\x0e\x8d\x0c\xd3\x34\xb4\x15\x20\x02\x14\x8d\xa1\x6a\xc8\x85\x9d\x18\x9d\x87\xd6\x71\x64\xc5\xdb\x16\x19\x5c\x08\x1d\x2e\xdd\x7d\x81\x57\xe2\xbf\x3b\x97\xa9\x0b\x4b\x47\x84\x32\x4e\xb8\xce\xac\x42\x61\x80\x9f\x67\x42\x56\xda\xf0\x07\xc4\xab\x1f\x22\x2f\x5f\xd2\x83\x98\xa5\xb8\x24\xde",
        p,
        q,
        g,
        b"\x58\x4f\xe0\xeb\x31\x4a\xfb\x86\x6c\x04\x66\xc3\x98\x0a\x2d\xf5\x45\x98\xd8\xa7\x05\xdc\x2d\x1b\xf5\x10\x2e\xac\x86\x31\x27\x84\xee\xbd\x01\x9b\x81\xa7\x64\x2d\x4a\x3c\x4c\xc6\x5d\xbe\xdd\x81\x87\xe3\x59\x3f\x0a\x9b\xcc\x06\xea\x36\x70\x09\xb7\xeb\x4d\x29\xb0\x45\x00\x61\x37\x8e\xdb\xe1\x63\xef\xd3\xf3\x44\xbb\x36\x23\x4f\xc8\x6f\xe1\xc3\x2f\x2c\x99\x95\xa0\x7c\x6e\x95\x7d\x19\x5e\x81\x05\xf5\x17\x9c\x2b\xd9\x76\xb3\x12\x70\x67\xc8\x0c\xa9\x34\x56\xc1\x6b\x98\xdf\xcc\x7d\xe3\x55\x79\x0f\x0b\x15\xcf\xd2\xff\x91\xdb\x09\x34\x55\x32\xd4\x60\x96\xc0\x6b\x40\xa2\x30\x46\x81\xd6\x28\x57\x67\x5a\xc5\x0e\x22\xc7\xd1\xab\x47\x58\x92\x35\x41\x9c\xbe\xdd\x4b\x7d\x24\xb9\x05\x31\xe5\xbf\xd8\x53\xe8\x8a\x28\x83\x6a\xc4\x6b\x6d\xf2\x67\x60\x98\x5b\x96\x2c\x6a\x24\x45\x80\x98\x66\xb4\x61\x26\x21\x2a\xa2\x63\xab\x2a\x46\x03\xff\x41\xa8\x52\xc7\x98\x8c\x2d\x43\x86\x24\x16\x55\xa7\x22\x2f\xa4\xe9\xf6\xea\xc6\xa1\x44\xa1\x6b\x05\x9e\xa2\x5b\x71\xa2\x13\x84\x91\xd5\x4e\xe9\x5a\x9d\x68\x19\x97\x7f\x90\xfe\x6a\x59\xe0\xca\xd8\x1b\x32\x9e\xba\x3e\x68\x27\x7d\xf0\x4f\x98\x28\xef\x6f\x08\x16\x10\xb4\x59\x5a\x92\x11\x3e\xc6\xd0\x69\xff\xe9\x71\x96\xd9\x56\x19\x1d\xaa\xbe\x98\x77\x37\x7a\xd0\x41\x6b\x0e\xe0\x65\x86\x63\x37\x7e\x07\xad\xb2\x46\x44\xe8\xa0\xe3\xce\x5f\xc1\x78\xf1\x52\xbe\x0c\xd9\xb0\x40\x71\x89\x04\x27\xc6\xb0\x01\xd5\x92\x62\xf3\x8f\xe8\x97\xce\x32\x04\x0d\xaa\x78\x07\x82\x1c\x40\xac\x8c\x63\x50\x5b\xed\x0a\xf0\x70\x44\x33\x37\xc9\xe9\xa6\x4e\x44\x20\x3c\x36\xa8\xca\x50\x64\xd8\x7a\xa0\xd3\xcd\x1d\x40\x3a\xa6\xa2\x4e\xcc",
        b"\x54\xc9\x9b\x21\xf2\x8f\xee\xe2\x7f\x0e\x99\x9a\xac\x6b\x49\xb6\xb0\x76\x33\xe1\xdb\x18\xa4\x59\x52\xfc\xf7\xe7\x3b\x16\x6b\xdb",
        b"\x7a\x18\x58\x8e\xa1\x45\x6f\x67\x56\x2d\x67\x78\x78\x34\x6f\xb3\x4b\x68\x4b\x9a\x8a\x61\xa7\x21\xb3\xdb\x0e\x95\x69\x5a\xb4\x3a",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x17\xb9\x25\xe2\xa1\xa5\x1c\x20\x36\xe2\x25\x71\x5f\x2f\x77\x1d\x8f\x0a\x6d\x98\xc7\xed\x9c\xac\xf5\xaa\x4c\xd3\x0a\xb1\x6a\xfb\x94\xe2\x1a\x7c\x95\x3e\x01\xca\x21\x1c\x28\x78\x2a\x06\x07\x3f\xda\xd2\x77\x13\xaa\x8c\x26\xae\x9e\xc4\x49\xaa\xaa\x8c\xcf\xda\x8c\x94\x71\x72\xde\x94\xb3\xf2\x0b\x54\xaf\x98\xdf\x15\x2d\x5d\x3a\x63\x6c\x73\x6f\xf0\x1b\xfa\x69\x9d\x62\x14\x00\x2d\xc7\x6d\xbb\x3f\x38\x60\xd9\x4e\x0e\x34\xed\xab\xa5\xf2\xbf\xd6\xb2\xbf\x66\x00\x86\xbe\x87\x64\x51\xa5\x0f\x6a\x2d\xc7\xc2\xb0\x98\xb7",
        p,
        q,
        g,
        b"\x42\xa9\x3b\xf4\x4e\xc7\xd2\xfb\xd6\x51\xcc\x1d\x1a\xc3\x91\xd6\x3c\xab\x00\x97\x1a\x7f\xf7\xa5\x61\x66\x76\x8b\x22\xe6\x11\xdc\x4d\x72\x9f\xaf\x8c\x94\xe7\xed\x4d\x6f\x82\xb7\x02\x0b\x7b\x4d\x2f\xb3\x59\x1c\xf2\x29\x5c\xc6\xe1\xb4\xbe\x2c\x25\x6c\x2f\xdd\xa4\x3e\x00\x05\x11\x14\x64\x5d\xa9\x1c\xbe\xd5\xcc\x08\x70\x85\xf7\xce\xcd\x8b\xac\xe6\x78\x89\x10\x0b\xcc\xe7\x92\x82\x20\x26\x6f\xd3\xfa\xf2\xea\xd9\xc2\x1e\x42\x3c\x99\x48\xec\x70\xc2\xd3\x1b\x66\x8c\xdc\x36\x0d\xdc\xeb\xdf\x42\x97\x20\x60\x7f\x96\xd8\x51\x23\x55\x15\xd6\xdb\xdf\x16\x3f\x7e\xa5\xdd\xf3\x51\xba\xa7\x6f\x38\x66\x3f\xdb\xfb\xd5\x87\x1b\xb2\x15\x7d\xf0\xa4\x34\x20\x64\x8c\x10\xe4\x82\x7f\x54\x06\x56\x14\x62\x3e\xd3\xab\xad\x10\xd3\x17\xbe\x9d\x49\xa4\xc6\x65\x64\xf2\x0d\xca\xc1\x76\xb6\x60\x5a\x2e\x3c\x3c\x01\xc3\x62\x22\x0f\x35\x2e\x47\x74\x19\xf2\xb4\xb2\x38\xaf\xfb\xc3\x92\x0e\x5b\xb5\x7c\xeb\xb9\xa7\x47\x46\xd6\x2c\xdd\x07\x0f\x4a\x13\xaf\x00\x1d\x26\x2d\xef\x01\x4f\x29\xb7\xf7\x54\xfa\xc8\x4e\x02\xd2\x92\x85\xb7\x3b\xb2\x0a\xc0\xc8\x62\x41\x23\xa5\x77\xbe\x8d\x6a\x6b\x97\x39\x18\x5e\x44\x58\x09\x0d\xdb\x42\xb0\x05\xea\x4f\xa8\xb5\x10\x07\xbd\x9c\xa5\xb4\xcf\x2a\x3d\xca\x44\x6a\x87\xec\x83\xc9\x54\x8d\xab\x46\xcf\x3d\xaf\x86\xdb\x3b\xc6\x9a\x99\xba\xed\x45\x9d\x6a\x19\x7f\x9b\xf5\x03\x2c\x1d\xc3\xa8\x77\xdd\x7e\x5c\x11\x61\x12\x4a\x6d\x70\x13\x24\xe9\xa9\x71\x2b\x82\x4a\x4f\xc3\xb1\xb3\x53\x25\x9a\xf2\x25\x81\x3c\x27\xe8\x20\xb0\xba\x72\xfb\x4e\x78\xf5\xc7\x86\x73\x92\x4e\x7f\xa2\xf4\x86\x03\x02\x84\xf2\x6c\xb6\xfa\x31\xda\x56\xf4\x9d\x3f",
        b"\x72\x6e\x4d\x3b\xaf\x00\xb2\x59\xf4\xbd\xca\x8b\x0a\x5e\x1c\xbf\xd3\x78\x27\xc4\x83\x73\xef\x50\x29\xf7\x60\x1a\x77\x69\x47\x8c",
        b"\x90\x30\x79\x43\x9e\xbd\xe1\xf7\x66\xd1\xa8\xff\x33\xe0\xf7\x78\xd7\x7b\x5e\x8b\x7b\x0d\x68\x74\x43\xc2\x71\xe8\xa6\x3b\x59\x75",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x1c\x11\x69\xf0\xe7\x90\x05\x3c\xd7\xdf\x78\x0b\x5c\x83\x2c\x64\x14\x76\x94\xb4\xa6\x44\x8b\xa1\x4a\x42\x6d\x9d\xef\x7d\xdc\x78\xe3\xed\x36\xa1\x2d\xa8\x1c\xf9\xc3\xf2\x45\xd6\x4c\x85\x9b\x6b\x4d\x81\x21\xd1\x12\x85\x19\x74\xdf\x17\x8d\xef\xc9\x77\xdb\x69\x12\x34\xd1\x42\xdf\xf9\x9b\xea\x19\x57\x89\x1b\x5d\x6f\xe8\xa7\x87\xe9\x63\x69\xd9\x3c\x24\x68\x2d\xeb\xd1\xcf\x3f\xdb\x64\x37\x9b\x8c\x1b\x3b\x73\xe1\xbc\x24\x67\xdc\xb0\x8b\x86\xcb\xd4\x94\xc0\x14\x77\xbe\x24\xd7\x90\x0f\x5a\x57\x89\x30\xf4\xbd\xdc\xb6",
        p,
        q,
        g,
        b"\x7f\xca\x22\x68\xfb\xa3\x3b\xf9\x4e\x76\x41\x6a\x9e\x38\x69\xf8\xa9\x0c\x3b\x0d\x2d\x37\xaa\xce\xcd\x3f\x67\x85\xb9\xa9\x5a\xee\xfe\x93\x24\xc3\xab\x09\xce\x61\xff\xde\x37\xb5\x0f\x82\xb6\x99\x41\x3f\x3b\x54\xf2\x4d\x6c\x52\xec\xa6\x23\x25\x02\x95\x23\xde\xb0\x5d\xb1\x38\x77\x84\x47\xbc\x3d\x0d\x05\xaf\xf7\xd8\x5b\x55\x25\xf2\xb8\x63\xd2\x64\x86\xe8\x4c\xde\x13\xe2\xe2\x11\x7d\x3f\xa3\x8a\x38\xd1\x07\x3a\xaa\x79\x4e\xd8\xea\xa7\xb3\xd1\xda\xa4\xac\x3e\x80\x8c\x37\x38\xa9\xcb\xef\x35\x46\xcd\x79\xec\xcb\x4f\xaa\x28\xb5\x0f\xce\x57\xcd\xc2\x40\x15\xfe\xc3\x90\xf0\xe7\xa7\xdc\x9f\x9c\x47\x1d\x22\xb3\x0c\x3e\x41\x74\x35\x8f\x1a\xd0\x73\x4c\xf7\x9a\x09\xa6\x39\xbd\xf3\xf3\xea\xbd\xa2\xb4\x7b\x81\xf9\x2e\x2a\x4f\x90\x04\xdd\x64\x13\x70\x33\x8c\x02\x02\x9b\xbf\x49\x71\xaa\x67\x48\x3e\xea\x7a\x4b\xf7\xdf\xf3\x88\x9f\x84\xfa\xa5\x76\x56\x17\xcc\xab\x37\xd1\x90\xa9\x4c\x57\xf9\x9d\x79\x28\x07\xa6\x96\x5e\x21\x13\x58\x6c\x6c\x5d\x1a\x81\xab\xfd\x37\x2e\x1c\x79\x54\xe2\xe0\x90\x64\xdf\x4d\x2d\x82\x88\xf5\xcd\xd8\x10\x6e\xd8\x4f\xfa\x79\x88\x19\xa0\x9a\x73\x2b\xc2\x04\xa8\x12\xc0\x35\x2e\x4e\x39\xd2\xce\xb8\x8f\x8e\x7d\x36\x24\xa5\xa5\xf3\xdc\x56\xea\x0f\x9c\x52\x90\x78\x8e\x12\xdc\x46\x31\x61\x60\x1f\xf3\xab\x68\x1b\xd0\x40\x3e\xe0\x3a\xf4\x5d\x5e\x58\x6d\x84\xd9\xc9\x01\x98\x67\x18\x19\x3e\x66\x12\x56\xf4\x02\xde\x73\x5d\x2c\xa6\x96\xef\x6b\x59\x48\x68\x95\x0a\xe1\x73\xf2\x2d\x95\x85\x66\x56\xa9\xd0\x06\x10\xfe\x8c\x2b\xd7\x25\xae\x55\xd7\x91\x27\x7b\x13\x17\x08\x5b\x67\x18\x8d\xa0\x06\x45\xce\x91\xbb\xe6\x2e\x32\x43\x11",
        b"\x10\x26\xec\xee\x0a\xc3\x1b\xdc\xdb\xd6\x10\x3b\x13\x43\xf8\x4b\x44\x1f\xc3\x26\xe1\xd8\x6a\xd0\x90\x3d\x0b\x17\xcf\xb2\xff\x9c",
        b"\xa5\xd3\xcb\x2e\x7c\x39\xd8\x76\x40\xc4\x54\x7a\xc6\xc3\x3a\xfc\xcb\xfc\x18\x20\x90\x5b\xa1\xe5\xbe\x5b\x26\x23\x13\x27\x7c\xb9",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x80\x5b\xaa\xbd\xd0\x18\xd9\xe5\xeb\xb4\xdc\x51\x43\x5b\xe6\x32\xd2\x38\x78\x69\x75\x6d\x74\x37\x88\x44\x27\x90\xd5\x5b\xb1\x83\xe2\x66\x55\xae\x3a\xac\x86\xdc\x16\xa4\x8d\xdd\x26\x8d\xd1\x5e\x18\xd8\x32\x0d\xf9\xa1\xa0\xa6\xcb\x2b\x49\xbc\x70\x1d\x7a\x15\xe3\xfe\x8d\xdd\x58\x4a\x75\xc8\xc9\xaa\xae\xcd\x1e\xfe\x17\x32\x4d\x62\x61\x88\x1f\x3d\x34\x68\x5b\x04\xf6\x2e\x96\x85\x05\x96\x6c\x9a\x5f\xeb\x0c\x39\xb5\x09\x5e\x55\x68\xe4\x0f\x20\xaa\x21\xcb\x25\x05\x35\x6d\xc9\x04\x9c\xe5\x61\x82\xd9\x4a\x2d\x94\xa9",
        p,
        q,
        g,
        b"\x43\x4d\x06\x12\xb2\xa8\x33\x2b\x0a\xb1\x56\x14\xe3\xee\x9f\xa2\x45\x13\x17\x12\xfb\x2b\xa8\x4f\x71\x39\x6f\xff\x94\x88\xdc\xa3\x40\xa3\x7e\x82\x0f\x44\xc1\x3a\xa8\x7f\xc9\xdf\x0b\x7a\xab\xea\xe2\xed\x85\xa9\x62\x2b\x8d\xef\xad\x47\x4a\xc3\x62\xa7\x03\x9a\xbd\xe3\x3d\x1d\xf7\x32\xa0\x52\x44\x6a\xff\x78\x57\xbc\x24\xd8\xf6\x1d\x25\x80\x15\xed\x2a\x30\x60\xa8\xbf\x9d\x44\x7e\x7d\x83\xd7\xb4\x97\xa8\xe6\x54\x73\x19\x69\xe4\x37\xb3\xf4\x6f\x83\xeb\x58\xf7\x88\x4f\xf2\xa2\x39\x0f\x5d\x82\x1e\xca\xa7\xfd\x09\xa1\x46\xc5\x5f\xc1\x18\x00\x73\xcc\x5a\xaa\x60\x7c\xab\xb9\x44\xf6\x07\x8a\x44\x86\xcf\x20\x6d\xdc\x56\x35\x24\x2d\xef\x2d\x3e\x2e\xdc\xbc\x02\x6b\xb8\x4e\x84\x95\x18\xf1\x97\x39\x9c\x22\xa9\x00\x9d\xde\x9a\xfc\xd8\x76\x9b\x24\x1c\x75\xd4\xcc\xce\x7f\x93\x90\x0b\x5f\x48\x83\x33\xdf\x47\xc0\x26\xc4\xf2\xb2\x76\x7e\x70\xd2\xd9\xdd\xe7\x84\x05\xe2\x26\xc9\x95\x2f\x6d\xb1\xa2\xe5\x58\x29\xbc\x8a\x76\xc7\xde\x5c\x2b\x58\x8f\x3f\x3e\x93\xce\x72\xfa\xda\xba\xcb\x75\xc7\xc1\x46\x69\x70\x1e\x0a\x2b\xa1\x27\xba\xc5\x68\x63\xc8\xc4\xe7\x20\x5c\xc0\xa7\x3c\x42\x9a\x80\x1e\x97\x97\xda\x4f\x26\xe8\x48\x98\x23\x06\xcc\x3c\x34\x39\xf9\xe3\x94\xdd\xc8\x0b\x0f\x13\xe0\xd5\x28\x19\x06\x38\xd8\xb9\x6b\xba\x3a\xf8\x89\xde\x37\x3b\x35\x49\xfc\x90\xa6\x82\x29\x64\xc2\x21\x71\xe7\x60\x1f\xde\xfb\xe5\x70\x89\x88\xb8\x4f\x3e\xa5\x54\xd6\x21\x60\x0a\x87\x64\x15\xd5\xbc\x1e\x55\x7e\x94\x8c\xaa\xce\x56\x3b\x37\x02\xf0\x91\x5a\x90\xa1\x3a\xad\xa7\x77\x09\xee\xba\x8c\x50\xa8\x62\x93\x51\xa4\x78\x7d\x0d\x58\x80\x8f\xfb\x8b\x21\x7c\x1d\x16\x4f",
        b"\x2d\x63\xe6\xd2\x56\x85\x71\xac\xfe\x4a\x93\x15\x80\xa0\x4b\x97\x4c\x7a\xae\x4c\xa9\xaa\x96\x10\xd8\x7b\xe1\xa9\x1c\x65\x7c\x31",
        b"\x57\x4b\x10\xd1\x4d\xcb\x8f\x07\x94\x61\xb2\x9a\xe1\xb9\x1e\xd6\xc5\xef\x32\xf9\x3c\xba\xd3\x06\x69\x75\x52\xc1\x17\x48\xfe\x0c",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xbe\x8c\xa5\xed\x4c\x22\xa0\x50\xd8\x30\x9c\x7a\x31\xac\xf6\x67\xf0\xc0\xfb\xaa\xdc\x64\xa3\x4d\x2b\x63\x07\x4a\x76\x3a\x2b\x8d\xb7\x3b\x24\xcd\xba\xad\x26\xcc\x6f\x2c\x3e\x90\xdf\x4b\x25\xbf\xa7\x24\xfc\xe5\x87\xfa\xa0\xfd\x65\xff\xb7\x19\xf0\xa0\x35\x16\x48\x23\x0d\x53\x54\xd7\x21\xd8\xfa\x6d\x0d\x68\x6c\x37\xf2\x57\xd7\xd9\xdb\xd1\x5f\x55\x5d\x50\x73\xf8\xbc\x71\xc9\x21\x39\xd1\xf6\x27\xd7\x43\xf7\xd6\x58\x6d\x51\x0d\x19\xd0\xd8\xa5\x55\xd0\xbf\x79\xec\x70\x59\x6e\x71\x21\x83\x88\x0c\x89\xca\xf6\x9d\x6f",
        p,
        q,
        g,
        b"\xaf\xaf\xf7\xa4\xd4\x38\xb4\x64\xf2\x74\x15\xd2\xe0\x3e\xd9\xc4\x16\xdb\x2b\xeb\xfb\xe0\xab\x34\xf1\x4e\xe1\x06\x44\x88\x5b\x5a\x45\x88\x87\x71\x50\xf4\x63\x27\xc2\xc7\xa6\xf7\x12\x67\x0b\xfd\x62\x37\xa2\x94\x52\x49\x48\x59\x94\x8f\x5e\x37\xc0\xe5\x86\x65\x6b\x11\x9a\x0e\x01\xc8\x1a\xce\xe5\x7c\x17\x75\xa3\xa1\x46\xe8\xfb\xaf\xc9\x9c\xd2\x03\xfc\x98\x19\x56\x87\xfb\x94\xa8\x8a\x4f\x44\x28\x0b\x03\xf0\x89\x5e\x0e\xca\x84\xdb\x08\x7c\x1b\xf7\xc4\x84\x3c\x85\x59\x73\x68\xe8\x39\x84\x11\x31\xe0\x27\x10\x9d\xaa\x7b\x81\x72\xa2\x5e\x11\x35\x5f\xa9\xa9\x20\x5a\xc3\x24\x94\x1a\x9f\xe4\x92\xc4\x84\x21\xf0\x68\x1a\x47\xe2\x80\x80\x3e\x8b\xd9\x1b\x11\x3e\x0f\xa1\x59\x76\x07\x43\x0b\xcb\x0a\xd5\x0b\x94\x08\xde\x00\x66\xd6\xa2\x32\x4d\x09\xcf\x6e\x99\x13\x36\x54\xdd\x64\xe8\xc8\xf7\x0c\xd6\x44\x53\x43\x75\x8b\x5c\xd5\xa0\xe7\x7e\x2d\x3f\xa1\xcb\x3f\x7e\xfe\xd7\x61\x24\xb2\x88\x1d\xfd\x20\x28\xab\x59\x18\xc3\x89\xb9\xc3\x97\x82\x71\xdb\x54\xa5\x17\x15\x15\xab\x2e\x85\xee\xb1\x0a\xb3\x07\x13\x01\x59\xbc\xa5\xfe\x13\xcc\x4a\x95\x9e\x88\xe9\x26\x72\x21\xac\x8d\x14\xee\x69\x38\xe1\x49\xf5\x2e\xc5\x91\x25\xb4\x49\xcb\x55\xc5\xa0\x02\x9f\x01\x87\x70\xb3\x1f\x08\x44\x0c\xe6\x87\x6e\x66\x00\xa3\x24\x11\x72\x2f\x58\xe6\x26\x33\x39\xbd\x9d\x34\xe1\x7a\xa5\x74\xb9\x21\x22\x89\x26\xff\x66\x8c\xe9\x03\x62\xc4\x39\x1e\xcd\x0c\x03\x74\x54\xe1\x2f\xdf\x80\xc9\x6b\xb7\xa8\x40\xcd\x86\x6e\x85\x70\xbb\x7d\x65\x86\xfb\xe3\xd1\xea\xe5\x33\x29\x31\x19\x8b\xa1\xd5\xd9\x02\xd6\xb7\xa1\x22\xdf\xa7\x70\x18\x55\x3a\x2d\xd3\x68\x0a\x80\x9b\xb0\x60\x53",
        b"\x9c\x7d\x40\xe2\x14\x08\x2b\xd5\xe7\x1f\x3b\xf4\xbe\x99\x78\x93\x03\xf3\x8e\x85\x1a\x76\xf8\x8c\xb9\x0a\xff\x71\x30\x80\xc5\x87",
        b"\x24\xca\x23\xbe\x94\xc6\x24\xb9\xd7\x36\x32\x8b\x53\x78\x2b\x5f\xeb\x38\x4d\xc9\xfe\x63\x70\x01\x6c\xc3\xf9\x7d\x8f\x48\xb6\xd0",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x62\xf0\xcb\x1b\xb0\x7f\x64\x97\xa1\xdc\x7a\x66\x95\x57\x65\xa9\xcc\x40\x3b\xde\x03\xfe\xf4\xe1\x6b\x09\xd7\xec\x54\x5b\x4c\x75\xd0\x8b\x6e\x9c\x4c\x5a\xf7\x23\x25\x48\xd4\x54\x45\x63\x8d\x71\x94\xa1\x99\xef\x15\x34\xe8\x12\x41\xea\xa9\xc7\xe7\x67\xfd\x54\xe2\xca\xce\xea\x4d\x2f\x72\x15\xd3\x7b\xaa\xd6\xb0\x5e\x28\xea\x09\x34\x97\xe2\xe8\xe1\xdb\x6e\x41\xa5\xeb\x13\xff\xa4\xca\xa2\x71\x08\xf2\x26\x3a\x74\xcf\x54\xbd\x5b\x6a\x6b\x62\x28\x4b\xac\x99\xfd\x79\x77\xaa\xa8\xff\xff\x18\xfa\x8a\x70\xab\x0d\xeb\xdf",
        p,
        q,
        g,
        b"\x73\x55\x4a\x69\xe1\xa0\x9f\x61\x91\xf0\xad\xed\x54\x2a\x07\x7e\xe8\xc8\x14\x26\x5d\x74\x5d\x9a\xe5\xc7\x92\xf4\x42\xc5\xfa\x47\xb3\x46\x43\xd3\xba\x1d\x51\x47\x16\x18\x98\xde\x51\x88\xa8\x07\x14\xee\x36\x51\x2a\x61\x8a\x33\xe4\x03\x00\xff\x11\x87\xe5\x53\xf5\x44\x33\xe1\x74\x66\xaf\x48\x64\x72\xbc\x07\x78\xaf\x55\xba\x73\x46\xc9\x61\xd7\xf1\x3a\xc6\xd8\xd6\xac\x9a\x42\x09\x2c\x01\x57\x9e\xe2\x17\x05\x90\xcb\xc3\xb4\x5e\xef\x79\x5b\x5d\x9e\x5d\x0a\x84\x49\x43\x9a\xb3\x07\xc1\x4c\x56\x74\xc4\xa7\xa3\xea\xf8\xb2\x40\xef\x36\xdd\x21\xf4\x3c\xce\xd5\x8c\x2d\xcf\x23\xc3\x14\x36\x4e\x8e\x31\x4e\x96\x71\xe8\x08\x13\xd1\x85\x80\x13\x58\xd5\xdf\x61\xd7\xe7\xec\x0d\xd6\x9e\x90\xc2\xcc\x75\xc1\xc3\x54\x3e\xfe\xca\x82\xb2\xec\x6e\xc5\x9e\x6c\x99\xbc\xd1\xa8\x63\x1c\x62\x28\xe2\x16\x88\x40\x82\xda\x11\x91\x25\xcb\x0a\x80\xc8\xfe\x34\x4a\xfe\x66\xe0\xf2\x06\x46\x43\x24\x65\xf3\xe0\x09\x6a\x17\x72\x5a\x88\x67\xb3\xbd\xba\x3c\x69\xa1\xaa\xcb\xb8\xd6\x47\x55\xb7\xf2\xa3\xdf\x0a\x49\xba\x0b\x21\x14\xe1\x12\xd4\xca\xe0\xad\x6d\x8d\x0f\xd6\x18\xe5\x4d\x53\xf0\x7b\xa1\x09\xb7\x5a\x54\xa9\x89\x61\x8b\x28\x63\xe4\x41\x5e\x17\x6e\x0b\xfd\x88\xdb\xf3\x65\x53\xca\x85\x3b\xb3\x63\x16\xc6\x6e\xb9\x3d\xa3\x4f\xf3\xae\x74\xcd\x5f\x18\x7f\x49\xbf\x38\xaf\x0f\x39\x3b\x2d\x7f\x85\x4d\xf1\x92\xad\xe2\xdf\x6b\x39\xa1\x76\xd2\x15\x2c\x91\x2b\xba\x24\x8d\x84\xa5\xb0\xaa\x40\x84\xa1\x8b\xb6\x4f\xd1\x36\x97\x3f\x73\xb4\x13\xd7\x7d\xb2\x75\xea\x5e\xce\x93\xce\x2f\xa0\x0d\x7c\x88\x87\xb7\xe5\x0b\x00\x64\x9d\x03\x53\xa7\xf5\x8c\xc6\x3f\x6b\x5f\xbd\xfc",
        b"\x54\xff\x5d\x3d\xc8\x76\x78\x56\xa1\x0f\x54\x08\x88\x82\xe2\x8c\x11\x09\x80\xef\x9b\x20\x4e\xb5\xf1\x62\xdb\xef\x73\xa3\x7c\x73",
        b"\x57\xed\x07\x48\x42\x7c\x08\x9d\x63\x95\x52\x8b\x2b\x45\x55\xc0\x1b\x4c\x13\x41\xab\x5f\xb9\x9c\x64\xd1\xcc\x24\x7a\x41\xc3\xa8",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xba\xeb\x12\xa1\xeb\xd8\x05\x7a\x99\xa0\x13\x7e\xe6\x0f\x60\xee\xd1\x0d\x26\xf1\xea\xb2\x2a\xe2\xd9\xad\xbc\x3e\x5f\xfc\x32\x52\xab\xf6\x2b\x61\x47\x07\xad\x25\x46\x14\x1b\xed\x77\x9f\x0c\xfa\xd9\x54\x4a\x74\xe5\x62\xda\x54\x9e\x2f\x7b\x28\x6e\xfb\x61\x54\x49\xb0\x94\x6d\xc7\xc4\x98\xd8\xf1\x21\x50\xb2\xea\xcb\xd2\x71\x57\x96\x6f\x59\x2a\xd5\xf3\xe4\x3a\x24\xc6\x0b\x7e\x06\x63\x0b\x82\xa4\xfd\xb6\x99\x11\x9d\xbd\x87\x8b\x13\xa9\x8b\xf2\x2a\x7b\x3d\xc7\xef\xdd\x99\x2c\xe6\xb8\xa9\x50\xe6\x12\x99\xc5\x66\x3b",
        p,
        q,
        g,
        b"\x00\x72\x8e\x23\xe7\x4b\xb8\x2d\xe0\xe1\x31\x5d\x58\x16\x4a\x5c\xec\xc8\x95\x1d\x89\xe8\x8d\xa7\x02\xf5\xb8\x78\x02\x0f\xd8\xd2\xa1\x79\x1b\x3e\x8a\xb7\x70\xe0\x84\xac\x23\x97\xd2\x97\x97\x1c\xa8\x70\x8a\x30\xa4\x09\x7d\x86\x74\x01\x53\xee\x2d\xb6\xab\x63\x43\xc5\xb6\xcc\x2c\x8a\x7f\xa5\x90\x82\xa8\xd6\x59\x93\x1c\xc4\x8a\x04\x33\xa0\x33\xdb\xb2\xff\xf3\xaa\x54\x56\x86\xf9\x22\xc7\x06\x3d\xa1\xd5\x2d\x96\x88\x14\x2e\xc6\x4a\x10\x02\x94\x8e\x5d\xa8\x91\x65\xd9\xdf\x8e\xed\x9a\xa4\x69\xb6\x1e\xe0\x21\x0b\x40\x33\x56\x23\x33\x09\x7b\xa8\x65\x99\x44\xe5\xf7\x92\x4e\x04\xa2\x1b\xc3\xed\xc6\xd5\x51\xe2\x02\xe4\xc5\x43\xe9\x75\x18\xf9\x1e\x0c\xab\x49\x11\x10\x29\xb2\x9c\x3a\xa1\xbe\xd5\xf3\x5e\x5c\x90\xfe\xb9\xd3\xc7\x45\x95\x3d\xbf\x85\x9d\xef\xce\x45\x37\xb4\xa0\x98\x01\xfd\xc8\xfe\x69\x99\xfb\xde\x39\x90\x80\x79\x81\x1b\x4b\x99\x2c\x2e\x83\x33\xb9\xf8\x00\xea\x0d\x9f\x0a\x5f\x53\x60\x7e\x30\x89\x42\xe6\x8e\xfe\xf0\x1e\x03\xd7\xcc\xa6\xf1\x96\x87\x2b\xf0\x1f\x43\x6d\x4a\x8e\x05\xfc\x59\xd8\xfb\xc6\xb8\x8a\x16\x6f\x57\xa4\xe9\x9d\x67\xdd\xae\xce\x84\x46\x53\xbe\x77\x81\x97\x47\xdd\x2e\x07\xd5\x81\xc5\x18\xcb\x97\x79\xe9\xf7\x96\x0c\x17\xff\x0b\xae\x71\x0e\xcf\x57\x5b\x09\x59\x1b\x01\x3b\x48\x05\xc8\x8b\x23\x5d\xf2\x62\xe6\x1a\x4c\x94\xf4\x6b\xf9\xa0\x82\x84\x61\x1d\xf4\x4e\xad\xd9\x4f\x44\xce\xf6\x22\x5a\x80\x8e\x21\x1e\x4d\x3a\xf5\xe9\x6b\xce\x64\xa9\x0f\x80\x13\x87\x4f\x10\x74\x9a\x83\x82\xa6\x02\x6a\x85\x5d\x90\x85\x34\x40\xbf\xce\x31\xf2\x58\xb3\xa2\x58\xf7\xb5\xe6\x59\xb4\x3e\x70\x2d\xee\x7c\x24\xc0\x2d\x22\x84",
        b"\x8d\x35\x7b\x0b\x95\x6f\xb9\x0e\x8e\x0b\x9f\xf2\x84\xce\xdc\x88\xa0\x4d\x17\x1a\x90\xc5\x99\x7d\x8e\xe1\xe9\xbc\x4d\x0b\x35\xff",
        b"\xab\x37\x32\x9c\x50\x14\x5d\x14\x65\x05\x01\x57\x04\xfd\xc4\xfb\x0f\xd7\x20\x7e\x0b\x11\xd8\xbe\xcb\xad\x93\x4e\x62\x55\xc3\x0c",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x18\x4e\x59\x9a\x4c\x1d\xe8\x6c\x41\x51\x20\x57\x54\xdf\x0b\x19\x12\xc2\xb3\xc5\x32\x55\x2c\x51\xa6\x1c\x64\x59\xdb\x98\xc8\x3e\x59\xd4\xa4\x08\x06\xc6\xa2\xc6\xb3\xfe\x74\xe3\xbb\x9e\x72\x0d\x7d\x0a\x3c\xc1\x1e\xf8\x89\x59\xa8\x99\x0c\x0f\xa0\x57\xa3\x91\x5f\xe0\xdd\x9a\x13\x8a\xa0\xec\x1c\xb1\xab\x69\xd9\x39\x10\xd8\xd6\xf9\xe1\x4f\x3b\x8a\x13\x5d\x3f\x03\x1a\x56\xc7\x6a\x9d\xc3\xae\xd1\x96\x2b\xdf\x05\x81\x5c\x24\x92\xd1\x4f\x23\x24\xd2\xda\x49\x18\x10\xd1\x67\x2b\x63\x3f\x24\x19\xda\x4e\x7e\xbd\xef\x24",
        p,
        q,
        g,
        b"\x60\x15\x97\x20\x02\x1f\xd2\xd5\xa2\xf5\x75\xb3\x22\x09\x05\x78\x8d\x32\x8d\x0c\x46\x89\x5a\x46\xbb\x98\x59\x42\x46\x72\x09\xec\x28\xd8\xdd\xfd\xc9\x7e\xc3\x4d\xa6\x5b\x16\x4c\xf4\x86\x52\xac\x47\x5d\x89\x78\x95\x9c\xfc\x43\x30\x74\x3e\xd9\x81\x37\x55\x93\x91\xb1\x20\x4d\xa6\xb2\x6b\x45\x12\x11\x40\x7e\x8f\xc7\x7d\x81\x99\x34\xc4\x87\x09\xc8\xea\xdc\x62\x0f\x6d\xb2\x59\x2b\x65\x48\x32\x65\x14\x9a\x32\x44\x67\xd9\x3c\x37\x5d\x97\x23\x0f\x2b\x1a\x68\x28\x97\xcf\x6d\x28\x0d\xf6\x1a\x34\xf2\x0f\x0c\x7c\x72\x9a\x40\x14\x19\x58\x04\x48\x76\xc4\x4e\x59\x5d\x23\x78\xa7\xd2\x2c\x6c\xda\x9a\xb8\x16\x48\x6c\x29\x4e\x4e\xdd\xea\x7a\xda\x88\xb1\x5e\xca\x53\x71\xda\x16\x44\x71\xed\xaf\xcd\xef\xc6\x54\xe6\x4a\x1f\x99\x50\x68\xfa\x85\xdb\xbb\x55\x16\x13\x7b\xc4\x42\xf6\x07\x17\xfe\x59\xc6\x29\x08\x1c\x23\x4f\x27\x19\x5d\x5f\x9c\x2b\xf8\x5c\xdc\x1e\xa4\xca\xe5\x7a\xa9\x08\xcb\xff\x9b\x2a\x53\x35\x3b\x13\xe9\xf6\xfe\x45\xda\xa5\x17\x4c\xd9\x56\x23\x6d\x44\x7b\x52\x01\x1d\x68\x8c\xd2\x2f\x23\x01\x84\x09\xb3\x9a\x36\x07\x9c\xb5\x3e\x03\xb6\xd3\xa7\x52\x73\x32\x97\xfe\xa4\xca\x27\xc6\x39\x5b\xec\xef\x40\x81\xd2\x01\xf4\x1d\x4a\x00\xe9\x9d\x95\xf4\x22\x81\xdc\xf4\x4b\x9e\xf6\x75\x49\x98\xd9\x42\x31\x93\x7c\x82\x59\x42\x18\xa7\x84\x63\xcc\x83\x71\x93\xde\x6b\xf1\xd3\xc3\xec\x31\xd8\xdc\x54\x68\xcb\x56\xde\xfc\x9c\x70\xd0\x8b\x95\xb0\x29\xd9\x7a\xa0\x43\xd5\x57\xf6\x28\x6b\x87\xee\x40\x98\x44\x2d\xf4\x95\xc0\xad\x8a\xe4\xd4\xae\x03\x73\x12\xc5\xf7\x23\x90\x32\xc0\x3b\x08\x8c\x10\x36\xfa\xd7\x77\x4b\x15\x19\x70\x92\x42\xc9\x51\x1e\x6e",
        b"\x07\x9d\x4d\xf1\x4a\xd7\x03\xa4\x35\xb2\x1b\xc7\x0a\x03\x45\x6c\xa8\x22\xb8\x76\xc9\xac\xcb\x01\x8b\xdd\xd6\x74\xbd\x63\x92\xd7",
        b"\x6c\x77\x65\xe1\xf1\xed\xdf\x91\x5a\x56\xa5\x73\x90\xdb\x45\x63\x6e\x52\xf0\x83\xce\x44\x07\x66\xad\x4f\x32\x58\x0f\x72\x24\x83",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\xb1\x89\xdd\x34\xf5\x8f\x3e\xfa\x85\xb6\xf9\x76\x77\xed\xfb\x82\x66\x4c\xbe\x43\xa2\x55\x0c\x33\x6f\xfa\x08\x70\x5b\xbd\xa2\x54\x5e\xf2\x44\xa2\x75\x01\x4c\x6a\x26\x59\x71\xf4\xc3\x65\x8e\x5e\x8d\x6a\x3f\xaf\xc8\x89\xf3\xc4\xed\xa6\xb5\x61\x60\x92\x95\x4b\x15\xc6\x04\x35\xef\xd7\x68\x06\xe2\x85\x57\xc0\x5f\xaa\xaa\x8a\x05\xc2\x62\x65\x78\x40\x86\x5f\xf6\x9c\x51\x1a\x68\xd1\x30\x22\xa7\x12\xd3\x5b\xde\x13\x8e\xb7\xa2\xf8\xf1\xa8\x7b\x34\x2c\x7c\xaf\x38\x8c\x1a\x8b\x95\x07\x9b\xc4\xa8\x00\x3e\xef\x84\xb8\x99",
        p,
        q,
        g,
        b"\x05\xe2\x80\x31\x08\x10\x71\x5d\x29\xea\x1c\xa0\x0a\x70\x03\x78\xbd\x59\x79\x49\x3b\x98\x03\x17\x4c\x93\x2b\x7d\xad\xb7\x02\x9a\x9a\x9f\x9c\x91\xcf\x8f\x93\x8a\xf2\xbc\xea\xa0\x52\xf2\x27\x3f\x0d\xe3\x93\xb0\xf7\x54\x44\x90\xd6\x93\xf5\x29\xa6\x8b\x81\x2e\x2e\x58\x9c\xc0\x92\xb8\x3e\xf8\x47\xc5\x30\x60\x39\xaa\x8e\xaf\x22\x51\x28\x92\x61\x45\x89\x3a\x51\x55\x1d\xb3\x82\xfd\xa4\xb6\x3e\x5a\xbc\x10\xfd\x07\x61\x00\x68\x4d\x4c\xa6\x57\xc8\x9b\x22\x65\xde\x6e\x0f\x04\x73\xf0\x1b\xb2\x22\xb2\xbc\x50\xec\x1c\x5f\xcd\xe9\x16\x18\x31\x01\x8a\xab\x30\x14\xa9\x56\x03\x3b\xb0\xa8\x38\x66\xdf\x11\x91\x58\x08\xf9\xe7\x46\x16\x45\xc8\x9c\x6e\x17\xab\x65\xdb\xf9\x7c\xbf\x4a\xc1\x16\x4d\x67\x1a\x15\x16\xca\x81\x64\x5b\xc3\xe0\x99\x13\xa0\x3f\x30\x64\x1b\xd0\x92\x00\x83\x57\x8c\xa8\x4d\xf7\x1f\x62\xeb\x75\x6b\xa4\x45\xa0\xdc\x44\xf8\x5a\x9e\x4f\x72\xce\x5f\x6b\xf8\x2c\xcb\xd6\x74\xd2\xce\x3c\x4a\xfc\x30\x05\x62\xa7\xdb\xd3\xe8\xab\x83\x89\x93\xf9\xde\xcc\x99\x33\xdc\x07\xdc\x01\xb5\x02\xfe\xe5\xb3\x90\x46\x1a\x8c\x82\xc4\xe6\x96\x15\xf1\x21\xb3\xf9\xfd\x4f\x0c\x8b\x76\x20\xa2\x59\x96\xdf\x43\xd7\xcf\x35\x5f\x15\xbe\x09\xe2\xc8\x21\x78\xc6\xf8\x83\x6c\x36\xc1\xd3\xef\x26\xad\x05\x21\x9f\xb5\x7e\x85\xef\x16\x2c\x8d\xd8\xf0\xe5\x50\x14\x76\x9d\x53\xcb\xa4\x78\xa2\xaa\x66\xd9\x0d\x8a\xcd\x6c\xb0\x48\x9d\x1e\xea\x46\xc2\xc4\x1b\xd5\x49\x5a\xb8\xde\xf4\x3b\x2c\xd5\xbb\x26\x73\x94\x5c\x21\xc8\x0a\x48\x33\xfd\x75\xd8\x84\xc7\x67\x5c\x09\xe7\x19\x1f\xb2\x6e\x92\xc5\x4c\x7c\x82\x08\xd0\xa0\xe8\xde\xe7\x5c\x29\x68\xe9\x62\xde\x44\x93\xe8",
        b"\x9f\xd1\x05\xc7\x4a\x0d\x36\x97\x37\x40\x86\x7c\xcc\x1c\x73\x1c\xf1\xc5\x0c\x79\x35\xd5\xc0\x9e\x92\xf5\x74\xd7\xa5\x69\x15\x7e",
        b"\x50\x1f\x50\xc3\x2b\x02\x88\x67\x2e\x02\xac\xa7\x8f\x90\xf4\x46\xac\xf9\x26\x26\x36\x59\x57\xa3\x75\x55\x0c\x77\x98\x0c\x3c\x17",
    )?;
    test(
        HashAlgorithm::SHA512,
        b"\x42\xc0\x65\xfa\xdd\x56\xd6\xa1\xfe\x68\xdd\x4e\x86\xc1\x7e\xfd\x76\xd0\xf9\xdb\x87\x03\x6b\xd7\xb6\x09\x15\x9d\x66\x84\x7f\x46\xde\x01\xb8\xae\x43\x59\x03\x60\xfa\x32\x45\x59\xa2\xd7\x09\xd4\x5c\xf0\x10\x34\xf5\xfa\xcb\x7f\x52\x32\x4e\x60\xdd\x46\x4a\x58\x3d\x42\xe4\x12\x65\x9d\x84\x20\xf7\x26\x5e\x30\xcf\x82\xbb\xbc\xb2\xc9\x9b\x0f\x00\xca\x6a\x46\xd2\x85\x56\x42\x87\x89\xf4\x15\x00\x0d\xc3\x1b\xab\xbd\x67\xcc\xc8\xfb\xaa\x84\xa8\x80\x46\x6b\xca\x47\x83\xea\xf0\x0b\x7f\x78\x23\x1c\x66\x71\x26\x43\x3e\x6a",
        p,
        q,
        g,
        b"\xb2\x65\xed\xfe\xd7\x7b\x3a\xd5\x11\xe5\x6d\x58\x31\x29\xb1\x2e\x57\x96\xd6\x59\xd4\x84\xa2\xfc\xe3\x50\x66\x1f\x79\xe5\x45\xdd\x0a\x06\xc2\x37\x74\xc8\xba\x2f\xb5\x10\x1a\x28\x48\xc4\x13\xdf\xc5\xb3\x74\xa7\xc5\xff\x3a\xcc\x73\x32\xf0\xff\x8b\xd6\xf5\xfa\x88\x2c\x0a\x67\x68\x93\x08\xbe\x71\x54\xc4\xef\xc5\x18\x35\xf3\x49\x52\x54\x19\xed\x72\x2a\x90\xbf\x26\xdd\xde\xd6\x5b\xc8\x96\x2b\xa1\x1d\xe9\xe7\x34\x44\x25\x71\xaf\xfc\x2d\x42\xb9\xf3\xf5\x4a\x46\x53\x5a\xe9\xeb\x01\x36\x1a\xdf\x03\xfc\x28\x41\x0a\xbf\x41\xdb\x3a\xe4\x11\x3d\xa4\xc4\x0e\x9a\x36\x8f\x9c\xd0\x29\xbe\x4d\x98\xc6\x6d\x83\x5d\x03\x4e\x3c\x86\x54\x4b\x60\xbc\xb0\x1f\xeb\x38\x3b\x2a\xdd\x9a\xfe\x7b\x62\x51\xa1\x7a\xd4\xe5\x43\x9a\x9c\xd2\xd1\xbf\x62\xb6\xcf\x53\x77\xc0\x97\xb7\x26\x8b\xd7\x36\xcc\xa9\xce\xb8\x22\xe5\xd1\x84\x4a\x09\xfa\x69\xc7\x82\x17\xc3\xd6\x73\x7f\x0b\xf4\x5e\x32\x36\x50\x8b\x5a\x3f\x5c\x46\x6d\xd0\xd7\x5a\xce\x95\xd4\x47\xf9\xbd\x7a\xa9\xee\x57\xbd\x10\xee\x3c\x5e\x83\x89\xa0\x6c\x00\x85\x7e\x69\x97\x94\xf5\xca\xcc\x7d\xc5\xbb\x15\x04\x42\x1d\xc9\x20\x56\x56\x18\xbe\xf0\x5d\xc1\x71\x3b\x6f\x08\xbc\x00\x68\x1c\x5a\x1c\x06\x85\x35\x97\x29\xfe\x4b\x54\x40\x90\xcc\xce\xaa\x82\xf4\xfe\xfa\x9f\x11\x17\xbf\x1e\x37\x1b\x99\xfe\x4e\xd7\x16\x35\xda\xd4\x15\x01\x7a\x62\x34\x1d\x70\x42\x27\xee\x7c\xfb\x64\xa8\xde\xae\x90\xd8\x6c\x0c\xfd\x37\xed\x36\x3d\x91\xa4\xa0\x6f\xd0\x6f\x64\xdb\xd8\x14\x2c\x12\x50\x3f\x49\xee\xb1\xb9\xa9\x71\xae\xb3\x43\xf1\x5c\xd2\x7d\x27\x9b\x99\xd4\xcf\xa5\x1f\x12\x12\x59\xb3\xc1\xb5\x5d\x28\xd9\x94\xbb\x32\x99",
        b"\x6e\xd8\x2a\xf8\xe8\x9e\x38\xc4\x9a\x58\x01\x0f\x05\x64\x16\x5a\x16\xa7\x6a\x2b\xfb\x34\x84\x66\xd9\xb4\xa9\x1e\x5c\xe5\x3a\xb2",
        b"\x8c\x46\x6a\x8b\x3e\x4c\x90\x88\x6f\x29\x98\x6a\x4d\x51\x39\x04\xf3\x1d\xb4\x3a\x68\xce\x88\x03\x11\x40\x3c\xc7\x55\x46\x66\x04",
    )?;

    Ok(())
}
